(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    503452,      21222]*)
(*NotebookOutlinePosition[    504202,      21248]*)
(*  CellTagsIndexPosition[    504158,      21244]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["\<\
\tKnotTheorybyComputer 
\tusing MathLink
\t
\t***KNOT2000(K2K)***
\t      Vesrion 1.3.3\t\
\>", "Title"],

Cell["\<\
Mitsuyuki Ochiai:ochiai@ics.nara-wu.ac.jp
Noriko Imafuji:imafuji@ics.nara-wu.ac.jp\
\>", "Subtitle"],

Cell[TextData[StyleBox["Graduate school of human culture\nNara Women's \
University, 630-8506,\nNara, Japan",
  FontSize->18,
  FontSlant->"Italic"]], "Subsubtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell["Set the current working directory to where K2K is placed. ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<K2K1_3_3\>"]\)], "Input"],

Cell[BoxData[
    \("C:\\Program Files\\Wolfram Research\\Mathematica\\4.0\\K2K1_3_3"\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Load the package file ",
  StyleBox["\"knotbycomp.m\"",
    FontWeight->"Bold"],
  ", which includes all the functions."
}], "Text"],

Cell[BoxData[
    \(<< knotbycomp.m\)], "Input"],

Cell[CellGroupData[{

Cell["All functions & external programs", "Subsection"],

Cell[TextData[{
  "This table confirms the names of functions and the corresponding external \
programs. All of these external programs need to be placed in Knot2000. \n\n\
",
  Cell[BoxData[GridBox[{
          {\(Functions\ in\ Mathematica\), \(External\ Programs\)},
          {
            RowBox[{
              StyleBox["GetPdatabyTracking",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              RowBox[{"(", 
                StyleBox["PLdataFileName",
                  FontSlant->"Italic"], 
                StyleBox[")",
                  FontSlant->"Italic"]}], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(MouseTracking . exe\)},
          {
            RowBox[{
              StyleBox["ShowKnotfromPdata",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Pdata",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(DrawKnot . exe\)},
          {
            RowBox[{
              StyleBox["ShowKnotbyOpengl",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Pdata",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            RowBox[{\(KnotOgl . exe\), "  ", 
              StyleBox["*",
                FontWeight->"Bold"], 
              StyleBox["1",
                FontWeight->"Bold"]}]},
          {
            RowBox[{
              StyleBox["ShowKnotFromFile",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["PdataFileName",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            StyleBox[\(\(*\)\(2\)\),
              FontWeight->"Bold"]},
          {
            RowBox[{
              StyleBox["KnotFromBraid",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Bword",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(BwordToPword . exe\)},
          {
            RowBox[{
              StyleBox["GetBraidRep",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{
                  StyleBox["P",
                    FontSlant->"Italic"], 
                  StyleBox["data",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]}]], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(BraidFromSc2 . exe\)},
          {
            RowBox[{
              StyleBox["ShowBraid",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Bword",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], "\[Placeholder]"},
          {
            RowBox[{
              StyleBox["ReductionKnotLink",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox[
                RowBox[{
                  StyleBox["P",
                    FontSlant->"Italic"], 
                  StyleBox["data",
                    FontWeight->"Plain",
                    FontSlant->"Italic"]}]], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(KnotLinkReduction . exe\)},
          {
            RowBox[{
              StyleBox["SkeinPolynomial",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox[\(type, Pdata\),
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(JonesPol . exe\)},
          {
            RowBox[{
              StyleBox["KauffmanPolynomial",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Pdata",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(KauffmanPol . exe\)},
          {
            RowBox[{
              StyleBox["AlexanderPolynomialbyBurauRep",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Bword",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(BurauAlexPol . exe\)},
          {
            RowBox[{
              StyleBox["ParallelJonesPolynomial",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Bword",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            RowBox[{\(ParallelLink . exe\), "  ", 
              StyleBox["*",
                FontWeight->"Bold"], 
              StyleBox["3",
                FontWeight->"Bold"]}]},
          {
            RowBox[{
              StyleBox["JonesPolynomialbyBraid",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["Bword",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], \(BraidRep . exe\)},
          {
            RowBox[{
              StyleBox["SkeinPolynomialFromFile",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["PdataFileName",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            StyleBox[\(\(*\)\(4\)\),
              FontWeight->"Bold"]},
          {
            RowBox[{
              StyleBox["JonesPolynomialbyBraidFromFile",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontWeight->"Bold"], 
              StyleBox["BwordFileName",
                FontSlant->"Italic"], 
              StyleBox["]",
                FontWeight->"Bold"]}], 
            StyleBox[\(\(*\)\(5\)\),
              FontWeight->"Bold"]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "\n\n(Notice)\n",
  StyleBox["*1",
    FontWeight->"Bold"],
  "; ",
  StyleBox["KnotOgl.exe",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["OpenGLKnot.exe",
    FontWeight->"Bold"],
  " which needs to use ",
  StyleBox["OpenGLDraw.dll",
    FontWeight->"Bold"],
  ". Be sure that these files are also placed in Knot2000.\n",
  StyleBox["*2",
    FontWeight->"Bold"],
  "; ",
  StyleBox["ShowKnotFromFile",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["ShowKnotfromPdata",
    FontWeight->"Bold"],
  " which needs DrawKnot.exe as an external program. \n",
  StyleBox["*3",
    FontWeight->"Bold"],
  "; ",
  StyleBox["ParallelLink.exe",
    FontWeight->"Bold"],
  " uses a matrix placed in directory Braid_9, Braid_ 12, or Braid_15. Be \
sure that these directory are placed in Knot2000. \n",
  StyleBox["*4",
    FontWeight->"Bold"],
  "; ",
  StyleBox["SkeinPolynomialFromFile",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["SkeinPolynomial",
    FontWeight->"Bold"],
  " which needs JonesPol.exe as an external program.\n",
  StyleBox["*5",
    FontWeight->"Bold"],
  "; ",
  StyleBox["JonesPolynomialbyBraidFromFile",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["JonesPolynomialbyBraid",
    FontWeight->"Bold"],
  " which needs BraidRep.exe as an external program."
}], "Text"],

Cell[TextData[{
  "See the usages, before you use them. More precise information of these \
function are in ",
  StyleBox["\"Manual.nb\"",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(?GetPdatabyTracking\)\)], "Input"],

Cell[BoxData[
    \(\(?ShowKnotfromPdata\)\)], "Input"],

Cell[BoxData[
    \(\(?ShowKnotbyOpengl\)\)], "Input"],

Cell[BoxData[
    \(\(?ShowKnotFromFile\)\)], "Input"],

Cell[BoxData[
    \(\(?KnotFromBraid\)\)], "Input"],

Cell[BoxData[
    \(\(?GetBraidRep\)\)], "Input"],

Cell[BoxData[
    \(\(?ShowBraid\)\)], "Input"],

Cell[BoxData[
    \(\(?ReductionKnotLink\)\)], "Input"],

Cell[BoxData[
    \(\(?SkeinPolynomial\)\)], "Input"],

Cell[BoxData[
    \(\(?KauffmanPolynomial\)\)], "Input"],

Cell[BoxData[
    \(\(?AlexanderPolynomialbyBurauRep\)\)], "Input"],

Cell[BoxData[
    \(\(?ParallelJonesPolynomial\)\)], "Input"],

Cell[BoxData[
    \(\(?JonesPolynomialbyBraid\)\)], "Input"],

Cell[BoxData[
    \(\(?SkeinPolynomialFromFile\)\)], "Input"],

Cell[BoxData[
    \(\(?JonesPolynomialbyBraidFromFile\)\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Input knots (and links)", "Section"],

Cell["\<\
To get started, you need input a knot (or link) diagram on the mouse-tracking \
window, and then get its P-data. Use the following function. Note that in \
this version the function returns back the true p-data but not the mirror \
image like as the version 3_1.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdata\  = \ GetPdatabyTracking[]\)], "Input"],

Cell[BoxData[
    \({{2, 3}, {\(-5\), \(-8\), \(-4\), 6, \(-1\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This function genarates \"",
  StyleBox["LastPLdata.pl",
    FontWeight->"Bold"],
  "\" which includes PL-data for the given knot (or link) and \"",
  StyleBox["MOUSETRACK.log",
    FontWeight->"Bold"],
  "\" which includes P-data (of file type) and PL-data. Both of these file \
are modified every time GetPdatabyTracking is called.\nIf you want to change \
something (change crossings, add other components, and so on) for the knot \
(or link) again, specify the name of its PL-data file. You can use \"",
  StyleBox["LastPLdata.pl\"",
    FontWeight->"Bold"],
  " or make a new file by referred to  \"",
  StyleBox["LastPLdata.pl\"",
    FontWeight->"Bold"],
  " or \"",
  StyleBox["MOUSETRACK.log",
    FontWeight->"Bold"],
  "\" and cutting and pasting. Note that you must not assign the file name \
MOUSETRACK.log\" as an input file name. The file has to finish by EOF (555) \
in the last line of the file. When the program will work,  you must input \"r\
\" or \"R\" for reading one next data. And also you can save the current data \
to the file \"",
  StyleBox["LastPLdata.pl\"",
    FontWeight->"Bold"],
  "  by keying \"w\" or \"W\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdata\  = \ GetPdatabyTracking["\<LastPLdata.pl\>"]\)], "Input"],

Cell[BoxData[
    \({{9}, {10, \(-11\), 12, 14, 16, \(-17\), 18, 4, 6}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "About P-data in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " & PL-data"
}], "Subsection"],

Cell[TextData[{
  "P-data is used as a data strucure representing a knot (or link). \
Originally P-data consists of 3 lines - the twice number of crossings and the \
number of components on the first line, the twice numbers of crossingsis of \
each components on the second, and P-word (mentioned later) on the third - as \
you see in MOUSETRACK.log. However, in order to deal with P-data much easier, \
we are using simplified P-data in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". P-data in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is a list having two entries which are also lists. The first one \
indicates the number of crossings of each components, and the second is \
number of sequence derived from the knot (or link), called P-word. \n\n\
PL-data is the data for drawing knot (or link) diagrams. Notice that with \
same PL-data, you can obtain the same diagram, but only with P-data, you \
cannot specify its diagram itself. "
}], "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Drawing knots (and links)", "Section"],

Cell["\<\
You can get a nice drawing of a knot (or link) diagram with rendering. Give \
the P-data to the following function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdata = {{10}, {\(-6\), \(-8\), \ 17, \(-2\), \ 14, \ 16, \(-19\), \ 
          10, \ 5, \(-13\)}}\)], "Input"],

Cell[BoxData[
    \({{10}, {\(-6\), \(-8\), 17, \(-2\), 14, 16, \(-19\), 10, 
        5, \(-13\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowKnotfromPdata[pdata]\)], "Input"],

Cell[BoxData[
    \(ParametricPlot3D::"ppcom" \(\(:\)\(\ \)\) 
      "\:95a2\:6570\!\(framing[\(\(\(\(mm \[LeftDoubleBracket] h \
\[RightDoubleBracket]\)\), i, t\)\)]\)\:306f\:30b3\:30f3\:30d1\:30a4\:30eb\
\:3067\:304d\:307e\:305b\:3093\:ff0e\:5143\:306e\:95a2\:6570\:3092\:4f7f\:3063\
\:3066\:30d7\:30ed\:30c3\:30c8\:51e6\:7406\:3092\:884c\:3044\:307e\:3059\:ff0e\
"\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93767 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 -0.0311632 1 [
[ 0 0 0 0 ]
[ 1 .93767 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .93767 L
0 .93767 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.61563 .58864 m .62224 .5936 L p .60812 .59731 L .859 .867 .845 r
F P
0 g
s
.62224 .5936 m .61334 .60311 L .60724 .59754 L p .859 .867 .845 r
F P
0 g
s
.63015 .58339 m .62224 .5936 L .6161 .589 L p .877 .865 .824 r
F P
0 g
s
.6161 .589 m .61563 .58864 L p .6166 .58829 L .877 .865 .824 r
F P
0 g
s
.63015 .58339 m .6161 .589 L .6166 .58829 L .877 .865 .824 r
F
.62224 .5936 m .63015 .58339 L .64535 .59268 L p .707 .577 .707 r
F P
0 g
s
.62304 .57917 m .63015 .58339 L p .6166 .58829 L .877 .865 .824 r
F P
0 g
s
.61563 .58864 m .62304 .57917 L p .6166 .58829 L .877 .865 .824 r
F P
0 g
s
.62939 .56898 m .63694 .5724 L p .62401 .5787 L .895 .858 .798 r
F P
0 g
s
.62304 .57917 m .62939 .56898 L p .62401 .5787 L .895 .858 .798 r
F P
0 g
s
.63694 .5724 m .63015 .58339 L .62304 .57917 L p .895 .858 .798 r
F P
0 g
s
.63527 .55669 m .64305 .55954 L p .63015 .56845 L .91 .847 .769 r
F P
0 g
s
.62939 .56898 m .63527 .55669 L p .63015 .56845 L .91 .847 .769 r
F P
0 g
s
.64305 .55954 m .63694 .5724 L .62939 .56898 L p .91 .847 .769 r
F P
0 g
s
.6404 .54341 m .6483 .54594 L p .63573 .5563 L .919 .837 .749 r
F P
0 g
s
.63527 .55669 m .6404 .54341 L p .63573 .5563 L .919 .837 .749 r
F P
0 g
s
.6483 .54594 m .64305 .55954 L .63527 .55669 L p .919 .837 .749 r
F P
0 g
s
.6404 .54341 m .64534 .52862 L .65316 .53137 L p .923 .831 .736 r
F P
0 g
s
.65316 .53137 m .6483 .54594 L .6404 .54341 L p .923 .831 .736 r
F P
0 g
s
.64305 .55954 m .6483 .54594 L .66519 .55158 L p .707 .577 .707 r
F P
0 g
s
.6483 .54594 m .65316 .53137 L .66994 .53735 L p .707 .577 .707 r
F P
0 g
s
.66994 .53735 m .66519 .55158 L .6483 .54594 L p .707 .577 .707 r
F P
0 g
s
.6404 .54341 m .64946 .54655 L p .6455 .52931 L .405 .263 .572 r
F P
0 g
s
.64534 .52862 m .6404 .54341 L p .6455 .52931 L .405 .263 .572 r
F P
0 g
s
.63694 .5724 m .64305 .55954 L .65968 .56594 L p .707 .577 .707 r
F P
0 g
s
.66519 .55158 m .65968 .56594 L .64305 .55954 L p .707 .577 .707 r
F P
0 g
s
.63527 .55669 m .64418 .56025 L p .64061 .54439 L .41 .257 .561 r
F P
0 g
s
.6404 .54341 m .63527 .55669 L p .64061 .54439 L .41 .257 .561 r
F P
0 g
s
.63015 .58339 m .63694 .5724 L .65303 .58003 L p .707 .577 .707 r
F P
0 g
s
.65968 .56594 m .65303 .58003 L .63694 .5724 L p .707 .577 .707 r
F P
0 g
s
.62939 .56898 m .63801 .57322 L p .63548 .55798 L .418 .248 .542 r
F P
0 g
s
.63527 .55669 m .62939 .56898 L p .63548 .55798 L .418 .248 .542 r
F P
0 g
s
.65303 .58003 m .64535 .59268 L .63015 .58339 L p .707 .577 .707 r
F P
0 g
s
.62304 .57917 m .63118 .58429 L p .62951 .57 L .432 .239 .517 r
F P
0 g
s
.6295 .56992 m .62304 .57917 L .62951 .57 L .432 .239 .517 r
F
.62939 .56898 m .62332 .57872 L p .6295 .56992 L F P
0 g
s
.62332 .57872 m .62304 .57917 L p .6295 .56992 L .432 .239 .517 r
F P
0 g
s
.61334 .60311 m .62224 .5936 L .63636 .60446 L p .707 .577 .707 r
F P
0 g
s
.64535 .59268 m .63636 .60446 L .62224 .5936 L p .707 .577 .707 r
F P
0 g
s
.61563 .58864 m .6232 .59458 L p .62305 .58006 L .449 .234 .494 r
F P
0 g
s
.62304 .57917 m .61563 .58864 L p .62305 .58006 L .449 .234 .494 r
F P
0 g
s
.60724 .59754 m .61563 .58864 L p .60812 .59731 L .859 .867 .845 r
F P
0 g
s
.59325 .08011 m .59143 .07283 L p .6195 .07829 L .625 .245 .302 r
F P
0 g
s
.59143 .07283 m .62723 .07252 L .62783 .07991 L p .625 .245 .302 r
F P
0 g
s
.55599 .0786 m .59143 .07283 L .59276 .07815 L p .577 .211 .31 r
F P
0 g
s
.59276 .07815 m .59325 .08011 L p .58537 .07979 L .577 .211 .31 r
F P
0 g
s
.55599 .0786 m .59276 .07815 L .58537 .07979 L .577 .211 .31 r
F
.59143 .07283 m .55599 .0786 L .55071 .06159 L p .707 .577 .707 r
F P
0 g
s
.55886 .08562 m .55599 .0786 L p .58537 .07979 L .577 .211 .31 r
F P
0 g
s
.59325 .08011 m .55886 .08562 L p .58537 .07979 L .577 .211 .31 r
F P
0 g
s
.52491 .09598 m .52106 .08936 L p .5508 .08641 L .536 .188 .324 r
F P
0 g
s
.55886 .08562 m .52491 .09598 L p .5508 .08641 L .536 .188 .324 r
F P
0 g
s
.52106 .08936 m .55599 .0786 L .55886 .08562 L p .536 .188 .324 r
F P
0 g
s
.48584 .10582 m .52106 .08936 L .52369 .09389 L p .498 .172 .344 r
F P
0 g
s
.52369 .09389 m .52491 .09598 L p .51557 .09833 L .498 .172 .344 r
F P
0 g
s
.48584 .10582 m .52369 .09389 L .51557 .09833 L .498 .172 .344 r
F
.52106 .08936 m .48584 .10582 L .47699 .09037 L p .707 .578 .707 r
F P
0 g
s
.49174 .1113 m .48584 .10582 L p .51557 .09833 L .498 .172 .344 r
F P
0 g
s
.52491 .09598 m .49174 .1113 L p .51557 .09833 L .498 .172 .344 r
F P
0 g
s
.46387 .11829 m .48584 .10582 L .49174 .1113 L p .49 .166 .345 r
F P
0 g
s
.48584 .10582 m .46387 .11829 L .45345 .10382 L p .723 .583 .697 r
F P
0 g
s
.45345 .10382 m .47699 .09037 L .48584 .10582 L p .723 .583 .697 r
F P
0 g
s
.47036 .12317 m .46387 .11829 L p .48827 .11217 L .49 .166 .345 r
F P
0 g
s
.49174 .1113 m .47036 .12317 L p .48827 .11217 L .49 .166 .345 r
F P
0 g
s
.44308 .1331 m .46387 .11829 L .47036 .12317 L p .463 .158 .363 r
F P
0 g
s
.46387 .11829 m .44308 .1331 L .43156 .11948 L p .723 .581 .696 r
F P
0 g
s
.43156 .11948 m .45345 .10382 L .46387 .11829 L p .723 .581 .696 r
F P
0 g
s
.44994 .13753 m .44308 .1331 L p .46771 .12414 L .463 .158 .363 r
F P
0 g
s
.47036 .12317 m .44994 .13753 L p .46771 .12414 L .463 .158 .363 r
F P
0 g
s
.42307 .14988 m .44308 .1331 L .44994 .13753 L p .444 .156 .379 r
F P
0 g
s
.44308 .1331 m .42307 .14988 L .41051 .13719 L p .721 .579 .695 r
F P
0 g
s
.41051 .13719 m .43156 .11948 L .44308 .1331 L p .721 .579 .695 r
F P
0 g
s
.43028 .15381 m .42307 .14988 L p .44724 .13877 L .444 .156 .379 r
F P
0 g
s
.44994 .13753 m .43028 .15381 L p .44724 .13877 L .444 .156 .379 r
F P
0 g
s
.40439 .1682 m .42307 .14988 L .43028 .15381 L p .426 .155 .397 r
F P
0 g
s
.42307 .14988 m .40439 .1682 L .39098 .15639 L p .72 .577 .693 r
F P
0 g
s
.39098 .15639 m .41051 .13719 L .42307 .14988 L p .72 .577 .693 r
F P
0 g
s
.41177 .17178 m .40439 .1682 L p .42815 .15499 L .426 .155 .397 r
F P
0 g
s
.43028 .15381 m .41177 .17178 L p .42815 .15499 L .426 .155 .397 r
F P
0 g
s
.38488 .19005 m .40439 .1682 L .41177 .17178 L p .412 .156 .414 r
F P
0 g
s
.40439 .1682 m .38488 .19005 L .37136 .17836 L p .719 .576 .694 r
F P
0 g
s
.37136 .17836 m .39098 .15639 L .40439 .1682 L p .719 .576 .694 r
F P
0 g
s
.39224 .19365 m .38488 .19005 L p .41142 .17202 L .412 .156 .414 r
F P
0 g
s
.41177 .17178 m .39224 .19365 L p .41142 .17202 L .412 .156 .414 r
F P
0 g
s
.36529 .21234 m .38488 .19005 L .39224 .19365 L p .41 .156 .416 r
F P
0 g
s
.38488 .19005 m .36529 .21234 L .35203 .20032 L p .719 .576 .693 r
F P
0 g
s
.35203 .20032 m .37136 .17836 L .38488 .19005 L p .719 .576 .693 r
F P
0 g
s
.39224 .19365 m .37248 .2162 L .36529 .21234 L p .41 .156 .416 r
F P
0 g
s
.39224 .19365 m .38603 .18549 L p .37272 .21567 L .863 .833 .816 r
F P
0 g
s
.37248 .2162 m .39224 .19365 L p .37272 .21567 L .863 .833 .816 r
F P
0 g
s
.41177 .17178 m .40571 .16349 L p .39376 .19024 L .861 .833 .817 r
F P
0 g
s
.39224 .19365 m .41177 .17178 L p .39376 .19024 L .861 .833 .817 r
F P
0 g
s
.43028 .15381 m .42489 .14499 L p .41312 .16902 L .851 .834 .829 r
F P
0 g
s
.41177 .17178 m .43028 .15381 L p .41312 .16902 L .851 .834 .829 r
F P
0 g
s
.44994 .13753 m .44524 .12826 L p .43181 .15119 L .837 .834 .843 r
F P
0 g
s
.43028 .15381 m .44994 .13753 L p .43181 .15119 L .837 .834 .843 r
F P
0 g
s
.47036 .12317 m .46641 .11351 L p .45209 .13439 L .822 .831 .856 r
F P
0 g
s
.44994 .13753 m .47036 .12317 L p .45209 .13439 L .822 .831 .856 r
F P
0 g
s
.49174 .1113 m .48876 .10125 L p .47073 .12274 L .8 .825 .871 r
F P
0 g
s
.4705 .12301 m .49174 .1113 L .47073 .12274 L .8 .825 .871 r
F
.47036 .12317 m .4815 .11699 L p .4705 .12301 L F P
0 g
s
.4815 .11699 m .49174 .1113 L p .4705 .12301 L .8 .825 .871 r
F P
0 g
s
.55599 .0786 m .52106 .08936 L .51356 .0732 L p .707 .577 .707 r
F P
0 g
s
.47699 .09037 m .51356 .0732 L .52106 .08936 L p .707 .578 .707 r
F P
0 g
s
.52491 .09598 m .52123 .08638 L p .49818 .10586 L .766 .81 .888 r
F P
0 g
s
.49174 .1113 m .52491 .09598 L p .49818 .10586 L .766 .81 .888 r
F P
0 g
s
.51356 .0732 m .55071 .06159 L .55599 .0786 L p .707 .577 .707 r
F P
0 g
s
.55886 .08562 m .55643 .07554 L p .53168 .09159 L .735 .793 .899 r
F P
0 g
s
.53144 .09175 m .55886 .08562 L .53168 .09159 L .735 .793 .899 r
F
.52491 .09598 m .55824 .0858 L p .53144 .09175 L F P
0 g
s
.55824 .0858 m .55886 .08562 L p .53144 .09175 L .735 .793 .899 r
F P
0 g
s
.62723 .07252 m .59143 .07283 L .58853 .05526 L p .707 .577 .707 r
F P
0 g
s
.55071 .06159 m .58853 .05526 L .59143 .07283 L p .707 .577 .707 r
F P
0 g
s
.59325 .08011 m .59215 .06972 L p .56654 .08195 L .702 .771 .906 r
F P
0 g
s
.55886 .08562 m .59325 .08011 L p .56654 .08195 L .702 .771 .906 r
F P
0 g
s
.62783 .07991 m .59325 .08011 L p .6195 .07829 L .625 .245 .302 r
F P
0 g
s
.33282 .67517 m .34362 .66044 L .35138 .665 L p .874 .848 .815 r
F P
0 g
s
.35138 .665 m .34065 .67964 L .33282 .67517 L p .874 .848 .815 r
F P
0 g
s
.36247 .65009 m .35138 .665 L .34362 .66044 L p .873 .849 .816 r
F P
0 g
s
.34065 .67964 m .35138 .665 L .36569 .67562 L p .707 .577 .707 r
F P
0 g
s
.35138 .665 m .36247 .65009 L .37616 .66149 L p .707 .577 .707 r
F P
0 g
s
.37616 .66149 m .36569 .67562 L .35138 .665 L p .707 .577 .707 r
F P
0 g
s
.42825 .57793 m .44239 .57006 L .44636 .57774 L p .786 .846 .896 r
F P
0 g
s
.44636 .57774 m .43289 .58527 L .42825 .57793 L p .786 .846 .896 r
F P
0 g
s
.46401 .56976 m .44636 .57774 L .44274 .57073 L p .76 .836 .91 r
F P
0 g
s
.46401 .56976 m .44274 .57073 L .44411 .57003 L .76 .836 .91 r
F
.44636 .57774 m .46401 .56976 L .4709 .58619 L p .702 .575 .709 r
F P
0 g
s
.44239 .57006 m .45642 .56357 L .46401 .56976 L p .76 .836 .91 r
F P
0 g
s
.47432 .56597 m .46401 .56976 L .45642 .56357 L p .702 .818 .937 r
F P
0 g
s
.45642 .56357 m .46738 .55911 L .47432 .56597 L p .702 .818 .937 r
F P
0 g
s
.46738 .55911 m .45871 .56264 L p .45573 .57389 L .506 .215 .406 r
F P
0 g
s
.45871 .56264 m .45642 .56357 L .45641 .56381 L p .506 .215 .406 r
F P
0 g
s
.45641 .56381 m .45573 .57389 L p .45871 .56264 L .506 .215 .406 r
F P
0 g
s
.44274 .57073 m .44239 .57006 L p .44411 .57003 L .76 .836 .91 r
F P
0 g
s
.58936 .61382 m .59797 .60596 L .6036 .61199 L p .868 .873 .839 r
F P
0 g
s
.60724 .59754 m .61334 .60311 L p .59877 .60581 L .842 .867 .861 r
F P
0 g
s
.59797 .60596 m .60724 .59754 L p .59877 .60581 L .842 .867 .861 r
F P
0 g
s
.61334 .60311 m .6036 .61199 L .59797 .60596 L p .842 .867 .861 r
F P
0 g
s
.6036 .61199 m .61334 .60311 L .62639 .61524 L p .707 .577 .707 r
F P
0 g
s
.63636 .60446 m .62639 .61524 L .61334 .60311 L p .707 .577 .707 r
F P
0 g
s
.60724 .59754 m .61423 .60416 L p .61556 .58942 L .465 .232 .476 r
F P
0 g
s
.61563 .58864 m .60724 .59754 L p .61556 .58942 L .465 .232 .476 r
F P
0 g
s
.59215 .62242 m .6036 .61199 L .61564 .62513 L p .735 .579 .681 r
F P
0 g
s
.62639 .61524 m .61564 .62513 L .6036 .61199 L p .707 .577 .707 r
F P
0 g
s
.60724 .59754 m .59938 .60468 L p .60442 .61312 L .479 .232 .461 r
F P
0 g
s
.59938 .60468 m .59797 .60596 L .59805 .60605 L p .479 .232 .461 r
F P
0 g
s
.6036 .61199 m .59215 .62242 L .58965 .61471 L p .868 .873 .839 r
F P
0 g
s
.6036 .61199 m .58965 .61471 L .59068 .61365 L .868 .873 .839 r
F
.59805 .60605 m .60442 .61312 L p .59938 .60468 L .479 .232 .461 r
F P
0 g
s
.58965 .61471 m .58936 .61382 L p .59068 .61365 L .868 .873 .839 r
F P
0 g
s
.64534 .52862 m .65131 .51225 L .65868 .51609 L p .921 .834 .743 r
F P
0 g
s
.65868 .51609 m .65316 .53137 L .64534 .52862 L p .921 .834 .743 r
F P
0 g
s
.65131 .51225 m .65828 .49844 L .66553 .50251 L p .907 .849 .775 r
F P
0 g
s
.66553 .50251 m .65868 .51609 L .65131 .51225 L p .907 .849 .775 r
F P
0 g
s
.65828 .49844 m .66505 .48576 L .67243 .48955 L p .904 .851 .781 r
F P
0 g
s
.67243 .48955 m .66553 .50251 L .65828 .49844 L p .904 .851 .781 r
F P
0 g
s
.66505 .48576 m .67101 .47345 L .67862 .4767 L p .909 .847 .771 r
F P
0 g
s
.67862 .4767 m .67243 .48955 L .66505 .48576 L p .909 .847 .771 r
F P
0 g
s
.67101 .47345 m .67588 .4614 L .68377 .46381 L p .918 .839 .752 r
F P
0 g
s
.68377 .46381 m .67862 .4767 L .67101 .47345 L p .918 .839 .752 r
F P
0 g
s
.67588 .4614 m .67925 .44957 L .68733 .45118 L p .928 .824 .722 r
F P
0 g
s
.68733 .45118 m .68377 .46381 L .67588 .4614 L p .928 .824 .722 r
F P
0 g
s
.67925 .44957 m .68148 .43719 L .68965 .43811 L p .935 .806 .693 r
F P
0 g
s
.68965 .43811 m .68733 .45118 L .67925 .44957 L p .935 .806 .693 r
F P
0 g
s
.68148 .43719 m .68269 .42425 L .69088 .42469 L p .939 .789 .668 r
F P
0 g
s
.69088 .42469 m .68965 .43811 L .68148 .43719 L p .939 .789 .668 r
F P
0 g
s
.69147 .4068 m .69088 .42469 L .68361 .4243 L p .94 .779 .655 r
F P
0 g
s
.69147 .4068 m .68361 .4243 L .68356 .42252 L .94 .779 .655 r
F
.69088 .42469 m .69147 .4068 L .70927 .40757 L p .707 .581 .712 r
F P
0 g
s
.68269 .42425 m .68311 .40989 L .69147 .4068 L p .94 .779 .655 r
F P
0 g
s
.69184 .39541 m .69147 .4068 L .68311 .40989 L p .939 .809 .688 r
F P
0 g
s
.68376 .3992 m .69184 .39541 L p .68353 .40919 L .939 .809 .688 r
F P
0 g
s
.68311 .40989 m .68376 .3992 L p .68353 .40919 L .939 .809 .688 r
F P
0 g
s
.69147 .4068 m .69184 .39541 L .70965 .39474 L p .704 .608 .746 r
F P
0 g
s
.69117 .38442 m .69184 .39541 L .68376 .3992 L p .943 .79 .662 r
F P
0 g
s
.68367 .38934 m .69117 .38442 L p .68425 .39822 L .943 .79 .662 r
F P
0 g
s
.68376 .3992 m .68367 .38934 L p .68425 .39822 L .943 .79 .662 r
F P
0 g
s
.69184 .39541 m .69117 .38442 L .70878 .38156 L p .707 .61 .746 r
F P
0 g
s
.68921 .37421 m .69117 .38442 L .68367 .38934 L p .944 .76 .623 r
F P
0 g
s
.68251 .38019 m .68921 .37421 L p .68403 .38836 L .944 .76 .623 r
F P
0 g
s
.68367 .38934 m .68251 .38019 L p .68403 .38836 L .944 .76 .623 r
F P
0 g
s
.69117 .38442 m .68921 .37421 L .70626 .36893 L p .712 .614 .746 r
F P
0 g
s
.68565 .36366 m .68921 .37421 L .68251 .38019 L p .94 .722 .58 r
F P
0 g
s
.67991 .37091 m .68565 .36366 L p .68274 .37897 L .94 .722 .58 r
F P
0 g
s
.68251 .38019 m .67991 .37091 L p .68274 .37897 L .94 .722 .58 r
F P
0 g
s
.68921 .37421 m .68565 .36366 L .70201 .35647 L p .718 .619 .746 r
F P
0 g
s
.68181 .35611 m .68565 .36366 L .67991 .37091 L p .933 .689 .547 r
F P
0 g
s
.67752 .36438 m .68181 .35611 L p .68003 .36998 L .933 .689 .547 r
F P
0 g
s
.67991 .37091 m .67752 .36438 L p .68003 .36998 L .933 .689 .547 r
F P
0 g
s
.68565 .36366 m .68181 .35611 L .69666 .34615 L p .724 .625 .747 r
F P
0 g
s
.69666 .34615 m .70201 .35647 L .68565 .36366 L p .724 .625 .747 r
F P
0 g
s
.67668 .34934 m .68181 .35611 L .67752 .36438 L p .913 .631 .495 r
F P
0 g
s
.67405 .35844 m .67668 .34934 L p .67747 .36341 L .913 .631 .495 r
F P
0 g
s
.67752 .36438 m .67405 .35844 L p .67747 .36341 L .913 .631 .495 r
F P
0 g
s
.68181 .35611 m .67668 .34934 L .68959 .33695 L p .731 .628 .744 r
F P
0 g
s
.68959 .33695 m .69666 .34615 L .68181 .35611 L p .731 .628 .744 r
F P
0 g
s
.67101 .34438 m .67668 .34934 L .67405 .35844 L p .883 .568 .449 r
F P
0 g
s
.67062 .35398 m .67101 .34438 L p .67386 .35755 L .883 .568 .449 r
F P
0 g
s
.67405 .35844 m .67062 .35398 L p .67386 .35755 L .883 .568 .449 r
F P
0 g
s
.67668 .34934 m .67101 .34438 L .68082 .32939 L p .737 .629 .739 r
F P
0 g
s
.68082 .32939 m .68959 .33695 L .67668 .34934 L p .737 .629 .739 r
F P
0 g
s
.66135 .3398 m .67101 .34438 L .67062 .35398 L p .827 .481 .4 r
F P
0 g
s
.67062 .35398 m .66663 .35057 L .66135 .3398 L p .827 .481 .4 r
F P
0 g
s
.67062 .35398 m .68012 .34856 L p .66742 .35045 L .544 .66 .912 r
F P
0 g
s
.66663 .35057 m .67062 .35398 L p .66742 .35045 L .544 .66 .912 r
F P
0 g
s
.67405 .35844 m .68441 .35512 L p .67101 .35401 L .49 .589 .88 r
F P
0 g
s
.67062 .35398 m .67405 .35844 L p .67101 .35401 L .49 .589 .88 r
F P
0 g
s
.67752 .36438 m .68817 .36269 L p .67498 .35872 L .454 .531 .847 r
F P
0 g
s
.67405 .35844 m .67752 .36438 L p .67498 .35872 L .454 .531 .847 r
F P
0 g
s
.67991 .37091 m .69062 .37098 L p .67764 .36445 L .423 .474 .808 r
F P
0 g
s
.67752 .36438 m .67991 .37091 L p .67764 .36445 L .423 .474 .808 r
F P
0 g
s
.68251 .38019 m .69294 .3809 L p .68092 .37168 L .41 .433 .773 r
F P
0 g
s
.67991 .37091 m .68251 .38019 L p .68092 .37168 L .41 .433 .773 r
F P
0 g
s
.68367 .38934 m .69387 .39141 L p .68312 .38079 L .395 .393 .739 r
F P
0 g
s
.68251 .38019 m .68367 .38934 L p .68312 .38079 L .395 .393 .739 r
F P
0 g
s
.68376 .3992 m .69358 .40234 L p .68399 .38975 L .387 .358 .705 r
F P
0 g
s
.68367 .38934 m .68376 .3992 L p .68399 .38975 L .387 .358 .705 r
F P
0 g
s
.68376 .3992 m .6832 .40836 L p .69261 .41377 L .384 .337 .682 r
F P
0 g
s
.6832 .40836 m .68311 .40989 L .68324 .40994 L p .384 .337 .682 r
F P
0 g
s
.68324 .40994 m .69261 .41377 L p .6832 .40836 L .384 .337 .682 r
F P
0 g
s
.68361 .4243 m .68269 .42425 L p .68356 .42252 L .94 .779 .655 r
F P
0 g
s
.84957 .37986 m .85179 .35547 L .85932 .35627 L p .952 .786 .64 r
F P
0 g
s
.85932 .35627 m .8569 .38286 L .84957 .37986 L p .952 .786 .64 r
F P
0 g
s
.85179 .35547 m .85334 .31957 L .86084 .31942 L p .95 .787 .644 r
F P
0 g
s
.86084 .31942 m .85932 .35627 L .85179 .35547 L p .95 .787 .644 r
F P
0 g
s
.85334 .31957 m .85058 .28421 L .85791 .28301 L p .951 .755 .604 r
F P
0 g
s
.85791 .28301 m .86084 .31942 L .85334 .31957 L p .951 .755 .604 r
F P
0 g
s
.85058 .28421 m .84334 .2505 L .85031 .24814 L p .945 .715 .559 r
F P
0 g
s
.85031 .24814 m .85791 .28301 L .85058 .28421 L p .945 .715 .559 r
F P
0 g
s
.84334 .2505 m .83086 .21785 L .83742 .21462 L p .932 .665 .51 r
F P
0 g
s
.83742 .21462 m .85031 .24814 L .84334 .2505 L p .932 .665 .51 r
F P
0 g
s
.83086 .21785 m .81609 .18984 L .82194 .18552 L p .916 .622 .472 r
F P
0 g
s
.82194 .18552 m .83742 .21462 L .83086 .21785 L p .916 .622 .472 r
F P
0 g
s
.797 .16447 m .80202 .15925 L p .8131 .18333 L .888 .563 .426 r
F P
0 g
s
.80202 .15925 m .82194 .18552 L .81609 .18984 L p .888 .563 .426 r
F P
0 g
s
.77401 .14204 m .77816 .1361 L p .7931 .1586 L .855 .505 .388 r
F P
0 g
s
.797 .16447 m .77401 .14204 L p .7931 .1586 L .855 .505 .388 r
F P
0 g
s
.77816 .1361 m .80202 .15925 L .797 .16447 L p .855 .505 .388 r
F P
0 g
s
.74681 .12228 m .75055 .11607 L p .77143 .13918 L .819 .45 .357 r
F P
0 g
s
.77401 .14204 m .74681 .12228 L p .77143 .13918 L .819 .45 .357 r
F P
0 g
s
.75055 .11607 m .77816 .1361 L .77401 .14204 L p .819 .45 .357 r
F P
0 g
s
.71949 .10505 m .72223 .09832 L p .74185 .11745 L .801 .425 .345 r
F P
0 g
s
.74681 .12228 m .71949 .10505 L p .74185 .11745 L .801 .425 .345 r
F P
0 g
s
.72223 .09832 m .75055 .11607 L .74681 .12228 L p .801 .425 .345 r
F P
0 g
s
.69041 .09197 m .692 .08484 L p .71365 .10076 L .76 .374 .324 r
F P
0 g
s
.71949 .10505 m .69041 .09197 L p .71365 .10076 L .76 .374 .324 r
F P
0 g
s
.692 .08484 m .72223 .09832 L .71949 .10505 L p .76 .374 .324 r
F P
0 g
s
.65999 .08349 m .66031 .07614 L p .68375 .08846 L .713 .323 .309 r
F P
0 g
s
.69041 .09197 m .65999 .08349 L p .68375 .08846 L .713 .323 .309 r
F P
0 g
s
.66031 .07614 m .692 .08484 L .69041 .09197 L p .713 .323 .309 r
F P
0 g
s
.62783 .07991 m .62723 .07252 L p .65428 .08158 L .662 .275 .302 r
F P
0 g
s
.65999 .08349 m .62783 .07991 L p .65428 .08158 L .662 .275 .302 r
F P
0 g
s
.62723 .07252 m .66031 .07614 L .65999 .08349 L p .662 .275 .302 r
F P
0 g
s
.66031 .07614 m .62723 .07252 L .62702 .05471 L p .707 .577 .707 r
F P
0 g
s
.58853 .05526 m .62702 .05471 L .62723 .07252 L p .707 .577 .707 r
F P
0 g
s
.62783 .07991 m .62823 .06941 L p .59967 .07814 L .665 .742 .908 r
F P
0 g
s
.59325 .08011 m .62783 .07991 L p .59967 .07814 L .665 .742 .908 r
F P
0 g
s
.692 .08484 m .66031 .07614 L .66221 .05843 L p .707 .577 .707 r
F P
0 g
s
.62702 .05471 m .66221 .05843 L .66031 .07614 L p .707 .577 .707 r
F P
0 g
s
.65999 .08349 m .66157 .07305 L p .63547 .07836 L .637 .718 .906 r
F P
0 g
s
.62783 .07991 m .65999 .08349 L p .63547 .07836 L .637 .718 .906 r
F P
0 g
s
.72223 .09832 m .692 .08484 L .69666 .06765 L p .707 .577 .707 r
F P
0 g
s
.66221 .05843 m .69666 .06765 L .692 .08484 L p .707 .577 .707 r
F P
0 g
s
.69041 .09197 m .69351 .08182 L p .66708 .08314 L .599 .68 .898 r
F P
0 g
s
.65999 .08349 m .69041 .09197 L p .66708 .08314 L .599 .68 .898 r
F P
0 g
s
.75055 .11607 m .72223 .09832 L .72944 .08204 L p .707 .577 .707 r
F P
0 g
s
.69666 .06765 m .72944 .08204 L .72223 .09832 L p .707 .577 .707 r
F P
0 g
s
.71949 .10505 m .72398 .09541 L p .69713 .09266 L .566 .642 .885 r
F P
0 g
s
.69041 .09197 m .71949 .10505 L p .69713 .09266 L .566 .642 .885 r
F P
0 g
s
.77816 .1361 m .75055 .11607 L .75997 .10096 L p .707 .577 .707 r
F P
0 g
s
.72944 .08204 m .75997 .10096 L .75055 .11607 L p .707 .577 .707 r
F P
0 g
s
.74681 .12228 m .75252 .1133 L p .72297 .10592 L .536 .604 .869 r
F P
0 g
s
.71949 .10505 m .74681 .12228 L p .72297 .10592 L .536 .604 .869 r
F P
0 g
s
.80202 .15925 m .77816 .1361 L .78861 .12167 L p .707 .577 .707 r
F P
0 g
s
.75997 .10096 m .78861 .12167 L .77816 .1361 L p .707 .577 .707 r
F P
0 g
s
.77401 .14204 m .78035 .13348 L p .75401 .12469 L .523 .586 .86 r
F P
0 g
s
.74681 .12228 m .77401 .14204 L p .75401 .12469 L .523 .586 .86 r
F P
0 g
s
.82194 .18552 m .80202 .15925 L .81439 .14644 L p .707 .577 .707 r
F P
0 g
s
.78861 .12167 m .81439 .14644 L .80202 .15925 L p .707 .577 .707 r
F P
0 g
s
.797 .16447 m .8044 .15682 L p .78056 .14522 L .496 .546 .837 r
F P
0 g
s
.77401 .14204 m .797 .16447 L p .78056 .14522 L .496 .546 .837 r
F P
0 g
s
.81609 .18984 m .797 .16447 L p .8131 .18333 L .888 .563 .426 r
F P
0 g
s
.27311 .72565 m .27662 .73305 L p .25469 .7291 L .67 .796 .942 r
F P
0 g
s
.27662 .73305 m .24344 .73502 L .24334 .7308 L p .67 .796 .942 r
F P
0 g
s
.24334 .7308 m .24324 .72704 L p .25375 .72893 L .67 .796 .942 r
F P
0 g
s
.27662 .73305 m .24334 .7308 L .25375 .72893 L .67 .796 .942 r
F
.27306 .72555 m .27311 .72565 L p .27228 .72569 L F P
0 g
s
.24324 .72704 m .27306 .72555 L p .27228 .72569 L .67 .796 .942 r
F P
0 g
s
.25469 .7291 m .24324 .72704 L .27311 .72565 L .67 .796 .942 r
F
.28224 .72313 m .28744 .72985 L p .27478 .72607 L .725 .827 .928 r
F P
0 g
s
.27478 .72607 m .27306 .72555 L .28224 .72313 L .725 .827 .928 r
F
.28744 .72985 m .27662 .73305 L .27306 .72555 L p F P
0 g
s
.29176 .71795 m .298 .72399 L p .28365 .72318 L .786 .85 .899 r
F P
0 g
s
.28365 .72318 m .28221 .72309 L .29176 .71795 L .786 .85 .899 r
F
.298 .72399 m .28744 .72985 L .28221 .72309 L p F P
0 g
s
.30132 .71068 m .30839 .71603 L p .29315 .71776 L .821 .856 .874 r
F P
0 g
s
.29315 .71776 m .29173 .71792 L .30132 .71068 L .821 .856 .874 r
F
.30839 .71603 m .298 .72399 L .29173 .71792 L p F P
0 g
s
.31084 .70119 m .3182 .70622 L p .30201 .71049 L .848 .856 .848 r
F P
0 g
s
.30201 .71049 m .30131 .71068 L .31084 .70119 L .848 .856 .848 r
F
.3182 .70622 m .30839 .71603 L .30131 .71068 L p F P
0 g
s
.32209 .68867 m .32975 .69335 L p .31186 .70076 L .858 .854 .837 r
F P
0 g
s
.31186 .70076 m .31083 .70119 L .32209 .68867 L .858 .854 .837 r
F
.32975 .69335 m .3182 .70622 L .31083 .70119 L p F P
0 g
s
.32208 .68867 m .33282 .67517 L .33282 .67517 L p .868 .851 .823 r
F P
0 g
s
.33282 .67517 m .34065 .67964 L p .32276 .68834 L .868 .851 .823 r
F P
0 g
s
.32276 .68834 m .32208 .68867 L .33282 .67517 L .868 .851 .823 r
F
.34065 .67964 m .32975 .69335 L .32237 .68884 L p F P
0 g
s
.32237 .68884 m .32208 .68867 L p .32276 .68834 L .868 .851 .823 r
F P
0 g
s
.34065 .67964 m .32237 .68884 L .32276 .68834 L .868 .851 .823 r
F
.32975 .69335 m .34065 .67964 L .35502 .69017 L p .707 .577 .707 r
F P
0 g
s
.33282 .67517 m .3394 .68129 L p .34346 .66123 L .422 .209 .483 r
F P
0 g
s
.34362 .66044 m .33292 .67503 L p .34346 .66123 L .422 .209 .483 r
F P
0 g
s
.33292 .67503 m .33282 .67517 L p .34346 .66123 L .422 .209 .483 r
F P
0 g
s
.3394 .68129 m .35022 .66655 L .34389 .66069 L p .422 .209 .483 r
F P
0 g
s
.34389 .66069 m .34362 .66044 L p .34346 .66124 L .422 .209 .483 r
F P
0 g
s
.34346 .66124 m .3394 .68129 L .34389 .66069 L .422 .209 .483 r
F
.3182 .70622 m .32975 .69335 L .3437 .70443 L p .707 .577 .707 r
F P
0 g
s
.32208 .68867 m .32841 .69511 L p .33258 .67626 L .43 .209 .475 r
F P
0 g
s
.33282 .67517 m .32208 .68867 L p .33258 .67626 L .43 .209 .475 r
F P
0 g
s
.32208 .68867 m .32209 .68867 L p .32201 .68875 L .858 .854 .837 r
F P
0 g
s
.31083 .70119 m .32208 .68867 L p .32201 .68875 L .858 .854 .837 r
F P
0 g
s
.35502 .69017 m .3437 .70443 L .32975 .69335 L p .707 .577 .707 r
F P
0 g
s
.32841 .69511 m .3394 .68129 L .3332 .67553 L p .43 .209 .475 r
F P
0 g
s
.3332 .67553 m .33282 .67517 L p .33258 .67626 L .43 .209 .475 r
F P
0 g
s
.33258 .67626 m .32841 .69511 L .3332 .67553 L .43 .209 .475 r
F
.30839 .71603 m .3182 .70622 L .33147 .7181 L p .707 .577 .707 r
F P
0 g
s
.31083 .70119 m .31677 .70809 L p .32182 .68961 L .443 .21 .464 r
F P
0 g
s
.32208 .68867 m .31083 .70119 L p .32182 .68961 L .443 .21 .464 r
F P
0 g
s
.31083 .70119 m .31084 .70119 L p .31063 .70139 L .848 .856 .848 r
F P
0 g
s
.30131 .71068 m .31083 .70119 L p .31063 .70139 L .848 .856 .848 r
F P
0 g
s
.3437 .70443 m .33147 .7181 L .3182 .70622 L p .707 .577 .707 r
F P
0 g
s
.31677 .70809 m .32841 .69511 L .32241 .689 L p .443 .21 .464 r
F P
0 g
s
.32241 .689 m .32208 .68867 L p .32182 .68961 L .443 .21 .464 r
F P
0 g
s
.32182 .68961 m .31677 .70809 L .32241 .689 L .443 .21 .464 r
F
.298 .72399 m .30839 .71603 L .32099 .72862 L p .707 .577 .707 r
F P
0 g
s
.30131 .71068 m .30688 .71797 L p .31046 .70275 L .456 .212 .455 r
F P
0 g
s
.31083 .70119 m .30131 .71068 L p .31046 .70275 L .456 .212 .455 r
F P
0 g
s
.30131 .71068 m .30132 .71068 L p .30124 .71074 L .821 .856 .874 r
F P
0 g
s
.29173 .71792 m .30131 .71068 L p .30124 .71074 L .821 .856 .874 r
F P
0 g
s
.33147 .7181 m .32099 .72862 L .30839 .71603 L p .707 .577 .707 r
F P
0 g
s
.30688 .71797 m .31677 .70809 L .31144 .7019 L p .456 .212 .455 r
F P
0 g
s
.31144 .7019 m .31083 .70119 L p .31046 .70275 L .456 .212 .455 r
F P
0 g
s
.31046 .70275 m .30688 .71797 L .31144 .7019 L .456 .212 .455 r
F
.28744 .72985 m .298 .72399 L .30891 .73807 L p .707 .577 .707 r
F P
0 g
s
.29173 .71792 m .29641 .72599 L p .30086 .71209 L .488 .222 .436 r
F P
0 g
s
.30131 .71068 m .29173 .71792 L p .30086 .71209 L .488 .222 .436 r
F P
0 g
s
.29173 .71792 m .29176 .71795 L p .29132 .71819 L .786 .85 .899 r
F P
0 g
s
.28221 .72309 m .29173 .71792 L p .29132 .71819 L .786 .85 .899 r
F P
0 g
s
.32099 .72862 m .30891 .73807 L .298 .72399 L p .707 .577 .707 r
F P
0 g
s
.29641 .72599 m .30688 .71797 L .30188 .71143 L p .488 .222 .436 r
F P
0 g
s
.30188 .71143 m .30131 .71068 L p .30086 .71209 L .488 .222 .436 r
F P
0 g
s
.30086 .71209 m .29641 .72599 L .30188 .71143 L .488 .222 .436 r
F
.27662 .73305 m .28744 .72985 L .29621 .74536 L p .707 .577 .707 r
F P
0 g
s
.28221 .72309 m .28577 .73191 L p .29098 .71969 L .527 .238 .419 r
F P
0 g
s
.29173 .71792 m .28221 .72309 L p .29098 .71969 L .527 .238 .419 r
F P
0 g
s
.28221 .72309 m .28224 .72313 L p .28183 .72324 L .725 .827 .928 r
F P
0 g
s
.27306 .72555 m .28221 .72309 L p .28183 .72324 L .725 .827 .928 r
F P
0 g
s
.30891 .73807 m .29621 .74536 L .28744 .72985 L p .707 .577 .707 r
F P
0 g
s
.28577 .73191 m .29641 .72599 L .29243 .71912 L p .527 .238 .419 r
F P
0 g
s
.29243 .71912 m .29173 .71792 L p .29098 .71969 L .527 .238 .419 r
F P
0 g
s
.29098 .71969 m .28577 .73191 L .29243 .71912 L .527 .238 .419 r
F
.24344 .73502 m .27662 .73305 L .28196 .75004 L p .721 .588 .706 r
F P
0 g
s
.27306 .72555 m .27486 .73513 L p .28162 .72406 L .589 .275 .405 r
F P
0 g
s
.2817 .72393 m .27306 .72555 L .28162 .72406 L .589 .275 .405 r
F
.28221 .72309 m .27393 .72532 L p .2817 .72393 L F P
0 g
s
.27393 .72532 m .27306 .72555 L p .2817 .72393 L .589 .275 .405 r
F P
0 g
s
.29621 .74536 m .28196 .75004 L .27662 .73305 L p .707 .577 .707 r
F P
0 g
s
.27486 .73513 m .28577 .73191 L .28253 .72389 L p .589 .275 .405 r
F P
0 g
s
.28253 .72389 m .28221 .72309 L p .28162 .72406 L .589 .275 .405 r
F P
0 g
s
.28162 .72406 m .27486 .73513 L .28253 .72389 L .589 .275 .405 r
F
.34362 .66044 m .35507 .64507 L .36247 .65009 L p .873 .849 .816 r
F P
0 g
s
.35507 .64507 m .36589 .63212 L .37294 .63754 L p .864 .852 .829 r
F P
0 g
s
.37294 .63754 m .36247 .65009 L .35507 .64507 L p .864 .852 .829 r
F P
0 g
s
.36589 .63212 m .37729 .61984 L .38401 .6256 L p .855 .854 .84 r
F P
0 g
s
.38401 .6256 m .37294 .63754 L .36589 .63212 L p .855 .854 .84 r
F P
0 g
s
.37729 .61984 m .38936 .60801 L .39564 .61419 L p .846 .855 .85 r
F P
0 g
s
.39564 .61419 m .38401 .6256 L .37729 .61984 L p .846 .855 .85 r
F P
0 g
s
.38936 .60801 m .40192 .5971 L .40783 .60357 L p .834 .855 .861 r
F P
0 g
s
.40783 .60357 m .39564 .61419 L .38936 .60801 L p .834 .855 .861 r
F P
0 g
s
.40192 .5971 m .41467 .58704 L .42 .59395 L p .824 .854 .87 r
F P
0 g
s
.42 .59395 m .40783 .60357 L .40192 .5971 L p .824 .854 .87 r
F P
0 g
s
.41467 .58704 m .42825 .57793 L .43289 .58527 L p .806 .851 .883 r
F P
0 g
s
.43289 .58527 m .42 .59395 L .41467 .58704 L p .806 .851 .883 r
F P
0 g
s
.43289 .58527 m .44636 .57774 L .45384 .59391 L p .707 .577 .707 r
F P
0 g
s
.45384 .59391 m .44161 .6008 L .43289 .58527 L p .707 .577 .707 r
F P
0 g
s
.4709 .58619 m .45384 .59391 L .44636 .57774 L p .702 .575 .709 r
F P
0 g
s
.65316 .53137 m .65868 .51609 L .67458 .52411 L p .707 .577 .707 r
F P
0 g
s
.67458 .52411 m .66994 .53735 L .65316 .53137 L p .707 .577 .707 r
F P
0 g
s
.65868 .51609 m .66553 .50251 L .68125 .51087 L p .707 .577 .707 r
F P
0 g
s
.68125 .51087 m .67458 .52411 L .65868 .51609 L p .707 .577 .707 r
F P
0 g
s
.66553 .50251 m .67243 .48955 L .68849 .49725 L p .707 .577 .707 r
F P
0 g
s
.68849 .49725 m .68125 .51087 L .66553 .50251 L p .707 .577 .707 r
F P
0 g
s
.67243 .48955 m .67862 .4767 L .69519 .48325 L p .707 .577 .707 r
F P
0 g
s
.69519 .48325 m .68849 .49725 L .67243 .48955 L p .707 .577 .707 r
F P
0 g
s
.67862 .4767 m .68377 .46381 L .70093 .46858 L p .707 .577 .707 r
F P
0 g
s
.70093 .46858 m .69519 .48325 L .67862 .4767 L p .707 .577 .707 r
F P
0 g
s
.68377 .46381 m .68733 .45118 L .70487 .45425 L p .707 .577 .707 r
F P
0 g
s
.70487 .45425 m .70093 .46858 L .68377 .46381 L p .707 .577 .707 r
F P
0 g
s
.68733 .45118 m .68965 .43811 L .70739 .43972 L p .707 .577 .707 r
F P
0 g
s
.70739 .43972 m .70487 .45425 L .68733 .45118 L p .707 .577 .707 r
F P
0 g
s
.68965 .43811 m .69088 .42469 L .70868 .42521 L p .707 .577 .707 r
F P
0 g
s
.70868 .42521 m .70739 .43972 L .68965 .43811 L p .707 .577 .707 r
F P
0 g
s
.70927 .40757 m .70868 .42521 L .69088 .42469 L p .707 .581 .712 r
F P
0 g
s
.8569 .38286 m .85932 .35627 L .87712 .35697 L p .709 .563 .688 r
F P
0 g
s
.85932 .35627 m .86084 .31942 L .87859 .31795 L p .707 .577 .707 r
F P
0 g
s
.87859 .31795 m .87712 .35697 L .85932 .35627 L p .707 .577 .707 r
F P
0 g
s
.86084 .31942 m .85791 .28301 L .8753 .27916 L p .707 .577 .707 r
F P
0 g
s
.8753 .27916 m .87859 .31795 L .86084 .31942 L p .707 .577 .707 r
F P
0 g
s
.85791 .28301 m .85031 .24814 L .86692 .24172 L p .707 .577 .707 r
F P
0 g
s
.86692 .24172 m .8753 .27916 L .85791 .28301 L p .707 .577 .707 r
F P
0 g
s
.85031 .24814 m .83742 .21462 L .85312 .2062 L p .707 .577 .707 r
F P
0 g
s
.85312 .2062 m .86692 .24172 L .85031 .24814 L p .707 .577 .707 r
F P
0 g
s
.83742 .21462 m .82194 .18552 L .8361 .17472 L p .707 .577 .707 r
F P
0 g
s
.8361 .17472 m .85312 .2062 L .83742 .21462 L p .707 .577 .707 r
F P
0 g
s
.81439 .14644 m .8361 .17472 L .82194 .18552 L p .707 .577 .707 r
F P
0 g
s
.36569 .67562 m .35502 .69017 L .34065 .67964 L p .707 .577 .707 r
F P
0 g
s
.36247 .65009 m .37294 .63754 L .38601 .64964 L p .707 .577 .707 r
F P
0 g
s
.38601 .64964 m .37616 .66149 L .36247 .65009 L p .707 .577 .707 r
F P
0 g
s
.37294 .63754 m .38401 .6256 L .39651 .6383 L p .707 .577 .707 r
F P
0 g
s
.39651 .6383 m .38601 .64964 L .37294 .63754 L p .707 .577 .707 r
F P
0 g
s
.38401 .6256 m .39564 .61419 L .40735 .62761 L p .707 .577 .707 r
F P
0 g
s
.40735 .62761 m .39651 .6383 L .38401 .6256 L p .707 .577 .707 r
F P
0 g
s
.39564 .61419 m .40783 .60357 L .41891 .61753 L p .707 .577 .707 r
F P
0 g
s
.41891 .61753 m .40735 .62761 L .39564 .61419 L p .707 .577 .707 r
F P
0 g
s
.40783 .60357 m .42 .59395 L .42998 .60871 L p .707 .577 .707 r
F P
0 g
s
.42998 .60871 m .41891 .61753 L .40783 .60357 L p .707 .577 .707 r
F P
0 g
s
.42 .59395 m .43289 .58527 L .44161 .6008 L p .707 .577 .707 r
F P
0 g
s
.44161 .6008 m .42998 .60871 L .42 .59395 L p .707 .577 .707 r
F P
0 g
s
.62639 .61524 m .63636 .60446 L .64398 .61044 L p .466 .237 .481 r
F P
0 g
s
.63636 .60446 m .64535 .59268 L .65354 .59784 L p .45 .239 .5 r
F P
0 g
s
.65354 .59784 m .64398 .61044 L .63636 .60446 L p .45 .239 .5 r
F P
0 g
s
.62702 .05471 m .58853 .05526 L .58742 .04482 L p .669 .743 .906 r
F P
0 g
s
.58853 .05526 m .55071 .06159 L .54826 .05146 L p .705 .771 .904 r
F P
0 g
s
.54826 .05146 m .58742 .04482 L .58853 .05526 L p .705 .771 .904 r
F P
0 g
s
.35502 .69017 m .36569 .67562 L .37234 .68176 L p .427 .215 .487 r
F P
0 g
s
.36569 .67562 m .37616 .66149 L .38254 .66797 L p .428 .215 .486 r
F P
0 g
s
.38254 .66797 m .37234 .68176 L .36569 .67562 L p .428 .215 .486 r
F P
0 g
s
.61564 .62513 m .60402 .63572 L .59215 .62242 L p .735 .579 .681 r
F P
0 g
s
.28196 .75004 m .24454 .75281 L .24344 .73502 L p .721 .588 .706 r
F P
0 g
s
.44161 .6008 m .45384 .59391 L .45741 .60251 L p .52 .233 .419 r
F P
0 g
s
.45741 .60251 m .44575 .60912 L .44161 .6008 L p .52 .233 .419 r
F P
0 g
s
.45384 .59391 m .4709 .58619 L .47027 .59655 L p .541 .242 .41 r
F P
0 g
s
.47027 .59655 m .45741 .60251 L .45384 .59391 L p .541 .242 .41 r
F P
0 g
s
.60402 .63572 m .61564 .62513 L .62213 .63233 L p .505 .231 .432 r
F P
0 g
s
.61564 .62513 m .62639 .61524 L .63343 .6219 L p .481 .237 .467 r
F P
0 g
s
.63343 .6219 m .62213 .63233 L .61564 .62513 L p .481 .237 .467 r
F P
0 g
s
.64398 .61044 m .63343 .6219 L .62639 .61524 L p .466 .237 .481 r
F P
0 g
s
.64535 .59268 m .65303 .58003 L .66171 .58429 L p .434 .245 .523 r
F P
0 g
s
.66171 .58429 m .65354 .59784 L .64535 .59268 L p .434 .245 .523 r
F P
0 g
s
.65303 .58003 m .65968 .56594 L .66865 .56953 L p .421 .254 .547 r
F P
0 g
s
.65968 .56594 m .66519 .55158 L .67432 .55473 L p .414 .262 .564 r
F P
0 g
s
.67432 .55473 m .66865 .56953 L .65968 .56594 L p .414 .262 .564 r
F P
0 g
s
.66519 .55158 m .66994 .53735 L .67902 .54062 L p .41 .267 .575 r
F P
0 g
s
.67902 .54062 m .67432 .55473 L .66519 .55158 L p .41 .267 .575 r
F P
0 g
s
.66994 .53735 m .67458 .52411 L .68325 .52835 L p .411 .266 .572 r
F P
0 g
s
.68325 .52835 m .67902 .54062 L .66994 .53735 L p .411 .266 .572 r
F P
0 g
s
.67458 .52411 m .68125 .51087 L .68985 .51524 L p .424 .25 .54 r
F P
0 g
s
.68325 .52835 m .67458 .52411 L p .68832 .51613 L .424 .25 .54 r
F P
0 g
s
.68325 .52835 m .67595 .52454 L p .67875 .5392 L .924 .836 .74 r
F P
0 g
s
.67902 .54062 m .68325 .52835 L p .67875 .5392 L .924 .836 .74 r
F P
0 g
s
.68985 .51524 m .68325 .52835 L p .68832 .51613 L .424 .25 .54 r
F P
0 g
s
.68125 .51087 m .68849 .49725 L .69729 .50123 L p .426 .248 .535 r
F P
0 g
s
.68985 .51524 m .68125 .51087 L p .69699 .50141 L .426 .248 .535 r
F P
0 g
s
.68985 .51524 m .68268 .5112 L p .68324 .52805 L .908 .852 .775 r
F P
0 g
s
.68325 .52835 m .68985 .51524 L p .68324 .52805 L .908 .852 .775 r
F P
0 g
s
.69729 .50123 m .68985 .51524 L p .69699 .50141 L .426 .248 .535 r
F P
0 g
s
.68849 .49725 m .69519 .48325 L .70427 .4866 L p .422 .253 .545 r
F P
0 g
s
.70427 .4866 m .69729 .50123 L .68849 .49725 L p .422 .253 .545 r
F P
0 g
s
.69519 .48325 m .70093 .46858 L .71034 .47097 L p .415 .261 .563 r
F P
0 g
s
.71034 .47097 m .70427 .4866 L .69519 .48325 L p .415 .261 .563 r
F P
0 g
s
.70093 .46858 m .70487 .45425 L .71448 .45574 L p .407 .276 .589 r
F P
0 g
s
.71448 .45574 m .71034 .47097 L .70093 .46858 L p .407 .276 .589 r
F P
0 g
s
.70487 .45425 m .70739 .43972 L .7171 .44041 L p .402 .293 .614 r
F P
0 g
s
.7171 .44041 m .71448 .45574 L .70487 .45425 L p .402 .293 .614 r
F P
0 g
s
.70739 .43972 m .70868 .42521 L .71844 .4253 L p .4 .308 .635 r
F P
0 g
s
.71844 .4253 m .7171 .44041 L .70739 .43972 L p .4 .308 .635 r
F P
0 g
s
.87712 .35697 m .87859 .31795 L .88898 .31662 L p .419 .335 .655 r
F P
0 g
s
.87859 .31795 m .8753 .27916 L .8855 .27649 L p .422 .362 .685 r
F P
0 g
s
.8855 .27649 m .88898 .31662 L .87859 .31795 L p .422 .362 .685 r
F P
0 g
s
.8753 .27916 m .86692 .24172 L .8767 .2376 L p .429 .394 .718 r
F P
0 g
s
.8767 .2376 m .8855 .27649 L .8753 .27916 L p .429 .394 .718 r
F P
0 g
s
.86692 .24172 m .85312 .2062 L .86238 .20095 L p .441 .432 .752 r
F P
0 g
s
.86238 .20095 m .8767 .2376 L .86692 .24172 L p .441 .432 .752 r
F P
0 g
s
.85312 .2062 m .8361 .17472 L .84452 .16815 L p .455 .465 .78 r
F P
0 g
s
.84452 .16815 m .86238 .20095 L .85312 .2062 L p .455 .465 .78 r
F P
0 g
s
.8361 .17472 m .81439 .14644 L .82183 .13874 L p .477 .508 .811 r
F P
0 g
s
.82183 .13874 m .84452 .16815 L .8361 .17472 L p .477 .508 .811 r
F P
0 g
s
.81439 .14644 m .78861 .12167 L .79498 .11307 L p .501 .55 .838 r
F P
0 g
s
.79498 .11307 m .82183 .13874 L .81439 .14644 L p .501 .55 .838 r
F P
0 g
s
.78861 .12167 m .75997 .10096 L .76572 .09193 L p .526 .587 .859 r
F P
0 g
s
.76572 .09193 m .79498 .11307 L .78861 .12167 L p .526 .587 .859 r
F P
0 g
s
.75997 .10096 m .72944 .08204 L .73395 .07234 L p .541 .607 .869 r
F P
0 g
s
.73395 .07234 m .76572 .09193 L .75997 .10096 L p .541 .607 .869 r
F P
0 g
s
.72944 .08204 m .69666 .06765 L .69977 .05745 L p .57 .644 .884 r
F P
0 g
s
.69977 .05745 m .73395 .07234 L .72944 .08204 L p .57 .644 .884 r
F P
0 g
s
.69666 .06765 m .66221 .05843 L .6638 .04793 L p .604 .682 .897 r
F P
0 g
s
.6638 .04793 m .69977 .05745 L .69666 .06765 L p .604 .682 .897 r
F P
0 g
s
.66221 .05843 m .62702 .05471 L .62742 .04415 L p .64 .718 .904 r
F P
0 g
s
.62742 .04415 m .6638 .04793 L .66221 .05843 L p .64 .718 .904 r
F P
0 g
s
.58742 .04482 m .62742 .04415 L .62702 .05471 L p .669 .743 .906 r
F P
0 g
s
.55071 .06159 m .51356 .0732 L .50985 .06354 L p .737 .792 .897 r
F P
0 g
s
.50985 .06354 m .54826 .05146 L .55071 .06159 L p .737 .792 .897 r
F P
0 g
s
.51356 .0732 m .47699 .09037 L .47396 .08027 L p .767 .808 .886 r
F P
0 g
s
.47396 .08027 m .50985 .06354 L .51356 .0732 L p .767 .808 .886 r
F P
0 g
s
.24454 .75281 m .28196 .75004 L .28378 .75967 L p .653 .326 .407 r
F P
0 g
s
.28196 .75004 m .29621 .74536 L .29982 .75422 L p .574 .268 .412 r
F P
0 g
s
.29982 .75422 m .28378 .75967 L .28196 .75004 L p .574 .268 .412 r
F P
0 g
s
.29621 .74536 m .30891 .73807 L .31364 .74619 L p .522 .239 .426 r
F P
0 g
s
.31364 .74619 m .29982 .75422 L .29621 .74536 L p .522 .239 .426 r
F P
0 g
s
.30891 .73807 m .32099 .72862 L .32661 .73595 L p .487 .225 .442 r
F P
0 g
s
.32661 .73595 m .31364 .74619 L .30891 .73807 L p .487 .225 .442 r
F P
0 g
s
.32099 .72862 m .33147 .7181 L .33747 .72504 L p .459 .217 .46 r
F P
0 g
s
.33747 .72504 m .32661 .73595 L .32099 .72862 L p .459 .217 .46 r
F P
0 g
s
.33147 .7181 m .3437 .70443 L .35009 .71091 L p .447 .216 .469 r
F P
0 g
s
.35009 .71091 m .33747 .72504 L .33147 .7181 L p .447 .216 .469 r
F P
0 g
s
.3437 .70443 m .35502 .69017 L .36166 .69632 L p .435 .215 .479 r
F P
0 g
s
.36166 .69632 m .35009 .71091 L .3437 .70443 L p .435 .215 .479 r
F P
0 g
s
.37234 .68176 m .36166 .69632 L .35502 .69017 L p .427 .215 .487 r
F P
0 g
s
.37616 .66149 m .38601 .64964 L .39212 .65643 L p .439 .215 .475 r
F P
0 g
s
.39212 .65643 m .38254 .66797 L .37616 .66149 L p .439 .215 .475 r
F P
0 g
s
.38601 .64964 m .39651 .6383 L .40237 .64534 L p .45 .215 .465 r
F P
0 g
s
.40237 .64534 m .39212 .65643 L .38601 .64964 L p .45 .215 .465 r
F P
0 g
s
.39651 .6383 m .40735 .62761 L .41286 .63498 L p .46 .216 .457 r
F P
0 g
s
.41286 .63498 m .40237 .64534 L .39651 .6383 L p .46 .216 .457 r
F P
0 g
s
.40735 .62761 m .41891 .61753 L .42415 .62511 L p .473 .219 .447 r
F P
0 g
s
.42415 .62511 m .41286 .63498 L .40735 .62761 L p .473 .219 .447 r
F P
0 g
s
.41891 .61753 m .42998 .60871 L .43471 .61666 L p .483 .221 .44 r
F P
0 g
s
.43471 .61666 m .42415 .62511 L .41891 .61753 L p .483 .221 .44 r
F P
0 g
s
.42998 .60871 m .44161 .6008 L .44575 .60912 L p .5 .226 .429 r
F P
0 g
s
.44575 .60912 m .43471 .61666 L .42998 .60871 L p .5 .226 .429 r
F P
0 g
s
.87712 .35697 m .87464 .38464 L .8569 .38286 L p .709 .563 .688 r
F P
0 g
s
.66865 .56953 m .66171 .58429 L .65303 .58003 L p .421 .254 .547 r
F P
0 g
s
.70868 .42521 m .70927 .40757 L .71884 .41143 L p .4 .32 .651 r
F P
0 g
s
.71884 .41143 m .71844 .4253 L .70868 .42521 L p .4 .32 .651 r
F P
0 g
s
.87464 .38464 m .87712 .35697 L .88752 .35689 L p .418 .309 .622 r
F P
0 g
s
.88898 .31662 m .88752 .35689 L .87712 .35697 L p .419 .335 .655 r
F P
0 g
s
.72957 .74073 m .73372 .7424 L .73411 .75026 L p .591 .744 .949 r
F P
0 g
s
.76432 .7508 m .73411 .75026 L .73372 .7424 L p .614 .754 .945 r
F P
0 g
s
.76194 .74351 m .76432 .7508 L p .74221 .74473 L .614 .754 .945 r
F P
0 g
s
.73372 .7424 m .76194 .74351 L p .74221 .74473 L .614 .754 .945 r
F P
0 g
s
.73411 .75026 m .76432 .7508 L .76839 .76816 L p .692 .565 .707 r
F P
0 g
s
.79456 .74387 m .76432 .7508 L .76194 .74351 L p .688 .817 .944 r
F P
0 g
s
.76432 .7508 m .79456 .74387 L .80184 .76016 L p .692 .568 .71 r
F P
0 g
s
.80184 .76016 m .76839 .76816 L .76432 .7508 L p .692 .568 .71 r
F P
0 g
s
.79081 .73733 m .79456 .74387 L p .76958 .74359 L .688 .817 .944 r
F P
0 g
s
.76194 .74351 m .79081 .73733 L p .76958 .74359 L .688 .817 .944 r
F P
0 g
s
.82386 .73098 m .79456 .74387 L .79081 .73733 L p .746 .855 .93 r
F P
0 g
s
.79456 .74387 m .82386 .73098 L .83415 .74558 L p .694 .571 .713 r
F P
0 g
s
.83415 .74558 m .80184 .76016 L .79456 .74387 L p .694 .571 .713 r
F P
0 g
s
.81886 .72546 m .82386 .73098 L p .79904 .73575 L .746 .855 .93 r
F P
0 g
s
.79081 .73733 m .81886 .72546 L p .79904 .73575 L .746 .855 .93 r
F P
0 g
s
.85092 .71217 m .82386 .73098 L .81886 .72546 L p .802 .881 .903 r
F P
0 g
s
.82386 .73098 m .85092 .71217 L .86289 .72543 L p .695 .574 .716 r
F P
0 g
s
.86289 .72543 m .83415 .74558 L .82386 .73098 L p .695 .574 .716 r
F P
0 g
s
.84532 .70733 m .85092 .71217 L p .82431 .7232 L .802 .881 .903 r
F P
0 g
s
.81886 .72546 m .84532 .70733 L p .82431 .7232 L .802 .881 .903 r
F P
0 g
s
.87659 .68928 m .85092 .71217 L .84532 .70733 L p .835 .89 .88 r
F P
0 g
s
.85092 .71217 m .87659 .68928 L .89069 .70028 L p .697 .576 .716 r
F P
0 g
s
.89069 .70028 m .86289 .72543 L .85092 .71217 L p .697 .576 .716 r
F P
0 g
s
.8702 .68564 m .87659 .68928 L p .85285 .70299 L .835 .89 .88 r
F P
0 g
s
.84532 .70733 m .8702 .68564 L p .85285 .70299 L .835 .89 .88 r
F P
0 g
s
.89789 .66237 m .87659 .68928 L .8702 .68564 L p .876 .892 .841 r
F P
0 g
s
.87659 .68928 m .89789 .66237 L .91366 .67083 L p .698 .579 .718 r
F P
0 g
s
.91366 .67083 m .89069 .70028 L .87659 .68928 L p .698 .579 .718 r
F P
0 g
s
.89093 .66 m .89789 .66237 L p .87677 .68012 L .876 .892 .841 r
F P
0 g
s
.8702 .68564 m .89093 .66 L p .87677 .68012 L .876 .892 .841 r
F P
0 g
s
.91475 .63146 m .89789 .66237 L .89093 .66 L p .91 .883 .795 r
F P
0 g
s
.89789 .66237 m .91475 .63146 L .93159 .63753 L p .7 .582 .719 r
F P
0 g
s
.93159 .63753 m .91366 .67083 L .89789 .66237 L p .7 .582 .719 r
F P
0 g
s
.90749 .63023 m .91475 .63146 L p .89614 .65376 L .91 .883 .795 r
F P
0 g
s
.89093 .66 m .90749 .63023 L p .89614 .65376 L .91 .883 .795 r
F P
0 g
s
.92735 .59732 m .91475 .63146 L .90749 .63023 L p .932 .866 .751 r
F P
0 g
s
.91475 .63146 m .92735 .59732 L .94452 .60245 L p .702 .584 .72 r
F P
0 g
s
.94452 .60245 m .93159 .63753 L .91475 .63146 L p .702 .584 .72 r
F P
0 g
s
.92005 .59645 m .92735 .59732 L p .9094 .62706 L .932 .866 .751 r
F P
0 g
s
.90749 .63023 m .92005 .59645 L p .9094 .62706 L .932 .866 .751 r
F P
0 g
s
.93782 .56314 m .92735 .59732 L .92005 .59645 L p .939 .857 .733 r
F P
0 g
s
.92735 .59732 m .93782 .56314 L .95557 .56571 L p .703 .585 .72 r
F P
0 g
s
.95557 .56571 m .94452 .60245 L .92735 .59732 L p .703 .585 .72 r
F P
0 g
s
.93045 .56347 m .93782 .56314 L p .92391 .58921 L .939 .857 .733 r
F P
0 g
s
.92005 .59645 m .93045 .56347 L p .92391 .58921 L .939 .857 .733 r
F P
0 g
s
.94312 .52834 m .93782 .56314 L .93045 .56347 L p .952 .829 .686 r
F P
0 g
s
.93782 .56314 m .94312 .52834 L .96106 .52785 L p .705 .587 .721 r
F P
0 g
s
.96106 .52785 m .95557 .56571 L .93782 .56314 L p .705 .587 .721 r
F P
0 g
s
.93589 .53011 m .94312 .52834 L p .93353 .55494 L .952 .829 .686 r
F P
0 g
s
.93045 .56347 m .93589 .53011 L p .93353 .55494 L .952 .829 .686 r
F P
0 g
s
.94242 .4939 m .94312 .52834 L .93589 .53011 L p .958 .788 .629 r
F P
0 g
s
.94312 .52834 m .94242 .4939 L .96002 .49033 L p .707 .589 .721 r
F P
0 g
s
.96002 .49033 m .96106 .52785 L .94312 .52834 L p .707 .589 .721 r
F P
0 g
s
.93558 .49705 m .94242 .4939 L p .93747 .52132 L .958 .788 .629 r
F P
0 g
s
.93589 .53011 m .93558 .49705 L p .93747 .52132 L .958 .788 .629 r
F P
0 g
s
.93565 .45939 m .94242 .4939 L .93558 .49705 L p .953 .737 .572 r
F P
0 g
s
.94242 .4939 m .93565 .45939 L .95274 .45381 L p .71 .591 .721 r
F P
0 g
s
.95274 .45381 m .96002 .49033 L .94242 .4939 L p .71 .591 .721 r
F P
0 g
s
.92922 .46348 m .93565 .45939 L p .93559 .49034 L .953 .737 .572 r
F P
0 g
s
.93558 .49705 m .92922 .46348 L p .93559 .49034 L .953 .737 .572 r
F P
0 g
s
.92599 .42915 m .93565 .45939 L .92922 .46348 L p .945 .701 .536 r
F P
0 g
s
.93565 .45939 m .92599 .42915 L .94166 .42032 L p .712 .593 .721 r
F P
0 g
s
.94166 .42032 m .95274 .45381 L .93565 .45939 L p .712 .593 .721 r
F P
0 g
s
.9205 .43466 m .92599 .42915 L p .92842 .455 L .945 .701 .536 r
F P
0 g
s
.92922 .46348 m .9205 .43466 L p .92842 .455 L .945 .701 .536 r
F P
0 g
s
.91075 .40173 m .92599 .42915 L .9205 .43466 L p .921 .632 .478 r
F P
0 g
s
.92599 .42915 m .91075 .40173 L .92442 .39001 L p .714 .594 .72 r
F P
0 g
s
.92442 .39001 m .94166 .42032 L .92599 .42915 L p .714 .594 .72 r
F P
0 g
s
.90646 .40846 m .91075 .40173 L p .91819 .42688 L .921 .632 .478 r
F P
0 g
s
.9205 .43466 m .90646 .40846 L p .91819 .42688 L .921 .632 .478 r
F P
0 g
s
.89189 .37942 m .91075 .40173 L .90646 .40846 L p .887 .562 .429 r
F P
0 g
s
.91075 .40173 m .89189 .37942 L .902 .36451 L p .717 .595 .719 r
F P
0 g
s
.902 .36451 m .92442 .39001 L .91075 .40173 L p .717 .595 .719 r
F P
0 g
s
.88961 .3874 m .89189 .37942 L p .90244 .40045 L .887 .562 .429 r
F P
0 g
s
.90646 .40846 m .88961 .3874 L p .90244 .40045 L .887 .562 .429 r
F P
0 g
s
.88752 .35689 m .88518 .38343 L .87464 .38464 L p .418 .309 .622 r
F P
0 g
s
.88518 .38343 m .88752 .35689 L .88008 .35609 L p .954 .788 .637 r
F P
0 g
s
.88008 .35609 m .87792 .38041 L .88518 .38343 L p .954 .788 .637 r
F P
0 g
s
.87792 .38041 m .88008 .35609 L .86214 .35538 L p .709 .561 .685 r
F P
0 g
s
.87022 .36393 m .89189 .37942 L .88961 .3874 L p .831 .473 .379 r
F P
0 g
s
.86368 .31824 m .86214 .35538 L .88008 .35609 L p .707 .577 .707 r
F P
0 g
s
.89189 .37942 m .87022 .36393 L .87516 .34659 L p .72 .595 .716 r
F P
0 g
s
.88752 .35689 m .88898 .31662 L .88157 .31677 L p .953 .788 .64 r
F P
0 g
s
.88157 .31677 m .88008 .35609 L .88752 .35689 L p .953 .788 .64 r
F P
0 g
s
.88008 .35609 m .88157 .31677 L .86368 .31824 L p .707 .577 .707 r
F P
0 g
s
.87516 .34659 m .902 .36451 L .89189 .37942 L p .72 .595 .716 r
F P
0 g
s
.8696 .4105 m .87464 .38464 L .88518 .38343 L p .421 .293 .599 r
F P
0 g
s
.88518 .38343 m .88017 .41027 L .8696 .4105 L p .421 .293 .599 r
F P
0 g
s
.88017 .41027 m .88518 .38343 L .87792 .38041 L p .951 .81 .668 r
F P
0 g
s
.86214 .35538 m .86005 .37862 L .87792 .38041 L p .709 .561 .685 r
F P
0 g
s
.86921 .37221 m .86923 .37204 L p .87104 .3734 L .831 .473 .379 r
F P
0 g
s
.86923 .37204 m .87022 .36393 L p .88428 .38095 L .831 .473 .379 r
F P
0 g
s
.88428 .38095 m .88961 .3874 L .86923 .37204 L .831 .473 .379 r
F
.86525 .37044 m .86407 .36188 L p .86877 .37132 L .734 .362 .347 r
F P
0 g
s
.86877 .37132 m .86921 .37221 L .86525 .37044 L .734 .362 .347 r
F
.86005 .37862 m .86214 .35538 L .85179 .35547 L p .414 .303 .618 r
F P
0 g
s
.86407 .36188 m .87022 .36393 L .86921 .37221 L p .734 .362 .347 r
F P
0 g
s
.85921 .37005 m .85658 .36156 L p .86469 .36991 L .656 .295 .348 r
F P
0 g
s
.86469 .36991 m .86526 .37051 L .85921 .37005 L .656 .295 .348 r
F
.85179 .35547 m .84957 .37986 L .86005 .37862 L p .414 .303 .618 r
F P
0 g
s
.85658 .36156 m .86407 .36188 L .86526 .37051 L p .656 .295 .348 r
F P
0 g
s
.85214 .37087 m .84825 .3626 L p .85852 .36962 L .61 .265 .36 r
F P
0 g
s
.85852 .36962 m .85922 .3701 L .85214 .37087 L .61 .265 .36 r
F
.84825 .3626 m .85658 .36156 L .85922 .3701 L p F P
0 g
s
.84369 .37327 m .83931 .36517 L p .85175 .3707 L .57 .244 .377 r
F P
0 g
s
.85175 .3707 m .85214 .37087 L .84369 .37327 L .57 .244 .377 r
F
.83931 .36517 m .84825 .3626 L .85214 .37087 L p F P
0 g
s
.83283 .37709 m .82783 .36923 L p .84289 .37308 L .556 .239 .385 r
F P
0 g
s
.84289 .37308 m .8437 .37328 L .83283 .37709 L .556 .239 .385 r
F
.82783 .36923 m .83931 .36517 L .8437 .37328 L p F P
0 g
s
.83283 .3771 m .822 .3819 L .822 .3819 L p .538 .232 .397 r
F P
0 g
s
.822 .3819 m .81655 .37426 L p .83216 .37698 L .538 .232 .397 r
F P
0 g
s
.83216 .37698 m .83283 .3771 L .822 .3819 L .538 .232 .397 r
F
.81655 .37426 m .82783 .36923 L .83262 .37676 L p F P
0 g
s
.83262 .37676 m .83283 .3771 L p .83217 .37698 L .538 .232 .397 r
F P
0 g
s
.81655 .37426 m .83262 .37676 L .83217 .37698 L .538 .232 .397 r
F
.81057 .38789 m .80502 .38031 L p .82178 .38188 L .524 .229 .408 r
F P
0 g
s
.82178 .38188 m .822 .3819 L .81057 .38789 L .524 .229 .408 r
F
.80502 .38031 m .81655 .37426 L .822 .3819 L p F P
0 g
s
.81057 .3879 m .79829 .39461 L .79311 .38683 L p .52 .228 .411 r
F P
0 g
s
.79311 .38683 m .80502 .38031 L .81057 .3879 L p .52 .228 .411 r
F P
0 g
s
.81057 .3879 m .80744 .37961 L p .79841 .39441 L .784 .848 .9 r
F P
0 g
s
.79829 .39461 m .81057 .3879 L p .79841 .39441 L .784 .848 .9 r
F P
0 g
s
.81057 .3879 m .81057 .38789 L p .81094 .3877 L .524 .229 .408 r
F P
0 g
s
.822 .3819 m .81057 .3879 L p .81094 .3877 L .524 .229 .408 r
F P
0 g
s
.80744 .37961 m .79544 .38617 L .79825 .3945 L p .784 .848 .9 r
F P
0 g
s
.79825 .3945 m .79829 .39461 L p .79841 .39441 L .784 .848 .9 r
F P
0 g
s
.79841 .39441 m .80744 .37961 L .79825 .3945 L .784 .848 .9 r
F
.822 .3819 m .81907 .37351 L p .81093 .38729 L .78 .846 .902 r
F P
0 g
s
.81057 .3879 m .82175 .38204 L p .81093 .38729 L .78 .846 .902 r
F P
0 g
s
.82175 .38204 m .822 .3819 L p .81093 .38729 L .78 .846 .902 r
F P
0 g
s
.81907 .37351 m .80744 .37961 L .81043 .38752 L p .78 .846 .902 r
F P
0 g
s
.81043 .38752 m .81057 .3879 L p .81095 .38726 L .78 .846 .902 r
F P
0 g
s
.81095 .38726 m .81907 .37351 L .81043 .38752 L .78 .846 .902 r
F
.83283 .3771 m .83044 .36844 L p .82243 .38123 L .763 .838 .909 r
F P
0 g
s
.822 .3819 m .83283 .3771 L p .82243 .38123 L .763 .838 .909 r
F P
0 g
s
.83283 .3771 m .83283 .37709 L p .83304 .37701 L .556 .239 .385 r
F P
0 g
s
.8437 .37328 m .83283 .3771 L p .83304 .37701 L .556 .239 .385 r
F P
0 g
s
.83044 .36844 m .81907 .37351 L .82185 .38146 L p .763 .838 .909 r
F P
0 g
s
.82185 .38146 m .822 .3819 L p .82243 .38123 L .763 .838 .909 r
F P
0 g
s
.82243 .38123 m .83044 .36844 L .82185 .38146 L .763 .838 .909 r
F
.84825 .3626 m .83931 .36517 L .83326 .34819 L p .707 .577 .707 r
F P
0 g
s
.8437 .37328 m .84201 .36434 L p .83317 .37663 L .742 .825 .916 r
F P
0 g
s
.83283 .3771 m .8437 .37328 L p .83317 .37663 L .742 .825 .916 r
F P
0 g
s
.8437 .37328 m .84369 .37327 L p .84414 .37314 L .57 .244 .377 r
F P
0 g
s
.85214 .37087 m .8437 .37328 L p .84414 .37314 L .57 .244 .377 r
F P
0 g
s
.84201 .36434 m .83044 .36844 L .83274 .37677 L p .742 .825 .916 r
F P
0 g
s
.83274 .37677 m .83283 .3771 L p .83317 .37663 L .742 .825 .916 r
F P
0 g
s
.83317 .37663 m .84201 .36434 L .83274 .37677 L .742 .825 .916 r
F
.85658 .36156 m .84825 .3626 L .84324 .34528 L p .707 .577 .707 r
F P
0 g
s
.85214 .37087 m .85102 .36176 L p .84426 .3724 L .726 .814 .92 r
F P
0 g
s
.8437 .37328 m .85214 .37087 L p .84426 .3724 L .726 .814 .92 r
F P
0 g
s
.85214 .37087 m .85214 .37087 L p .85224 .37085 L .61 .265 .36 r
F P
0 g
s
.85922 .3701 m .85214 .37087 L p .85224 .37085 L .61 .265 .36 r
F P
0 g
s
.83326 .34819 m .84324 .34528 L .84825 .3626 L p .707 .577 .707 r
F P
0 g
s
.85102 .36176 m .84201 .36434 L .84356 .37254 L p .726 .814 .92 r
F P
0 g
s
.84356 .37254 m .8437 .37328 L p .84426 .3724 L .726 .814 .92 r
F P
0 g
s
.84426 .3724 m .85102 .36176 L .84356 .37254 L .726 .814 .92 r
F
.85334 .31957 m .85179 .35547 L .86214 .35538 L p .415 .33 .652 r
F P
0 g
s
.86407 .36188 m .85658 .36156 L .85414 .3437 L p .707 .577 .707 r
F P
0 g
s
.85922 .3701 m .85942 .36071 L p .85262 .37021 L .681 .78 .926 r
F P
0 g
s
.85214 .37087 m .85922 .3701 L p .85262 .37021 L .681 .78 .926 r
F P
0 g
s
.85922 .3701 m .85921 .37005 L p .85978 .37009 L .656 .295 .348 r
F P
0 g
s
.86526 .37051 m .85922 .3701 L p .85978 .37009 L .656 .295 .348 r
F P
0 g
s
.84324 .34528 m .85414 .3437 L .85658 .36156 L p .707 .577 .707 r
F P
0 g
s
.85942 .36071 m .85102 .36176 L .85206 .37022 L p .681 .78 .926 r
F P
0 g
s
.85206 .37022 m .85214 .37087 L p .85262 .37021 L .681 .78 .926 r
F P
0 g
s
.85262 .37021 m .85942 .36071 L .85206 .37022 L .681 .78 .926 r
F
.87022 .36393 m .86407 .36188 L .86456 .34386 L p .707 .577 .707 r
F P
0 g
s
.86526 .37051 m .86696 .36103 L p .86005 .36913 L .635 .739 .923 r
F P
0 g
s
.85922 .3701 m .86526 .37051 L p .86005 .36913 L .635 .739 .923 r
F P
0 g
s
.86526 .37051 m .86525 .37044 L p .86561 .3706 L .734 .362 .347 r
F P
0 g
s
.86921 .37221 m .86526 .37051 L p .86561 .3706 L .734 .362 .347 r
F P
0 g
s
.86214 .35538 m .86368 .31824 L .85334 .31957 L p .415 .33 .652 r
F P
0 g
s
.85414 .3437 m .86456 .34386 L .86407 .36188 L p .707 .577 .707 r
F P
0 g
s
.86696 .36103 m .85942 .36071 L .85925 .36893 L p .635 .739 .923 r
F P
0 g
s
.85925 .36893 m .85922 .3701 L p .86005 .36913 L .635 .739 .923 r
F P
0 g
s
.86005 .36913 m .86696 .36103 L .85925 .36893 L .635 .739 .923 r
F
.86921 .37221 m .87317 .36309 L p .8658 .37 L .553 .648 .897 r
F P
0 g
s
.86526 .37051 m .86921 .37221 L p .8658 .37 L .553 .648 .897 r
F P
0 g
s
.88961 .3874 m .86921 .37221 L p .87104 .3734 L .831 .473 .379 r
F P
0 g
s
.86456 .34386 m .87516 .34659 L .87022 .36393 L p .707 .577 .707 r
F P
0 g
s
.87317 .36309 m .86696 .36103 L .86539 .36976 L p .553 .648 .897 r
F P
0 g
s
.86539 .36976 m .86526 .37051 L p .8658 .37 L .553 .648 .897 r
F P
0 g
s
.8658 .37 m .87317 .36309 L .86539 .36976 L .553 .648 .897 r
F
.88961 .3874 m .89749 .38041 L p .87685 .37443 L .522 .603 .876 r
F P
0 g
s
.86921 .37221 m .88961 .3874 L p .87685 .37443 L .522 .603 .876 r
F P
0 g
s
.90646 .40846 m .91592 .40344 L p .89522 .39082 L .477 .529 .832 r
F P
0 g
s
.88961 .3874 m .90646 .40846 L p .89522 .39082 L .477 .529 .832 r
F P
0 g
s
.9205 .43466 m .93075 .4313 L p .9125 .41414 L .452 .477 .794 r
F P
0 g
s
.90646 .40846 m .9205 .43466 L p .9125 .41414 L .452 .477 .794 r
F P
0 g
s
.92922 .46348 m .93996 .46197 L p .92332 .43862 L .433 .425 .75 r
F P
0 g
s
.9205 .43466 m .92922 .46348 L p .92332 .43862 L .433 .425 .75 r
F P
0 g
s
.93558 .49705 m .94643 .49663 L p .93363 .47197 L .426 .397 .723 r
F P
0 g
s
.92922 .46348 m .93558 .49705 L p .93363 .47197 L .426 .397 .723 r
F P
0 g
s
.93589 .53011 m .94668 .5314 L p .93825 .50529 L .422 .358 .681 r
F P
0 g
s
.93558 .49705 m .93589 .53011 L p .93825 .50529 L .422 .358 .681 r
F P
0 g
s
.93045 .56347 m .94091 .56639 L p .93696 .53784 L .423 .326 .64 r
F P
0 g
s
.93589 .53011 m .93045 .56347 L p .93696 .53784 L .423 .326 .64 r
F P
0 g
s
.92005 .59645 m .93 .60075 L p .93041 .56667 L .429 .303 .605 r
F P
0 g
s
.93045 .56347 m .92005 .59645 L p .93041 .56667 L .429 .303 .605 r
F P
0 g
s
.90749 .63023 m .91716 .63511 L p .91936 .60561 L .433 .295 .593 r
F P
0 g
s
.92005 .59645 m .90749 .63023 L p .91936 .60561 L .433 .295 .593 r
F P
0 g
s
.89093 .66 m .89982 .66613 L p .90557 .63922 L .446 .279 .56 r
F P
0 g
s
.90749 .63023 m .89093 .66 L p .90557 .63922 L .446 .279 .56 r
F P
0 g
s
.8702 .68564 m .87796 .69306 L p .88777 .66807 L .467 .266 .524 r
F P
0 g
s
.89093 .66 m .8702 .68564 L p .88777 .66807 L .467 .266 .524 r
F P
0 g
s
.84532 .70733 m .85176 .71582 L p .8669 .69104 L .493 .261 .49 r
F P
0 g
s
.8702 .68564 m .84532 .70733 L p .8669 .69104 L .493 .261 .49 r
F P
0 g
s
.81886 .72546 m .82418 .73461 L p .83962 .71469 L .513 .261 .471 r
F P
0 g
s
.84532 .70733 m .81886 .72546 L p .83962 .71469 L .513 .261 .471 r
F P
0 g
s
.79081 .73733 m .79437 .74715 L p .81278 .73084 L .552 .271 .442 r
F P
0 g
s
.81886 .72546 m .79081 .73733 L p .81278 .73084 L .552 .271 .442 r
F P
0 g
s
.76194 .74351 m .76364 .75365 L p .78265 .74223 L .593 .289 .422 r
F P
0 g
s
.79081 .73733 m .76194 .74351 L p .78265 .74223 L .593 .289 .422 r
F P
0 g
s
.76194 .74351 m .73372 .7424 L .73371 .74256 L p .653 .326 .406 r
F P
0 g
s
.73411 .75026 m .72176 .74701 L .7277 .74223 L p .591 .744 .949 r
F P
0 g
s
.73411 .75026 m .7277 .74223 L .73035 .74237 L .591 .744 .949 r
F
.72176 .74701 m .73411 .75026 L .73387 .76807 L p .741 .613 .716 r
F P
0 g
s
.76839 .76816 m .73387 .76807 L .73411 .75026 L p .692 .565 .707 r
F P
0 g
s
.73371 .74256 m .73309 .75242 L p .76023 .74404 L .653 .326 .406 r
F P
0 g
s
.76194 .74351 m .73371 .74256 L .76023 .74404 L .653 .326 .406 r
F
.7277 .74223 m .72957 .74073 L p .73035 .74237 L .591 .744 .949 r
F P
0 g
s
.73387 .76807 m .71687 .76415 L .72176 .74701 L p .741 .613 .716 r
F P
0 g
s
.71687 .76415 m .73387 .76807 L .73324 .77816 L p .748 .413 .415 r
F P
0 g
s
.73387 .76807 m .76839 .76816 L .77011 .77836 L p .649 .325 .41 r
F P
0 g
s
.77011 .77836 m .73324 .77816 L .73387 .76807 L p .649 .325 .41 r
F P
0 g
s
.47699 .09037 m .45345 .10382 L .44945 .09412 L p .799 .823 .87 r
F P
0 g
s
.44945 .09412 m .47396 .08027 L .47699 .09037 L p .799 .823 .87 r
F P
0 g
s
.14383 .29913 m .1491 .33499 L .14224 .33939 L p .32 .309 .691 r
F P
0 g
s
.14224 .33939 m .13622 .29984 L .14383 .29913 L p .32 .309 .691 r
F P
0 g
s
.14777 .36248 m .14224 .33939 L .1491 .33499 L p .316 .303 .686 r
F P
0 g
s
.13622 .29984 m .14224 .33939 L .12493 .3436 L p .709 .589 .719 r
F P
0 g
s
.14224 .33939 m .14777 .36248 L .13104 .36863 L p .702 .557 .687 r
F P
0 g
s
.13104 .36863 m .12493 .3436 L .14224 .33939 L p .702 .557 .687 r
F P
0 g
s
.12493 .3436 m .11858 .30236 L .13622 .29984 L p .709 .589 .719 r
F P
0 g
s
.11858 .30236 m .12493 .3436 L .11436 .34345 L p .908 .721 .638 r
F P
0 g
s
.12493 .3436 m .13104 .36863 L .12058 .36962 L p .9 .673 .586 r
F P
0 g
s
.12058 .36962 m .11436 .34345 L .12493 .3436 L p .9 .673 .586 r
F P
0 g
s
.50745 .35269 m .50315 .34542 L .50957 .33898 L p .876 .572 .469 r
F P
0 g
s
.50957 .33898 m .51791 .35336 L p .50818 .34794 L .876 .572 .469 r
F P
0 g
s
.51795 .35343 m .50957 .33898 L .52535 .33072 L p .685 .531 .671 r
F P
0 g
s
.50287 .32532 m .50957 .33898 L .50315 .34542 L p .919 .668 .543 r
F P
0 g
s
.50315 .34542 m .49578 .33107 L .50287 .32532 L p .919 .668 .543 r
F P
0 g
s
.49578 .33107 m .50315 .34542 L .51258 .3436 L p .419 .467 .803 r
F P
0 g
s
.50957 .33898 m .50287 .32532 L .5194 .31863 L p .724 .619 .74 r
F P
0 g
s
.5194 .31863 m .52535 .33072 L .50957 .33898 L p .724 .619 .74 r
F P
0 g
s
.51258 .3436 m .50528 .33011 L .49578 .33107 L p .419 .467 .803 r
F P
0 g
s
.52535 .33072 m .53332 .3444 L .51795 .35343 L p .685 .531 .671 r
F P
0 g
s
.53332 .3444 m .52535 .33072 L .53483 .32884 L p .357 .365 .731 r
F P
0 g
s
.51258 .3436 m .52849 .33527 L p .50828 .33078 L .722 .615 .737 r
F P
0 g
s
.50528 .33011 m .5104 .33957 L p .50828 .33078 L .722 .615 .737 r
F P
0 g
s
.5104 .33957 m .51258 .3436 L p .50828 .33078 L .722 .615 .737 r
F P
0 g
s
.51795 .35343 m .50745 .35269 L p .50818 .34794 L .876 .572 .469 r
F P
0 g
s
.51791 .35336 m .51795 .35343 L p .50818 .34794 L .876 .572 .469 r
F P
0 g
s
.50315 .34542 m .50745 .35269 L .51157 .3444 L p .367 .38 .741 r
F P
0 g
s
.51235 .34283 m .51258 .3436 L .50353 .34535 L p .367 .38 .741 r
F P
0 g
s
.51157 .3444 m .51235 .34283 L p .51126 .34314 L .367 .38 .741 r
F P
0 g
s
.50353 .34535 m .50315 .34542 L p .50349 .34533 L .367 .38 .741 r
F P
0 g
s
.50349 .34533 m .51235 .34283 L .50353 .34535 L .367 .38 .741 r
F
.50315 .34542 m .51157 .3444 L .51126 .34314 L F
.52535 .33072 m .5194 .31863 L .52876 .31765 L p .425 .479 .812 r
F P
0 g
s
.52888 .31788 m .52535 .33072 L .52876 .31765 L .425 .479 .812 r
F
.52895 .31762 m .53483 .32884 L .52535 .33072 L p F P
0 g
s
.52849 .33527 m .52193 .32336 L .50528 .33011 L p .722 .615 .737 r
F P
0 g
s
.51258 .3436 m .51235 .34283 L .52678 .33435 L p .783 .932 .93 r
F P
0 g
s
.52539 .32489 m .52802 .33443 L .53468 .329 L .916 .658 .534 r
F
.52193 .32336 m .52635 .33139 L p .52539 .32489 L F P
0 g
s
.52635 .33139 m .52802 .33443 L p .52539 .32489 L .916 .658 .534 r
F P
0 g
s
.52678 .33435 m .52783 .33373 L p .52687 .33435 L .783 .932 .93 r
F P
0 g
s
.51258 .3436 m .52678 .33435 L .52687 .33435 L .783 .932 .93 r
F
.52802 .33443 m .52849 .33527 L .52923 .33452 L p .916 .658 .534 r
F P
0 g
s
.52923 .33452 m .53468 .329 L p .52802 .33443 L .916 .658 .534 r
F P
0 g
s
.5383 .33455 m .53332 .3444 L p .53474 .32985 L .357 .365 .731 r
F P
0 g
s
.53483 .32884 m .5383 .33455 L p .53474 .32985 L .357 .365 .731 r
F P
0 g
s
.5383 .33455 m .53483 .32884 L .53229 .33142 L p .872 .833 .806 r
F P
0 g
s
.53229 .33142 m .52849 .33527 L p .5383 .33455 L .872 .833 .806 r
F P
0 g
s
.5379 .34915 m .53332 .3444 L .5383 .33455 L p .359 .388 .755 r
F P
0 g
s
.54176 .33878 m .5379 .34915 L p .53828 .33528 L .359 .388 .755 r
F P
0 g
s
.5383 .33455 m .54176 .33878 L p .53828 .33528 L .359 .388 .755 r
F P
0 g
s
.54302 .35301 m .5379 .34915 L .54176 .33878 L p .373 .428 .789 r
F P
0 g
s
.54548 .34219 m .54302 .35301 L p .54182 .33943 L .373 .428 .789 r
F P
0 g
s
.54176 .33878 m .54548 .34219 L p .54182 .33943 L .373 .428 .789 r
F P
0 g
s
.54857 .35594 m .54302 .35301 L .54548 .34219 L p .397 .476 .824 r
F P
0 g
s
.54954 .3449 m .54857 .35594 L p .54554 .34245 L .397 .476 .824 r
F P
0 g
s
.54548 .34219 m .54954 .3449 L p .54554 .34245 L .397 .476 .824 r
F P
0 g
s
.5545 .35857 m .54857 .35594 L .54954 .3449 L p .423 .517 .85 r
F P
0 g
s
.55422 .34744 m .5545 .35857 L p .54988 .34581 L .423 .517 .85 r
F P
0 g
s
.54954 .3449 m .55422 .34744 L p .54988 .34581 L .423 .517 .85 r
F P
0 g
s
.56044 .35974 m .5545 .35857 L .55422 .34744 L p .448 .564 .879 r
F P
0 g
s
.55849 .34881 m .56044 .35974 L p .55444 .34787 L .448 .564 .879 r
F P
0 g
s
.55422 .34744 m .55849 .34881 L p .55444 .34787 L .448 .564 .879 r
F P
0 g
s
.56653 .36008 m .56044 .35974 L .55849 .34881 L p .488 .616 .904 r
F P
0 g
s
.56306 .34957 m .56653 .36008 L p .5589 .34938 L .488 .616 .904 r
F P
0 g
s
.55849 .34881 m .56306 .34957 L p .5589 .34938 L .488 .616 .904 r
F P
0 g
s
.57249 .35928 m .56653 .36008 L .56306 .34957 L p .531 .67 .926 r
F P
0 g
s
.56742 .34952 m .57249 .35928 L p .56321 .34974 L .531 .67 .926 r
F P
0 g
s
.56306 .34957 m .56742 .34952 L p .56321 .34974 L .531 .67 .926 r
F P
0 g
s
.57866 .35781 m .57249 .35928 L .56742 .34952 L p .585 .719 .936 r
F P
0 g
s
.57263 .34886 m .57866 .35781 L p .56789 .34987 L .585 .719 .936 r
F P
0 g
s
.56742 .34952 m .57263 .34886 L p .56789 .34987 L .585 .719 .936 r
F P
0 g
s
.58485 .35544 m .57866 .35781 L .57263 .34886 L p .628 .759 .941 r
F P
0 g
s
.57771 .34746 m .58485 .35544 L p .57282 .34896 L .628 .759 .941 r
F P
0 g
s
.57263 .34886 m .57771 .34746 L p .57282 .34896 L .628 .759 .941 r
F P
0 g
s
.59123 .35252 m .58485 .35544 L .57771 .34746 L p .668 .787 .938 r
F P
0 g
s
.58348 .34531 m .59123 .35252 L p .57804 .34758 L .668 .787 .938 r
F P
0 g
s
.57771 .34746 m .58348 .34531 L p .57804 .34758 L .668 .787 .938 r
F P
0 g
s
.59768 .34901 m .59123 .35252 L .58348 .34531 L p .697 .807 .934 r
F P
0 g
s
.58348 .34531 m .58938 .34254 L .59768 .34901 L p .697 .807 .934 r
F P
0 g
s
.58348 .34531 m .58149 .35519 L p .58912 .34297 L .474 .181 .388 r
F P
0 g
s
.58938 .34254 m .58348 .34531 L p .58912 .34297 L .474 .181 .388 r
F P
0 g
s
.57771 .34746 m .57445 .35706 L p .5831 .34581 L .499 .19 .373 r
F P
0 g
s
.58348 .34531 m .57771 .34746 L p .5831 .34581 L .499 .19 .373 r
F P
0 g
s
.57263 .34886 m .56793 .35785 L p .57733 .34786 L .532 .205 .359 r
F P
0 g
s
.57771 .34746 m .57263 .34886 L p .57733 .34786 L .532 .205 .359 r
F P
0 g
s
.56742 .34952 m .56113 .3577 L p .57209 .34927 L .572 .227 .345 r
F P
0 g
s
.57263 .34886 m .56742 .34952 L p .57209 .34927 L .572 .227 .345 r
F P
0 g
s
.56306 .34957 m .55542 .35655 L p .567 .34976 L .615 .257 .339 r
F P
0 g
s
.56742 .34952 m .56306 .34957 L p .567 .34976 L .615 .257 .339 r
F P
0 g
s
.55849 .34881 m .54984 .35453 L p .56258 .34975 L .662 .293 .335 r
F P
0 g
s
.56306 .34957 m .55849 .34881 L p .56258 .34975 L .662 .293 .335 r
F P
0 g
s
.55422 .34744 m .54473 .35171 L p .55809 .34889 L .708 .336 .342 r
F P
0 g
s
.55849 .34881 m .55422 .34744 L p .55809 .34889 L .708 .336 .342 r
F P
0 g
s
.54954 .3449 m .53969 .34814 L p .55375 .34746 L .747 .374 .347 r
F P
0 g
s
.55422 .34744 m .54954 .3449 L p .55375 .34746 L .747 .374 .347 r
F P
0 g
s
.54548 .34219 m .53519 .34394 L p .54904 .34486 L .783 .419 .369 r
F P
0 g
s
.54954 .3449 m .54548 .34219 L p .54904 .34486 L .783 .419 .369 r
F P
0 g
s
.54176 .33878 m .53131 .33919 L p .54504 .34209 L .818 .467 .391 r
F P
0 g
s
.54548 .34219 m .54176 .33878 L p .54504 .34209 L .818 .467 .391 r
F P
0 g
s
.52849 .33527 m .52783 .33373 L .5383 .33455 L p .872 .833 .806 r
F P
0 g
s
.5383 .33455 m .52783 .33373 L p .54143 .33866 L .849 .512 .416 r
F P
0 g
s
.54176 .33878 m .5383 .33455 L p .54143 .33866 L .849 .512 .416 r
F P
0 g
s
.52783 .33373 m .52849 .33527 L .51258 .3436 L p .783 .932 .93 r
F P
0 g
s
.53131 .33919 m .52783 .33373 L .52678 .33435 L p .667 .505 .655 r
F P
0 g
s
.52678 .33435 m .51235 .34283 L p .5276 .3399 L .667 .505 .655 r
F P
0 g
s
.5276 .3399 m .53131 .33919 L .52678 .33435 L .667 .505 .655 r
F
.53468 .329 m .53483 .32884 L p .53453 .32871 L .916 .658 .534 r
F P
0 g
s
.52193 .32336 m .53468 .329 L .53453 .32871 L .916 .658 .534 r
F
.52876 .31765 m .52895 .31762 L p .52888 .31788 L .425 .479 .812 r
F P
0 g
s
.70965 .39474 m .70927 .40757 L .69147 .4068 L p .704 .608 .746 r
F P
0 g
s
.70927 .40757 m .70965 .39474 L .71953 .39786 L p .392 .338 .678 r
F P
0 g
s
.71953 .39786 m .71884 .41143 L .70927 .40757 L p .392 .338 .678 r
F P
0 g
s
.46401 .56976 m .47432 .56597 L .4797 .58296 L p .654 .551 .726 r
F P
0 g
s
.4797 .58296 m .4709 .58619 L .46401 .56976 L p .654 .551 .726 r
F P
0 g
s
.4709 .58619 m .4797 .58296 L .47822 .59296 L p .485 .201 .406 r
F P
0 g
s
.47799 .59305 m .4709 .58619 L .47822 .59296 L .485 .201 .406 r
F
.47818 .59323 m .47027 .59655 L .4709 .58619 L p F P
0 g
s
.47123 .58646 m .46268 .59043 L .47004 .59636 L p .719 .824 .93 r
F P
0 g
s
.47004 .59636 m .47027 .59655 L p .4703 .59625 L .719 .824 .93 r
F P
0 g
s
.47123 .58646 m .47004 .59636 L .4703 .59625 L .719 .824 .93 r
F
.47822 .59296 m .47818 .59323 L p .47799 .59305 L .485 .201 .406 r
F P
0 g
s
.61271 .35586 m .6106 .34842 L .61675 .34006 L p .92 .668 .541 r
F P
0 g
s
.61675 .34006 m .62222 .35882 L .61699 .3572 L p .92 .668 .541 r
F P
0 g
s
.61675 .34006 m .61699 .3572 L .61365 .35218 L .92 .668 .541 r
F
.62222 .35882 m .61675 .34006 L .63372 .33462 L p .701 .556 .687 r
F P
0 g
s
.6146 .33451 m .61675 .34006 L .6106 .34842 L p .945 .742 .598 r
F P
0 g
s
.60915 .34336 m .6146 .33451 L p .6107 .34808 L .945 .742 .598 r
F P
0 g
s
.6106 .34842 m .60915 .34336 L p .6107 .34808 L .945 .742 .598 r
F P
0 g
s
.61198 .32923 m .6146 .33451 L .60915 .34336 L p .941 .718 .573 r
F P
0 g
s
.60743 .33865 m .61198 .32923 L p .60923 .34295 L .941 .718 .573 r
F P
0 g
s
.60915 .34336 m .60743 .33865 L p .60923 .34295 L .941 .718 .573 r
F P
0 g
s
.61675 .34006 m .6146 .33451 L .63112 .32778 L p .725 .647 .771 r
F P
0 g
s
.63112 .32778 m .63372 .33462 L .61675 .34006 L p .725 .647 .771 r
F P
0 g
s
.60901 .32459 m .61198 .32923 L .60743 .33865 L p .933 .688 .544 r
F P
0 g
s
.60551 .33447 m .60901 .32459 L p .60746 .33837 L .933 .688 .544 r
F P
0 g
s
.60743 .33865 m .60551 .33447 L p .60746 .33837 L .933 .688 .544 r
F P
0 g
s
.6146 .33451 m .61198 .32923 L .62784 .32104 L p .73 .65 .769 r
F P
0 g
s
.62784 .32104 m .63112 .32778 L .6146 .33451 L p .73 .65 .769 r
F P
0 g
s
.60493 .31911 m .60901 .32459 L .60551 .33447 L p .927 .66 .513 r
F P
0 g
s
.60551 .33447 m .60285 .33011 L .60493 .31911 L p .927 .66 .513 r
F P
0 g
s
.60551 .33447 m .61702 .33454 L p .60343 .33029 L .443 .548 .869 r
F P
0 g
s
.60285 .33011 m .60551 .33447 L p .60343 .33029 L .443 .548 .869 r
F P
0 g
s
.60743 .33865 m .61881 .33989 L p .60571 .33455 L .417 .515 .851 r
F P
0 g
s
.60551 .33447 m .60743 .33865 L p .60571 .33455 L .417 .515 .851 r
F P
0 g
s
.60915 .34336 m .62029 .34549 L p .60764 .33876 L .401 .481 .827 r
F P
0 g
s
.60743 .33865 m .60915 .34336 L p .60764 .33876 L .401 .481 .827 r
F P
0 g
s
.60915 .34336 m .6106 .34842 L .6215 .35136 L p .389 .453 .806 r
F P
0 g
s
.6215 .35136 m .62029 .34549 L .61926 .34529 L p .389 .453 .806 r
F P
0 g
s
.61926 .34529 m .60915 .34336 L p .61532 .34736 L .389 .453 .806 r
F P
0 g
s
.61532 .34736 m .6215 .35136 L .61926 .34529 L .389 .453 .806 r
F
.62047 .34819 m .6215 .35136 L .61127 .3486 L p .358 .307 .663 r
F P
0 g
s
.61114 .3484 m .62047 .34819 L .61127 .3486 L .358 .307 .663 r
F
.61699 .3572 m .61271 .35586 L p .61365 .35218 L .92 .668 .541 r
F P
0 g
s
.61271 .35586 m .62047 .34819 L p .61342 .34835 L .358 .307 .663 r
F P
0 g
s
.61127 .3486 m .6106 .34842 L p .61114 .3484 L .358 .307 .663 r
F P
0 g
s
.6106 .34842 m .61095 .34964 L p .61342 .34835 L .358 .307 .663 r
F P
0 g
s
.61095 .34964 m .61271 .35586 L p .61342 .34835 L .358 .307 .663 r
F P
0 g
s
.63372 .33462 m .63943 .35416 L .62222 .35882 L p .701 .556 .687 r
F P
0 g
s
.63943 .35416 m .63372 .33462 L .64466 .3375 L p .374 .327 .676 r
F P
0 g
s
.63372 .33462 m .63112 .32778 L .64229 .32985 L p .406 .444 .788 r
F P
0 g
s
.64229 .32985 m .64466 .3375 L .63372 .33462 L p .406 .444 .788 r
F P
0 g
s
.14386 .2639 m .14383 .29913 L .13622 .29984 L p .309 .262 .642 r
F P
0 g
s
.13622 .29984 m .13633 .26345 L .14372 .26389 L p .309 .262 .642 r
F P
0 g
s
.13622 .29984 m .14372 .26389 L .14372 .26455 L .309 .262 .642 r
F
.13633 .26345 m .13622 .29984 L .11858 .30236 L p .707 .588 .72 r
F P
0 g
s
.11858 .30236 m .11849 .26339 L .13633 .26345 L p .707 .588 .72 r
F P
0 g
s
.13347 .26429 m .13372 .30094 L .14376 .29914 L p .909 .754 .677 r
F P
0 g
s
.14376 .29914 m .14383 .29913 L p .14376 .29887 L .909 .754 .677 r
F P
0 g
s
.14376 .29887 m .13347 .26429 L .14376 .29914 L .909 .754 .677 r
F
.14372 .26389 m .14386 .2639 L p .14372 .26455 L .309 .262 .642 r
F P
0 g
s
.11849 .26339 m .11858 .30236 L .1084 .30417 L p .907 .749 .674 r
F P
0 g
s
.11436 .34345 m .1084 .30417 L .11858 .30236 L p .908 .721 .638 r
F P
0 g
s
.21343 .72163 m .24324 .72704 L .24344 .73502 L p .592 .737 .945 r
F P
0 g
s
.24344 .73502 m .2117 .72921 L .21336 .72192 L p .592 .737 .945 r
F P
0 g
s
.24344 .73502 m .21336 .72192 L .21452 .72212 L .592 .737 .945 r
F
.2117 .72921 m .24344 .73502 L .24454 .75281 L p .721 .591 .709 r
F P
0 g
s
.24454 .75281 m .20867 .74679 L .2117 .72921 L p .721 .591 .709 r
F P
0 g
s
.21211 .73171 m .24415 .73694 L .24325 .72713 L p .721 .389 .416 r
F P
0 g
s
.24325 .72713 m .24324 .72704 L p .24299 .72708 L .721 .389 .416 r
F P
0 g
s
.24299 .72708 m .21211 .73171 L .24325 .72713 L .721 .389 .416 r
F
.21336 .72192 m .21343 .72163 L p .21452 .72212 L .592 .737 .945 r
F P
0 g
s
.20867 .74679 m .24454 .75281 L .24544 .76277 L p .712 .383 .418 r
F P
0 g
s
.28378 .75967 m .24544 .76277 L .24454 .75281 L p .653 .326 .407 r
F P
0 g
s
.76839 .76816 m .80184 .76016 L .80542 .77003 L p .593 .291 .426 r
F P
0 g
s
.80542 .77003 m .77011 .77836 L .76839 .76816 L p .593 .291 .426 r
F P
0 g
s
.45345 .10382 m .43156 .11948 L .42681 .11018 L p .82 .828 .855 r
F P
0 g
s
.42681 .11018 m .44945 .09412 L .45345 .10382 L p .82 .828 .855 r
F P
0 g
s
.84505 .40325 m .84957 .37986 L .8569 .38286 L p .948 .81 .674 r
F P
0 g
s
.8569 .38286 m .85211 .407 L .84516 .4033 L p .948 .81 .674 r
F P
0 g
s
.8569 .38286 m .84516 .4033 L .84523 .40294 L .948 .81 .674 r
F
.85211 .407 m .8569 .38286 L .87464 .38464 L p .711 .564 .687 r
F P
0 g
s
.85557 .40299 m .86005 .37862 L .84968 .37984 L p .417 .285 .592 r
F P
0 g
s
.84968 .37984 m .84957 .37986 L p .84963 .38009 L .417 .285 .592 r
F P
0 g
s
.84963 .38009 m .85557 .40299 L .84968 .37984 L .417 .285 .592 r
F
.84516 .4033 m .84505 .40325 L p .84523 .40294 L .948 .81 .674 r
F P
0 g
s
.87464 .38464 m .8696 .4105 L .85211 .407 L p .711 .564 .687 r
F P
0 g
s
.15417 .35725 m .14777 .36248 L p .14893 .3385 L .316 .303 .686 r
F P
0 g
s
.15598 .38506 m .14777 .36248 L .15417 .35725 L p .329 .342 .722 r
F P
0 g
s
.14777 .36248 m .15598 .38506 L .13983 .39264 L p .7 .556 .688 r
F P
0 g
s
.13983 .39264 m .13104 .36863 L .14777 .36248 L p .7 .556 .688 r
F P
0 g
s
.16199 .37931 m .15598 .38506 L p .15435 .36003 L .329 .342 .722 r
F P
0 g
s
.15417 .35725 m .16199 .37931 L p .15435 .36003 L .329 .342 .722 r
F P
0 g
s
.16639 .40745 m .15598 .38506 L .16199 .37931 L p .341 .372 .749 r
F P
0 g
s
.15598 .38506 m .16639 .40745 L .15093 .41637 L p .698 .556 .689 r
F P
0 g
s
.15093 .41637 m .13983 .39264 L .15598 .38506 L p .698 .556 .689 r
F P
0 g
s
.17196 .40118 m .16639 .40745 L p .16244 .38219 L .341 .372 .749 r
F P
0 g
s
.16199 .37931 m .17196 .40118 L p .16244 .38219 L .341 .372 .749 r
F P
0 g
s
.17868 .42894 m .16639 .40745 L .17196 .40118 L p .354 .402 .773 r
F P
0 g
s
.16639 .40745 m .17868 .42894 L .16387 .43894 L p .697 .555 .69 r
F P
0 g
s
.16387 .43894 m .15093 .41637 L .16639 .40745 L p .697 .555 .69 r
F P
0 g
s
.18395 .42242 m .17868 .42894 L p .17249 .40339 L .354 .402 .773 r
F P
0 g
s
.17196 .40118 m .18395 .42242 L p .17249 .40339 L .354 .402 .773 r
F P
0 g
s
.19429 .45234 m .17868 .42894 L .18395 .42242 L p .368 .43 .793 r
F P
0 g
s
.17868 .42894 m .19429 .45234 L .17961 .46256 L p .697 .556 .692 r
F P
0 g
s
.17961 .46256 m .16387 .43894 L .17868 .42894 L p .697 .556 .692 r
F P
0 g
s
.19953 .44582 m .19429 .45234 L p .18415 .42301 L .368 .43 .793 r
F P
0 g
s
.18395 .42242 m .19953 .44582 L p .18415 .42301 L .368 .43 .793 r
F P
0 g
s
.21041 .47588 m .19429 .45234 L .19953 .44582 L p .371 .434 .797 r
F P
0 g
s
.19429 .45234 m .21041 .47588 L .19552 .48582 L p .696 .556 .692 r
F P
0 g
s
.19552 .48582 m .17961 .46256 L .19429 .45234 L p .696 .556 .692 r
F P
0 g
s
.19953 .44582 m .21583 .46956 L .21041 .47588 L p .371 .434 .797 r
F P
0 g
s
.19953 .44582 m .19003 .44955 L p .21522 .46908 L .862 .572 .496 r
F P
0 g
s
.21583 .46956 m .19953 .44582 L p .21522 .46908 L .862 .572 .496 r
F P
0 g
s
.18395 .42242 m .17434 .42593 L p .19667 .44356 L .864 .576 .499 r
F P
0 g
s
.19953 .44582 m .18395 .42242 L p .19667 .44356 L .864 .576 .499 r
F P
0 g
s
.17196 .40118 m .16199 .40386 L p .18162 .42045 L .873 .595 .513 r
F P
0 g
s
.18395 .42242 m .17196 .40118 L p .18162 .42045 L .873 .595 .513 r
F P
0 g
s
.16199 .37931 m .15176 .38115 L p .16981 .39905 L .884 .619 .533 r
F P
0 g
s
.17196 .40118 m .16199 .37931 L p .16981 .39905 L .884 .619 .533 r
F P
0 g
s
.15417 .35725 m .14375 .3582 L p .15952 .37646 L .893 .643 .554 r
F P
0 g
s
.16199 .37931 m .15417 .35725 L p .15952 .37646 L .893 .643 .554 r
F P
0 g
s
.1491 .33499 m .15417 .35725 L p .14893 .3385 L .316 .303 .686 r
F P
0 g
s
.13104 .36863 m .13983 .39264 L .12956 .39452 L p .891 .644 .557 r
F P
0 g
s
.12956 .39452 m .12058 .36962 L .13104 .36863 L p .891 .644 .557 r
F P
0 g
s
.49754 .3111 m .50287 .32532 L .49578 .33107 L p .927 .697 .571 r
F P
0 g
s
.50287 .32532 m .49754 .3111 L .51465 .30607 L p .721 .618 .742 r
F P
0 g
s
.51465 .30607 m .5194 .31863 L .50287 .32532 L p .721 .618 .742 r
F P
0 g
s
.5194 .31863 m .51465 .30607 L .52399 .30594 L p .409 .448 .789 r
F P
0 g
s
.52409 .30619 m .5194 .31863 L .52399 .30594 L .409 .448 .789 r
F
.52419 .30594 m .52895 .31762 L .5194 .31863 L p F P
0 g
s
.51654 .31087 m .52193 .32336 L .52877 .31777 L p .924 .687 .562 r
F P
0 g
s
.52877 .31777 m .52895 .31762 L p .52865 .31746 L .924 .687 .562 r
F P
0 g
s
.51654 .31087 m .52877 .31777 L .52865 .31746 L .924 .687 .562 r
F
.52399 .30594 m .52419 .30594 L p .52409 .30619 L .409 .448 .789 r
F P
0 g
s
.70878 .38156 m .70965 .39474 L .69184 .39541 L p .707 .61 .746 r
F P
0 g
s
.70965 .39474 m .70878 .38156 L .71903 .38359 L p .395 .358 .699 r
F P
0 g
s
.71903 .38359 m .71953 .39786 L .70965 .39474 L p .395 .358 .699 r
F P
0 g
s
.58125 .61982 m .58936 .61382 L .59215 .62242 L p .846 .873 .861 r
F P
0 g
s
.59215 .62242 m .58316 .62869 L .5813 .62008 L p .846 .873 .861 r
F P
0 g
s
.59215 .62242 m .5813 .62008 L .58155 .61989 L .846 .873 .861 r
F
.58316 .62869 m .59215 .62242 L .60402 .63572 L p .739 .584 .682 r
F P
0 g
s
.58995 .62539 m .59851 .61855 L .58958 .61393 L p .528 .23 .404 r
F P
0 g
s
.58958 .61393 m .58936 .61382 L p .58937 .61408 L .528 .23 .404 r
F P
0 g
s
.58937 .61408 m .58995 .62539 L .58958 .61393 L .528 .23 .404 r
F
.5813 .62008 m .58125 .61982 L p .58155 .61989 L .846 .873 .861 r
F P
0 g
s
.60402 .63572 m .59371 .64307 L .58316 .62869 L p .739 .584 .682 r
F P
0 g
s
.59371 .64307 m .60402 .63572 L .61319 .64052 L p .525 .239 .424 r
F P
0 g
s
.62213 .63233 m .61319 .64052 L .60402 .63572 L p .505 .231 .432 r
F P
0 g
s
.48505 .56316 m .47432 .56597 L .46738 .55911 L p .673 .799 .942 r
F P
0 g
s
.47432 .56597 m .48505 .56316 L .48865 .58063 L p .651 .546 .722 r
F P
0 g
s
.48865 .58063 m .4797 .58296 L .47432 .56597 L p .651 .546 .722 r
F P
0 g
s
.4797 .58296 m .48865 .58063 L .4862 .5904 L p .505 .206 .393 r
F P
0 g
s
.48594 .59049 m .4797 .58296 L .4862 .5904 L .505 .206 .393 r
F
.48612 .59071 m .47818 .59323 L .4797 .58296 L p F P
0 g
s
.47995 .58325 m .47123 .58646 L .47793 .59299 L p .694 .808 .936 r
F P
0 g
s
.47793 .59299 m .47818 .59323 L p .47824 .5929 L .694 .808 .936 r
F P
0 g
s
.47995 .58325 m .47793 .59299 L .47824 .5929 L .694 .808 .936 r
F
.4862 .5904 m .48612 .59071 L p .48594 .59049 L .505 .206 .393 r
F P
0 g
s
.72515 .73788 m .72957 .74073 L .72176 .74701 L p .518 .638 .908 r
F P
0 g
s
.72176 .74701 m .71596 .74245 L .72515 .73788 L p .518 .638 .908 r
F P
0 g
s
.71596 .74245 m .72176 .74701 L .71687 .76415 L p .746 .627 .728 r
F P
0 g
s
.71687 .76415 m .70734 .75808 L .71596 .74245 L p .746 .627 .728 r
F P
0 g
s
.70734 .75808 m .71687 .76415 L .71977 .77515 L p .805 .476 .432 r
F P
0 g
s
.73324 .77816 m .71977 .77515 L .71687 .76415 L p .748 .413 .415 r
F P
0 g
s
.61475 .36376 m .61271 .35586 L .62222 .35882 L p .92 .647 .506 r
F P
0 g
s
.62222 .35882 m .62419 .36692 L .61475 .36376 L p .92 .647 .506 r
F P
0 g
s
.62419 .36692 m .62222 .35882 L .63943 .35416 L p .69 .517 .647 r
F P
0 g
s
.63943 .35416 m .64152 .36266 L .62419 .36692 L p .69 .517 .647 r
F P
0 g
s
.64152 .36266 m .63943 .35416 L .64725 .3465 L p .371 .317 .667 r
F P
0 g
s
.64466 .3375 m .64725 .3465 L .63943 .35416 L p .374 .327 .676 r
F P
0 g
s
.51319 .36038 m .50745 .35269 L .51795 .35343 L p .832 .474 .378 r
F P
0 g
s
.51795 .35343 m .52366 .3599 L .51319 .36038 L p .832 .474 .378 r
F P
0 g
s
.52366 .3599 m .51795 .35343 L .53332 .3444 L p .655 .483 .639 r
F P
0 g
s
.53332 .3444 m .5379 .34915 L .52366 .3599 L p .655 .483 .639 r
F P
0 g
s
.63112 .32778 m .62784 .32104 L .63925 .32221 L p .418 .468 .805 r
F P
0 g
s
.63925 .32221 m .64229 .32985 L .63112 .32778 L p .418 .468 .805 r
F P
0 g
s
.1489 .22967 m .14386 .2639 L .13633 .26345 L p .305 .22 .593 r
F P
0 g
s
.13633 .26345 m .14162 .22805 L .14876 .22964 L p .305 .22 .593 r
F P
0 g
s
.13633 .26345 m .14876 .22964 L .14867 .2303 L .305 .22 .593 r
F
.14162 .22805 m .13633 .26345 L .11849 .26339 L p .705 .587 .72 r
F P
0 g
s
.11849 .26339 m .12397 .2254 L .14162 .22805 L p .705 .587 .72 r
F P
0 g
s
.13844 .22863 m .13347 .26429 L .14378 .2639 L p .903 .778 .713 r
F P
0 g
s
.14378 .2639 m .14386 .2639 L p .14382 .26363 L .903 .778 .713 r
F P
0 g
s
.14382 .26363 m .13844 .22863 L .14378 .2639 L .903 .778 .713 r
F
.14876 .22964 m .1489 .22967 L p .14867 .2303 L .305 .22 .593 r
F P
0 g
s
.12397 .2254 m .11849 .26339 L .10804 .26379 L p .902 .774 .71 r
F P
0 g
s
.1084 .30417 m .10804 .26379 L .11849 .26339 L p .907 .749 .674 r
F P
0 g
s
.18365 .71045 m .21343 .72163 L .2117 .72921 L p .531 .681 .934 r
F P
0 g
s
.2117 .72921 m .18053 .71742 L .18357 .71065 L p .531 .681 .934 r
F P
0 g
s
.2117 .72921 m .18357 .71065 L .18441 .71096 L .531 .681 .934 r
F
.18053 .71742 m .2117 .72921 L .20867 .74679 L p .72 .592 .712 r
F P
0 g
s
.20867 .74679 m .17428 .73414 L .18053 .71742 L p .72 .592 .712 r
F P
0 g
s
.18051 .72029 m .21211 .73171 L .21342 .72173 L p .764 .438 .434 r
F P
0 g
s
.21342 .72173 m .21343 .72163 L p .21314 .72162 L .764 .438 .434 r
F P
0 g
s
.21314 .72162 m .18051 .72029 L .21342 .72173 L .764 .438 .434 r
F
.18357 .71065 m .18365 .71045 L p .18441 .71096 L .531 .681 .934 r
F P
0 g
s
.17428 .73414 m .20867 .74679 L .20733 .75693 L p .757 .433 .436 r
F P
0 g
s
.24544 .76277 m .20733 .75693 L .20867 .74679 L p .712 .383 .418 r
F P
0 g
s
.80184 .76016 m .83415 .74558 L .83951 .75476 L p .552 .274 .447 r
F P
0 g
s
.83951 .75476 m .80542 .77003 L .80184 .76016 L p .552 .274 .447 r
F P
0 g
s
.43156 .11948 m .41051 .13719 L .40506 .12834 L p .835 .831 .843 r
F P
0 g
s
.40506 .12834 m .42681 .11018 L .43156 .11948 L p .835 .831 .843 r
F P
0 g
s
.13983 .39264 m .15093 .41637 L .14091 .4191 L p .883 .62 .537 r
F P
0 g
s
.14091 .4191 m .12956 .39452 L .13983 .39264 L p .883 .62 .537 r
F P
0 g
s
.83837 .42671 m .84505 .40325 L .85211 .407 L p .942 .827 .702 r
F P
0 g
s
.85211 .407 m .84513 .43107 L .83846 .42677 L p .942 .827 .702 r
F P
0 g
s
.85211 .407 m .83846 .42677 L .83855 .42645 L .942 .827 .702 r
F
.84513 .43107 m .85211 .407 L .8696 .4105 L p .712 .566 .688 r
F P
0 g
s
.84883 .42737 m .85557 .40299 L .84515 .40324 L p .422 .272 .571 r
F P
0 g
s
.84515 .40324 m .84505 .40325 L p .84509 .40347 L .422 .272 .571 r
F P
0 g
s
.84509 .40347 m .84883 .42737 L .84515 .40324 L .422 .272 .571 r
F
.83846 .42677 m .83837 .42671 L p .83855 .42645 L .942 .827 .702 r
F P
0 g
s
.8696 .4105 m .86227 .43607 L .84513 .43107 L p .712 .566 .688 r
F P
0 g
s
.86227 .43607 m .8696 .4105 L .88017 .41027 L p .426 .279 .577 r
F P
0 g
s
.49578 .33107 m .48982 .31603 L .49754 .3111 L p .927 .697 .571 r
F P
0 g
s
.49357 .29632 m .49754 .3111 L .48982 .31603 L p .931 .724 .6 r
F P
0 g
s
.49754 .3111 m .49357 .29632 L .51109 .29288 L p .717 .615 .743 r
F P
0 g
s
.51109 .29288 m .51465 .30607 L .49754 .3111 L p .717 .615 .743 r
F P
0 g
s
.51465 .30607 m .51109 .29288 L .52035 .29354 L p .395 .416 .764 r
F P
0 g
s
.52042 .29378 m .51465 .30607 L .52035 .29354 L .395 .416 .764 r
F
.52053 .29355 m .52419 .30594 L .51465 .30607 L p F P
0 g
s
.51239 .2977 m .51654 .31087 L .52401 .30605 L p .93 .716 .591 r
F P
0 g
s
.52401 .30605 m .52419 .30594 L p .52392 .30576 L .93 .716 .591 r
F P
0 g
s
.51239 .2977 m .52401 .30605 L .52392 .30576 L .93 .716 .591 r
F
.52035 .29354 m .52053 .29355 L p .52042 .29378 L .395 .416 .764 r
F P
0 g
s
.57312 .62433 m .58125 .61982 L .58316 .62869 L p .814 .868 .887 r
F P
0 g
s
.58316 .62869 m .57379 .63342 L .57314 .62468 L p .814 .868 .887 r
F P
0 g
s
.58316 .62869 m .57314 .62468 L .57349 .62449 L .814 .868 .887 r
F
.57379 .63342 m .58316 .62869 L .59371 .64307 L p .742 .589 .686 r
F P
0 g
s
.58118 .63089 m .58995 .62539 L .58151 .61999 L p .563 .243 .385 r
F P
0 g
s
.58151 .61999 m .58125 .61982 L p .58125 .62014 L .563 .243 .385 r
F P
0 g
s
.58125 .62014 m .58118 .63089 L .58151 .61999 L .563 .243 .385 r
F
.57314 .62468 m .57312 .62433 L p .57349 .62449 L .814 .868 .887 r
F P
0 g
s
.59371 .64307 m .58246 .64903 L .57379 .63342 L p .742 .589 .686 r
F P
0 g
s
.58246 .64903 m .59371 .64307 L .60243 .64871 L p .554 .252 .411 r
F P
0 g
s
.61319 .64052 m .60243 .64871 L .59371 .64307 L p .525 .239 .424 r
F P
0 g
s
.70626 .36893 m .70878 .38156 L .69117 .38442 L p .712 .614 .746 r
F P
0 g
s
.70878 .38156 m .70626 .36893 L .71675 .36959 L p .402 .391 .732 r
F P
0 g
s
.71675 .36959 m .71903 .38359 L .70878 .38156 L p .402 .391 .732 r
F P
0 g
s
.46738 .55911 m .4789 .55563 L .48505 .56316 L p .673 .799 .942 r
F P
0 g
s
.49605 .56155 m .48505 .56316 L .4789 .55563 L p .639 .774 .945 r
F P
0 g
s
.48505 .56316 m .49605 .56155 L .49758 .57934 L p .648 .539 .716 r
F P
0 g
s
.49758 .57934 m .48865 .58063 L .48505 .56316 L p .648 .539 .716 r
F P
0 g
s
.48865 .58063 m .49758 .57934 L .49396 .58906 L p .528 .214 .379 r
F P
0 g
s
.49396 .58906 m .48612 .59071 L .48865 .58063 L p .528 .214 .379 r
F P
0 g
s
.71966 .73339 m .72515 .73788 L .71596 .74245 L p .485 .599 .891 r
F P
0 g
s
.71596 .74245 m .70991 .73676 L .71966 .73339 L p .485 .599 .891 r
F P
0 g
s
.70991 .73676 m .71596 .74245 L .70734 .75808 L p .742 .629 .734 r
F P
0 g
s
.70734 .75808 m .69894 .75084 L .70991 .73676 L p .742 .629 .734 r
F P
0 g
s
.69894 .75084 m .70734 .75808 L .70785 .76924 L p .845 .528 .452 r
F P
0 g
s
.71977 .77515 m .70785 .76924 L .70734 .75808 L p .805 .476 .432 r
F P
0 g
s
.617 .37218 m .61475 .36376 L .62419 .36692 L p .919 .64 .498 r
F P
0 g
s
.62419 .36692 m .62647 .37524 L .617 .37218 L p .919 .64 .498 r
F P
0 g
s
.62647 .37524 m .62419 .36692 L .64152 .36266 L p .689 .514 .645 r
F P
0 g
s
.64152 .36266 m .64377 .37083 L .62647 .37524 L p .689 .514 .645 r
F P
0 g
s
.64377 .37083 m .64152 .36266 L .64953 .35521 L p .368 .314 .666 r
F P
0 g
s
.64725 .3465 m .64953 .35521 L .64152 .36266 L p .371 .317 .667 r
F P
0 g
s
.52002 .36741 m .51319 .36038 L .52366 .3599 L p .795 .421 .348 r
F P
0 g
s
.52366 .3599 m .53033 .36558 L .52002 .36741 L p .795 .421 .348 r
F P
0 g
s
.53033 .36558 m .52366 .3599 L .5379 .34915 L p .644 .478 .644 r
F P
0 g
s
.5379 .34915 m .54302 .35301 L .53033 .36558 L p .644 .478 .644 r
F P
0 g
s
.61198 .32923 m .60901 .32459 L .62393 .31477 L p .736 .652 .766 r
F P
0 g
s
.62393 .31477 m .62784 .32104 L .61198 .32923 L p .736 .652 .766 r
F P
0 g
s
.62784 .32104 m .62393 .31477 L .63546 .31477 L p .433 .497 .825 r
F P
0 g
s
.63546 .31477 m .63925 .32221 L .62784 .32104 L p .433 .497 .825 r
F P
0 g
s
.15928 .19687 m .1489 .22967 L .14162 .22805 L p .309 .181 .538 r
F P
0 g
s
.14162 .22805 m .15248 .19404 L .15914 .19681 L p .309 .181 .538 r
F P
0 g
s
.14162 .22805 m .15914 .19681 L .15891 .19753 L .309 .181 .538 r
F
.15248 .19404 m .14162 .22805 L .12397 .2254 L p .703 .584 .72 r
F P
0 g
s
.12397 .2254 m .13545 .18861 L .15248 .19404 L p .703 .584 .72 r
F P
0 g
s
.14899 .19426 m .13844 .22863 L .14882 .22966 L p .891 .799 .751 r
F P
0 g
s
.14882 .22966 m .1489 .22967 L p .1489 .2294 L .891 .799 .751 r
F P
0 g
s
.1489 .2294 m .14899 .19426 L .14882 .22966 L .891 .799 .751 r
F
.15914 .19681 m .15928 .19687 L p .15891 .19753 L .309 .181 .538 r
F P
0 g
s
.13545 .18861 m .12397 .2254 L .11345 .22435 L p .891 .794 .747 r
F P
0 g
s
.10804 .26379 m .11345 .22435 L .12397 .2254 L p .902 .774 .71 r
F P
0 g
s
.15633 .69372 m .18365 .71045 L .18053 .71742 L p .471 .615 .911 r
F P
0 g
s
.18053 .71742 m .1519 .69979 L .1562 .69389 L p .471 .615 .911 r
F P
0 g
s
.18053 .71742 m .1562 .69389 L .15699 .69437 L .471 .615 .911 r
F
.1519 .69979 m .18053 .71742 L .17428 .73414 L p .719 .593 .714 r
F P
0 g
s
.17428 .73414 m .14259 .71504 L .1519 .69979 L p .719 .593 .714 r
F P
0 g
s
.15141 .70297 m .18051 .72029 L .18363 .71054 L p .804 .492 .461 r
F P
0 g
s
.18363 .71054 m .18365 .71045 L p .18338 .71039 L .804 .492 .461 r
F P
0 g
s
.18338 .71039 m .15141 .70297 L .18363 .71054 L .804 .492 .461 r
F
.1562 .69389 m .15633 .69372 L p .15699 .69437 L .471 .615 .911 r
F P
0 g
s
.14259 .71504 m .17428 .73414 L .17111 .74403 L p .798 .486 .461 r
F P
0 g
s
.20733 .75693 m .17111 .74403 L .17428 .73414 L p .757 .433 .436 r
F P
0 g
s
.83415 .74558 m .86289 .72543 L .86937 .73395 L p .515 .265 .474 r
F P
0 g
s
.86937 .73395 m .83951 .75476 L .83415 .74558 L p .515 .265 .474 r
F P
0 g
s
.41051 .13719 m .39098 .15639 L .38486 .14807 L p .849 .831 .829 r
F P
0 g
s
.38486 .14807 m .40506 .12834 L .41051 .13719 L p .849 .831 .829 r
F P
0 g
s
.82956 .44943 m .83837 .42671 L .84513 .43107 L p .934 .843 .731 r
F P
0 g
s
.84513 .43107 m .83595 .45442 L .82965 .4495 L p .934 .843 .731 r
F P
0 g
s
.84513 .43107 m .82965 .4495 L .82978 .44917 L .934 .843 .731 r
F
.83595 .45442 m .84513 .43107 L .86227 .43607 L p .714 .568 .689 r
F P
0 g
s
.83988 .45101 m .84883 .42737 L .83847 .42672 L p .43 .26 .549 r
F P
0 g
s
.83847 .42672 m .83837 .42671 L p .83838 .42694 L .43 .26 .549 r
F P
0 g
s
.83838 .42694 m .83988 .45101 L .83847 .42672 L .43 .26 .549 r
F
.82965 .4495 m .82956 .44943 L p .82978 .44917 L .934 .843 .731 r
F P
0 g
s
.86227 .43607 m .85256 .46098 L .83595 .45442 L p .714 .568 .689 r
F P
0 g
s
.85256 .46098 m .86227 .43607 L .87278 .43676 L p .433 .267 .555 r
F P
0 g
s
.88017 .41027 m .87278 .43676 L .86227 .43607 L p .426 .279 .577 r
F P
0 g
s
.15093 .41637 m .16387 .43894 L .15422 .4425 L p .872 .596 .517 r
F P
0 g
s
.15422 .4425 m .14091 .4191 L .15093 .41637 L p .872 .596 .517 r
F P
0 g
s
.48982 .31603 m .48536 .30047 L .49357 .29632 L p .931 .724 .6 r
F P
0 g
s
.49091 .28177 m .49357 .29632 L .48536 .30047 L p .933 .745 .626 r
F P
0 g
s
.49357 .29632 m .49091 .28177 L .50861 .27932 L p .713 .612 .743 r
F P
0 g
s
.50861 .27932 m .51109 .29288 L .49357 .29632 L p .713 .612 .743 r
F P
0 g
s
.51109 .29288 m .50861 .27932 L .51781 .28019 L p .384 .385 .737 r
F P
0 g
s
.51784 .28034 m .51109 .29288 L .51781 .28019 L .384 .385 .737 r
F
.51792 .2802 m .52053 .29355 L .51109 .29288 L p F P
0 g
s
.50946 .28356 m .51239 .2977 L .52042 .29361 L p .934 .742 .62 r
F P
0 g
s
.52042 .29361 m .52053 .29355 L p .52039 .29343 L .934 .742 .62 r
F P
0 g
s
.50946 .28356 m .52042 .29361 L .52039 .29343 L .934 .742 .62 r
F
.51781 .28019 m .51792 .2802 L p .51784 .28034 L .384 .385 .737 r
F P
0 g
s
.70201 .35647 m .70626 .36893 L .68921 .37421 L p .718 .619 .746 r
F P
0 g
s
.70626 .36893 m .70201 .35647 L .71276 .35649 L p .416 .43 .766 r
F P
0 g
s
.71276 .35649 m .71675 .36959 L .70626 .36893 L p .416 .43 .766 r
F P
0 g
s
.56476 .62742 m .57312 .62433 L .57379 .63342 L p .774 .854 .91 r
F P
0 g
s
.57379 .63342 m .56404 .63655 L .56473 .62784 L p .774 .854 .91 r
F P
0 g
s
.57379 .63342 m .56473 .62784 L .56515 .62768 L .774 .854 .91 r
F
.56404 .63655 m .57379 .63342 L .58246 .64903 L p .744 .596 .692 r
F P
0 g
s
.57186 .63506 m .58118 .63089 L .5734 .62455 L p .604 .266 .371 r
F P
0 g
s
.5734 .62455 m .57312 .62433 L p .57308 .62467 L .604 .266 .371 r
F P
0 g
s
.57308 .62467 m .57186 .63506 L .5734 .62455 L .604 .266 .371 r
F
.56473 .62784 m .56476 .62742 L p .56515 .62768 L .774 .854 .91 r
F P
0 g
s
.58246 .64903 m .57036 .65327 L .56404 .63655 L p .744 .596 .692 r
F P
0 g
s
.57036 .65327 m .58246 .64903 L .59052 .65566 L p .589 .272 .4 r
F P
0 g
s
.60243 .64871 m .59052 .65566 L .58246 .64903 L p .554 .252 .411 r
F P
0 g
s
.71462 .72789 m .71966 .73339 L .70991 .73676 L p .457 .555 .867 r
F P
0 g
s
.70991 .73676 m .70438 .72999 L .71462 .72789 L p .457 .555 .867 r
F P
0 g
s
.70438 .72999 m .70991 .73676 L .69894 .75084 L p .737 .629 .739 r
F P
0 g
s
.69894 .75084 m .69149 .74235 L .70438 .72999 L p .737 .629 .739 r
F P
0 g
s
.69149 .74235 m .69894 .75084 L .69763 .76166 L p .874 .574 .476 r
F P
0 g
s
.70785 .76924 m .69763 .76166 L .69894 .75084 L p .845 .528 .452 r
F P
0 g
s
.4789 .55563 m .49091 .55334 L .49605 .56155 L p .639 .774 .945 r
F P
0 g
s
.50705 .56117 m .49605 .56155 L .49091 .55334 L p .604 .744 .943 r
F P
0 g
s
.49605 .56155 m .50705 .56117 L .50673 .57904 L p .648 .533 .71 r
F P
0 g
s
.50673 .57904 m .49758 .57934 L .49605 .56155 L p .648 .533 .71 r
F P
0 g
s
.49758 .57934 m .50673 .57904 L .50236 .58806 L p .564 .235 .37 r
F P
0 g
s
.50209 .58809 m .49758 .57934 L .50236 .58806 L .564 .235 .37 r
F
.50222 .58834 m .49396 .58906 L .49758 .57934 L p F P
0 g
s
.498 .57972 m .48879 .58092 L .49378 .58877 L p .627 .758 .941 r
F P
0 g
s
.49378 .58877 m .49396 .58906 L p .4941 .58874 L .627 .758 .941 r
F P
0 g
s
.498 .57972 m .49378 .58877 L .4941 .58874 L .627 .758 .941 r
F
.50236 .58806 m .50222 .58834 L p .50209 .58809 L .564 .235 .37 r
F P
0 g
s
.61958 .38088 m .617 .37218 L .62647 .37524 L p .915 .628 .486 r
F P
0 g
s
.62647 .37524 m .62912 .38364 L .61958 .38088 L p .915 .628 .486 r
F P
0 g
s
.62912 .38364 m .62647 .37524 L .64377 .37083 L p .687 .512 .644 r
F P
0 g
s
.64377 .37083 m .64631 .37874 L .62912 .38364 L p .687 .512 .644 r
F P
0 g
s
.64631 .37874 m .64377 .37083 L .65174 .36333 L p .367 .318 .671 r
F P
0 g
s
.65174 .36333 m .64377 .37083 L p .64943 .35548 L .368 .314 .666 r
F P
0 g
s
.65408 .37105 m .64631 .37874 L p .6516 .36373 L .367 .318 .671 r
F P
0 g
s
.65174 .36333 m .65408 .37105 L p .6516 .36373 L .367 .318 .671 r
F P
0 g
s
.64897 .38615 m .64631 .37874 L .65408 .37105 L p .36 .314 .671 r
F P
0 g
s
.65635 .37772 m .64897 .38615 L p .6538 .37189 L .36 .314 .671 r
F P
0 g
s
.65408 .37105 m .65635 .37772 L p .6538 .37189 L .36 .314 .671 r
F P
0 g
s
.65225 .39209 m .64897 .38615 L .65635 .37772 L p .354 .326 .689 r
F P
0 g
s
.65884 .38303 m .65225 .39209 L p .65614 .37843 L .354 .326 .689 r
F P
0 g
s
.65635 .37772 m .65884 .38303 L p .65614 .37843 L .354 .326 .689 r
F P
0 g
s
.65617 .39729 m .65225 .39209 L .65884 .38303 L p .353 .348 .715 r
F P
0 g
s
.66162 .38742 m .65617 .39729 L p .65863 .38414 L .353 .348 .715 r
F P
0 g
s
.65884 .38303 m .66162 .38742 L p .65863 .38414 L .353 .348 .715 r
F P
0 g
s
.66083 .40094 m .65617 .39729 L .66162 .38742 L p .357 .387 .755 r
F P
0 g
s
.66453 .39033 m .66083 .40094 L p .66155 .38859 L .357 .387 .755 r
F P
0 g
s
.66162 .38742 m .66453 .39033 L p .66155 .38859 L .357 .387 .755 r
F P
0 g
s
.66593 .40315 m .66083 .40094 L .66453 .39033 L p .343 .415 .792 r
F P
0 g
s
.66699 .3917 m .66593 .40315 L p .66457 .39066 L .343 .415 .792 r
F P
0 g
s
.66453 .39033 m .66699 .3917 L p .66457 .39066 L .343 .415 .792 r
F P
0 g
s
.67088 .40404 m .66593 .40315 L .66699 .3917 L p .384 .491 .845 r
F P
0 g
s
.66984 .39272 m .67088 .40404 L p .66699 .39171 L .384 .491 .845 r
F P
0 g
s
.66699 .3917 m .66984 .39272 L p .66699 .39171 L .384 .491 .845 r
F P
0 g
s
.67617 .40467 m .67088 .40404 L .66984 .39272 L p .439 .562 .882 r
F P
0 g
s
.67362 .39375 m .67617 .40467 L p .67005 .39311 L .439 .562 .882 r
F P
0 g
s
.66984 .39272 m .67362 .39375 L p .67005 .39311 L .439 .562 .882 r
F P
0 g
s
.68161 .40454 m .67617 .40467 L .67362 .39375 L p .478 .617 .909 r
F P
0 g
s
.67362 .39375 m .67755 .39421 L .68161 .40454 L p .478 .617 .909 r
F P
0 g
s
.67362 .39375 m .66501 .3998 L p .67718 .39438 L .65 .286 .34 r
F P
0 g
s
.67755 .39421 m .67362 .39375 L p .67718 .39438 L .65 .286 .34 r
F P
0 g
s
.66984 .39272 m .66028 .39727 L p .6731 .39388 L .694 .324 .341 r
F P
0 g
s
.67362 .39375 m .66984 .39272 L p .6731 .39388 L .694 .324 .341 r
F P
0 g
s
.66699 .3917 m .65667 .3942 L p .66945 .39277 L .745 .379 .36 r
F P
0 g
s
.66984 .39272 m .66699 .3917 L p .66945 .39277 L .745 .379 .36 r
F P
0 g
s
.66453 .39033 m .65432 .39112 L p .66687 .3917 L .795 .437 .38 r
F P
0 g
s
.66699 .3917 m .66453 .39033 L p .66687 .3917 L .795 .437 .38 r
F P
0 g
s
.66162 .38742 m .65141 .38637 L p .66417 .39022 L .844 .503 .409 r
F P
0 g
s
.66453 .39033 m .66162 .38742 L p .66417 .39022 L .844 .503 .409 r
F P
0 g
s
.65884 .38303 m .64888 .38095 L p .66131 .38726 L .877 .553 .434 r
F P
0 g
s
.66162 .38742 m .65884 .38303 L p .66131 .38726 L .877 .553 .434 r
F P
0 g
s
.65635 .37772 m .64661 .37467 L p .65861 .38288 L .898 .593 .461 r
F P
0 g
s
.65884 .38303 m .65635 .37772 L p .65861 .38288 L .898 .593 .461 r
F P
0 g
s
.65408 .37105 m .6446 .36824 L p .65635 .37771 L .912 .617 .472 r
F P
0 g
s
.65635 .37772 m .65408 .37105 L p .65635 .37771 L .912 .617 .472 r
F P
0 g
s
.65174 .36333 m .64233 .36022 L p .65398 .37095 L .917 .635 .491 r
F P
0 g
s
.65408 .37105 m .65174 .36333 L p .65398 .37095 L .917 .635 .491 r
F P
0 g
s
.64953 .35521 m .65174 .36333 L p .64943 .35548 L .368 .314 .666 r
F P
0 g
s
.52795 .37354 m .52002 .36741 L .53033 .36558 L p .752 .367 .324 r
F P
0 g
s
.53033 .36558 m .53781 .37021 L .52795 .37354 L p .752 .367 .324 r
F P
0 g
s
.53781 .37021 m .53033 .36558 L .54302 .35301 L p .635 .478 .652 r
F P
0 g
s
.54302 .35301 m .54857 .35594 L .53781 .37021 L p .635 .478 .652 r
F P
0 g
s
.60901 .32459 m .60493 .31911 L .61908 .30819 L p .744 .659 .766 r
F P
0 g
s
.61908 .30819 m .62393 .31477 L .60901 .32459 L p .744 .659 .766 r
F P
0 g
s
.62393 .31477 m .61908 .30819 L .63124 .30819 L p .453 .532 .849 r
F P
0 g
s
.63124 .30819 m .63546 .31477 L .62393 .31477 L p .453 .532 .849 r
F P
0 g
s
.17226 .16802 m .15928 .19687 L .15248 .19404 L p .317 .158 .501 r
F P
0 g
s
.15248 .19404 m .16597 .16423 L .17216 .16796 L p .317 .158 .501 r
F P
0 g
s
.15248 .19404 m .17216 .16796 L .17196 .1684 L .317 .158 .501 r
F
.16597 .16423 m .15248 .19404 L .13545 .18861 L p .701 .583 .721 r
F P
0 g
s
.13545 .18861 m .14971 .1568 L .16597 .16423 L p .701 .583 .721 r
F P
0 g
s
.1622 .16434 m .14899 .19426 L .1592 .19685 L p .879 .81 .778 r
F P
0 g
s
.1592 .19685 m .15928 .19687 L p .1593 .19663 L .879 .81 .778 r
F P
0 g
s
.1593 .19663 m .1622 .16434 L .1592 .19685 L .879 .81 .778 r
F
.17216 .16796 m .17226 .16802 L p .17196 .1684 L .317 .158 .501 r
F P
0 g
s
.14971 .1568 m .13545 .18861 L .12511 .18597 L p .879 .806 .774 r
F P
0 g
s
.11345 .22435 m .12511 .18597 L .13545 .18861 L p .891 .794 .747 r
F P
0 g
s
.86289 .72543 m .89069 .70028 L .8985 .70772 L p .494 .265 .494 r
F P
0 g
s
.8985 .70772 m .86937 .73395 L .86289 .72543 L p .494 .265 .494 r
F P
0 g
s
.12977 .67299 m .15633 .69372 L .1519 .69979 L p .436 .573 .892 r
F P
0 g
s
.1519 .69979 m .12466 .67841 L .12969 .67307 L p .436 .573 .892 r
F P
0 g
s
.1519 .69979 m .12969 .67307 L .1301 .67339 L .436 .573 .892 r
F
.12466 .67841 m .1519 .69979 L .14259 .71504 L p .718 .594 .716 r
F P
0 g
s
.14259 .71504 m .11359 .69245 L .12466 .67841 L p .718 .594 .716 r
F P
0 g
s
.12376 .68167 m .15141 .70297 L .15629 .69379 L p .825 .524 .479 r
F P
0 g
s
.15629 .69379 m .15633 .69372 L p .15608 .69363 L .825 .524 .479 r
F P
0 g
s
.15608 .69363 m .12376 .68167 L .15629 .69379 L .825 .524 .479 r
F
.12969 .67307 m .12977 .67299 L p .1301 .67339 L .436 .573 .892 r
F P
0 g
s
.11359 .69245 m .14259 .71504 L .13764 .72433 L p .822 .521 .481 r
F P
0 g
s
.17111 .74403 m .13764 .72433 L .14259 .71504 L p .798 .486 .461 r
F P
0 g
s
.39098 .15639 m .37136 .17836 L .36508 .17017 L p .86 .83 .817 r
F P
0 g
s
.36508 .17017 m .38486 .14807 L .39098 .15639 L p .86 .83 .817 r
F P
0 g
s
.16387 .43894 m .17961 .46256 L .17007 .46633 L p .863 .577 .502 r
F P
0 g
s
.17007 .46633 m .15422 .4425 L .16387 .43894 L p .863 .577 .502 r
F P
0 g
s
.81767 .47371 m .82956 .44943 L .83595 .45442 L p .923 .855 .757 r
F P
0 g
s
.83595 .45442 m .82372 .47911 L .81774 .47378 L p .923 .855 .757 r
F P
0 g
s
.83595 .45442 m .81774 .47378 L .81789 .47347 L .923 .855 .757 r
F
.82372 .47911 m .83595 .45442 L .85256 .46098 L p .715 .571 .691 r
F P
0 g
s
.8277 .47629 m .83988 .45101 L .82966 .44944 L p .438 .253 .531 r
F P
0 g
s
.82966 .44944 m .82956 .44943 L p .82955 .44966 L .438 .253 .531 r
F P
0 g
s
.82955 .44966 m .8277 .47629 L .82966 .44944 L .438 .253 .531 r
F
.81774 .47378 m .81767 .47371 L p .81789 .47347 L .923 .855 .757 r
F P
0 g
s
.85256 .46098 m .83973 .48706 L .82372 .47911 L p .715 .571 .691 r
F P
0 g
s
.83973 .48706 m .85256 .46098 L .86293 .4626 L p .441 .259 .536 r
F P
0 g
s
.87278 .43676 m .86293 .4626 L .85256 .46098 L p .433 .267 .555 r
F P
0 g
s
.48536 .30047 m .48238 .28512 L .49091 .28177 L p .933 .745 .626 r
F P
0 g
s
.48886 .26532 m .49091 .28177 L .48238 .28512 L p .932 .756 .641 r
F P
0 g
s
.49091 .28177 m .48886 .26532 L .50669 .26407 L p .711 .608 .74 r
F P
0 g
s
.50669 .26407 m .50861 .27932 L .49091 .28177 L p .711 .608 .74 r
F P
0 g
s
.50861 .27932 m .50669 .26407 L .51575 .2655 L p .378 .367 .72 r
F P
0 g
s
.51578 .2657 m .50861 .27932 L .51575 .2655 L .378 .367 .72 r
F
.51587 .26552 m .51792 .2802 L .50861 .27932 L p F P
0 g
s
.50715 .26824 m .50946 .28356 L .51779 .28025 L p .933 .752 .634 r
F P
0 g
s
.51779 .28025 m .51792 .2802 L p .51775 .28002 L .933 .752 .634 r
F P
0 g
s
.50715 .26824 m .51779 .28025 L .51775 .28002 L .933 .752 .634 r
F
.51575 .2655 m .51587 .26552 L p .51578 .2657 L .378 .367 .72 r
F P
0 g
s
.55657 .62933 m .56476 .62742 L .56404 .63655 L p .742 .84 .925 r
F P
0 g
s
.56404 .63655 m .55437 .63838 L .55648 .62971 L p .742 .84 .925 r
F P
0 g
s
.56404 .63655 m .55648 .62971 L .55687 .62962 L .742 .84 .925 r
F
.55437 .63838 m .56404 .63655 L .57036 .65327 L p .749 .603 .696 r
F P
0 g
s
.56292 .63775 m .57186 .63506 L .56499 .62767 L p .641 .292 .365 r
F P
0 g
s
.56499 .62767 m .56476 .62742 L p .56471 .62773 L .641 .292 .365 r
F P
0 g
s
.56471 .62773 m .56292 .63775 L .56499 .62767 L .641 .292 .365 r
F
.55648 .62971 m .55657 .62933 L p .55687 .62962 L .742 .84 .925 r
F P
0 g
s
.57036 .65327 m .55848 .65578 L .55437 .63838 L p .749 .603 .696 r
F P
0 g
s
.55848 .65578 m .57036 .65327 L .57745 .66097 L p .625 .294 .39 r
F P
0 g
s
.59052 .65566 m .57745 .66097 L .57036 .65327 L p .589 .272 .4 r
F P
0 g
s
.70726 .71895 m .71462 .72789 L .70438 .72999 L p .443 .531 .853 r
F P
0 g
s
.70438 .72999 m .69739 .72106 L .70705 .719 L p .443 .531 .853 r
F P
0 g
s
.70438 .72999 m .70705 .719 L .7072 .71918 L .443 .531 .853 r
F
.70334 .72834 m .71195 .73824 L .71457 .72812 L p .895 .604 .488 r
F P
0 g
s
.71457 .72812 m .71462 .72789 L p .71439 .7279 L .895 .604 .488 r
F P
0 g
s
.71439 .7279 m .70334 .72834 L .71457 .72812 L .895 .604 .488 r
F
.70705 .719 m .70726 .71895 L p .7072 .71918 L .443 .531 .853 r
F P
0 g
s
.69739 .72106 m .70438 .72999 L .69149 .74235 L p .731 .621 .736 r
F P
0 g
s
.69149 .74235 m .68364 .73249 L .69739 .72106 L p .731 .621 .736 r
F P
0 g
s
.68364 .73249 m .69149 .74235 L .68873 .75272 L p .886 .596 .489 r
F P
0 g
s
.69763 .76166 m .68873 .75272 L .69149 .74235 L p .874 .574 .476 r
F P
0 g
s
.49091 .55334 m .50286 .55248 L .50705 .56117 L p .604 .744 .943 r
F P
0 g
s
.51816 .56198 m .50705 .56117 L .50286 .55248 L p .572 .713 .938 r
F P
0 g
s
.50705 .56117 m .51816 .56198 L .51585 .57971 L p .648 .528 .704 r
F P
0 g
s
.51585 .57971 m .50673 .57904 L .50705 .56117 L p .648 .528 .704 r
F P
0 g
s
.50673 .57904 m .51585 .57971 L .51059 .58819 L p .591 .251 .362 r
F P
0 g
s
.5103 .58818 m .50673 .57904 L .51059 .58819 L .591 .251 .362 r
F
.51041 .58847 m .50222 .58834 L .50673 .57904 L p F P
0 g
s
.50726 .57942 m .498 .57972 L .50206 .58801 L p .598 .731 .938 r
F P
0 g
s
.50206 .58801 m .50222 .58834 L p .50241 .58802 L .598 .731 .938 r
F P
0 g
s
.50726 .57942 m .50206 .58801 L .50241 .58802 L .598 .731 .938 r
F
.51059 .58819 m .51041 .58847 L p .5103 .58818 L .591 .251 .362 r
F P
0 g
s
.70201 .35647 m .69666 .34615 L .70734 .3444 L p .429 .466 .797 r
F P
0 g
s
.70734 .3444 m .71276 .35649 L .70201 .35647 L p .429 .466 .797 r
F P
0 g
s
.62214 .38859 m .61958 .38088 L .62912 .38364 L p .909 .61 .467 r
F P
0 g
s
.62912 .38364 m .63193 .39157 L .62214 .38859 L p .909 .61 .467 r
F P
0 g
s
.63193 .39157 m .62912 .38364 L .64631 .37874 L p .682 .502 .636 r
F P
0 g
s
.64631 .37874 m .64897 .38615 L .63193 .39157 L p .682 .502 .636 r
F P
0 g
s
.53586 .37829 m .52795 .37354 L .53781 .37021 L p .72 .332 .314 r
F P
0 g
s
.53781 .37021 m .54535 .37394 L .53586 .37829 L p .72 .332 .314 r
F P
0 g
s
.54535 .37394 m .53781 .37021 L .54857 .35594 L p .632 .482 .66 r
F P
0 g
s
.54857 .35594 m .5545 .35857 L .54535 .37394 L p .632 .482 .66 r
F P
0 g
s
.60178 .31644 m .60493 .31911 L .60285 .33011 L p .909 .625 .494 r
F P
0 g
s
.60493 .31911 m .60178 .31644 L .61423 .3036 L p .751 .665 .766 r
F P
0 g
s
.61423 .3036 m .61908 .30819 L .60493 .31911 L p .751 .665 .766 r
F P
0 g
s
.61908 .30819 m .61423 .3036 L .62638 .30194 L p .469 .56 .866 r
F P
0 g
s
.62638 .30194 m .63124 .30819 L .61908 .30819 L p .469 .56 .866 r
F P
0 g
s
.89069 .70028 m .91366 .67083 L .92259 .67698 L p .469 .27 .527 r
F P
0 g
s
.92259 .67698 m .8985 .70772 L .89069 .70028 L p .469 .27 .527 r
F P
0 g
s
.10814 .64868 m .12977 .67299 L .12466 .67841 L p .387 .503 .854 r
F P
0 g
s
.12466 .67841 m .10212 .65295 L .10799 .64879 L p .387 .503 .854 r
F P
0 g
s
.12466 .67841 m .10799 .64879 L .10855 .64941 L .387 .503 .854 r
F
.10212 .65295 m .12466 .67841 L .11359 .69245 L p .716 .593 .718 r
F P
0 g
s
.11359 .69245 m .08874 .66483 L .10212 .65295 L p .716 .593 .718 r
F P
0 g
s
.10072 .65635 m .12376 .68167 L .12972 .67306 L p .856 .576 .513 r
F P
0 g
s
.12972 .67306 m .12977 .67299 L p .12953 .67285 L .856 .576 .513 r
F P
0 g
s
.12953 .67285 m .10072 .65635 L .12972 .67306 L .856 .576 .513 r
F
.10799 .64879 m .10814 .64868 L p .10855 .64941 L .387 .503 .854 r
F P
0 g
s
.08874 .66483 m .11359 .69245 L .10754 .70118 L p .851 .57 .512 r
F P
0 g
s
.13764 .72433 m .10754 .70118 L .11359 .69245 L p .822 .521 .481 r
F P
0 g
s
.1894 .14261 m .17226 .16802 L .16597 .16423 L p .339 .133 .447 r
F P
0 g
s
.16597 .16423 m .18398 .13772 L .18927 .14249 L p .339 .133 .447 r
F P
0 g
s
.16597 .16423 m .18927 .14249 L .18884 .14312 L .339 .133 .447 r
F
.18398 .13772 m .16597 .16423 L .14971 .1568 L p .699 .58 .719 r
F P
0 g
s
.14971 .1568 m .16918 .12767 L .18398 .13772 L p .699 .58 .719 r
F P
0 g
s
.17994 .13741 m .1622 .16434 L .17216 .16798 L p .856 .82 .813 r
F P
0 g
s
.17216 .16798 m .17226 .16802 L p .17233 .16773 L .856 .82 .813 r
F P
0 g
s
.17233 .16773 m .17994 .13741 L .17216 .16798 L .856 .82 .813 r
F
.18927 .14249 m .1894 .14261 L p .18884 .14312 L .339 .133 .447 r
F P
0 g
s
.16918 .12767 m .14971 .1568 L .1396 .1531 L p .857 .816 .807 r
F P
0 g
s
.12511 .18597 m .1396 .1531 L .14971 .1568 L p .879 .806 .774 r
F P
0 g
s
.37136 .17836 m .35203 .20032 L .34588 .19209 L p .862 .83 .815 r
F P
0 g
s
.34593 .19203 m .37136 .17836 L .34588 .19209 L .862 .83 .815 r
F
.34587 .19207 m .36508 .17017 L .37136 .17836 L p F P
0 g
s
.35301 .19586 m .3724 .17371 L .36511 .17018 L p .404 .149 .411 r
F P
0 g
s
.36511 .17018 m .36508 .17017 L p .36505 .17025 L .404 .149 .411 r
F P
0 g
s
.35301 .19586 m .36511 .17018 L .36505 .17025 L .404 .149 .411 r
F
.34588 .19209 m .34587 .19207 L p .34593 .19203 L .862 .83 .815 r
F P
0 g
s
.80446 .49843 m .81767 .47371 L .82372 .47911 L p .918 .859 .767 r
F P
0 g
s
.82372 .47911 m .81037 .504 L .80449 .49846 L p .918 .859 .767 r
F P
0 g
s
.82372 .47911 m .80449 .49846 L .80455 .49834 L .918 .859 .767 r
F
.81037 .504 m .82372 .47911 L .83973 .48706 L p .716 .571 .691 r
F P
0 g
s
.81435 .50144 m .8277 .47629 L .81771 .47372 L p .442 .25 .523 r
F P
0 g
s
.81771 .47372 m .81767 .47371 L p .81765 .47382 L .442 .25 .523 r
F P
0 g
s
.81765 .47382 m .81435 .50144 L .81771 .47372 L .442 .25 .523 r
F
.80449 .49846 m .80446 .49843 L p .80455 .49834 L .918 .859 .767 r
F P
0 g
s
.83973 .48706 m .82609 .51254 L .81037 .504 L p .716 .571 .691 r
F P
0 g
s
.82609 .51254 m .83973 .48706 L .84982 .48968 L p .446 .255 .527 r
F P
0 g
s
.86293 .4626 m .84982 .48968 L .83973 .48706 L p .441 .259 .536 r
F P
0 g
s
.17961 .46256 m .19552 .48582 L .18598 .4895 L p .861 .572 .499 r
F P
0 g
s
.18594 .48944 m .17961 .46256 L .18598 .4895 L .861 .572 .499 r
F
.18595 .48951 m .17007 .46633 L .17961 .46256 L p F P
0 g
s
.19131 .48321 m .17524 .45984 L .17008 .46631 L p .365 .432 .797 r
F P
0 g
s
.17008 .46631 m .17007 .46633 L p .17012 .46637 L .365 .432 .797 r
F P
0 g
s
.19131 .48321 m .17008 .46631 L .17012 .46637 L .365 .432 .797 r
F
.18598 .4895 m .18595 .48951 L p .18594 .48944 L .861 .572 .499 r
F P
0 g
s
.48238 .28512 m .48006 .26803 L .48886 .26532 L p .932 .756 .641 r
F P
0 g
s
.48786 .24893 m .48886 .26532 L .48006 .26803 L p .931 .77 .66 r
F P
0 g
s
.48886 .26532 m .48786 .24893 L .50575 .24856 L p .709 .606 .74 r
F P
0 g
s
.50575 .24856 m .50669 .26407 L .48886 .26532 L p .709 .606 .74 r
F P
0 g
s
.50669 .26407 m .50575 .24856 L .51472 .25035 L p .372 .346 .7 r
F P
0 g
s
.51473 .2505 m .50669 .26407 L .51472 .25035 L .372 .346 .7 r
F
.51481 .25037 m .51587 .26552 L .50669 .26407 L p F P
0 g
s
.50591 .25257 m .50715 .26824 L .51578 .26555 L p .933 .769 .655 r
F P
0 g
s
.51578 .26555 m .51587 .26552 L p .51577 .26538 L .933 .769 .655 r
F P
0 g
s
.50591 .25257 m .51578 .26555 L .51577 .26538 L .933 .769 .655 r
F
.51472 .25035 m .51481 .25037 L p .51473 .2505 L .372 .346 .7 r
F P
0 g
s
.70072 .70952 m .70726 .71895 L .69739 .72106 L p .431 .507 .836 r
F P
0 g
s
.69739 .72106 m .69066 .71094 L .7005 .70955 L p .431 .507 .836 r
F P
0 g
s
.69739 .72106 m .7005 .70955 L .70065 .70977 L .431 .507 .836 r
F
.69611 .71847 m .70334 .72834 L .70718 .71913 L p .908 .631 .506 r
F P
0 g
s
.70718 .71913 m .70726 .71895 L p .70706 .71895 L .908 .631 .506 r
F P
0 g
s
.70706 .71895 m .69611 .71847 L .70718 .71913 L .908 .631 .506 r
F
.7005 .70955 m .70072 .70952 L p .70065 .70977 L .431 .507 .836 r
F P
0 g
s
.69066 .71094 m .69739 .72106 L .68364 .73249 L p .728 .62 .738 r
F P
0 g
s
.68364 .73249 m .67602 .72123 L .69066 .71094 L p .728 .62 .738 r
F P
0 g
s
.67602 .72123 m .68364 .73249 L .67964 .74189 L p .899 .62 .506 r
F P
0 g
s
.68873 .75272 m .67964 .74189 L .68364 .73249 L p .886 .596 .489 r
F P
0 g
s
.54868 .62981 m .55657 .62933 L .55437 .63838 L p .691 .808 .937 r
F P
0 g
s
.55437 .63838 m .54502 .63844 L .54849 .63028 L p .691 .808 .937 r
F P
0 g
s
.55437 .63838 m .54849 .63028 L .54897 .63024 L .691 .808 .937 r
F
.54502 .63844 m .55437 .63838 L .55848 .65578 L p .749 .609 .703 r
F P
0 g
s
.55371 .63911 m .56292 .63775 L .55682 .62966 L p .69 .331 .361 r
F P
0 g
s
.55682 .62966 m .55657 .62933 L p .55646 .62969 L .69 .331 .361 r
F P
0 g
s
.55646 .62969 m .55371 .63911 L .55682 .62966 L .69 .331 .361 r
F
.54849 .63028 m .54868 .62981 L p .54897 .63024 L .691 .808 .937 r
F P
0 g
s
.55848 .65578 m .54634 .65628 L .54502 .63844 L p .749 .609 .703 r
F P
0 g
s
.54634 .65628 m .55848 .65578 L .56481 .66427 L p .664 .325 .389 r
F P
0 g
s
.57745 .66097 m .56481 .66427 L .55848 .65578 L p .625 .294 .39 r
F P
0 g
s
.43236 .58619 m .44593 .5786 L .44239 .57006 L p .519 .229 .413 r
F P
0 g
s
.44239 .57006 m .42825 .57793 L .43236 .58619 L p .519 .229 .413 r
F P
0 g
s
.44593 .5786 m .45573 .57389 L .45642 .56357 L p .538 .237 .405 r
F P
0 g
s
.45642 .56357 m .44239 .57006 L .44593 .5786 L p .538 .237 .405 r
F P
0 g
s
.73251 .75168 m .73309 .75242 L .73372 .7424 L p .835 .464 .351 r
F P
0 g
s
.73372 .7424 m .72957 .74073 L .73251 .75168 L p .835 .464 .351 r
F P
0 g
s
.59851 .61855 m .60442 .61312 L .59797 .60596 L p .502 .225 .426 r
F P
0 g
s
.59797 .60596 m .58936 .61382 L .59851 .61855 L p .502 .225 .426 r
F P
0 g
s
.60442 .61312 m .61423 .60416 L .60724 .59754 L p .479 .232 .461 r
F P
0 g
s
.61423 .60416 m .6232 .59458 L .61563 .58864 L p .465 .232 .476 r
F P
0 g
s
.6232 .59458 m .63118 .58429 L .62304 .57917 L p .449 .234 .494 r
F P
0 g
s
.63118 .58429 m .63801 .57322 L .62939 .56898 L p .432 .239 .517 r
F P
0 g
s
.63801 .57322 m .64418 .56025 L .63527 .55669 L p .418 .248 .542 r
F P
0 g
s
.64418 .56025 m .64946 .54655 L .6404 .54341 L p .41 .257 .561 r
F P
0 g
s
.64946 .54655 m .65436 .53186 L .64534 .52862 L p .405 .263 .572 r
F P
0 g
s
.65436 .53186 m .65992 .51646 L .65131 .51225 L p .408 .259 .565 r
F P
0 g
s
.65131 .51225 m .64534 .52862 L .65436 .53186 L p .408 .259 .565 r
F P
0 g
s
.65992 .51646 m .66683 .50277 L .65828 .49844 L p .42 .246 .537 r
F P
0 g
s
.65828 .49844 m .65131 .51225 L .65992 .51646 L p .42 .246 .537 r
F P
0 g
s
.66683 .50277 m .67379 .48971 L .66505 .48576 L p .422 .243 .531 r
F P
0 g
s
.66505 .48576 m .65828 .49844 L .66683 .50277 L p .422 .243 .531 r
F P
0 g
s
.67379 .48971 m .68003 .47677 L .67101 .47345 L p .418 .247 .541 r
F P
0 g
s
.67101 .47345 m .66505 .48576 L .67379 .48971 L p .418 .247 .541 r
F P
0 g
s
.68003 .47677 m .68522 .46377 L .67588 .4614 L p .411 .255 .557 r
F P
0 g
s
.67588 .4614 m .67101 .47345 L .68003 .47677 L p .411 .255 .557 r
F P
0 g
s
.68522 .46377 m .6888 .45104 L .67925 .44957 L p .403 .27 .584 r
F P
0 g
s
.67925 .44957 m .67588 .4614 L .68522 .46377 L p .403 .27 .584 r
F P
0 g
s
.6888 .45104 m .69114 .43787 L .68148 .43719 L p .398 .287 .61 r
F P
0 g
s
.68148 .43719 m .67925 .44957 L .6888 .45104 L p .398 .287 .61 r
F P
0 g
s
.69114 .43787 m .69238 .42434 L .68269 .42425 L p .396 .303 .632 r
F P
0 g
s
.68269 .42425 m .68148 .43719 L .69114 .43787 L p .396 .303 .632 r
F P
0 g
s
.69238 .42434 m .69261 .41377 L .68311 .40989 L p .395 .316 .649 r
F P
0 g
s
.68311 .40989 m .68269 .42425 L .69238 .42434 L p .395 .316 .649 r
F P
0 g
s
.13372 .30094 m .13858 .3348 L .1491 .33499 L p .91 .724 .639 r
F P
0 g
s
.1491 .33499 m .14383 .29913 L .13372 .30094 L p .91 .724 .639 r
F P
0 g
s
.15417 .35725 m .1491 .33499 L .13858 .3348 L p .902 .674 .583 r
F P
0 g
s
.86368 .31824 m .86072 .28155 L .85058 .28421 L p .418 .357 .682 r
F P
0 g
s
.85058 .28421 m .85334 .31957 L .86368 .31824 L p .418 .357 .682 r
F P
0 g
s
.86072 .28155 m .85306 .24641 L .84334 .2505 L p .424 .388 .715 r
F P
0 g
s
.84334 .2505 m .85058 .28421 L .86072 .28155 L p .424 .388 .715 r
F P
0 g
s
.85306 .24641 m .84007 .21262 L .83086 .21785 L p .437 .427 .751 r
F P
0 g
s
.83086 .21785 m .84334 .2505 L .85306 .24641 L p .437 .427 .751 r
F P
0 g
s
.84007 .21262 m .82447 .1833 L .81609 .18984 L p .45 .46 .777 r
F P
0 g
s
.81609 .18984 m .83086 .21785 L .84007 .21262 L p .45 .46 .777 r
F P
0 g
s
.82447 .1833 m .8044 .15682 L .797 .16447 L p .472 .504 .81 r
F P
0 g
s
.797 .16447 m .81609 .18984 L .82447 .1833 L p .472 .504 .81 r
F P
0 g
s
.8044 .15682 m .78035 .13348 L .77401 .14204 L p .496 .546 .837 r
F P
0 g
s
.78035 .13348 m .75252 .1133 L .74681 .12228 L p .523 .586 .86 r
F P
0 g
s
.75252 .1133 m .72398 .09541 L .71949 .10505 L p .536 .604 .869 r
F P
0 g
s
.72398 .09541 m .69351 .08182 L .69041 .09197 L p .566 .642 .885 r
F P
0 g
s
.69351 .08182 m .66157 .07305 L .65999 .08349 L p .599 .68 .898 r
F P
0 g
s
.66157 .07305 m .62823 .06941 L .62783 .07991 L p .637 .718 .906 r
F P
0 g
s
.62823 .06941 m .59215 .06972 L .59325 .08011 L p .665 .742 .908 r
F P
0 g
s
.59215 .06972 m .55643 .07554 L .55886 .08562 L p .702 .771 .906 r
F P
0 g
s
.55643 .07554 m .52123 .08638 L .52491 .09598 L p .735 .793 .899 r
F P
0 g
s
.52123 .08638 m .48876 .10125 L .49174 .1113 L p .766 .81 .888 r
F P
0 g
s
.24415 .73694 m .27486 .73513 L .27306 .72555 L p .662 .331 .402 r
F P
0 g
s
.27306 .72555 m .24324 .72704 L .24415 .73694 L p .662 .331 .402 r
F P
0 g
s
.35022 .66655 m .36139 .65151 L .35507 .64507 L p .424 .209 .481 r
F P
0 g
s
.35507 .64507 m .34362 .66044 L .35022 .66655 L p .424 .209 .481 r
F P
0 g
s
.36139 .65151 m .37195 .63887 L .36589 .63212 L p .435 .209 .47 r
F P
0 g
s
.36589 .63212 m .35507 .64507 L .36139 .65151 L p .435 .209 .47 r
F P
0 g
s
.37195 .63887 m .3831 .62684 L .37729 .61984 L p .446 .21 .461 r
F P
0 g
s
.37729 .61984 m .36589 .63212 L .37195 .63887 L p .446 .21 .461 r
F P
0 g
s
.3831 .62684 m .39482 .61533 L .38936 .60801 L p .456 .211 .452 r
F P
0 g
s
.38936 .60801 m .37729 .61984 L .3831 .62684 L p .456 .211 .452 r
F P
0 g
s
.39482 .61533 m .40711 .60463 L .40192 .5971 L p .47 .213 .442 r
F P
0 g
s
.40192 .5971 m .38936 .60801 L .39482 .61533 L p .47 .213 .442 r
F P
0 g
s
.40711 .60463 m .41937 .59494 L .41467 .58704 L p .481 .216 .435 r
F P
0 g
s
.41467 .58704 m .40192 .5971 L .40711 .60463 L p .481 .216 .435 r
F P
0 g
s
.41937 .59494 m .43236 .58619 L .42825 .57793 L p .499 .221 .424 r
F P
0 g
s
.42825 .57793 m .41467 .58704 L .41937 .59494 L p .499 .221 .424 r
F P
0 g
s
.44575 .60912 m .45741 .60251 L .45347 .59489 L p .787 .849 .897 r
F P
0 g
s
.45347 .59489 m .44115 .60184 L .44575 .60912 L p .787 .849 .897 r
F P
0 g
s
.45741 .60251 m .47027 .59655 L .46268 .59043 L p .78 .847 .902 r
F P
0 g
s
.46268 .59043 m .45347 .59489 L .45741 .60251 L p .78 .847 .902 r
F P
0 g
s
.47027 .59655 m .47818 .59323 L .47123 .58646 L p .719 .824 .93 r
F P
0 g
s
.71977 .77515 m .73324 .77816 L .73284 .77037 L p .597 .764 .959 r
F P
0 g
s
.73324 .77816 m .77011 .77836 L .76774 .77114 L p .613 .757 .947 r
F P
0 g
s
.76774 .77114 m .73284 .77037 L .73324 .77816 L p .613 .757 .947 r
F P
0 g
s
.64423 .33809 m .63859 .34588 L p .64663 .34646 L .854 .84 .831 r
F P
0 g
s
.63692 .33871 m .63859 .34588 L .64466 .3375 L p .959 .771 .606 r
F P
0 g
s
.64663 .34646 m .64725 .3465 L .64423 .33809 L .854 .84 .831 r
F
.63859 .34588 m .63745 .34101 L p .62029 .34549 L .728 .663 .785 r
F P
0 g
s
.63745 .34101 m .63692 .33871 L .63604 .33907 L p .728 .663 .785 r
F P
0 g
s
.63604 .33907 m .62029 .34549 L p .63745 .34101 L .728 .663 .785 r
F P
0 g
s
.6378 .34349 m .64725 .3465 L p .64663 .34646 L .854 .84 .831 r
F P
0 g
s
.63859 .34588 m .6378 .34349 L p .64663 .34646 L .854 .84 .831 r
F P
0 g
s
.62029 .34549 m .6215 .35136 L .63859 .34588 L p .728 .663 .785 r
F P
0 g
s
.63859 .34588 m .6215 .35136 L p .63729 .34373 L .731 .739 .858 r
F P
0 g
s
.6378 .34349 m .63783 .34357 L p .63729 .34373 L .731 .739 .858 r
F P
0 g
s
.63783 .34357 m .63859 .34588 L p .63729 .34373 L .731 .739 .858 r
F P
0 g
s
.6215 .35136 m .62047 .34819 L .6378 .34349 L p .731 .739 .858 r
F P
0 g
s
.62269 .35628 m .64015 .35199 L p .62183 .34845 L .689 .513 .643 r
F P
0 g
s
.62047 .34819 m .62064 .34881 L p .62183 .34845 L .689 .513 .643 r
F P
0 g
s
.62064 .34881 m .62269 .35628 L p .62183 .34845 L .689 .513 .643 r
F P
0 g
s
.6378 .34349 m .64015 .35199 L .64725 .35442 L p .922 .641 .494 r
F P
0 g
s
.64725 .35442 m .6491 .35506 L p .6436 .34943 L .922 .641 .494 r
F P
0 g
s
.6378 .34349 m .64725 .35442 L .6436 .34943 L .922 .641 .494 r
F
.6491 .35506 m .64953 .35521 L p .64898 .35465 L F P
0 g
s
.6378 .34349 m .6491 .35506 L .64898 .35465 L .922 .641 .494 r
F
.64725 .3465 m .64466 .3375 L .64423 .33809 L p .854 .84 .831 r
F P
0 g
s
.64466 .3375 m .64229 .32985 L .63692 .33871 L p .959 .771 .606 r
F P
0 g
s
.61319 .64052 m .62213 .63233 L .61655 .62635 L p .88 .88 .83 r
F P
0 g
s
.62213 .63233 m .63343 .6219 L .62738 .61639 L p .844 .87 .862 r
F P
0 g
s
.62738 .61639 m .61655 .62635 L .62213 .63233 L p .844 .87 .862 r
F P
0 g
s
.63343 .6219 m .64398 .61044 L .63743 .60553 L p .861 .87 .844 r
F P
0 g
s
.63743 .60553 m .62738 .61639 L .63343 .6219 L p .861 .87 .844 r
F P
0 g
s
.64398 .61044 m .65354 .59784 L .64649 .59366 L p .879 .867 .823 r
F P
0 g
s
.64649 .59366 m .63743 .60553 L .64398 .61044 L p .879 .867 .823 r
F P
0 g
s
.65354 .59784 m .66171 .58429 L .65424 .5809 L p .897 .86 .796 r
F P
0 g
s
.65424 .5809 m .64649 .59366 L .65354 .59784 L p .897 .86 .796 r
F P
0 g
s
.66171 .58429 m .66865 .56953 L .66093 .5667 L p .912 .85 .768 r
F P
0 g
s
.66093 .5667 m .65424 .5809 L .66171 .58429 L p .912 .85 .768 r
F P
0 g
s
.66865 .56953 m .67432 .55473 L .66649 .55223 L p .921 .84 .748 r
F P
0 g
s
.66649 .55223 m .66093 .5667 L .66865 .56953 L p .921 .84 .748 r
F P
0 g
s
.67432 .55473 m .67902 .54062 L .67127 .53789 L p .925 .833 .735 r
F P
0 g
s
.67127 .53789 m .66649 .55223 L .67432 .55473 L p .925 .833 .735 r
F P
0 g
s
.67595 .52454 m .67127 .53789 L .67902 .54062 L p .924 .836 .74 r
F P
0 g
s
.68268 .5112 m .67595 .52454 L .68325 .52835 L p .908 .852 .775 r
F P
0 g
s
.68985 .51524 m .69729 .50123 L .68997 .49748 L p .905 .854 .781 r
F P
0 g
s
.68997 .49748 m .68268 .5112 L .68985 .51524 L p .905 .854 .781 r
F P
0 g
s
.69729 .50123 m .70427 .4866 L .69672 .48337 L p .911 .85 .77 r
F P
0 g
s
.69672 .48337 m .68997 .49748 L .69729 .50123 L p .911 .85 .77 r
F P
0 g
s
.70427 .4866 m .71034 .47097 L .70251 .46858 L p .92 .841 .75 r
F P
0 g
s
.70251 .46858 m .69672 .48337 L .70427 .4866 L p .92 .841 .75 r
F P
0 g
s
.71034 .47097 m .71448 .45574 L .70648 .45414 L p .931 .825 .719 r
F P
0 g
s
.70648 .45414 m .70251 .46858 L .71034 .47097 L p .931 .825 .719 r
F P
0 g
s
.71448 .45574 m .7171 .44041 L .70902 .43949 L p .937 .807 .691 r
F P
0 g
s
.70902 .43949 m .70648 .45414 L .71448 .45574 L p .937 .807 .691 r
F P
0 g
s
.7171 .44041 m .71844 .4253 L .71032 .42487 L p .941 .79 .666 r
F P
0 g
s
.71032 .42487 m .70902 .43949 L .7171 .44041 L p .941 .79 .666 r
F P
0 g
s
.71844 .4253 m .71884 .41143 L .71055 .41454 L p .942 .769 .638 r
F P
0 g
s
.71055 .41454 m .71032 .42487 L .71844 .4253 L p .942 .769 .638 r
F P
0 g
s
.71884 .41143 m .71953 .39786 L .71153 .40167 L p .942 .818 .693 r
F P
0 g
s
.71153 .40167 m .71055 .41454 L .71884 .41143 L p .942 .818 .693 r
F P
0 g
s
.53483 .32884 m .52895 .31762 L .52193 .32336 L p .916 .658 .534 r
F P
0 g
s
.1084 .30417 m .11436 .34345 L .12114 .33905 L p .313 .304 .689 r
F P
0 g
s
.11436 .34345 m .12058 .36962 L .12689 .36441 L p .308 .296 .682 r
F P
0 g
s
.12689 .36441 m .12114 .33905 L .11436 .34345 L p .308 .296 .682 r
F P
0 g
s
.88898 .31662 m .8855 .27649 L .87825 .27767 L p .953 .755 .599 r
F P
0 g
s
.87825 .27767 m .88157 .31677 L .88898 .31662 L p .953 .755 .599 r
F P
0 g
s
.8855 .27649 m .8767 .2376 L .86981 .23993 L p .947 .715 .554 r
F P
0 g
s
.86981 .23993 m .87825 .27767 L .8855 .27649 L p .947 .715 .554 r
F P
0 g
s
.8767 .2376 m .86238 .20095 L .85589 .20414 L p .934 .664 .504 r
F P
0 g
s
.85589 .20414 m .86981 .23993 L .8767 .2376 L p .934 .664 .504 r
F P
0 g
s
.86238 .20095 m .84452 .16815 L .83874 .17241 L p .917 .619 .465 r
F P
0 g
s
.83874 .17241 m .85589 .20414 L .86238 .20095 L p .917 .619 .465 r
F P
0 g
s
.84452 .16815 m .82183 .13874 L .81686 .1439 L p .888 .559 .419 r
F P
0 g
s
.81686 .1439 m .83874 .17241 L .84452 .16815 L p .888 .559 .419 r
F P
0 g
s
.82183 .13874 m .79498 .11307 L .79088 .11894 L p .855 .5 .38 r
F P
0 g
s
.79088 .11894 m .81686 .1439 L .82183 .13874 L p .855 .5 .38 r
F P
0 g
s
.79498 .11307 m .76572 .09193 L .76202 .09807 L p .819 .447 .35 r
F P
0 g
s
.76202 .09807 m .79088 .11894 L .79498 .11307 L p .819 .447 .35 r
F P
0 g
s
.76572 .09193 m .73395 .07234 L .73124 .079 L p .799 .42 .337 r
F P
0 g
s
.73124 .079 m .76202 .09807 L .76572 .09193 L p .799 .42 .337 r
F P
0 g
s
.73395 .07234 m .69977 .05745 L .69821 .0645 L p .757 .368 .316 r
F P
0 g
s
.69821 .0645 m .73124 .079 L .73395 .07234 L p .757 .368 .316 r
F P
0 g
s
.69977 .05745 m .6638 .04793 L .66349 .0552 L p .71 .316 .301 r
F P
0 g
s
.66349 .0552 m .69821 .0645 L .69977 .05745 L p .71 .316 .301 r
F P
0 g
s
.6638 .04793 m .62742 .04415 L .62802 .05146 L p .659 .269 .294 r
F P
0 g
s
.62802 .05146 m .66349 .0552 L .6638 .04793 L p .659 .269 .294 r
F P
0 g
s
.62742 .04415 m .58742 .04482 L .58922 .05201 L p .621 .237 .295 r
F P
0 g
s
.58922 .05201 m .62802 .05146 L .62742 .04415 L p .621 .237 .295 r
F P
0 g
s
.58742 .04482 m .54826 .05146 L .55111 .05839 L p .573 .204 .304 r
F P
0 g
s
.55111 .05839 m .58922 .05201 L .58742 .04482 L p .573 .204 .304 r
F P
0 g
s
.54826 .05146 m .50985 .06354 L .51367 .07009 L p .531 .18 .318 r
F P
0 g
s
.51367 .07009 m .55111 .05839 L .54826 .05146 L p .531 .18 .318 r
F P
0 g
s
.50985 .06354 m .47396 .08027 L .47983 .08568 L p .494 .165 .337 r
F P
0 g
s
.47983 .08568 m .51367 .07009 L .50985 .06354 L p .494 .165 .337 r
F P
0 g
s
.47396 .08027 m .44945 .09412 L .45592 .09893 L p .486 .159 .336 r
F P
0 g
s
.45592 .09893 m .47983 .08568 L .47396 .08027 L p .486 .159 .336 r
F P
0 g
s
.24544 .76277 m .28378 .75967 L .28024 .75225 L p .671 .8 .944 r
F P
0 g
s
.28378 .75967 m .29982 .75422 L .29461 .74753 L p .734 .834 .927 r
F P
0 g
s
.29461 .74753 m .28024 .75225 L .28378 .75967 L p .734 .834 .927 r
F P
0 g
s
.29982 .75422 m .31364 .74619 L .30741 .74018 L p .79 .854 .899 r
F P
0 g
s
.30741 .74018 m .29461 .74753 L .29982 .75422 L p .79 .854 .899 r
F P
0 g
s
.31364 .74619 m .32661 .73595 L .31958 .73066 L p .824 .859 .873 r
F P
0 g
s
.31958 .73066 m .30741 .74018 L .31364 .74619 L p .824 .859 .873 r
F P
0 g
s
.32661 .73595 m .33747 .72504 L .33015 .72006 L p .849 .859 .849 r
F P
0 g
s
.33015 .72006 m .31958 .73066 L .32661 .73595 L p .849 .859 .849 r
F P
0 g
s
.33747 .72504 m .35009 .71091 L .34247 .70628 L p .86 .857 .837 r
F P
0 g
s
.34247 .70628 m .33015 .72006 L .33747 .72504 L p .86 .857 .837 r
F P
0 g
s
.35009 .71091 m .36166 .69632 L .35388 .69191 L p .87 .854 .824 r
F P
0 g
s
.35388 .69191 m .34247 .70628 L .35009 .71091 L p .87 .854 .824 r
F P
0 g
s
.36166 .69632 m .37234 .68176 L .36463 .67724 L p .876 .851 .815 r
F P
0 g
s
.36463 .67724 m .35388 .69191 L .36166 .69632 L p .876 .851 .815 r
F P
0 g
s
.37234 .68176 m .38254 .66797 L .37518 .663 L p .875 .852 .816 r
F P
0 g
s
.37518 .663 m .36463 .67724 L .37234 .68176 L p .875 .852 .816 r
F P
0 g
s
.38254 .66797 m .39212 .65643 L .38511 .65107 L p .866 .855 .829 r
F P
0 g
s
.38511 .65107 m .37518 .663 L .38254 .66797 L p .866 .855 .829 r
F P
0 g
s
.39212 .65643 m .40237 .64534 L .39569 .63963 L p .856 .857 .841 r
F P
0 g
s
.39569 .63963 m .38511 .65107 L .39212 .65643 L p .856 .857 .841 r
F P
0 g
s
.40237 .64534 m .41286 .63498 L .40662 .62886 L p .847 .858 .85 r
F P
0 g
s
.40662 .62886 m .39569 .63963 L .40237 .64534 L p .847 .858 .85 r
F P
0 g
s
.41286 .63498 m .42415 .62511 L .41827 .61869 L p .835 .858 .862 r
F P
0 g
s
.41827 .61869 m .40662 .62886 L .41286 .63498 L p .835 .858 .862 r
F P
0 g
s
.42415 .62511 m .43471 .61666 L .42943 .60981 L p .825 .857 .871 r
F P
0 g
s
.42943 .60981 m .41827 .61869 L .42415 .62511 L p .825 .857 .871 r
F P
0 g
s
.43471 .61666 m .44575 .60912 L .44115 .60184 L p .808 .854 .884 r
F P
0 g
s
.44115 .60184 m .42943 .60981 L .43471 .61666 L p .808 .854 .884 r
F P
0 g
s
.50286 .55248 m .51505 .55287 L .51816 .56198 L p .572 .713 .938 r
F P
0 g
s
.52899 .56392 m .51816 .56198 L .51505 .55287 L p .541 .68 .929 r
F P
0 g
s
.51816 .56198 m .52899 .56392 L .52497 .58136 L p .649 .524 .698 r
F P
0 g
s
.52497 .58136 m .51585 .57971 L .51816 .56198 L p .649 .524 .698 r
F P
0 g
s
.51585 .57971 m .52497 .58136 L .51901 .58934 L p .627 .278 .36 r
F P
0 g
s
.51876 .58931 m .51585 .57971 L .51901 .58934 L .627 .278 .36 r
F
.51884 .58957 m .51041 .58847 L .51585 .57971 L p F P
0 g
s
.51671 .58027 m .50726 .57942 L .51031 .58817 L p .562 .697 .931 r
F P
0 g
s
.51031 .58817 m .51041 .58847 L p .51061 .58821 L .562 .697 .931 r
F P
0 g
s
.51671 .58027 m .51031 .58817 L .51061 .58821 L .562 .697 .931 r
F
.51901 .58934 m .51884 .58957 L p .51876 .58931 L .627 .278 .36 r
F P
0 g
s
.69666 .34615 m .68959 .33695 L .69997 .33357 L p .457 .52 .834 r
F P
0 g
s
.69997 .33357 m .70734 .3444 L .69666 .34615 L p .457 .52 .834 r
F P
0 g
s
.62577 .39707 m .62214 .38859 L .63193 .39157 L p .89 .565 .428 r
F P
0 g
s
.63193 .39157 m .63577 .39908 L .62577 .39707 L p .89 .565 .428 r
F P
0 g
s
.63577 .39908 m .63193 .39157 L .64897 .38615 L p .673 .491 .631 r
F P
0 g
s
.64897 .38615 m .65225 .39209 L .63577 .39908 L p .673 .491 .631 r
F P
0 g
s
.54515 .38216 m .53586 .37829 L .54535 .37394 L p .664 .275 .298 r
F P
0 g
s
.54535 .37394 m .55379 .37636 L .54515 .38216 L p .664 .275 .298 r
F P
0 g
s
.55379 .37636 m .54535 .37394 L .5545 .35857 L p .62 .48 .669 r
F P
0 g
s
.5545 .35857 m .56044 .35974 L .55379 .37636 L p .62 .48 .669 r
F P
0 g
s
.60139 .32771 m .60178 .31644 L p .60282 .32978 L .909 .625 .494 r
F P
0 g
s
.59823 .31434 m .60178 .31644 L .60139 .32771 L p .884 .573 .456 r
F P
0 g
s
.60139 .32771 m .59981 .3257 L .59823 .31434 L p .884 .573 .456 r
F P
0 g
s
.60139 .32771 m .61353 .32612 L p .6 .32571 L .485 .664 .941 r
F P
0 g
s
.59981 .3257 m .60139 .32771 L p .6 .32571 L .485 .664 .941 r
F P
0 g
s
.60285 .33011 m .60139 .32771 L p .60282 .32978 L .909 .625 .494 r
F P
0 g
s
.60178 .31644 m .59823 .31434 L .60856 .29972 L p .76 .666 .758 r
F P
0 g
s
.60856 .29972 m .61423 .3036 L .60178 .31644 L p .76 .666 .758 r
F P
0 g
s
.61423 .3036 m .60856 .29972 L .62055 .29637 L p .502 .606 .889 r
F P
0 g
s
.62055 .29637 m .62638 .30194 L .61423 .3036 L p .502 .606 .889 r
F P
0 g
s
.91366 .67083 m .93159 .63753 L .94131 .64242 L p .449 .283 .563 r
F P
0 g
s
.94131 .64242 m .92259 .67698 L .91366 .67083 L p .449 .283 .563 r
F P
0 g
s
.09077 .62059 m .10814 .64868 L .10212 .65295 L p .348 .435 .809 r
F P
0 g
s
.10212 .65295 m .08407 .6236 L .09061 .62067 L p .348 .435 .809 r
F P
0 g
s
.10212 .65295 m .09061 .62067 L .09104 .62137 L .348 .435 .809 r
F
.08407 .6236 m .10212 .65295 L .08874 .66483 L p .714 .593 .719 r
F P
0 g
s
.08874 .66483 m .06883 .633 L .08407 .6236 L p .714 .593 .719 r
F P
0 g
s
.08216 .62702 m .10072 .65635 L .10808 .64875 L p .878 .623 .549 r
F P
0 g
s
.10808 .64875 m .10814 .64868 L p .10792 .6485 L .878 .623 .549 r
F P
0 g
s
.10792 .6485 m .08216 .62702 L .10808 .64875 L .878 .623 .549 r
F
.09061 .62067 m .09077 .62059 L p .09104 .62137 L .348 .435 .809 r
F P
0 g
s
.06883 .633 m .08874 .66483 L .08128 .67254 L p .874 .617 .547 r
F P
0 g
s
.10754 .70118 m .08128 .67254 L .08874 .66483 L p .851 .57 .512 r
F P
0 g
s
.2105 .12032 m .1894 .14261 L .18398 .13772 L p .369 .121 .401 r
F P
0 g
s
.18398 .13772 m .2061 .11451 L .21039 .12018 L p .369 .121 .401 r
F P
0 g
s
.18398 .13772 m .21039 .12018 L .20988 .12072 L .369 .121 .401 r
F
.2061 .11451 m .18398 .13772 L .16918 .12767 L p .697 .578 .718 r
F P
0 g
s
.16918 .12767 m .19313 .10216 L .2061 .11451 L p .697 .578 .718 r
F P
0 g
s
.20187 .11373 m .17994 .13741 L .18931 .14256 L p .829 .821 .842 r
F P
0 g
s
.18931 .14256 m .1894 .14261 L p .18952 .14234 L .829 .821 .842 r
F P
0 g
s
.18952 .14234 m .20187 .11373 L .18931 .14256 L .829 .821 .842 r
F
.21039 .12018 m .2105 .12032 L p .20988 .12072 L .369 .121 .401 r
F P
0 g
s
.19313 .10216 m .16918 .12767 L .15968 .12243 L p .831 .818 .837 r
F P
0 g
s
.1396 .1531 m .15968 .12243 L .16918 .12767 L p .857 .816 .807 r
F P
0 g
s
.34469 .23438 m .36529 .21234 L .37248 .2162 L p .415 .155 .408 r
F P
0 g
s
.36529 .21234 m .34469 .23438 L .33295 .22086 L p .719 .576 .693 r
F P
0 g
s
.33295 .22086 m .35203 .20032 L .36529 .21234 L p .719 .576 .693 r
F P
0 g
s
.35203 .20032 m .33295 .22086 L .32767 .21214 L p .86 .831 .818 r
F P
0 g
s
.32787 .21193 m .35203 .20032 L .32767 .21214 L .86 .831 .818 r
F
.32762 .21205 m .34587 .19207 L .35203 .20032 L p F P
0 g
s
.33408 .21679 m .35301 .19586 L .34599 .19214 L p .408 .15 .407 r
F P
0 g
s
.34599 .19214 m .34587 .19207 L p .34566 .19249 L .408 .15 .407 r
F P
0 g
s
.33408 .21679 m .34599 .19214 L .34566 .19249 L .408 .15 .407 r
F
.32767 .21214 m .32762 .21205 L p .32787 .21193 L .86 .831 .818 r
F P
0 g
s
.79086 .52364 m .80446 .49843 L .81037 .504 L p .918 .86 .768 r
F P
0 g
s
.81037 .504 m .7968 .52914 L .79086 .52365 L p .918 .86 .768 r
F P
0 g
s
.81037 .504 m .79086 .52365 L .79087 .52363 L .918 .86 .768 r
F
.7968 .52914 m .81037 .504 L .82609 .51254 L p .716 .571 .691 r
F P
0 g
s
.80069 .52678 m .81435 .50144 L .80446 .49843 L p .442 .25 .523 r
F P
0 g
s
.80446 .49843 m .80446 .49843 L p .80446 .49845 L .442 .25 .523 r
F P
0 g
s
.80446 .49845 m .80069 .52678 L .80446 .49843 L .442 .25 .523 r
F
.79086 .52365 m .79086 .52364 L p .79087 .52363 L .918 .86 .768 r
F P
0 g
s
.82609 .51254 m .8125 .53776 L .7968 .52914 L p .716 .571 .691 r
F P
0 g
s
.8125 .53776 m .82609 .51254 L .83602 .51559 L p .446 .254 .526 r
F P
0 g
s
.84982 .48968 m .83602 .51559 L .82609 .51254 L p .446 .255 .527 r
F P
0 g
s
.22619 .50031 m .21041 .47588 L .21583 .46956 L p .365 .425 .79 r
F P
0 g
s
.21041 .47588 m .22619 .50031 L .21025 .50848 L p .696 .555 .691 r
F P
0 g
s
.21025 .50848 m .19552 .48582 L .21041 .47588 L p .696 .555 .691 r
F P
0 g
s
.19552 .48582 m .21025 .50848 L .20047 .51122 L p .862 .575 .501 r
F P
0 g
s
.20031 .51098 m .19552 .48582 L .20047 .51122 L .862 .575 .501 r
F
.20036 .51125 m .18595 .48951 L .19552 .48582 L p F P
0 g
s
.20645 .50581 m .19131 .48321 L .18605 .4894 L p .363 .427 .794 r
F P
0 g
s
.18605 .4894 m .18595 .48951 L p .1863 .48978 L .363 .427 .794 r
F P
0 g
s
.20645 .50581 m .18605 .4894 L .1863 .48978 L .363 .427 .794 r
F
.20047 .51122 m .20036 .51125 L p .20031 .51098 L .862 .575 .501 r
F P
0 g
s
.48006 .26803 m .47889 .25111 L .48786 .24893 L p .931 .77 .66 r
F P
0 g
s
.48766 .23231 m .48786 .24893 L .47889 .25111 L p .929 .78 .674 r
F P
0 g
s
.48786 .24893 m .48766 .23231 L .50556 .2328 L p .707 .604 .74 r
F P
0 g
s
.50556 .2328 m .50575 .24856 L .48786 .24893 L p .707 .604 .74 r
F P
0 g
s
.50575 .24856 m .50556 .2328 L .51441 .23495 L p .369 .332 .686 r
F P
0 g
s
.51441 .2351 m .50575 .24856 L .51441 .23495 L .369 .332 .686 r
F
.51449 .23497 m .51481 .25037 L .50575 .24856 L p F P
0 g
s
.50545 .23668 m .50591 .25257 L .51472 .2504 L p .931 .779 .669 r
F P
0 g
s
.51472 .2504 m .51481 .25037 L p .51472 .25023 L .931 .779 .669 r
F P
0 g
s
.50545 .23668 m .51472 .2504 L .51472 .25023 L .931 .779 .669 r
F
.51441 .23495 m .51449 .23497 L p .51441 .2351 L .369 .332 .686 r
F P
0 g
s
.69442 .69916 m .70072 .70952 L .69066 .71094 L p .422 .489 .823 r
F P
0 g
s
.69066 .71094 m .68428 .70011 L .69425 .69918 L p .422 .489 .823 r
F P
0 g
s
.69066 .71094 m .69425 .69918 L .69436 .69935 L .422 .489 .823 r
F
.68927 .70768 m .69611 .71847 L .70065 .70965 L p .915 .648 .52 r
F P
0 g
s
.70065 .70965 m .70072 .70952 L p .70056 .7095 L .915 .648 .52 r
F P
0 g
s
.70056 .7095 m .68927 .70768 L .70065 .70965 L .915 .648 .52 r
F
.69425 .69918 m .69442 .69916 L p .69436 .69935 L .422 .489 .823 r
F P
0 g
s
.68428 .70011 m .69066 .71094 L .67602 .72123 L p .726 .619 .739 r
F P
0 g
s
.67602 .72123 m .66903 .7095 L .68428 .70011 L p .726 .619 .739 r
F P
0 g
s
.66903 .7095 m .67602 .72123 L .67133 .73019 L p .908 .64 .52 r
F P
0 g
s
.67964 .74189 m .67133 .73019 L .67602 .72123 L p .899 .62 .506 r
F P
0 g
s
.54055 .62915 m .54868 .62981 L .54502 .63844 L p .648 .777 .942 r
F P
0 g
s
.54502 .63844 m .53562 .63718 L .54031 .62955 L p .648 .777 .942 r
F P
0 g
s
.54502 .63844 m .54031 .62955 L .54076 .62958 L .648 .777 .942 r
F
.53562 .63718 m .54502 .63844 L .54634 .65628 L p .749 .614 .709 r
F P
0 g
s
.54421 .63906 m .55371 .63911 L .54887 .63016 L p .728 .369 .371 r
F P
0 g
s
.54887 .63016 m .54868 .62981 L p .54853 .63014 L .728 .369 .371 r
F P
0 g
s
.54853 .63014 m .54421 .63906 L .54887 .63016 L .728 .369 .371 r
F
.54031 .62955 m .54055 .62915 L p .54076 .62958 L .648 .777 .942 r
F P
0 g
s
.54634 .65628 m .53433 .65504 L .53562 .63718 L p .749 .614 .709 r
F P
0 g
s
.53433 .65504 m .54634 .65628 L .55134 .66564 L p .704 .36 .392 r
F P
0 g
s
.56481 .66427 m .55134 .66564 L .54634 .65628 L p .664 .325 .389 r
F P
0 g
s
.72573 .74901 m .73251 .75168 L .72957 .74073 L p .872 .532 .404 r
F P
0 g
s
.72957 .74073 m .72515 .73788 L .72573 .74901 L p .872 .532 .404 r
F P
0 g
s
.62269 .35628 m .62047 .34819 L .61271 .35586 L p .361 .305 .66 r
F P
0 g
s
.61271 .35586 m .61475 .36376 L .62269 .35628 L p .361 .305 .66 r
F P
0 g
s
.58936 .61382 m .58125 .61982 L .58995 .62539 L p .528 .23 .404 r
F P
0 g
s
.51697 .35002 m .51235 .34283 L .50745 .35269 L p .387 .422 .776 r
F P
0 g
s
.50745 .35269 m .51319 .36038 L .51697 .35002 L p .387 .422 .776 r
F P
0 g
s
.14383 .29913 m .14386 .2639 L .13347 .26429 L p .909 .754 .677 r
F P
0 g
s
.84957 .37986 m .84505 .40325 L .85557 .40299 L p .417 .285 .592 r
F P
0 g
s
.24324 .72704 m .21343 .72163 L .21211 .73171 L p .721 .389 .416 r
F P
0 g
s
.70785 .76924 m .71977 .77515 L .7276 .76895 L p .532 .704 .949 r
F P
0 g
s
.73284 .77037 m .7276 .76895 L .71977 .77515 L p .597 .764 .959 r
F P
0 g
s
.64953 .35521 m .64725 .3465 L .6378 .34349 L p .922 .641 .494 r
F P
0 g
s
.60243 .64871 m .61319 .64052 L .61047 .63195 L p .858 .882 .854 r
F P
0 g
s
.61655 .62635 m .61047 .63195 L .61319 .64052 L p .88 .88 .83 r
F P
0 g
s
.10804 .26379 m .1084 .30417 L .11593 .30347 L p .301 .259 .643 r
F P
0 g
s
.12114 .33905 m .11593 .30347 L .1084 .30417 L p .313 .304 .689 r
F P
0 g
s
.20733 .75693 m .24544 .76277 L .24525 .75487 L p .597 .746 .948 r
F P
0 g
s
.28024 .75225 m .24525 .75487 L .24544 .76277 L p .671 .8 .944 r
F P
0 g
s
.45573 .57389 m .46581 .56933 L .46738 .55911 L p .506 .215 .406 r
F P
0 g
s
.4789 .55563 m .46738 .55911 L .46581 .56933 L p .53 .226 .395 r
F P
0 g
s
.73309 .75242 m .76364 .75365 L .76194 .74351 L p .653 .326 .406 r
F P
0 g
s
.69261 .41377 m .69358 .40234 L .68376 .3992 L p .384 .337 .682 r
F P
0 g
s
.48982 .31603 m .49578 .33107 L .50528 .33011 L p .404 .436 .78 r
F P
0 g
s
.13858 .3348 m .14375 .3582 L .15417 .35725 L p .902 .674 .583 r
F P
0 g
s
.48876 .10125 m .46641 .11351 L .47036 .12317 L p .8 .825 .871 r
F P
0 g
s
.47818 .59323 m .48612 .59071 L .47995 .58325 L p .694 .808 .936 r
F P
0 g
s
.77011 .77836 m .80542 .77003 L .8017 .76356 L p .686 .82 .947 r
F P
0 g
s
.8017 .76356 m .76774 .77114 L .77011 .77836 L p .686 .82 .947 r
F P
0 g
s
.64229 .32985 m .63925 .32221 L .63478 .33164 L p .959 .751 .579 r
F P
0 g
s
.63478 .33164 m .63692 .33871 L .64229 .32985 L p .959 .751 .579 r
F P
0 g
s
.71953 .39786 m .71903 .38359 L .71161 .38852 L p .947 .804 .67 r
F P
0 g
s
.71161 .38852 m .71153 .40167 L .71953 .39786 L p .947 .804 .67 r
F P
0 g
s
.52895 .31762 m .52419 .30594 L .51654 .31087 L p .924 .687 .562 r
F P
0 g
s
.12058 .36962 m .12956 .39452 L .13549 .38879 L p .32 .335 .719 r
F P
0 g
s
.13549 .38879 m .12689 .36441 L .12058 .36962 L p .32 .335 .719 r
F P
0 g
s
.44945 .09412 m .42681 .11018 L .43363 .11454 L p .459 .151 .355 r
F P
0 g
s
.43363 .11454 m .45592 .09893 L .44945 .09412 L p .459 .151 .355 r
F P
0 g
s
.51505 .55287 m .5269 .55456 L .52899 .56392 L p .541 .68 .929 r
F P
0 g
s
.53956 .56674 m .52899 .56392 L .5269 .55456 L p .519 .652 .918 r
F P
0 g
s
.52899 .56392 m .53956 .56674 L .53438 .58388 L p .653 .523 .693 r
F P
0 g
s
.53438 .58388 m .52497 .58136 L .52899 .56392 L p .653 .523 .693 r
F P
0 g
s
.52497 .58136 m .53438 .58388 L .52792 .59152 L p .66 .307 .364 r
F P
0 g
s
.52773 .59148 m .52497 .58136 L .52792 .59152 L .66 .307 .364 r
F
.52779 .59168 m .51884 .58957 L .52497 .58136 L p F P
0 g
s
.52636 .58226 m .51671 .58027 L .51879 .58936 L p .531 .664 .921 r
F P
0 g
s
.51879 .58936 m .51884 .58957 L p .519 .58941 L .531 .664 .921 r
F P
0 g
s
.52636 .58226 m .51879 .58936 L .519 .58941 L .531 .664 .921 r
F
.52792 .59152 m .52779 .59168 L p .52773 .59148 L .66 .307 .364 r
F P
0 g
s
.68959 .33695 m .68082 .32939 L .69032 .3239 L p .491 .575 .868 r
F P
0 g
s
.69032 .3239 m .69997 .33357 L .68959 .33695 L p .491 .575 .868 r
F P
0 g
s
.63035 .40516 m .62577 .39707 L .63577 .39908 L p .863 .516 .392 r
F P
0 g
s
.63577 .39908 m .64059 .40613 L .63035 .40516 L p .863 .516 .392 r
F P
0 g
s
.64059 .40613 m .63577 .39908 L .65225 .39209 L p .661 .481 .63 r
F P
0 g
s
.65225 .39209 m .65617 .39729 L .64059 .40613 L p .661 .481 .63 r
F P
0 g
s
.55481 .38457 m .54515 .38216 L .55379 .37636 L p .616 .235 .297 r
F P
0 g
s
.55379 .37636 m .56242 .37751 L .55481 .38457 L p .616 .235 .297 r
F P
0 g
s
.56242 .37751 m .55379 .37636 L .56044 .35974 L p .617 .488 .682 r
F P
0 g
s
.56044 .35974 m .56653 .36008 L .56242 .37751 L p .617 .488 .682 r
F P
0 g
s
.59486 .31343 m .59823 .31434 L .59981 .3257 L p .844 .512 .425 r
F P
0 g
s
.59823 .31434 m .59486 .31343 L .60224 .2971 L p .767 .663 .748 r
F P
0 g
s
.60224 .2971 m .60856 .29972 L .59823 .31434 L p .767 .663 .748 r
F P
0 g
s
.60856 .29972 m .60224 .2971 L .61351 .29159 L p .541 .654 .909 r
F P
0 g
s
.61351 .29159 m .62055 .29637 L .60856 .29972 L p .541 .654 .909 r
F P
0 g
s
.93159 .63753 m .94452 .60245 L .95453 .60675 L p .437 .299 .595 r
F P
0 g
s
.95453 .60675 m .94131 .64242 L .93159 .63753 L p .437 .299 .595 r
F P
0 g
s
.07797 .58963 m .09077 .62059 L .08407 .6236 L p .319 .374 .762 r
F P
0 g
s
.08407 .6236 m .07084 .59139 L .07781 .58967 L p .319 .374 .762 r
F P
0 g
s
.08407 .6236 m .07781 .58967 L .0781 .59038 L .319 .374 .762 r
F
.07084 .59139 m .08407 .6236 L .06883 .633 L p .712 .592 .72 r
F P
0 g
s
.06883 .633 m .05426 .59819 L .07084 .59139 L p .712 .592 .72 r
F P
0 g
s
.06844 .59473 m .08216 .62702 L .0907 .62065 L p .894 .665 .585 r
F P
0 g
s
.0907 .62065 m .09077 .62059 L p .09059 .62038 L .894 .665 .585 r
F P
0 g
s
.09059 .62038 m .06844 .59473 L .0907 .62065 L .894 .665 .585 r
F
.07781 .58967 m .07797 .58963 L p .0781 .59038 L .319 .374 .762 r
F P
0 g
s
.05426 .59819 m .06883 .633 L .06016 .63945 L p .89 .659 .583 r
F P
0 g
s
.08128 .67254 m .06016 .63945 L .06883 .633 L p .874 .617 .547 r
F P
0 g
s
.23509 .10149 m .2105 .12032 L .2061 .11451 L p .406 .12 .362 r
F P
0 g
s
.2061 .11451 m .23179 .09496 L .23501 .10134 L p .406 .12 .362 r
F P
0 g
s
.2061 .11451 m .23501 .10134 L .23444 .10178 L .406 .12 .362 r
F
.23179 .09496 m .2061 .11451 L .19313 .10216 L p .695 .575 .716 r
F P
0 g
s
.19313 .10216 m .22095 .0807 L .23179 .09496 L p .695 .575 .716 r
F P
0 g
s
.22748 .09369 m .20187 .11373 L .21042 .12026 L p .798 .816 .866 r
F P
0 g
s
.21042 .12026 m .2105 .12032 L p .21066 .12007 L .798 .816 .866 r
F P
0 g
s
.21066 .12007 m .22748 .09369 L .21042 .12026 L .798 .816 .866 r
F
.23501 .10134 m .23509 .10149 L p .23444 .10178 L .406 .12 .362 r
F P
0 g
s
.22095 .0807 m .19313 .10216 L .18447 .09552 L p .802 .814 .861 r
F P
0 g
s
.15968 .12243 m .18447 .09552 L .19313 .10216 L p .831 .818 .837 r
F P
0 g
s
.77875 .55101 m .79086 .52364 L .7968 .52914 L p .928 .849 .744 r
F P
0 g
s
.7968 .52914 m .78517 .55583 L .77875 .55101 L p .928 .849 .744 r
F P
0 g
s
.78517 .55583 m .7968 .52914 L .8125 .53776 L p .715 .569 .69 r
F P
0 g
s
.8125 .53776 m .80152 .56318 L .78517 .55583 L p .715 .569 .69 r
F P
0 g
s
.80152 .56318 m .8125 .53776 L .82238 .54095 L p .437 .261 .543 r
F P
0 g
s
.82238 .54095 m .8125 .53776 L p .83315 .5183 L .446 .254 .526 r
F P
0 g
s
.81157 .56574 m .80152 .56318 L p .81726 .5464 L .437 .261 .543 r
F P
0 g
s
.82238 .54095 m .81157 .56574 L p .81726 .5464 L .437 .261 .543 r
F P
0 g
s
.79626 .58882 m .80152 .56318 L .81157 .56574 L p .419 .284 .59 r
F P
0 g
s
.80656 .58971 m .79626 .58882 L p .81035 .56758 L .419 .284 .59 r
F P
0 g
s
.81157 .56574 m .80656 .58971 L p .81035 .56758 L .419 .284 .59 r
F P
0 g
s
.79257 .616 m .79626 .58882 L .80656 .58971 L p .414 .295 .608 r
F P
0 g
s
.80656 .58971 m .80287 .61629 L .79257 .616 L p .414 .295 .608 r
F P
0 g
s
.80656 .58971 m .79935 .5865 L p .80252 .61332 L .949 .799 .66 r
F P
0 g
s
.80287 .61629 m .80656 .58971 L p .80252 .61332 L .949 .799 .66 r
F P
0 g
s
.81157 .56574 m .80523 .56094 L p .80628 .58372 L .946 .817 .684 r
F P
0 g
s
.80656 .58971 m .81157 .56574 L p .80628 .58372 L .946 .817 .684 r
F P
0 g
s
.82238 .54095 m .81651 .53547 L p .81209 .56258 L .93 .852 .744 r
F P
0 g
s
.81157 .56574 m .82238 .54095 L p .81209 .56258 L .93 .852 .744 r
F P
0 g
s
.83602 .51559 m .82238 .54095 L p .83315 .5183 L .446 .254 .526 r
F P
0 g
s
.37248 .2162 m .3512 .23919 L .34469 .23438 L p .415 .155 .408 r
F P
0 g
s
.32087 .25394 m .34469 .23438 L .3512 .23919 L p .445 .157 .38 r
F P
0 g
s
.34469 .23438 m .32087 .25394 L .31262 .23803 L p .722 .579 .694 r
F P
0 g
s
.31262 .23803 m .33295 .22086 L .34469 .23438 L p .722 .579 .694 r
F P
0 g
s
.33295 .22086 m .31262 .23803 L .30931 .22849 L p .843 .833 .836 r
F P
0 g
s
.30957 .22826 m .33295 .22086 L .30931 .22849 L .843 .833 .836 r
F
.30926 .22836 m .32762 .21205 L .33295 .22086 L p F P
0 g
s
.31418 .23464 m .33408 .21679 L .3279 .21226 L p .434 .152 .385 r
F P
0 g
s
.3279 .21226 m .32762 .21205 L p .32705 .213 L .434 .152 .385 r
F P
0 g
s
.31418 .23464 m .3279 .21226 L .32705 .213 L .434 .152 .385 r
F
.30931 .22849 m .30926 .22836 L p .30957 .22826 L .843 .833 .836 r
F P
0 g
s
.21583 .46956 m .23235 .49484 L .22619 .50031 L p .365 .425 .79 r
F P
0 g
s
.23898 .52704 m .22619 .50031 L .23235 .49484 L p .345 .38 .755 r
F P
0 g
s
.22619 .50031 m .23898 .52704 L .22158 .53131 L p .697 .554 .688 r
F P
0 g
s
.22158 .53131 m .21025 .50848 L .22619 .50031 L p .697 .554 .688 r
F P
0 g
s
.21025 .50848 m .22158 .53131 L .2115 .53211 L p .876 .602 .52 r
F P
0 g
s
.21135 .53183 m .21025 .50848 L .2115 .53211 L .876 .602 .52 r
F
.21137 .53212 m .20036 .51125 L .21025 .50848 L p F P
0 g
s
.21861 .52863 m .20645 .50581 L .20062 .51102 L p .347 .391 .765 r
F P
0 g
s
.20062 .51102 m .20036 .51125 L p .2011 .51195 L .347 .391 .765 r
F P
0 g
s
.21861 .52863 m .20062 .51102 L .2011 .51195 L .347 .391 .765 r
F
.2115 .53211 m .21137 .53212 L p .21135 .53183 L .876 .602 .52 r
F P
0 g
s
.47889 .25111 m .47855 .234 L .48766 .23231 L p .929 .78 .674 r
F P
0 g
s
.4882 .21607 m .48766 .23231 L .47855 .234 L p .927 .788 .687 r
F P
0 g
s
.48766 .23231 m .4882 .21607 L .50608 .2173 L p .705 .603 .739 r
F P
0 g
s
.50608 .2173 m .50556 .2328 L .48766 .23231 L p .705 .603 .739 r
F P
0 g
s
.50556 .2328 m .50608 .2173 L .51484 .21941 L p .366 .318 .672 r
F P
0 g
s
.51484 .21953 m .50556 .2328 L .51484 .21941 L .366 .318 .672 r
F
.5149 .21943 m .51449 .23497 L .50556 .2328 L p F P
0 g
s
.50578 .22033 m .50545 .23668 L .51442 .23499 L p .929 .788 .684 r
F P
0 g
s
.51442 .23499 m .51449 .23497 L p .51442 .23486 L .929 .788 .684 r
F P
0 g
s
.50578 .22033 m .51442 .23499 L .51442 .23486 L .929 .788 .684 r
F
.51484 .21941 m .5149 .21943 L p .51484 .21953 L .366 .318 .672 r
F P
0 g
s
.68772 .68796 m .69442 .69916 L .68428 .70011 L p .42 .488 .823 r
F P
0 g
s
.68428 .70011 m .67759 .68885 L .6877 .68797 L p .42 .488 .823 r
F P
0 g
s
.68428 .70011 m .6877 .68797 L .68771 .688 L .42 .488 .823 r
F
.68246 .69637 m .68927 .70768 L .6944 .69919 L p .914 .648 .521 r
F P
0 g
s
.6944 .69919 m .69442 .69916 L p .69438 .69916 L .914 .648 .521 r
F P
0 g
s
.69438 .69916 m .68246 .69637 L .6944 .69919 L .914 .648 .521 r
F
.6877 .68797 m .68772 .68796 L p .68771 .688 L .42 .488 .823 r
F P
0 g
s
.67759 .68885 m .68428 .70011 L .66903 .7095 L p .726 .621 .74 r
F P
0 g
s
.66903 .7095 m .66223 .69809 L .67759 .68885 L p .726 .621 .74 r
F P
0 g
s
.66223 .69809 m .66903 .7095 L .66381 .71803 L p .912 .647 .524 r
F P
0 g
s
.67133 .73019 m .66381 .71803 L .66903 .7095 L p .908 .64 .52 r
F P
0 g
s
.5323 .62737 m .54055 .62915 L .53562 .63718 L p .609 .744 .941 r
F P
0 g
s
.53562 .63718 m .52631 .63469 L .53204 .6277 L p .609 .744 .941 r
F P
0 g
s
.53562 .63718 m .53204 .6277 L .53244 .62778 L .609 .744 .941 r
F
.52631 .63469 m .53562 .63718 L .53433 .65504 L p .748 .618 .715 r
F P
0 g
s
.53463 .63766 m .54421 .63906 L .54068 .6295 L p .762 .407 .383 r
F P
0 g
s
.54068 .6295 m .54055 .62915 L p .54036 .62943 L .762 .407 .383 r
F P
0 g
s
.54036 .62943 m .53463 .63766 L .54068 .6295 L .762 .407 .383 r
F
.53204 .6277 m .5323 .62737 L p .53244 .62778 L .609 .744 .941 r
F P
0 g
s
.53433 .65504 m .52263 .65223 L .52631 .63469 L p .748 .618 .715 r
F P
0 g
s
.52263 .65223 m .53433 .65504 L .53795 .66501 L p .739 .395 .399 r
F P
0 g
s
.55134 .66564 m .53795 .66501 L .53433 .65504 L p .704 .36 .392 r
F P
0 g
s
.46581 .56933 m .47632 .56564 L .4789 .55563 L p .53 .226 .395 r
F P
0 g
s
.49091 .55334 m .4789 .55563 L .47632 .56564 L p .559 .241 .385 r
F P
0 g
s
.71843 .74418 m .72573 .74901 L .72515 .73788 L p .879 .561 .444 r
F P
0 g
s
.72515 .73788 m .71966 .73339 L .71843 .74418 L p .879 .561 .444 r
F P
0 g
s
.76364 .75365 m .79437 .74715 L .79081 .73733 L p .593 .289 .422 r
F P
0 g
s
.62489 .36466 m .62269 .35628 L .61475 .36376 L p .364 .313 .666 r
F P
0 g
s
.61475 .36376 m .617 .37218 L .62489 .36466 L p .364 .313 .666 r
F P
0 g
s
.62029 .34549 m .61881 .33989 L .60743 .33865 L p .401 .481 .827 r
F P
0 g
s
.58125 .61982 m .57312 .62433 L .58118 .63089 L p .563 .243 .385 r
F P
0 g
s
.69358 .40234 m .69387 .39141 L .68367 .38934 L p .387 .358 .705 r
F P
0 g
s
.52241 .3566 m .51697 .35002 L .51319 .36038 L p .408 .466 .808 r
F P
0 g
s
.51319 .36038 m .52002 .36741 L .52241 .3566 L p .408 .466 .808 r
F P
0 g
s
.50528 .33011 m .49929 .31593 L .48982 .31603 L p .404 .436 .78 r
F P
0 g
s
.48536 .30047 m .48982 .31603 L .49929 .31593 L p .39 .405 .755 r
F P
0 g
s
.14386 .2639 m .1489 .22967 L .13844 .22863 L p .903 .778 .713 r
F P
0 g
s
.14375 .3582 m .15176 .38115 L .16199 .37931 L p .893 .643 .554 r
F P
0 g
s
.84505 .40325 m .83837 .42671 L .84883 .42737 L p .422 .272 .571 r
F P
0 g
s
.46641 .11351 m .44524 .12826 L .44994 .13753 L p .822 .831 .856 r
F P
0 g
s
.21343 .72163 m .18365 .71045 L .18051 .72029 L p .764 .438 .434 r
F P
0 g
s
.48612 .59071 m .49396 .58906 L .48879 .58092 L p .665 .787 .939 r
F P
0 g
s
.48879 .58092 m .47995 .58325 L .48612 .59071 L p .665 .787 .939 r
F P
0 g
s
.69763 .76166 m .70785 .76924 L .71705 .76475 L p .487 .635 .92 r
F P
0 g
s
.7276 .76895 m .71705 .76475 L .70785 .76924 L p .532 .704 .949 r
F P
0 g
s
.80542 .77003 m .83951 .75476 L .83455 .74931 L p .745 .858 .932 r
F P
0 g
s
.83455 .74931 m .8017 .76356 L .80542 .77003 L p .745 .858 .932 r
F P
0 g
s
.65174 .36333 m .64953 .35521 L .64015 .35199 L p .921 .642 .496 r
F P
0 g
s
.63925 .32221 m .63546 .31477 L .63204 .32465 L p .957 .726 .548 r
F P
0 g
s
.63204 .32465 m .63478 .33164 L .63925 .32221 L p .957 .726 .548 r
F P
0 g
s
.59052 .65566 m .60243 .64871 L .60058 .63989 L p .832 .882 .879 r
F P
0 g
s
.61047 .63195 m .60058 .63989 L .60243 .64871 L p .858 .882 .854 r
F P
0 g
s
.71903 .38359 m .71675 .36959 L .71013 .37557 L p .95 .776 .631 r
F P
0 g
s
.71013 .37557 m .71161 .38852 L .71903 .38359 L p .95 .776 .631 r
F P
0 g
s
.52783 .33373 m .53131 .33919 L .54176 .33878 L p .849 .512 .416 r
F P
0 g
s
.52419 .30594 m .52053 .29355 L .51239 .2977 L p .93 .716 .591 r
F P
0 g
s
.11345 .22435 m .10804 .26379 L .11549 .26424 L p .296 .216 .593 r
F P
0 g
s
.11593 .30347 m .11549 .26424 L .10804 .26379 L p .301 .259 .643 r
F P
0 g
s
.12956 .39452 m .14091 .4191 L .14641 .41286 L p .333 .366 .746 r
F P
0 g
s
.14641 .41286 m .13549 .38879 L .12956 .39452 L p .333 .366 .746 r
F P
0 g
s
.87278 .43676 m .88017 .41027 L .8732 .40652 L p .946 .828 .697 r
F P
0 g
s
.87792 .38041 m .8732 .40652 L .88017 .41027 L p .951 .81 .668 r
F P
0 g
s
.42681 .11018 m .40506 .12834 L .41223 .1322 L p .439 .148 .372 r
F P
0 g
s
.41223 .1322 m .43363 .11454 L .42681 .11018 L p .439 .148 .372 r
F P
0 g
s
.17111 .74403 m .20733 .75693 L .20905 .74943 L p .533 .688 .938 r
F P
0 g
s
.24525 .75487 m .20905 .74943 L .20733 .75693 L p .597 .746 .948 r
F P
0 g
s
.5269 .55456 m .53819 .55726 L .53956 .56674 L p .519 .652 .918 r
F P
0 g
s
.54962 .56981 m .53956 .56674 L .53819 .55726 L p .51 .637 .911 r
F P
0 g
s
.53956 .56674 m .54962 .56981 L .54457 .58701 L p .658 .525 .691 r
F P
0 g
s
.54457 .58701 m .53438 .58388 L .53956 .56674 L p .658 .525 .691 r
F P
0 g
s
.53438 .58388 m .54457 .58701 L .53792 .59482 L p .687 .335 .371 r
F P
0 g
s
.53792 .59482 m .52779 .59168 L .53438 .58388 L p .687 .335 .371 r
F P
0 g
s
.67101 .34438 m .66135 .3398 L .66731 .32288 L p .75 .637 .735 r
F P
0 g
s
.66731 .32288 m .68082 .32939 L .67101 .34438 L p .75 .637 .735 r
F P
0 g
s
.68082 .32939 m .66731 .32288 L .67858 .31663 L p .542 .644 .9 r
F P
0 g
s
.67858 .31663 m .69032 .3239 L .68082 .32939 L p .542 .644 .9 r
F P
0 g
s
.56507 .38542 m .55481 .38457 L .56242 .37751 L p .562 .196 .305 r
F P
0 g
s
.56242 .37751 m .57132 .37717 L .56507 .38542 L p .562 .196 .305 r
F P
0 g
s
.57132 .37717 m .56242 .37751 L .56653 .36008 L p .613 .496 .696 r
F P
0 g
s
.56653 .36008 m .57249 .35928 L .57132 .37717 L p .613 .496 .696 r
F P
0 g
s
.63674 .41319 m .63035 .40516 L .64059 .40613 L p .816 .441 .346 r
F P
0 g
s
.64059 .40613 m .64698 .41233 L .63674 .41319 L p .816 .441 .346 r
F P
0 g
s
.64698 .41233 m .64059 .40613 L .65617 .39729 L p .643 .468 .631 r
F P
0 g
s
.65617 .39729 m .66083 .40094 L .64698 .41233 L p .643 .468 .631 r
F P
0 g
s
.59524 .3145 m .59486 .31343 L p .59545 .31489 L .844 .512 .425 r
F P
0 g
s
.59497 .31407 m .59486 .31343 L .5987 .32435 L p .901 .493 .102 r
F P
0 g
s
.59927 .29667 m .60224 .2971 L .59486 .31343 L p .779 .665 .737 r
F P
0 g
s
.59486 .31343 m .59497 .31407 L .59927 .29667 L p .779 .665 .737 r
F P
0 g
s
.58708 .29455 m .59927 .29667 L .59498 .31402 L p .747 .618 .716 r
F P
0 g
s
.59498 .31402 m .59497 .31407 L p .59486 .3138 L .747 .618 .716 r
F P
0 g
s
.58708 .29455 m .59498 .31402 L .59486 .3138 L .747 .618 .716 r
F
.5987 .32435 m .59524 .3145 L p .59975 .32554 L .844 .512 .425 r
F P
0 g
s
.59545 .31489 m .59981 .3257 L .59524 .3145 L .844 .512 .425 r
F
.5987 .32435 m .59724 .32322 L .59497 .31407 L p .901 .493 .102 r
F P
0 g
s
.5987 .32435 m .60999 .31892 L p .59759 .3231 L .602 .805 .978 r
F P
0 g
s
.59724 .32322 m .5987 .32435 L p .59759 .3231 L .602 .805 .978 r
F P
0 g
s
.59981 .3257 m .5987 .32435 L p .59975 .32554 L .844 .512 .425 r
F P
0 g
s
.60224 .2971 m .59927 .29667 L .60587 .28829 L p .592 .71 .925 r
F P
0 g
s
.60587 .28829 m .61351 .29159 L .60224 .2971 L p .592 .71 .925 r
F P
0 g
s
.94452 .60245 m .95557 .56571 L .96608 .56863 L p .433 .307 .608 r
F P
0 g
s
.96608 .56863 m .95453 .60675 L .94452 .60245 L p .433 .307 .608 r
F P
0 g
s
.06821 .559 m .07797 .58963 L .07084 .59139 L p .307 .344 .737 r
F P
0 g
s
.07084 .59139 m .06093 .55999 L .06814 .55901 L p .307 .344 .737 r
F P
0 g
s
.07084 .59139 m .06814 .55901 L .06824 .55934 L .307 .344 .737 r
F
.06093 .55999 m .07084 .59139 L .05426 .59819 L p .711 .593 .722 r
F P
0 g
s
.05426 .59819 m .0438 .56529 L .06093 .55999 L p .711 .593 .722 r
F P
0 g
s
.05829 .56335 m .06844 .59473 L .0779 .58967 L p .9 .687 .606 r
F P
0 g
s
.0779 .58967 m .07797 .58963 L p .07784 .58946 L .9 .687 .606 r
F P
0 g
s
.07784 .58946 m .05829 .56335 L .0779 .58967 L .9 .687 .606 r
F
.06814 .55901 m .06821 .559 L p .06824 .55934 L .307 .344 .737 r
F P
0 g
s
.0438 .56529 m .05426 .59819 L .04468 .6033 L p .897 .684 .605 r
F P
0 g
s
.06016 .63945 m .04468 .6033 L .05426 .59819 L p .89 .659 .583 r
F P
0 g
s
.26443 .08289 m .23509 .10149 L .23179 .09496 L p .431 .125 .343 r
F P
0 g
s
.23179 .09496 m .26169 .07611 L .2644 .08281 L p .431 .125 .343 r
F P
0 g
s
.23179 .09496 m .2644 .08281 L .26406 .08302 L .431 .125 .343 r
F
.26169 .07611 m .23179 .09496 L .22095 .0807 L p .695 .574 .714 r
F P
0 g
s
.22095 .0807 m .2522 .06089 L .26169 .07611 L p .695 .574 .714 r
F P
0 g
s
.25763 .07438 m .22748 .09369 L .23503 .10144 L p .782 .811 .876 r
F P
0 g
s
.23503 .10144 m .23509 .10149 L p .23524 .10131 L .782 .811 .876 r
F P
0 g
s
.23524 .10131 m .25763 .07438 L .23503 .10144 L .782 .811 .876 r
F
.2644 .08281 m .26443 .08289 L p .26406 .08302 L .431 .125 .343 r
F P
0 g
s
.2522 .06089 m .22095 .0807 L .21332 .07284 L p .783 .809 .873 r
F P
0 g
s
.18447 .09552 m .21332 .07284 L .22095 .0807 L p .802 .814 .861 r
F P
0 g
s
.23235 .49484 m .24631 .52355 L .23898 .52704 L p .345 .38 .755 r
F P
0 g
s
.24557 .55576 m .23898 .52704 L .24631 .52355 L p .326 .311 .688 r
F P
0 g
s
.23898 .52704 m .24557 .55576 L .22778 .55798 L p .702 .558 .688 r
F P
0 g
s
.22778 .55798 m .22158 .53131 L .23898 .52704 L p .702 .558 .688 r
F P
0 g
s
.22158 .53131 m .22778 .55798 L .21768 .55786 L p .902 .673 .582 r
F P
0 g
s
.21762 .55759 m .22158 .53131 L .21768 .55786 L .902 .673 .582 r
F
.21758 .55786 m .21137 .53212 L .22158 .53131 L p F P
0 g
s
.22523 .55549 m .21861 .52863 L .21149 .53206 L p .321 .31 .691 r
F P
0 g
s
.21149 .53206 m .21137 .53212 L p .2116 .53251 L .321 .31 .691 r
F P
0 g
s
.22523 .55549 m .21149 .53206 L .2116 .53251 L .321 .31 .691 r
F
.21768 .55786 m .21758 .55786 L p .21762 .55759 L .902 .673 .582 r
F P
0 g
s
.7715 .58152 m .77875 .55101 L .78517 .55583 L p .944 .814 .685 r
F P
0 g
s
.78517 .55583 m .77879 .58474 L .7715 .58152 L p .944 .814 .685 r
F P
0 g
s
.77879 .58474 m .78517 .55583 L .80152 .56318 L p .711 .565 .687 r
F P
0 g
s
.80152 .56318 m .79626 .58882 L .77879 .58474 L p .711 .565 .687 r
F P
0 g
s
.3512 .23919 m .32581 .2603 L .32087 .25394 L p .445 .157 .38 r
F P
0 g
s
.29552 .26655 m .32087 .25394 L .32581 .2603 L p .51 .181 .346 r
F P
0 g
s
.32087 .25394 m .29552 .26655 L .2892 .24977 L p .725 .584 .698 r
F P
0 g
s
.2892 .24977 m .31262 .23803 L .32087 .25394 L p .725 .584 .698 r
F P
0 g
s
.31262 .23803 m .2892 .24977 L .28679 .24 L p .793 .824 .877 r
F P
0 g
s
.28704 .23988 m .31262 .23803 L .28679 .24 L .793 .824 .877 r
F
.28676 .2399 m .30926 .22836 L .31262 .23803 L p F P
0 g
s
.29068 .24686 m .31418 .23464 L .30935 .22847 L p .502 .174 .343 r
F P
0 g
s
.30935 .22847 m .30926 .22836 L p .30894 .22868 L .502 .174 .343 r
F P
0 g
s
.29068 .24686 m .30935 .22847 L .30894 .22868 L .502 .174 .343 r
F
.28679 .24 m .28676 .2399 L p .28704 .23988 L .793 .824 .877 r
F P
0 g
s
.47855 .234 m .47901 .21696 L .4882 .21607 L p .927 .788 .687 r
F P
0 g
s
.48945 .19752 m .4882 .21607 L .47901 .21696 L p .925 .792 .694 r
F P
0 g
s
.4882 .21607 m .48945 .19752 L .50734 .1987 L p .705 .598 .735 r
F P
0 g
s
.50734 .1987 m .50608 .2173 L .4882 .21607 L p .705 .598 .735 r
F P
0 g
s
.50608 .2173 m .50734 .1987 L .51619 .20073 L p .365 .304 .655 r
F P
0 g
s
.51619 .20073 m .5149 .21943 L .50608 .2173 L p .365 .304 .655 r
F P
0 g
s
.68026 .67694 m .68772 .68796 L .67759 .68885 L p .429 .511 .841 r
F P
0 g
s
.67759 .68885 m .67012 .67821 L .68026 .67694 L p .429 .511 .841 r
F P
0 g
s
.67012 .67821 m .67759 .68885 L .66223 .69809 L p .731 .627 .743 r
F P
0 g
s
.66223 .69809 m .65531 .68833 L .67012 .67821 L p .731 .627 .743 r
F P
0 g
s
.65531 .68833 m .66223 .69809 L .65689 .7065 L p .907 .635 .513 r
F P
0 g
s
.65689 .7065 m .66223 .69809 L p .66371 .71682 L .912 .647 .524 r
F P
0 g
s
.65053 .69725 m .65531 .68833 L p .65687 .70628 L .907 .635 .513 r
F P
0 g
s
.65689 .7065 m .65053 .69725 L p .65687 .70628 L .907 .635 .513 r
F P
0 g
s
.64818 .67868 m .65531 .68833 L .65053 .69725 L p .902 .624 .505 r
F P
0 g
s
.64359 .68773 m .64818 .67868 L p .65052 .69717 L .902 .624 .505 r
F P
0 g
s
.65053 .69725 m .64359 .68773 L p .65052 .69717 L .902 .624 .505 r
F P
0 g
s
.64089 .66894 m .64818 .67868 L .64359 .68773 L p .9 .62 .503 r
F P
0 g
s
.63637 .67802 m .64089 .66894 L p .64355 .68745 L .9 .62 .503 r
F P
0 g
s
.64359 .68773 m .63637 .67802 L p .64355 .68745 L .9 .62 .503 r
F P
0 g
s
.63343 .65943 m .64089 .66894 L .63637 .67802 L p .897 .614 .498 r
F P
0 g
s
.62904 .66857 m .63343 .65943 L p .63635 .67786 L .897 .614 .498 r
F P
0 g
s
.63637 .67802 m .62904 .66857 L p .63635 .67786 L .897 .614 .498 r
F P
0 g
s
.62591 .65003 m .63343 .65943 L .62904 .66857 L p .896 .61 .496 r
F P
0 g
s
.62163 .65924 m .62591 .65003 L p .62897 .66817 L .896 .61 .496 r
F P
0 g
s
.62904 .66857 m .62163 .65924 L p .62897 .66817 L .896 .61 .496 r
F P
0 g
s
.6182 .64104 m .62591 .65003 L .62163 .65924 L p .892 .602 .49 r
F P
0 g
s
.61413 .65036 m .6182 .64104 L p .62154 .65878 L .892 .602 .49 r
F P
0 g
s
.62163 .65924 m .61413 .65036 L p .62154 .65878 L .892 .602 .49 r
F P
0 g
s
.61019 .63242 m .6182 .64104 L .61413 .65036 L p .886 .591 .481 r
F P
0 g
s
.60641 .64188 m .61019 .63242 L p .61406 .65006 L .886 .591 .481 r
F P
0 g
s
.61413 .65036 m .60641 .64188 L p .61406 .65006 L .886 .591 .481 r
F P
0 g
s
.60058 .63989 m .61047 .63195 L .59851 .61855 L p .744 .584 .677 r
F P
0 g
s
.59851 .61855 m .58995 .62539 L .60058 .63989 L p .744 .584 .677 r
F P
0 g
s
.60188 .62395 m .61019 .63242 L .60641 .64188 L p .881 .581 .475 r
F P
0 g
s
.60641 .64188 m .60027 .63552 L p .60188 .62395 L .881 .581 .475 r
F P
0 g
s
.60027 .63552 m .59832 .6335 L .59846 .63311 L p .881 .581 .475 r
F P
0 g
s
.59846 .63311 m .60188 .62395 L p .60027 .63552 L .881 .581 .475 r
F P
0 g
s
.59295 .61491 m .60012 .62206 L .59111 .62571 L p .806 .462 .406 r
F P
0 g
s
.59111 .62571 m .59098 .62576 L p .591 .62561 L .806 .462 .406 r
F P
0 g
s
.591 .62561 m .59295 .61491 L .59111 .62571 L .806 .462 .406 r
F
.58562 .60842 m .59295 .61491 L .58412 .61894 L p .787 .437 .393 r
F P
0 g
s
.58412 .61894 m .58394 .61903 L p .58397 .61882 L .787 .437 .393 r
F P
0 g
s
.58397 .61882 m .58562 .60842 L .58412 .61894 L .787 .437 .393 r
F
.57796 .60261 m .58562 .60842 L .57704 .61298 L p .762 .407 .381 r
F P
0 g
s
.57704 .61298 m .57682 .6131 L p .57685 .61285 L .762 .407 .381 r
F P
0 g
s
.57685 .61285 m .57796 .60261 L .57704 .61298 L .762 .407 .381 r
F
.5703 .59774 m .57796 .60261 L .56973 .60789 L p .737 .378 .371 r
F P
0 g
s
.56973 .60789 m .56951 .60803 L p .56953 .60778 L .737 .378 .371 r
F P
0 g
s
.56953 .60778 m .5703 .59774 L .56973 .60789 L .737 .378 .371 r
F
.56218 .59353 m .5703 .59774 L .56238 .60361 L p .71 .35 .364 r
F P
0 g
s
.56238 .60361 m .56215 .60378 L p .56215 .60351 L .71 .35 .364 r
F P
0 g
s
.56215 .60351 m .56218 .59353 L .56238 .60361 L .71 .35 .364 r
F
.55359 .59 m .56218 .59353 L .55475 .60014 L p .689 .33 .362 r
F P
0 g
s
.55475 .60014 m .55456 .60031 L p .55453 .60006 L .689 .33 .362 r
F P
0 g
s
.55453 .60006 m .55359 .59 L .55475 .60014 L .689 .33 .362 r
F
.54457 .58701 m .55359 .59 L .54666 .59726 L p .676 .32 .364 r
F P
0 g
s
.54666 .59726 m .54652 .5974 L p .54649 .59721 L .676 .32 .364 r
F P
0 g
s
.54649 .59721 m .54457 .58701 L .54666 .59726 L .676 .32 .364 r
F
.54652 .5974 m .53792 .59482 L .54457 .58701 L p F P
0 g
s
.54552 .58786 m .53629 .58537 L .53788 .59463 L p .513 .643 .914 r
F P
0 g
s
.53788 .59463 m .53792 .59482 L p .53807 .59469 L .513 .643 .914 r
F P
0 g
s
.54552 .58786 m .53788 .59463 L .53807 .59469 L .513 .643 .914 r
F
.55456 .60031 m .54652 .5974 L .55359 .59 L p .689 .33 .362 r
F P
0 g
s
.55441 .5907 m .54552 .58786 L .54649 .59713 L p .501 .626 .906 r
F P
0 g
s
.54649 .59713 m .54652 .5974 L p .54674 .59722 L .501 .626 .906 r
F P
0 g
s
.55441 .5907 m .54649 .59713 L .54674 .59722 L .501 .626 .906 r
F
.56215 .60378 m .55456 .60031 L .56218 .59353 L p .71 .35 .364 r
F P
0 g
s
.56297 .59419 m .55441 .5907 L .55455 .6 L p .481 .599 .894 r
F P
0 g
s
.55455 .6 m .55456 .60031 L p .55482 .60012 L .481 .599 .894 r
F P
0 g
s
.56297 .59419 m .55455 .6 L .55482 .60012 L .481 .599 .894 r
F
.56951 .60803 m .56215 .60378 L .5703 .59774 L p .737 .378 .371 r
F P
0 g
s
.57135 .59862 m .56297 .59419 L .56217 .60351 L p .458 .566 .877 r
F P
0 g
s
.56217 .60351 m .56215 .60378 L p .5624 .60364 L .458 .566 .877 r
F P
0 g
s
.57135 .59862 m .56217 .60351 L .5624 .60364 L .458 .566 .877 r
F
.57682 .6131 m .56951 .60803 L .57796 .60261 L p .762 .407 .381 r
F P
0 g
s
.57954 .60388 m .57135 .59862 L .56957 .60776 L p .442 .539 .861 r
F P
0 g
s
.56957 .60776 m .56951 .60803 L p .56979 .60791 L .442 .539 .861 r
F P
0 g
s
.57954 .60388 m .56957 .60776 L .56979 .60791 L .442 .539 .861 r
F
.58394 .61903 m .57682 .6131 L .58562 .60842 L p .787 .437 .393 r
F P
0 g
s
.58737 .61004 m .57954 .60388 L .57688 .61289 L p .423 .508 .841 r
F P
0 g
s
.57688 .61289 m .57682 .6131 L p .57704 .61303 L .423 .508 .841 r
F P
0 g
s
.58737 .61004 m .57688 .61289 L .57704 .61303 L .423 .508 .841 r
F
.59098 .62576 m .58394 .61903 L .59295 .61491 L p .806 .462 .406 r
F P
0 g
s
.59489 .61695 m .58737 .61004 L .58399 .61889 L p .41 .483 .825 r
F P
0 g
s
.58399 .61889 m .58394 .61903 L p .5841 .619 L .41 .483 .825 r
F P
0 g
s
.59489 .61695 m .58399 .61889 L .5841 .619 L .41 .483 .825 r
F
.60012 .62206 m .60188 .62395 L .59832 .6335 L p .82 .483 .418 r
F P
0 g
s
.59832 .6335 m .59098 .62576 L .60012 .62206 L p .82 .483 .418 r
F P
0 g
s
.60785 .63055 m .59489 .61695 L .59171 .62411 L p .419 .487 .824 r
F P
0 g
s
.59171 .62411 m .59098 .62576 L p .59348 .62647 L .419 .487 .824 r
F P
0 g
s
.60785 .63055 m .59171 .62411 L .59348 .62647 L .419 .487 .824 r
F
.60641 .64188 m .61606 .63924 L p .59866 .63361 L .454 .561 .874 r
F P
0 g
s
.59832 .6335 m .60641 .64188 L p .59866 .63361 L .454 .561 .874 r
F P
0 g
s
.61413 .65036 m .62392 .64809 L p .60679 .64202 L .449 .551 .868 r
F P
0 g
s
.60641 .64188 m .61413 .65036 L p .60679 .64202 L .449 .551 .868 r
F P
0 g
s
.62163 .65924 m .63152 .65727 L p .61441 .65047 L .441 .539 .861 r
F P
0 g
s
.61413 .65036 m .62163 .65924 L p .61441 .65047 L .441 .539 .861 r
F P
0 g
s
.62904 .66857 m .63895 .6667 L p .62175 .6593 L .436 .531 .856 r
F P
0 g
s
.62163 .65924 m .62904 .66857 L p .62175 .6593 L .436 .531 .856 r
F P
0 g
s
.63637 .67802 m .64635 .67637 L p .62925 .66866 L .434 .526 .852 r
F P
0 g
s
.62904 .66857 m .63637 .67802 L p .62925 .66866 L .434 .526 .852 r
F P
0 g
s
.64359 .68773 m .65361 .68622 L p .63653 .67809 L .43 .52 .848 r
F P
0 g
s
.63637 .67802 m .64359 .68773 L p .63653 .67809 L .43 .52 .848 r
F P
0 g
s
.65053 .69725 m .66063 .69605 L p .64396 .68791 L .429 .515 .845 r
F P
0 g
s
.64359 .68773 m .65053 .69725 L p .64396 .68791 L .429 .515 .845 r
F P
0 g
s
.65689 .7065 m .66698 .70568 L p .6509 .69744 L .424 .505 .838 r
F P
0 g
s
.65053 .69725 m .65689 .7065 L p .6509 .69744 L .424 .505 .838 r
F P
0 g
s
.66381 .71803 m .65689 .7065 L p .66371 .71682 L .912 .647 .524 r
F P
0 g
s
.52204 .62463 m .5323 .62737 L .52631 .63469 L p .594 .732 .94 r
F P
0 g
s
.52631 .63469 m .51588 .63167 L .52193 .62476 L p .594 .732 .94 r
F P
0 g
s
.52631 .63469 m .52193 .62476 L .52212 .62481 L .594 .732 .94 r
F
.51588 .63167 m .52631 .63469 L .52263 .65223 L p .747 .619 .717 r
F P
0 g
s
.52346 .63496 m .53463 .63766 L .53235 .62755 L p .765 .417 .395 r
F P
0 g
s
.53235 .62755 m .5323 .62737 L p .53215 .6275 L .765 .417 .395 r
F P
0 g
s
.53215 .6275 m .52346 .63496 L .53235 .62755 L .765 .417 .395 r
F
.52193 .62476 m .52204 .62463 L p .52212 .62481 L .594 .732 .94 r
F P
0 g
s
.52263 .65223 m .51113 .64896 L .51588 .63167 L p .747 .619 .717 r
F P
0 g
s
.51113 .64896 m .52263 .65223 L .52491 .66258 L p .758 .414 .402 r
F P
0 g
s
.53795 .66501 m .52491 .66258 L .52263 .65223 L p .739 .395 .399 r
F P
0 g
s
.58632 .31247 m .59497 .31407 L .59724 .32322 L p .745 .374 .35 r
F P
0 g
s
.59497 .31407 m .58632 .31247 L .58708 .29455 L p .747 .618 .716 r
F P
0 g
s
.59927 .29667 m .58708 .29455 L .59197 .28507 L p .626 .731 .923 r
F P
0 g
s
.59197 .28507 m .60587 .28829 L .59927 .29667 L p .626 .731 .923 r
F P
0 g
s
.47632 .56564 m .48725 .563 L .49091 .55334 L p .559 .241 .385 r
F P
0 g
s
.50286 .55248 m .49091 .55334 L .48725 .563 L p .589 .258 .376 r
F P
0 g
s
.71195 .73824 m .71843 .74418 L .71966 .73339 L p .903 .607 .475 r
F P
0 g
s
.71966 .73339 m .71462 .72789 L .71195 .73824 L p .903 .607 .475 r
F P
0 g
s
.79437 .74715 m .82418 .73461 L .81886 .72546 L p .552 .271 .442 r
F P
0 g
s
.62729 .37318 m .62489 .36466 L .617 .37218 L p .367 .323 .676 r
F P
0 g
s
.617 .37218 m .61958 .38088 L .62729 .37318 L p .367 .323 .676 r
F P
0 g
s
.61881 .33989 m .61702 .33454 L .60551 .33447 L p .417 .515 .851 r
F P
0 g
s
.57312 .62433 m .56476 .62742 L .57186 .63506 L p .604 .266 .371 r
F P
0 g
s
.69387 .39141 m .69294 .3809 L .68251 .38019 L p .395 .393 .739 r
F P
0 g
s
.52885 .36252 m .52241 .3566 L .52002 .36741 L p .436 .514 .841 r
F P
0 g
s
.52002 .36741 m .52795 .37354 L .52885 .36252 L p .436 .514 .841 r
F P
0 g
s
.49929 .31593 m .49473 .30117 L .48536 .30047 L p .39 .405 .755 r
F P
0 g
s
.48238 .28512 m .48536 .30047 L .49473 .30117 L p .379 .378 .732 r
F P
0 g
s
.1489 .22967 m .15928 .19687 L .14899 .19426 L p .891 .799 .751 r
F P
0 g
s
.15176 .38115 m .16199 .40386 L .17196 .40118 L p .884 .619 .533 r
F P
0 g
s
.83837 .42671 m .82956 .44943 L .83988 .45101 L p .43 .26 .549 r
F P
0 g
s
.44524 .12826 m .42489 .14499 L .43028 .15381 L p .837 .834 .843 r
F P
0 g
s
.18365 .71045 m .15633 .69372 L .15141 .70297 L p .804 .492 .461 r
F P
0 g
s
.49396 .58906 m .50222 .58834 L .498 .57972 L p .627 .758 .941 r
F P
0 g
s
.68873 .75272 m .69763 .76166 L .70737 .75837 L p .453 .582 .892 r
F P
0 g
s
.71705 .76475 m .70737 .75837 L .69763 .76166 L p .487 .635 .92 r
F P
0 g
s
.83951 .75476 m .86937 .73395 L .86383 .72918 L p .801 .884 .905 r
F P
0 g
s
.86383 .72918 m .83455 .74931 L .83951 .75476 L p .801 .884 .905 r
F P
0 g
s
.64015 .35199 m .64233 .36022 L .65174 .36333 L p .921 .642 .496 r
F P
0 g
s
.63546 .31477 m .63124 .30819 L .62924 .31918 L p .949 .691 .511 r
F P
0 g
s
.62924 .31918 m .63204 .32465 L .63546 .31477 L p .949 .691 .511 r
F P
0 g
s
.57745 .66097 m .59052 .65566 L .58991 .64661 L p .795 .874 .905 r
F P
0 g
s
.60058 .63989 m .58991 .64661 L .59052 .65566 L p .832 .882 .879 r
F P
0 g
s
.71675 .36959 m .71276 .35649 L .7071 .36375 L p .948 .739 .586 r
F P
0 g
s
.7071 .36375 m .71013 .37557 L .71675 .36959 L p .948 .739 .586 r
F P
0 g
s
.53131 .33919 m .53519 .34394 L .54548 .34219 L p .818 .467 .391 r
F P
0 g
s
.52053 .29355 m .51792 .2802 L .50946 .28356 L p .934 .742 .62 r
F P
0 g
s
.12511 .18597 m .11345 .22435 L .12065 .22596 L p .3 .175 .538 r
F P
0 g
s
.11549 .26424 m .12065 .22596 L .11345 .22435 L p .296 .216 .593 r
F P
0 g
s
.14091 .4191 m .15422 .4425 L .15942 .43601 L p .347 .397 .771 r
F P
0 g
s
.15942 .43601 m .14641 .41286 L .14091 .4191 L p .347 .397 .771 r
F P
0 g
s
.86293 .4626 m .87278 .43676 L .8661 .43241 L p .937 .845 .726 r
F P
0 g
s
.8732 .40652 m .8661 .43241 L .87278 .43676 L p .946 .828 .697 r
F P
0 g
s
.40506 .12834 m .38486 .14807 L .3922 .15158 L p .421 .147 .39 r
F P
0 g
s
.3922 .15158 m .41223 .1322 L .40506 .12834 L p .421 .147 .39 r
F P
0 g
s
.13764 .72433 m .17111 .74403 L .17421 .73715 L p .471 .621 .916 r
F P
0 g
s
.20905 .74943 m .17421 .73715 L .17111 .74403 L p .533 .688 .938 r
F P
0 g
s
.53819 .55726 m .54805 .5603 L .54962 .56981 L p .51 .637 .911 r
F P
0 g
s
.55967 .57312 m .54962 .56981 L .54805 .5603 L p .501 .631 .91 r
F P
0 g
s
.54962 .56981 m .55967 .57312 L .55359 .59 L p .652 .52 .689 r
F P
0 g
s
.55359 .59 m .54457 .58701 L .54962 .56981 L p .652 .52 .689 r
F P
0 g
s
.57535 .38476 m .56507 .38542 L .57132 .37717 L p .526 .181 .325 r
F P
0 g
s
.57132 .37717 m .58001 .3757 L .57535 .38476 L p .526 .181 .325 r
F P
0 g
s
.58001 .3757 m .57132 .37717 L .57249 .35928 L p .622 .513 .709 r
F P
0 g
s
.57249 .35928 m .57866 .35781 L .58001 .3757 L p .622 .513 .709 r
F P
0 g
s
.6443 .41966 m .63674 .41319 L .64698 .41233 L p .749 .353 .301 r
F P
0 g
s
.64698 .41233 m .65463 .41708 L .6443 .41966 L p .749 .353 .301 r
F P
0 g
s
.65463 .41708 m .64698 .41233 L .66083 .40094 L p .616 .448 .632 r
F P
0 g
s
.66083 .40094 m .66593 .40315 L .65463 .41708 L p .616 .448 .632 r
F P
0 g
s
.65847 .34027 m .66135 .3398 L .66663 .35057 L p .769 .417 .389 r
F P
0 g
s
.66135 .3398 m .65847 .34027 L .66065 .32246 L p .778 .657 .729 r
F P
0 g
s
.66065 .32246 m .66731 .32288 L .66135 .3398 L p .778 .657 .729 r
F P
0 g
s
.66731 .32288 m .66065 .32246 L .67034 .31402 L p .615 .734 .931 r
F P
0 g
s
.67034 .31402 m .67858 .31663 L .66731 .32288 L p .615 .734 .931 r
F P
0 g
s
.95557 .56571 m .96106 .52785 L .97191 .52912 L p .426 .33 .643 r
F P
0 g
s
.97191 .52912 m .96608 .56863 L .95557 .56571 L p .426 .33 .643 r
F P
0 g
s
.29504 .07011 m .26443 .08289 L .26169 .07611 L p .481 .143 .316 r
F P
0 g
s
.26169 .07611 m .2936 .06289 L .29501 .06994 L p .481 .143 .316 r
F P
0 g
s
.26169 .07611 m .29501 .06994 L .2943 .07024 L .481 .143 .316 r
F
.2936 .06289 m .26169 .07611 L .2522 .06089 L p .694 .571 .712 r
F P
0 g
s
.2522 .06089 m .28673 .0463 L .2936 .06289 L p .694 .571 .712 r
F P
0 g
s
.28957 .06068 m .25763 .07438 L .26437 .08282 L p .744 .794 .893 r
F P
0 g
s
.26437 .08282 m .26443 .08289 L p .26464 .08271 L .744 .794 .893 r
F P
0 g
s
.26464 .08271 m .28957 .06068 L .26437 .08282 L .744 .794 .893 r
F
.29501 .06994 m .29504 .07011 L p .2943 .07024 L .481 .143 .316 r
F P
0 g
s
.28673 .0463 m .2522 .06089 L .24538 .05233 L p .749 .794 .89 r
F P
0 g
s
.21332 .07284 m .24538 .05233 L .2522 .06089 L p .783 .809 .873 r
F P
0 g
s
.06377 .52862 m .06821 .559 L .06093 .55999 L p .292 .289 .684 r
F P
0 g
s
.06093 .55999 m .05639 .52829 L .0636 .52862 L p .292 .289 .684 r
F P
0 g
s
.06093 .55999 m .0636 .52862 L .0637 .52932 L .292 .289 .684 r
F
.05639 .52829 m .06093 .55999 L .0438 .56529 L p .709 .591 .722 r
F P
0 g
s
.0438 .56529 m .03863 .53082 L .05639 .52829 L p .709 .591 .722 r
F P
0 g
s
.05329 .53152 m .05829 .56335 L .06812 .55904 L p .906 .724 .645 r
F P
0 g
s
.06812 .55904 m .06821 .559 L p .06808 .55875 L .906 .724 .645 r
F P
0 g
s
.06808 .55875 m .05329 .53152 L .06812 .55904 L .906 .724 .645 r
F
.0636 .52862 m .06377 .52862 L p .0637 .52932 L .292 .289 .684 r
F P
0 g
s
.03863 .53082 m .0438 .56529 L .03382 .56965 L p .904 .718 .641 r
F P
0 g
s
.04468 .6033 m .03382 .56965 L .0438 .56529 L p .897 .684 .605 r
F P
0 g
s
.24631 .52355 m .25331 .55339 L .24557 .55576 L p .326 .311 .688 r
F P
0 g
s
.24895 .58473 m .24557 .55576 L .25331 .55339 L p .324 .281 .655 r
F P
0 g
s
.24557 .55576 m .24895 .58473 L .2311 .58655 L p .705 .56 .689 r
F P
0 g
s
.2311 .58655 m .22778 .55798 L .24557 .55576 L p .705 .56 .689 r
F P
0 g
s
.22778 .55798 m .2311 .58655 L .22095 .58635 L p .91 .705 .613 r
F P
0 g
s
.22094 .58628 m .22778 .55798 L .22095 .58635 L .91 .705 .613 r
F
.22092 .58635 m .21758 .55786 L .22778 .55798 L p F P
0 g
s
.22866 .58432 m .22523 .55549 L .2176 .55785 L p .317 .276 .653 r
F P
0 g
s
.2176 .55785 m .21758 .55786 L p .21761 .55793 L .317 .276 .653 r
F P
0 g
s
.22866 .58432 m .2176 .55785 L .21761 .55793 L .317 .276 .653 r
F
.22095 .58635 m .22092 .58635 L p .22094 .58628 L .91 .705 .613 r
F P
0 g
s
.76724 .61093 m .7715 .58152 L .77879 .58474 L p .947 .795 .66 r
F P
0 g
s
.77879 .58474 m .77482 .61333 L .76724 .61093 L p .947 .795 .66 r
F P
0 g
s
.77482 .61333 m .77879 .58474 L .79626 .58882 L p .71 .564 .688 r
F P
0 g
s
.79626 .58882 m .79257 .616 L .77482 .61333 L p .71 .564 .688 r
F P
0 g
s
.32581 .2603 m .29946 .27359 L .29552 .26655 L p .51 .181 .346 r
F P
0 g
s
.26925 .2762 m .29552 .26655 L .29946 .27359 L p .544 .201 .338 r
F P
0 g
s
.29552 .26655 m .26925 .2762 L .26328 .25928 L p .725 .586 .7 r
F P
0 g
s
.26328 .25928 m .2892 .24977 L .29552 .26655 L p .725 .586 .7 r
F P
0 g
s
.2892 .24977 m .26328 .25928 L .26091 .24943 L p .764 .814 .892 r
F P
0 g
s
.26098 .24941 m .2892 .24977 L .26091 .24943 L .764 .814 .892 r
F
.26091 .24941 m .28676 .2399 L .2892 .24977 L p F P
0 g
s
.26454 .25652 m .29068 .24686 L .28677 .23992 L p .54 .195 .331 r
F P
0 g
s
.28677 .23992 m .28676 .2399 L p .2867 .23994 L .54 .195 .331 r
F P
0 g
s
.26454 .25652 m .28677 .23992 L .2867 .23994 L .54 .195 .331 r
F
.26091 .24943 m .26091 .24941 L p .26098 .24941 L .764 .814 .892 r
F P
0 g
s
.47901 .21696 m .48026 .19837 L .48945 .19752 L p .925 .792 .694 r
F P
0 g
s
.49052 .17926 m .48945 .19752 L .48026 .19837 L p .925 .79 .693 r
F P
0 g
s
.48945 .19752 m .49052 .17926 L .50847 .17967 L p .705 .598 .734 r
F P
0 g
s
.50847 .17967 m .50734 .1987 L .48945 .19752 L p .705 .598 .734 r
F P
0 g
s
.50734 .1987 m .50847 .17967 L .51745 .18129 L p .366 .304 .655 r
F P
0 g
s
.51745 .18129 m .51619 .20073 L .50734 .1987 L p .366 .304 .655 r
F P
0 g
s
.67276 .66656 m .68026 .67694 L .67012 .67821 L p .433 .519 .847 r
F P
0 g
s
.67012 .67821 m .6627 .66814 L .67276 .66656 L p .433 .519 .847 r
F P
0 g
s
.6627 .66814 m .67012 .67821 L .65531 .68833 L p .732 .626 .741 r
F P
0 g
s
.65531 .68833 m .64818 .67868 L .6627 .66814 L p .732 .626 .741 r
F P
0 g
s
.51359 .62095 m .52204 .62463 L .51588 .63167 L p .551 .685 .928 r
F P
0 g
s
.51588 .63167 m .50647 .62711 L .51329 .62121 L p .551 .685 .928 r
F P
0 g
s
.51588 .63167 m .51329 .62121 L .51368 .62138 L .551 .685 .928 r
F
.50647 .62711 m .51588 .63167 L .51113 .64896 L p .744 .62 .722 r
F P
0 g
s
.51367 .63138 m .52346 .63496 L .52209 .62496 L p .807 .466 .41 r
F P
0 g
s
.52209 .62496 m .52204 .62463 L p .52179 .62483 L .807 .466 .41 r
F P
0 g
s
.52179 .62483 m .51367 .63138 L .52209 .62496 L .807 .466 .41 r
F
.51329 .62121 m .51359 .62095 L p .51368 .62138 L .551 .685 .928 r
F P
0 g
s
.51113 .64896 m .49942 .64362 L .50647 .62711 L p .744 .62 .722 r
F P
0 g
s
.49942 .64362 m .51113 .64896 L .5125 .65935 L p .786 .449 .418 r
F P
0 g
s
.52491 .66258 m .5125 .65935 L .51113 .64896 L p .758 .414 .402 r
F P
0 g
s
.59045 .32105 m .58632 .31247 L p .59647 .32246 L .745 .374 .35 r
F P
0 g
s
.57728 .31253 m .58632 .31247 L .59045 .32105 L p .687 .315 .335 r
F P
0 g
s
.5828 .32035 m .57728 .31253 L p .5896 .3205 L .687 .315 .335 r
F P
0 g
s
.59045 .32105 m .5828 .32035 L p .5896 .3205 L .687 .315 .335 r
F P
0 g
s
.58632 .31247 m .57728 .31253 L .57501 .29472 L p .749 .613 .708 r
F P
0 g
s
.57501 .29472 m .58708 .29455 L .58632 .31247 L p .749 .613 .708 r
F P
0 g
s
.56821 .31415 m .57728 .31253 L .5828 .32035 L p .636 .27 .333 r
F P
0 g
s
.57507 .32095 m .56821 .31415 L p .58181 .31993 L .636 .27 .333 r
F P
0 g
s
.5828 .32035 m .57507 .32095 L p .58181 .31993 L .636 .27 .333 r
F P
0 g
s
.57728 .31253 m .56821 .31415 L .56286 .29701 L p .748 .606 .7 r
F P
0 g
s
.56286 .29701 m .57501 .29472 L .57728 .31253 L p .748 .606 .7 r
F P
0 g
s
.55932 .31724 m .56821 .31415 L .57507 .32095 L p .586 .233 .338 r
F P
0 g
s
.56668 .32332 m .55932 .31724 L p .57432 .32077 L .586 .233 .338 r
F P
0 g
s
.57507 .32095 m .56668 .32332 L p .57432 .32077 L .586 .233 .338 r
F P
0 g
s
.56821 .31415 m .55932 .31724 L .55188 .30088 L p .748 .6 .693 r
F P
0 g
s
.54969 .32202 m .55932 .31724 L .56668 .32332 L p .547 .213 .353 r
F P
0 g
s
.5579 .32702 m .54969 .32202 L p .56547 .32323 L .547 .213 .353 r
F P
0 g
s
.56668 .32332 m .5579 .32702 L p .56547 .32323 L .547 .213 .353 r
F P
0 g
s
.55932 .31724 m .54969 .32202 L .53991 .30692 L p .742 .592 .69 r
F P
0 g
s
.54075 .32819 m .54969 .32202 L .5579 .32702 L p .508 .195 .371 r
F P
0 g
s
.54952 .33218 m .54075 .32819 L p .55683 .32709 L .508 .195 .371 r
F P
0 g
s
.5579 .32702 m .54952 .33218 L p .55683 .32709 L .508 .195 .371 r
F P
0 g
s
.54969 .32202 m .54075 .32819 L .52908 .31448 L p .739 .586 .684 r
F P
0 g
s
.53197 .33594 m .54075 .32819 L .54952 .33218 L p .476 .185 .392 r
F P
0 g
s
.54106 .33921 m .53197 .33594 L p .54878 .33234 L .476 .185 .392 r
F P
0 g
s
.54952 .33218 m .54106 .33921 L p .54878 .33234 L .476 .185 .392 r
F P
0 g
s
.53519 .34394 m .53969 .34814 L .54954 .3449 L p .783 .419 .369 r
F P
0 g
s
.53519 .34394 m .53131 .33919 L .51697 .35002 L p .661 .504 .661 r
F P
0 g
s
.51697 .35002 m .52241 .3566 L .53519 .34394 L p .661 .504 .661 r
F P
0 g
s
.53969 .34814 m .53519 .34394 L .52241 .3566 L p .656 .506 .668 r
F P
0 g
s
.49929 .31593 m .50528 .33011 L .52193 .32336 L p .719 .613 .738 r
F P
0 g
s
.54075 .32819 m .53197 .33594 L .51914 .3233 L p .736 .58 .68 r
F P
0 g
s
.51235 .34283 m .51697 .35002 L .53131 .33919 L p .667 .505 .655 r
F P
0 g
s
.52549 .34245 m .53197 .33594 L .54106 .33921 L p .458 .175 .396 r
F P
0 g
s
.54106 .33921 m .53197 .34838 L .52549 .34245 L p .458 .175 .396 r
F P
0 g
s
.54106 .33921 m .53729 .32977 L p .53238 .34694 L .875 .855 .819 r
F P
0 g
s
.53197 .34838 m .54106 .33921 L p .53238 .34694 L .875 .855 .819 r
F P
0 g
s
.54952 .33218 m .5466 .32239 L p .54155 .33772 L .862 .858 .836 r
F P
0 g
s
.54106 .33921 m .54952 .33218 L p .54155 .33772 L .862 .858 .836 r
F P
0 g
s
.5579 .32702 m .55634 .31683 L p .55007 .33094 L .837 .858 .861 r
F P
0 g
s
.54952 .33218 m .5579 .32702 L p .55007 .33094 L .837 .858 .861 r
F P
0 g
s
.56668 .32332 m .56659 .31297 L p .5585 .32606 L .803 .85 .885 r
F P
0 g
s
.5579 .32702 m .56668 .32332 L p .5585 .32606 L .803 .85 .885 r
F P
0 g
s
.57507 .32095 m .57659 .31052 L p .56765 .32207 L .777 .842 .901 r
F P
0 g
s
.56668 .32332 m .57507 .32095 L p .56765 .32207 L .777 .842 .901 r
F P
0 g
s
.5828 .32035 m .58608 .31029 L p .57584 .3202 L .732 .819 .919 r
F P
0 g
s
.57507 .32095 m .5828 .32035 L p .57584 .3202 L .732 .819 .919 r
F P
0 g
s
.59045 .32105 m .59538 .31163 L p .58398 .31953 L .686 .789 .928 r
F P
0 g
s
.5828 .32035 m .59045 .32105 L p .58398 .31953 L .686 .789 .928 r
F P
0 g
s
.59724 .32322 m .59045 .32105 L p .59647 .32246 L .745 .374 .35 r
F P
0 g
s
.58708 .29455 m .57501 .29472 L .57825 .28461 L p .679 .776 .924 r
F P
0 g
s
.57825 .28461 m .59197 .28507 L .58708 .29455 L p .679 .776 .924 r
F P
0 g
s
.48725 .563 m .49832 .56172 L .50286 .55248 L p .589 .258 .376 r
F P
0 g
s
.51505 .55287 m .50286 .55248 L .49832 .56172 L p .619 .279 .372 r
F P
0 g
s
.82418 .73461 m .85176 .71582 L .84532 .70733 L p .513 .261 .471 r
F P
0 g
s
.61702 .33454 m .61499 .33018 L .60285 .33011 L p .443 .548 .869 r
F P
0 g
s
.60139 .32771 m .60285 .33011 L .61499 .33018 L p .443 .605 .915 r
F P
0 g
s
.69294 .3809 m .69062 .37098 L .67991 .37091 L p .41 .433 .773 r
F P
0 g
s
.49473 .30117 m .49163 .28603 L .48238 .28512 L p .379 .378 .732 r
F P
0 g
s
.48006 .26803 m .48238 .28512 L .49163 .28603 L p .374 .359 .714 r
F P
0 g
s
.16199 .40386 m .17434 .42593 L .18395 .42242 L p .873 .595 .513 r
F P
0 g
s
.42489 .14499 m .40571 .16349 L .41177 .17178 L p .851 .834 .829 r
F P
0 g
s
.50222 .58834 m .51041 .58847 L .50726 .57942 L p .598 .731 .938 r
F P
0 g
s
.86937 .73395 m .8985 .70772 L .89217 .70414 L p .835 .893 .882 r
F P
0 g
s
.89217 .70414 m .86383 .72918 L .86937 .73395 L p .835 .893 .882 r
F P
0 g
s
.63124 .30819 m .62638 .30194 L .62607 .31319 L p .958 .686 .478 r
F P
0 g
s
.62607 .31319 m .62924 .31918 L .63124 .30819 L p .958 .686 .478 r
F P
0 g
s
.71276 .35649 m .70734 .3444 L .70313 .35266 L p .946 .714 .554 r
F P
0 g
s
.70313 .35266 m .7071 .36375 L .71276 .35649 L p .946 .714 .554 r
F P
0 g
s
.51792 .2802 m .51587 .26552 L .50715 .26824 L p .933 .752 .634 r
F P
0 g
s
.15422 .4425 m .17007 .46633 L .17524 .45984 L p .362 .426 .793 r
F P
0 g
s
.17524 .45984 m .15942 .43601 L .15422 .4425 L p .362 .426 .793 r
F P
0 g
s
.38486 .14807 m .36508 .17017 L .3724 .17371 L p .406 .149 .408 r
F P
0 g
s
.3724 .17371 m .3922 .15158 L .38486 .14807 L p .406 .149 .408 r
F P
0 g
s
.71462 .72789 m .70726 .71895 L .70334 .72834 L p .895 .604 .488 r
F P
0 g
s
.62944 .38013 m .62729 .37318 L .61958 .38088 L p .363 .322 .678 r
F P
0 g
s
.61958 .38088 m .62214 .38859 L .62944 .38013 L p .363 .322 .678 r
F P
0 g
s
.56476 .62742 m .55657 .62933 L .56292 .63775 L p .641 .292 .365 r
F P
0 g
s
.53551 .36719 m .52885 .36252 L .52795 .37354 L p .456 .548 .862 r
F P
0 g
s
.52795 .37354 m .53586 .37829 L .53551 .36719 L p .456 .548 .862 r
F P
0 g
s
.15928 .19687 m .17226 .16802 L .1622 .16434 L p .879 .81 .778 r
F P
0 g
s
.82956 .44943 m .81767 .47371 L .8277 .47629 L p .438 .253 .531 r
F P
0 g
s
.15633 .69372 m .12977 .67299 L .12376 .68167 L p .825 .524 .479 r
F P
0 g
s
.67964 .74189 m .68873 .75272 L .69895 .7507 L p .44 .541 .863 r
F P
0 g
s
.70737 .75837 m .69895 .7507 L .68873 .75272 L p .453 .582 .892 r
F P
0 g
s
.64233 .36022 m .6446 .36824 L .65408 .37105 L p .917 .635 .491 r
F P
0 g
s
.56481 .66427 m .57745 .66097 L .57823 .6519 L p .76 .861 .924 r
F P
0 g
s
.58991 .64661 m .57823 .6519 L .57745 .66097 L p .795 .874 .905 r
F P
0 g
s
.1396 .1531 m .12511 .18597 L .13183 .18879 L p .308 .151 .499 r
F P
0 g
s
.12065 .22596 m .13183 .18879 L .12511 .18597 L p .3 .175 .538 r
F P
0 g
s
.84982 .48968 m .86293 .4626 L .85662 .45762 L p .926 .858 .754 r
F P
0 g
s
.8661 .43241 m .85662 .45762 L .86293 .4626 L p .937 .845 .726 r
F P
0 g
s
.10754 .70118 m .13764 .72433 L .14203 .71834 L p .433 .575 .896 r
F P
0 g
s
.17421 .73715 m .14203 .71834 L .13764 .72433 L p .471 .621 .916 r
F P
0 g
s
.54805 .5603 m .55872 .56352 L .55967 .57312 L p .501 .631 .91 r
F P
0 g
s
.56965 .57721 m .55967 .57312 L .55872 .56352 L p .482 .608 .901 r
F P
0 g
s
.55967 .57312 m .56965 .57721 L .56218 .59353 L p .651 .516 .686 r
F P
0 g
s
.56218 .59353 m .55359 .59 L .55967 .57312 L p .651 .516 .686 r
F P
0 g
s
.58554 .38263 m .57535 .38476 L .58001 .3757 L p .489 .167 .347 r
F P
0 g
s
.58001 .3757 m .58875 .37297 L .58554 .38263 L p .489 .167 .347 r
F P
0 g
s
.58875 .37297 m .58001 .3757 L .57866 .35781 L p .625 .524 .72 r
F P
0 g
s
.57866 .35781 m .58485 .35544 L .58875 .37297 L p .625 .524 .72 r
F P
0 g
s
.65288 .42452 m .6443 .41966 L .65463 .41708 L p .681 .279 .278 r
F P
0 g
s
.65463 .41708 m .66243 .41988 L .65288 .42452 L p .681 .279 .278 r
F P
0 g
s
.66243 .41988 m .65463 .41708 L .66593 .40315 L p .603 .451 .648 r
F P
0 g
s
.66593 .40315 m .67088 .40404 L .66243 .41988 L p .603 .451 .648 r
F P
0 g
s
.66663 .35057 m .66597 .34976 L .65847 .34027 L p .769 .417 .389 r
F P
0 g
s
.6554 .34092 m .65847 .34027 L .66597 .34976 L p .724 .354 .349 r
F P
0 g
s
.65847 .34027 m .6554 .34092 L .65472 .32298 L p .786 .65 .712 r
F P
0 g
s
.65472 .32298 m .66065 .32246 L .65847 .34027 L p .786 .65 .712 r
F P
0 g
s
.66065 .32246 m .65472 .32298 L .66272 .31318 L p .676 .789 .934 r
F P
0 g
s
.66272 .31318 m .67034 .31402 L .66065 .32246 L p .676 .789 .934 r
F P
0 g
s
.96106 .52785 m .96002 .49033 L .97092 .48988 L p .425 .362 .684 r
F P
0 g
s
.97092 .48988 m .97191 .52912 L .96106 .52785 L p .425 .362 .684 r
F P
0 g
s
.32679 .06305 m .29504 .07011 L .2936 .06289 L p .537 .174 .298 r
F P
0 g
s
.2936 .06289 m .32681 .05559 L .32679 .06287 L p .537 .174 .298 r
F P
0 g
s
.2936 .06289 m .32679 .06287 L .32598 .06305 L .537 .174 .298 r
F
.32681 .05559 m .2936 .06289 L .28673 .0463 L p .693 .568 .71 r
F P
0 g
s
.28673 .0463 m .32294 .03805 L .32681 .05559 L p .693 .568 .71 r
F P
0 g
s
.32287 .0529 m .28957 .06068 L .29499 .07003 L p .701 .77 .905 r
F P
0 g
s
.29499 .07003 m .29504 .07011 L p .29527 .06997 L .701 .77 .905 r
F P
0 g
s
.29527 .06997 m .32287 .0529 L .29499 .07003 L .701 .77 .905 r
F
.32679 .06287 m .32679 .06305 L p .32598 .06305 L .537 .174 .298 r
F P
0 g
s
.32294 .03805 m .28673 .0463 L .28125 .03682 L p .708 .771 .901 r
F P
0 g
s
.24538 .05233 m .28125 .03682 L .28673 .0463 L p .749 .794 .89 r
F P
0 g
s
.06436 .49807 m .06377 .52862 L .05639 .52829 L p .287 .24 .629 r
F P
0 g
s
.05639 .52829 m .05712 .49636 L .06419 .49803 L p .287 .24 .629 r
F P
0 g
s
.05639 .52829 m .06419 .49803 L .06417 .49877 L .287 .24 .629 r
F
.05712 .49636 m .05639 .52829 L .03863 .53082 L p .707 .589 .722 r
F P
0 g
s
.03863 .53082 m .03916 .49597 L .05712 .49636 L p .707 .589 .722 r
F P
0 g
s
.05356 .49938 m .05329 .53152 L .06367 .52865 L p .907 .758 .685 r
F P
0 g
s
.06367 .52865 m .06377 .52862 L p .06367 .52835 L .907 .758 .685 r
F P
0 g
s
.06367 .52835 m .05356 .49938 L .06367 .52865 L .907 .758 .685 r
F
.06419 .49803 m .06436 .49807 L p .06417 .49877 L .287 .24 .629 r
F P
0 g
s
.03916 .49597 m .03863 .53082 L .02809 .53372 L p .905 .751 .68 r
F P
0 g
s
.03382 .56965 m .02809 .53372 L .03863 .53082 L p .904 .718 .641 r
F P
0 g
s
.25331 .55339 m .25677 .58269 L .24895 .58473 L p .324 .281 .655 r
F P
0 g
s
.25175 .61392 m .24895 .58473 L .25677 .58269 L p .324 .276 .649 r
F P
0 g
s
.24895 .58473 m .25175 .61392 L .2339 .61593 L p .705 .561 .689 r
F P
0 g
s
.2339 .61593 m .2311 .58655 L .24895 .58473 L p .705 .561 .689 r
F P
0 g
s
.2311 .58655 m .2339 .61593 L .22372 .61594 L p .911 .711 .619 r
F P
0 g
s
.22372 .61594 m .22092 .58635 L .2311 .58655 L p .911 .711 .619 r
F P
0 g
s
.76315 .63889 m .76724 .61093 L .77482 .61333 L p .947 .797 .662 r
F P
0 g
s
.77482 .61333 m .77074 .64122 L .76315 .63889 L p .947 .797 .662 r
F P
0 g
s
.77482 .61333 m .76315 .63889 L .76315 .63888 L .947 .797 .662 r
F
.77074 .64122 m .77482 .61333 L .79257 .616 L p .71 .564 .688 r
F P
0 g
s
.79257 .616 m .78849 .64396 L .77074 .64122 L p .71 .564 .688 r
F P
0 g
s
.77338 .6393 m .77748 .61119 L .76724 .61093 L p .41 .29 .605 r
F P
0 g
s
.76724 .61093 m .76724 .61093 L p .76724 .61094 L .41 .29 .605 r
F P
0 g
s
.76724 .61094 m .77338 .6393 L .76724 .61093 L .41 .29 .605 r
F
.76315 .63889 m .76315 .63889 L p .76315 .63888 L .947 .797 .662 r
F P
0 g
s
.78849 .64396 m .79257 .616 L .80287 .61629 L p .414 .294 .607 r
F P
0 g
s
.29946 .27359 m .2729 .28339 L .26925 .2762 L p .544 .201 .338 r
F P
0 g
s
.24267 .2854 m .26925 .2762 L .2729 .28339 L p .55 .205 .337 r
F P
0 g
s
.26925 .2762 m .24267 .2854 L .23648 .26854 L p .724 .586 .701 r
F P
0 g
s
.23648 .26854 m .26328 .25928 L .26925 .2762 L p .724 .586 .701 r
F P
0 g
s
.26328 .25928 m .23648 .26854 L .23389 .25872 L p .759 .811 .894 r
F P
0 g
s
.23389 .25872 m .26091 .24941 L .26328 .25928 L p .759 .811 .894 r
F P
0 g
s
.48142 .18046 m .49052 .17926 L p .48069 .19756 L .925 .79 .693 r
F P
0 g
s
.49078 .1614 m .49052 .17926 L .48142 .18046 L p .927 .783 .681 r
F P
0 g
s
.48183 .16309 m .49078 .1614 L p .48193 .17942 L .927 .783 .681 r
F P
0 g
s
.48142 .18046 m .48183 .16309 L p .48193 .17942 L .927 .783 .681 r
F P
0 g
s
.49052 .17926 m .49078 .1614 L .50873 .16071 L p .706 .599 .734 r
F P
0 g
s
.48992 .14283 m .49078 .1614 L .48183 .16309 L p .93 .771 .663 r
F P
0 g
s
.48183 .16309 m .48118 .14555 L .48992 .14283 L p .93 .771 .663 r
F P
0 g
s
.48183 .16309 m .4909 .1641 L p .48173 .1466 L .367 .331 .686 r
F P
0 g
s
.48118 .14555 m .48183 .16309 L p .48173 .1466 L .367 .331 .686 r
F P
0 g
s
.48142 .18046 m .49033 .18209 L p .48213 .16376 L .362 .313 .668 r
F P
0 g
s
.48183 .16309 m .48142 .18046 L p .48213 .16376 L .362 .313 .668 r
F P
0 g
s
.48026 .19837 m .48142 .18046 L p .48069 .19756 L .925 .79 .693 r
F P
0 g
s
.50873 .16071 m .50847 .17967 L .49052 .17926 L p .706 .599 .734 r
F P
0 g
s
.50847 .17967 m .50873 .16071 L .51787 .16171 L p .368 .316 .668 r
F P
0 g
s
.51787 .16171 m .51745 .18129 L .50847 .17967 L p .368 .316 .668 r
F P
0 g
s
.66533 .65652 m .67276 .66656 L .6627 .66814 L p .435 .522 .848 r
F P
0 g
s
.6627 .66814 m .65532 .65824 L .66533 .65652 L p .435 .522 .848 r
F P
0 g
s
.65532 .65824 m .6627 .66814 L .64818 .67868 L p .732 .626 .741 r
F P
0 g
s
.64818 .67868 m .64089 .66894 L .65532 .65824 L p .732 .626 .741 r
F P
0 g
s
.50605 .6162 m .51359 .62095 L .50647 .62711 L p .51 .637 .911 r
F P
0 g
s
.50647 .62711 m .49801 .62126 L .50567 .61644 L p .51 .637 .911 r
F P
0 g
s
.50647 .62711 m .50567 .61644 L .50607 .61668 L .51 .637 .911 r
F
.49801 .62126 m .50647 .62711 L .49942 .64362 L p .741 .622 .727 r
F P
0 g
s
.50468 .62653 m .51367 .63138 L .5136 .62131 L p .843 .516 .434 r
F P
0 g
s
.5136 .62131 m .51359 .62095 L p .5133 .62113 L .843 .516 .434 r
F P
0 g
s
.5133 .62113 m .50468 .62653 L .5136 .62131 L .843 .516 .434 r
F
.50567 .61644 m .50605 .6162 L p .50607 .61668 L .51 .637 .911 r
F P
0 g
s
.49942 .64362 m .48861 .63656 L .49801 .62126 L p .741 .622 .727 r
F P
0 g
s
.48861 .63656 m .49942 .64362 L .49945 .6541 L p .819 .493 .438 r
F P
0 g
s
.5125 .65935 m .49945 .6541 L .49942 .64362 L p .786 .449 .418 r
F P
0 g
s
.57501 .29472 m .56286 .29701 L .56433 .28652 L p .723 .807 .916 r
F P
0 g
s
.56433 .28652 m .57825 .28461 L .57501 .29472 L p .723 .807 .916 r
F P
0 g
s
.45347 .59489 m .46268 .59043 L .45573 .57389 L p .716 .581 .703 r
F P
0 g
s
.45573 .57389 m .44593 .5786 L .45347 .59489 L p .716 .581 .703 r
F P
0 g
s
.46581 .56933 m .45573 .57389 L .46268 .59043 L p .662 .555 .724 r
F P
0 g
s
.46268 .59043 m .47123 .58646 L .46581 .56933 L p .662 .555 .724 r
F P
0 g
s
.49832 .56172 m .50959 .56155 L .51505 .55287 L p .619 .279 .372 r
F P
0 g
s
.5269 .55456 m .51505 .55287 L .50959 .56155 L p .648 .301 .369 r
F P
0 g
s
.70726 .71895 m .70072 .70952 L .69611 .71847 L p .908 .631 .506 r
F P
0 g
s
.85176 .71582 m .87796 .69306 L .8702 .68564 L p .493 .261 .49 r
F P
0 g
s
.63228 .38799 m .62944 .38013 L .62214 .38859 L p .373 .354 .709 r
F P
0 g
s
.62214 .38859 m .62577 .39707 L .63228 .38799 L p .373 .354 .709 r
F P
0 g
s
.61499 .33018 m .61353 .32612 L .60139 .32771 L p .443 .605 .915 r
F P
0 g
s
.55657 .62933 m .54868 .62981 L .55371 .63911 L p .69 .331 .361 r
F P
0 g
s
.69062 .37098 m .68817 .36269 L .67752 .36438 L p .423 .474 .808 r
F P
0 g
s
.54314 .37127 m .53551 .36719 L .53586 .37829 L p .494 .601 .889 r
F P
0 g
s
.53586 .37829 m .54515 .38216 L .54314 .37127 L p .494 .601 .889 r
F P
0 g
s
.49163 .28603 m .48918 .2695 L .48006 .26803 L p .374 .359 .714 r
F P
0 g
s
.47889 .25111 m .48006 .26803 L .48918 .2695 L p .368 .34 .696 r
F P
0 g
s
.17226 .16802 m .1894 .14261 L .17994 .13741 L p .856 .82 .813 r
F P
0 g
s
.17434 .42593 m .19003 .44955 L .19953 .44582 L p .864 .576 .499 r
F P
0 g
s
.81767 .47371 m .80446 .49843 L .81435 .50144 L p .442 .25 .523 r
F P
0 g
s
.40571 .16349 m .38603 .18549 L .39224 .19365 L p .861 .833 .817 r
F P
0 g
s
.12977 .67299 m .10814 .64868 L .10072 .65635 L p .856 .576 .513 r
F P
0 g
s
.51041 .58847 m .51884 .58957 L .51671 .58027 L p .562 .697 .931 r
F P
0 g
s
.67133 .73019 m .67964 .74189 L .68948 .73986 L p .426 .514 .845 r
F P
0 g
s
.69895 .7507 m .68948 .73986 L .67964 .74189 L p .44 .541 .863 r
F P
0 g
s
.8985 .70772 m .92259 .67698 L .91571 .67466 L p .877 .896 .842 r
F P
0 g
s
.91571 .67466 m .89217 .70414 L .8985 .70772 L p .877 .896 .842 r
F P
0 g
s
.6446 .36824 m .64661 .37467 L .65635 .37772 L p .912 .617 .472 r
F P
0 g
s
.62638 .30194 m .62055 .29637 L .62222 .3077 L p .941 .631 .423 r
F P
0 g
s
.62222 .3077 m .62607 .31319 L .62638 .30194 L p .941 .631 .423 r
F P
0 g
s
.55134 .66564 m .56481 .66427 L .56706 .65528 L p .714 .839 .941 r
F P
0 g
s
.57823 .6519 m .56706 .65528 L .56481 .66427 L p .76 .861 .924 r
F P
0 g
s
.70734 .3444 m .69997 .33357 L .69743 .34264 L p .93 .655 .498 r
F P
0 g
s
.69743 .34264 m .70313 .35266 L .70734 .3444 L p .93 .655 .498 r
F P
0 g
s
.53969 .34814 m .54473 .35171 L .55422 .34744 L p .747 .374 .347 r
F P
0 g
s
.51587 .26552 m .51481 .25037 L .50591 .25257 L p .933 .769 .655 r
F P
0 g
s
.15968 .12243 m .1396 .1531 L .14581 .15686 L p .328 .125 .446 r
F P
0 g
s
.13183 .18879 m .14581 .15686 L .1396 .1531 L p .308 .151 .499 r
F P
0 g
s
.17007 .46633 m .18595 .48951 L .19131 .48321 L p .365 .432 .797 r
F P
0 g
s
.83602 .51559 m .84982 .48968 L .84384 .48431 L p .921 .862 .766 r
F P
0 g
s
.85662 .45762 m .84384 .48431 L .84982 .48968 L p .926 .858 .754 r
F P
0 g
s
.36508 .17017 m .34587 .19207 L .35301 .19586 L p .404 .149 .411 r
F P
0 g
s
.08128 .67254 m .10754 .70118 L .1126 .69582 L p .384 .507 .859 r
F P
0 g
s
.14203 .71834 m .1126 .69582 L .10754 .70118 L p .433 .575 .896 r
F P
0 g
s
.55872 .56352 m .56956 .56755 L .56965 .57721 L p .482 .608 .901 r
F P
0 g
s
.57927 .58218 m .56965 .57721 L .56956 .56755 L p .461 .578 .886 r
F P
0 g
s
.56965 .57721 m .57927 .58218 L .5703 .59774 L p .652 .513 .681 r
F P
0 g
s
.5703 .59774 m .56218 .59353 L .56965 .57721 L p .652 .513 .681 r
F P
0 g
s
.71032 .42487 m .71055 .41454 L .69261 .41377 L p .707 .571 .7 r
F P
0 g
s
.69261 .41377 m .69238 .42434 L .71032 .42487 L p .707 .571 .7 r
F P
0 g
s
.69358 .40234 m .69261 .41377 L .71055 .41454 L p .704 .612 .751 r
F P
0 g
s
.71055 .41454 m .71153 .40167 L .69358 .40234 L p .704 .612 .751 r
F P
0 g
s
.59508 .37946 m .58554 .38263 L .58875 .37297 L p .467 .165 .368 r
F P
0 g
s
.58875 .37297 m .59701 .36953 L .59508 .37946 L p .467 .165 .368 r
F P
0 g
s
.59701 .36953 m .58875 .37297 L .58485 .35544 L p .633 .537 .727 r
F P
0 g
s
.58485 .35544 m .59123 .35252 L .59701 .36953 L p .633 .537 .727 r
F P
0 g
s
.11593 .30347 m .12114 .33905 L .13858 .3348 L p .709 .592 .723 r
F P
0 g
s
.13858 .3348 m .13372 .30094 L .11593 .30347 L p .709 .592 .723 r
F P
0 g
s
.14375 .3582 m .13858 .3348 L .12114 .33905 L p .702 .555 .685 r
F P
0 g
s
.12114 .33905 m .12689 .36441 L .14375 .3582 L p .702 .555 .685 r
F P
0 g
s
.51367 .07009 m .47983 .08568 L .48876 .10125 L p .707 .577 .707 r
F P
0 g
s
.48876 .10125 m .52123 .08638 L .51367 .07009 L p .707 .577 .707 r
F P
0 g
s
.47983 .08568 m .45592 .09893 L .46641 .11351 L p .725 .583 .697 r
F P
0 g
s
.46641 .11351 m .48876 .10125 L .47983 .08568 L p .725 .583 .697 r
F P
0 g
s
.7276 .76895 m .73284 .77037 L .73309 .75242 L p .975 .893 .678 r
F P
0 g
s
.73309 .75242 m .73251 .75168 L .7276 .76895 L p .975 .893 .678 r
F P
0 g
s
.76364 .75365 m .73309 .75242 L .73284 .77037 L p .69 .563 .707 r
F P
0 g
s
.73284 .77037 m .76774 .77114 L .76364 .75365 L p .69 .563 .707 r
F P
0 g
s
.64649 .59366 m .65424 .5809 L .63801 .57322 L p .707 .577 .707 r
F P
0 g
s
.63801 .57322 m .63118 .58429 L .64649 .59366 L p .707 .577 .707 r
F P
0 g
s
.64418 .56025 m .63801 .57322 L .65424 .5809 L p .707 .577 .707 r
F P
0 g
s
.70902 .43949 m .71032 .42487 L .69238 .42434 L p .707 .577 .707 r
F P
0 g
s
.69238 .42434 m .69114 .43787 L .70902 .43949 L p .707 .577 .707 r
F P
0 g
s
.44115 .60184 m .45347 .59489 L .44593 .5786 L p .707 .577 .707 r
F P
0 g
s
.44593 .5786 m .43236 .58619 L .44115 .60184 L p .707 .577 .707 r
F P
0 g
s
.61047 .63195 m .61655 .62635 L .60442 .61312 L p .746 .579 .668 r
F P
0 g
s
.60442 .61312 m .59851 .61855 L .61047 .63195 L p .746 .579 .668 r
F P
0 g
s
.61655 .62635 m .62738 .61639 L .61423 .60416 L p .707 .577 .707 r
F P
0 g
s
.61423 .60416 m .60442 .61312 L .61655 .62635 L p .707 .577 .707 r
F P
0 g
s
.6232 .59458 m .61423 .60416 L .62738 .61639 L p .707 .577 .707 r
F P
0 g
s
.63743 .60553 m .64649 .59366 L .63118 .58429 L p .707 .577 .707 r
F P
0 g
s
.63118 .58429 m .6232 .59458 L .63743 .60553 L p .707 .577 .707 r
F P
0 g
s
.65424 .5809 m .66093 .5667 L .64418 .56025 L p .707 .577 .707 r
F P
0 g
s
.66093 .5667 m .66649 .55223 L .64946 .54655 L p .707 .577 .707 r
F P
0 g
s
.64946 .54655 m .64418 .56025 L .66093 .5667 L p .707 .577 .707 r
F P
0 g
s
.66649 .55223 m .67127 .53789 L .65436 .53186 L p .707 .577 .707 r
F P
0 g
s
.65436 .53186 m .64946 .54655 L .66649 .55223 L p .707 .577 .707 r
F P
0 g
s
.67127 .53789 m .67595 .52454 L .65992 .51646 L p .707 .577 .707 r
F P
0 g
s
.65992 .51646 m .65436 .53186 L .67127 .53789 L p .707 .577 .707 r
F P
0 g
s
.67595 .52454 m .68268 .5112 L .66683 .50277 L p .707 .577 .707 r
F P
0 g
s
.66683 .50277 m .65992 .51646 L .67595 .52454 L p .707 .577 .707 r
F P
0 g
s
.68268 .5112 m .68997 .49748 L .67379 .48971 L p .707 .577 .707 r
F P
0 g
s
.67379 .48971 m .66683 .50277 L .68268 .5112 L p .707 .577 .707 r
F P
0 g
s
.68997 .49748 m .69672 .48337 L .68003 .47677 L p .707 .577 .707 r
F P
0 g
s
.68003 .47677 m .67379 .48971 L .68997 .49748 L p .707 .577 .707 r
F P
0 g
s
.69672 .48337 m .70251 .46858 L .68522 .46377 L p .707 .577 .707 r
F P
0 g
s
.68522 .46377 m .68003 .47677 L .69672 .48337 L p .707 .577 .707 r
F P
0 g
s
.70251 .46858 m .70648 .45414 L .6888 .45104 L p .707 .577 .707 r
F P
0 g
s
.6888 .45104 m .68522 .46377 L .70251 .46858 L p .707 .577 .707 r
F P
0 g
s
.70648 .45414 m .70902 .43949 L .69114 .43787 L p .707 .577 .707 r
F P
0 g
s
.69114 .43787 m .6888 .45104 L .70648 .45414 L p .707 .577 .707 r
F P
0 g
s
.88157 .31677 m .87825 .27767 L .86072 .28155 L p .707 .577 .707 r
F P
0 g
s
.86072 .28155 m .86368 .31824 L .88157 .31677 L p .707 .577 .707 r
F P
0 g
s
.87825 .27767 m .86981 .23993 L .85306 .24641 L p .707 .577 .707 r
F P
0 g
s
.85306 .24641 m .86072 .28155 L .87825 .27767 L p .707 .577 .707 r
F P
0 g
s
.86981 .23993 m .85589 .20414 L .84007 .21262 L p .707 .577 .707 r
F P
0 g
s
.84007 .21262 m .85306 .24641 L .86981 .23993 L p .707 .577 .707 r
F P
0 g
s
.85589 .20414 m .83874 .17241 L .82447 .1833 L p .707 .577 .707 r
F P
0 g
s
.82447 .1833 m .84007 .21262 L .85589 .20414 L p .707 .577 .707 r
F P
0 g
s
.83874 .17241 m .81686 .1439 L .8044 .15682 L p .707 .577 .707 r
F P
0 g
s
.8044 .15682 m .82447 .1833 L .83874 .17241 L p .707 .577 .707 r
F P
0 g
s
.81686 .1439 m .79088 .11894 L .78035 .13348 L p .707 .577 .707 r
F P
0 g
s
.78035 .13348 m .8044 .15682 L .81686 .1439 L p .707 .577 .707 r
F P
0 g
s
.79088 .11894 m .76202 .09807 L .75252 .1133 L p .707 .577 .707 r
F P
0 g
s
.75252 .1133 m .78035 .13348 L .79088 .11894 L p .707 .577 .707 r
F P
0 g
s
.76202 .09807 m .73124 .079 L .72398 .09541 L p .707 .577 .707 r
F P
0 g
s
.72398 .09541 m .75252 .1133 L .76202 .09807 L p .707 .577 .707 r
F P
0 g
s
.73124 .079 m .69821 .0645 L .69351 .08182 L p .707 .577 .707 r
F P
0 g
s
.69351 .08182 m .72398 .09541 L .73124 .079 L p .707 .577 .707 r
F P
0 g
s
.69821 .0645 m .66349 .0552 L .66157 .07305 L p .707 .577 .707 r
F P
0 g
s
.66157 .07305 m .69351 .08182 L .69821 .0645 L p .707 .577 .707 r
F P
0 g
s
.66349 .0552 m .62802 .05146 L .62823 .06941 L p .707 .577 .707 r
F P
0 g
s
.62823 .06941 m .66157 .07305 L .66349 .0552 L p .707 .577 .707 r
F P
0 g
s
.59215 .06972 m .62823 .06941 L .62802 .05146 L p .707 .577 .707 r
F P
0 g
s
.58922 .05201 m .55111 .05839 L .55643 .07554 L p .707 .577 .707 r
F P
0 g
s
.55643 .07554 m .59215 .06972 L .58922 .05201 L p .707 .577 .707 r
F P
0 g
s
.55111 .05839 m .51367 .07009 L .52123 .08638 L p .707 .577 .707 r
F P
0 g
s
.52123 .08638 m .55643 .07554 L .55111 .05839 L p .707 .577 .707 r
F P
0 g
s
.24525 .75487 m .28024 .75225 L .27486 .73513 L p .724 .59 .706 r
F P
0 g
s
.27486 .73513 m .24415 .73694 L .24525 .75487 L p .724 .59 .706 r
F P
0 g
s
.28024 .75225 m .29461 .74753 L .28577 .73191 L p .707 .577 .707 r
F P
0 g
s
.28577 .73191 m .27486 .73513 L .28024 .75225 L p .707 .577 .707 r
F P
0 g
s
.29461 .74753 m .30741 .74018 L .29641 .72599 L p .707 .577 .707 r
F P
0 g
s
.29641 .72599 m .28577 .73191 L .29461 .74753 L p .707 .577 .707 r
F P
0 g
s
.30741 .74018 m .31958 .73066 L .30688 .71797 L p .707 .577 .707 r
F P
0 g
s
.30688 .71797 m .29641 .72599 L .30741 .74018 L p .707 .577 .707 r
F P
0 g
s
.31958 .73066 m .33015 .72006 L .31677 .70809 L p .707 .577 .707 r
F P
0 g
s
.31677 .70809 m .30688 .71797 L .31958 .73066 L p .707 .577 .707 r
F P
0 g
s
.33015 .72006 m .34247 .70628 L .32841 .69511 L p .707 .577 .707 r
F P
0 g
s
.32841 .69511 m .31677 .70809 L .33015 .72006 L p .707 .577 .707 r
F P
0 g
s
.34247 .70628 m .35388 .69191 L .3394 .68129 L p .707 .577 .707 r
F P
0 g
s
.3394 .68129 m .32841 .69511 L .34247 .70628 L p .707 .577 .707 r
F P
0 g
s
.35022 .66655 m .3394 .68129 L .35388 .69191 L p .707 .577 .707 r
F P
0 g
s
.36463 .67724 m .37518 .663 L .36139 .65151 L p .707 .577 .707 r
F P
0 g
s
.36139 .65151 m .35022 .66655 L .36463 .67724 L p .707 .577 .707 r
F P
0 g
s
.37518 .663 m .38511 .65107 L .37195 .63887 L p .707 .577 .707 r
F P
0 g
s
.37195 .63887 m .36139 .65151 L .37518 .663 L p .707 .577 .707 r
F P
0 g
s
.38511 .65107 m .39569 .63963 L .3831 .62684 L p .707 .577 .707 r
F P
0 g
s
.3831 .62684 m .37195 .63887 L .38511 .65107 L p .707 .577 .707 r
F P
0 g
s
.39569 .63963 m .40662 .62886 L .39482 .61533 L p .707 .577 .707 r
F P
0 g
s
.39482 .61533 m .3831 .62684 L .39569 .63963 L p .707 .577 .707 r
F P
0 g
s
.40662 .62886 m .41827 .61869 L .40711 .60463 L p .707 .577 .707 r
F P
0 g
s
.40711 .60463 m .39482 .61533 L .40662 .62886 L p .707 .577 .707 r
F P
0 g
s
.41827 .61869 m .42943 .60981 L .41937 .59494 L p .707 .577 .707 r
F P
0 g
s
.41937 .59494 m .40711 .60463 L .41827 .61869 L p .707 .577 .707 r
F P
0 g
s
.42943 .60981 m .44115 .60184 L .43236 .58619 L p .707 .577 .707 r
F P
0 g
s
.43236 .58619 m .41937 .59494 L .42943 .60981 L p .707 .577 .707 r
F P
0 g
s
.62738 .61639 m .63743 .60553 L .6232 .59458 L p .707 .577 .707 r
F P
0 g
s
.62802 .05146 m .58922 .05201 L .59215 .06972 L p .707 .577 .707 r
F P
0 g
s
.35388 .69191 m .36463 .67724 L .35022 .66655 L p .707 .577 .707 r
F P
0 g
s
.66157 .42774 m .65288 .42452 L .66243 .41988 L p .637 .246 .285 r
F P
0 g
s
.66243 .41988 m .67016 .4216 L .66157 .42774 L p .637 .246 .285 r
F P
0 g
s
.67016 .4216 m .66243 .41988 L .67088 .40404 L p .607 .468 .667 r
F P
0 g
s
.67088 .40404 m .67617 .40467 L .67016 .4216 L p .607 .468 .667 r
F P
0 g
s
.66408 .34919 m .6554 .34092 L p .66591 .3497 L .724 .354 .349 r
F P
0 g
s
.65182 .34198 m .6554 .34092 L .66408 .34919 L p .679 .307 .334 r
F P
0 g
s
.6616 .34901 m .65182 .34198 L p .66407 .34919 L .679 .307 .334 r
F P
0 g
s
.66408 .34919 m .6616 .34901 L p .66407 .34919 L .679 .307 .334 r
F P
0 g
s
.64864 .34293 m .65182 .34198 L .6616 .34901 L p .645 .259 .299 r
F P
0 g
s
.65774 .34961 m .64864 .34293 L p .6616 .34901 L .645 .259 .299 r
F P
0 g
s
.6616 .34901 m .65774 .34961 L p .6616 .34901 L .645 .259 .299 r
F P
0 g
s
.64346 .34478 m .64864 .34293 L .65774 .34961 L p .616 .249 .324 r
F P
0 g
s
.65317 .35063 m .64346 .34478 L p .65743 .34951 L .616 .249 .324 r
F P
0 g
s
.65774 .34961 m .65317 .35063 L p .65743 .34951 L .616 .249 .324 r
F P
0 g
s
.64015 .35199 m .6378 .34349 L .62047 .34819 L p .689 .513 .643 r
F P
0 g
s
.6384 .34706 m .64346 .34478 L .65317 .35063 L p .588 .228 .326 r
F P
0 g
s
.64848 .3522 m .6384 .34706 L p .65294 .35057 L .588 .228 .326 r
F P
0 g
s
.65317 .35063 m .64848 .3522 L p .65294 .35057 L .588 .228 .326 r
F P
0 g
s
.65182 .34198 m .64864 .34293 L .64421 .32551 L p .792 .633 .684 r
F P
0 g
s
.63308 .34982 m .6384 .34706 L .64848 .3522 L p .565 .212 .329 r
F P
0 g
s
.64233 .36022 m .64015 .35199 L .62269 .35628 L p .689 .515 .646 r
F P
0 g
s
.64345 .35441 m .63308 .34982 L p .64832 .35218 L .565 .212 .329 r
F P
0 g
s
.64848 .3522 m .64345 .35441 L p .64832 .35218 L .565 .212 .329 r
F P
0 g
s
.64864 .34293 m .64346 .34478 L .63738 .32785 L p .774 .617 .685 r
F P
0 g
s
.61881 .33989 m .62029 .34549 L .63692 .33871 L p .735 .668 .785 r
F P
0 g
s
.63692 .33871 m .63478 .33164 L .61881 .33989 L p .735 .668 .785 r
F P
0 g
s
.61702 .33454 m .61881 .33989 L .63478 .33164 L p .744 .676 .784 r
F P
0 g
s
.6384 .34706 m .63308 .34982 L .63286 .34939 L p .771 .605 .672 r
F P
0 g
s
.63286 .34939 m .6247 .33386 L p .63619 .34493 L .771 .605 .672 r
F P
0 g
s
.63619 .34493 m .6384 .34706 L .63286 .34939 L .771 .605 .672 r
F
.63735 .34742 m .63308 .34982 L p .63376 .35012 L .5 .298 .536 r
F P
0 g
s
.63735 .34742 m .63762 .35183 L .64345 .35441 L p .5 .298 .536 r
F P
0 g
s
.63735 .34742 m .63796 .35725 L p .63046 .3526 L .453 .181 .41 r
F P
0 g
s
.6293 .35188 m .6322 .35027 L p .63046 .3526 L .453 .181 .41 r
F P
0 g
s
.63478 .33164 m .63204 .32465 L .61702 .33454 L p .744 .676 .784 r
F P
0 g
s
.6247 .33386 m .63098 .33065 L .6384 .34706 L p .771 .605 .672 r
F P
0 g
s
.61499 .33018 m .61702 .33454 L .63204 .32465 L p .751 .675 .777 r
F P
0 g
s
.63204 .32465 m .62924 .31918 L .61499 .33018 L p .751 .675 .777 r
F P
0 g
s
.63098 .33065 m .6247 .33386 L .62485 .33293 L p .818 .865 .882 r
F P
0 g
s
.62485 .33293 m .62662 .32239 L p .6294 .32766 L .818 .865 .882 r
F P
0 g
s
.6294 .32766 m .63098 .33065 L .62485 .33293 L .818 .865 .882 r
F
.63735 .34742 m .63154 .34355 L p .63308 .34982 L .617 .54 .745 r
F P
0 g
s
.62861 .33165 m .6247 .33386 L .63286 .34939 L p .617 .54 .745 r
F P
0 g
s
.63286 .34939 m .63308 .34982 L p .63297 .34935 L .617 .54 .745 r
F P
0 g
s
.62861 .33165 m .63286 .34939 L .63297 .34935 L .617 .54 .745 r
F
.6322 .35027 m .63646 .34791 L p .63046 .3526 L .453 .181 .41 r
F P
0 g
s
.63646 .34791 m .63735 .34742 L p .63697 .3477 L .453 .181 .41 r
F P
0 g
s
.63646 .34791 m .63697 .3477 L .63046 .3526 L .453 .181 .41 r
F
.62861 .33165 m .63735 .34742 L p .62149 .33684 L .655 .557 .732 r
F P
0 g
s
.62047 .33617 m .62353 .33447 L p .62149 .33684 L .655 .557 .732 r
F P
0 g
s
.61353 .32612 m .61499 .33018 L .62924 .31918 L p .773 .712 .795 r
F P
0 g
s
.62041 .32559 m .62662 .32239 L .62485 .33293 L p .836 .872 .87 r
F P
0 g
s
.62485 .33293 m .6247 .33386 L p .62446 .3334 L .836 .872 .87 r
F P
0 g
s
.62041 .32559 m .62485 .33293 L .62446 .3334 L .836 .872 .87 r
F
.62353 .33447 m .62355 .33446 L p .62149 .33684 L .655 .557 .732 r
F P
0 g
s
.62861 .33165 m .62088 .32594 L p .62446 .3334 L .836 .872 .87 r
F P
0 g
s
.62063 .32602 m .62446 .3334 L .62088 .32594 L .836 .872 .87 r
F
.6247 .33386 m .62861 .33165 L p .62446 .3334 L F P
0 g
s
.63738 .32785 m .63098 .33065 L .63358 .31927 L p .797 .858 .895 r
F P
0 g
s
.63358 .31927 m .64098 .31663 L .63738 .32785 L p .797 .858 .895 r
F P
0 g
s
.62662 .32239 m .63358 .31927 L .63098 .33065 L p .818 .865 .882 r
F P
0 g
s
.62861 .33165 m .62047 .33617 L .61222 .33019 L p .739 .826 .918 r
F P
0 g
s
.62088 .32594 m .62041 .32559 L p .62063 .32602 L .836 .872 .87 r
F P
0 g
s
.61222 .33019 m .62041 .32559 L .62861 .33165 L p .739 .826 .918 r
F P
0 g
s
.62096 .33539 m .637 .3269 L .629 .32342 L p .538 .219 .374 r
F P
0 g
s
.629 .32342 m .62662 .32239 L p .62573 .32444 L .538 .219 .374 r
F P
0 g
s
.62096 .33539 m .629 .32342 L .62573 .32444 L .538 .219 .374 r
F
.62355 .33446 m .62861 .33165 L p .62158 .33678 L .655 .557 .732 r
F P
0 g
s
.62355 .33446 m .62158 .33678 L .62149 .33684 L .655 .557 .732 r
F
.64345 .35441 m .63796 .35725 L .63735 .34742 L p .5 .298 .536 r
F P
0 g
s
.64345 .35441 m .64544 .34296 L p .6382 .35681 L .843 .881 .869 r
F P
0 g
s
.63796 .35725 m .64345 .35441 L p .6382 .35681 L .843 .881 .869 r
F P
0 g
s
.64848 .3522 m .65115 .34086 L p .64371 .35395 L .834 .883 .878 r
F P
0 g
s
.64345 .35441 m .64848 .3522 L p .64371 .35395 L .834 .883 .878 r
F P
0 g
s
.65317 .35063 m .65684 .33946 L p .64875 .35179 L .818 .883 .892 r
F P
0 g
s
.64848 .3522 m .65317 .35063 L p .64875 .35179 L .818 .883 .892 r
F P
0 g
s
.65774 .34961 m .66243 .33879 L p .65345 .35028 L .794 .876 .907 r
F P
0 g
s
.65317 .35063 m .65774 .34961 L p .65345 .35028 L .794 .876 .907 r
F P
0 g
s
.6616 .34901 m .66817 .33829 L p .6585 .34879 L .786 .886 .918 r
F P
0 g
s
.65774 .34961 m .6616 .34901 L p .6585 .34879 L .786 .886 .918 r
F P
0 g
s
.66408 .34919 m .67214 .33945 L p .66203 .34862 L .758 .896 .939 r
F P
0 g
s
.6616 .34901 m .66408 .34919 L p .66203 .34862 L .758 .896 .939 r
F P
0 g
s
.66597 .34976 m .66408 .34919 L p .66591 .3497 L .724 .354 .349 r
F P
0 g
s
.6554 .34092 m .65182 .34198 L .64856 .32431 L p .786 .639 .699 r
F P
0 g
s
.64856 .32431 m .65472 .32298 L .6554 .34092 L p .786 .639 .699 r
F P
0 g
s
.65472 .32298 m .64856 .32431 L .65507 .31354 L p .72 .819 .927 r
F P
0 g
s
.65507 .31354 m .66272 .31318 L .65472 .32298 L p .72 .819 .927 r
F P
0 g
s
.96002 .49033 m .95274 .45381 L .96352 .45227 L p .43 .4 .724 r
F P
0 g
s
.96352 .45227 m .97092 .48988 L .96002 .49033 L p .43 .4 .724 r
F P
0 g
s
.35939 .06173 m .32679 .06305 L .32681 .05559 L p .598 .217 .292 r
F P
0 g
s
.32681 .05559 m .36088 .05429 L .35943 .06154 L p .598 .217 .292 r
F P
0 g
s
.32681 .05559 m .35943 .06154 L .35859 .06158 L .598 .217 .292 r
F
.36088 .05429 m .32681 .05559 L .32294 .03805 L p .693 .566 .708 r
F P
0 g
s
.32294 .03805 m .36017 .03633 L .36088 .05429 L p .693 .566 .708 r
F P
0 g
s
.35717 .05112 m .32287 .0529 L .32676 .06297 L p .658 .738 .909 r
F P
0 g
s
.32676 .06297 m .32679 .06305 L p .32704 .06295 L .658 .738 .909 r
F P
0 g
s
.32704 .06295 m .35717 .05112 L .32676 .06297 L .658 .738 .909 r
F
.35943 .06154 m .35939 .06173 L p .35859 .06158 L .598 .217 .292 r
F P
0 g
s
.36017 .03633 m .32294 .03805 L .31902 .02784 L p .665 .741 .907 r
F P
0 g
s
.28125 .03682 m .31902 .02784 L .32294 .03805 L p .708 .771 .901 r
F P
0 g
s
.07006 .46798 m .06436 .49807 L .05712 .49636 L p .293 .199 .574 r
F P
0 g
s
.05712 .49636 m .06318 .46493 L .06989 .46791 L p .293 .199 .574 r
F P
0 g
s
.05712 .49636 m .06989 .46791 L .06975 .46866 L .293 .199 .574 r
F
.06318 .46493 m .05712 .49636 L .03916 .49597 L p .704 .587 .722 r
F P
0 g
s
.03916 .49597 m .04553 .46155 L .06318 .46493 L p .704 .587 .722 r
F P
0 g
s
.05921 .46764 m .05356 .49938 L .06425 .49808 L p .901 .786 .725 r
F P
0 g
s
.06425 .49808 m .06436 .49807 L p .06431 .49778 L .901 .786 .725 r
F P
0 g
s
.06431 .49778 m .05921 .46764 L .06425 .49808 L .901 .786 .725 r
F
.06989 .46791 m .07006 .46798 L p .06975 .46866 L .293 .199 .574 r
F P
0 g
s
.04553 .46155 m .03916 .49597 L .0283 .49726 L p .9 .779 .72 r
F P
0 g
s
.02809 .53372 m .0283 .49726 L .03916 .49597 L p .905 .751 .68 r
F P
0 g
s
.25956 .6119 m .25175 .61392 L p .25668 .58325 L .324 .276 .649 r
F P
0 g
s
.25489 .6427 m .25175 .61392 L .25956 .6119 L p .324 .279 .652 r
F P
0 g
s
.25175 .61392 m .25489 .6427 L .23721 .64593 L p .705 .561 .689 r
F P
0 g
s
.23721 .64593 m .2339 .61593 L .25175 .61392 L p .705 .561 .689 r
F P
0 g
s
.26249 .64006 m .25489 .6427 L p .25907 .6151 L .324 .279 .652 r
F P
0 g
s
.25956 .6119 m .26249 .64006 L p .25907 .6151 L .324 .279 .652 r
F P
0 g
s
.25954 .66868 m .25489 .6427 L .26249 .64006 L p .324 .295 .671 r
F P
0 g
s
.25489 .6427 m .25954 .66868 L .24214 .67327 L p .703 .559 .688 r
F P
0 g
s
.24214 .67327 m .23721 .64593 L .25489 .6427 L p .703 .559 .688 r
F P
0 g
s
.26688 .66549 m .25954 .66868 L p .2622 .6429 L .324 .295 .671 r
F P
0 g
s
.26249 .64006 m .26688 .66549 L p .2622 .6429 L .324 .295 .671 r
F P
0 g
s
.26617 .69423 m .25954 .66868 L .26688 .66549 L p .325 .316 .695 r
F P
0 g
s
.25954 .66868 m .26617 .69423 L .24917 .70015 L p .702 .558 .688 r
F P
0 g
s
.24917 .70015 m .24214 .67327 L .25954 .66868 L p .702 .558 .688 r
F P
0 g
s
.27321 .69047 m .26617 .69423 L p .26681 .66835 L .325 .316 .695 r
F P
0 g
s
.26688 .66549 m .27321 .69047 L p .26681 .66835 L .325 .316 .695 r
F P
0 g
s
.27453 .71849 m .26617 .69423 L .27321 .69047 L p .328 .338 .718 r
F P
0 g
s
.26617 .69423 m .27453 .71849 L .25819 .72609 L p .7 .557 .689 r
F P
0 g
s
.25819 .72609 m .24917 .70015 L .26617 .69423 L p .7 .557 .689 r
F P
0 g
s
.28109 .71406 m .27453 .71849 L p .27337 .69387 L .328 .338 .718 r
F P
0 g
s
.27321 .69047 m .28109 .71406 L p .27337 .69387 L .328 .338 .718 r
F P
0 g
s
.28444 .74041 m .27453 .71849 L .28109 .71406 L p .334 .365 .745 r
F P
0 g
s
.27453 .71849 m .28444 .74041 L .26877 .74931 L p .698 .555 .689 r
F P
0 g
s
.26877 .74931 m .25819 .72609 L .27453 .71849 L p .698 .555 .689 r
F P
0 g
s
.28109 .71406 m .29146 .73702 L .28444 .74041 L p .334 .365 .745 r
F P
0 g
s
.28109 .71406 m .27125 .71724 L p .28894 .73455 L .883 .621 .537 r
F P
0 g
s
.29146 .73702 m .28109 .71406 L p .28894 .73455 L .883 .621 .537 r
F P
0 g
s
.27321 .69047 m .26316 .69266 L p .27946 .71211 L .895 .649 .559 r
F P
0 g
s
.28109 .71406 m .27321 .69047 L p .27946 .71211 L .895 .649 .559 r
F P
0 g
s
.26688 .66549 m .25675 .6669 L p .27158 .68814 L .902 .67 .577 r
F P
0 g
s
.27321 .69047 m .26688 .66549 L p .27158 .68814 L .902 .67 .577 r
F P
0 g
s
.26249 .64006 m .25233 .64066 L p .2657 .66347 L .908 .69 .596 r
F P
0 g
s
.26688 .66549 m .26249 .64006 L p .2657 .66347 L .908 .69 .596 r
F P
0 g
s
.25956 .6119 m .24944 .6119 L p .26236 .63977 L .913 .709 .614 r
F P
0 g
s
.26249 .64006 m .25956 .6119 L p .26236 .63977 L .913 .709 .614 r
F P
0 g
s
.25677 .58269 m .25956 .6119 L p .25668 .58325 L .324 .276 .649 r
F P
0 g
s
.2339 .61593 m .23721 .64593 L .22699 .64655 L p .911 .708 .617 r
F P
0 g
s
.22699 .64655 m .22372 .61594 L .2339 .61593 L p .911 .708 .617 r
F P
0 g
s
.75816 .66607 m .76315 .63889 L .77074 .64122 L p .946 .806 .673 r
F P
0 g
s
.77074 .64122 m .76567 .66861 L .7582 .66608 L p .946 .806 .673 r
F P
0 g
s
.77074 .64122 m .7582 .66608 L .75822 .66595 L .946 .806 .673 r
F
.76567 .66861 m .77074 .64122 L .78849 .64396 L p .71 .565 .689 r
F P
0 g
s
.78849 .64396 m .78332 .67198 L .76567 .66861 L p .71 .565 .689 r
F P
0 g
s
.76839 .66691 m .77338 .6393 L .76319 .63889 L p .412 .285 .596 r
F P
0 g
s
.76319 .63889 m .76315 .63889 L p .76317 .639 L .412 .285 .596 r
F P
0 g
s
.76317 .639 m .76839 .66691 L .76319 .63889 L .412 .285 .596 r
F
.7582 .66608 m .75816 .66607 L p .75822 .66595 L .946 .806 .673 r
F P
0 g
s
.78332 .67198 m .78849 .64396 L .79879 .64439 L p .417 .29 .599 r
F P
0 g
s
.80287 .61629 m .79879 .64439 L .78849 .64396 L p .414 .294 .607 r
F P
0 g
s
.24632 .29257 m .24267 .2854 L p .27229 .28343 L .55 .205 .337 r
F P
0 g
s
.21655 .29489 m .24267 .2854 L .24632 .29257 L p .545 .202 .338 r
F P
0 g
s
.24267 .2854 m .21655 .29489 L .20919 .27849 L p .724 .586 .701 r
F P
0 g
s
.20919 .27849 m .23648 .26854 L .24267 .2854 L p .724 .586 .701 r
F P
0 g
s
.2208 .30169 m .21655 .29489 L p .24326 .29281 L .545 .202 .338 r
F P
0 g
s
.24632 .29257 m .2208 .30169 L p .24326 .29281 L .545 .202 .338 r
F P
0 g
s
.19385 .30499 m .21655 .29489 L .2208 .30169 L p .525 .189 .341 r
F P
0 g
s
.21655 .29489 m .19385 .30499 L .18513 .28925 L p .725 .585 .699 r
F P
0 g
s
.18513 .28925 m .20919 .27849 L .21655 .29489 L p .725 .585 .699 r
F P
0 g
s
.19863 .31135 m .19385 .30499 L p .21807 .30203 L .525 .189 .341 r
F P
0 g
s
.2208 .30169 m .19863 .31135 L p .21807 .30203 L .525 .189 .341 r
F P
0 g
s
.1721 .31694 m .19385 .30499 L .19863 .31135 L p .498 .174 .348 r
F P
0 g
s
.19385 .30499 m .1721 .31694 L .16205 .302 L p .724 .584 .697 r
F P
0 g
s
.16205 .302 m .18513 .28925 L .19385 .30499 L p .724 .584 .697 r
F P
0 g
s
.17742 .32279 m .1721 .31694 L p .19588 .31193 L .498 .174 .348 r
F P
0 g
s
.19863 .31135 m .17742 .32279 L p .19588 .31193 L .498 .174 .348 r
F P
0 g
s
.15222 .33022 m .1721 .31694 L .17742 .32279 L p .472 .161 .357 r
F P
0 g
s
.1721 .31694 m .15222 .33022 L .1405 .31654 L p .724 .582 .695 r
F P
0 g
s
.1405 .31654 m .16205 .302 L .1721 .31694 L p .724 .582 .695 r
F P
0 g
s
.15816 .33532 m .15222 .33022 L p .17421 .32374 L .472 .161 .357 r
F P
0 g
s
.17742 .32279 m .15816 .33532 L p .17421 .32374 L .472 .161 .357 r
F P
0 g
s
.13608 .34349 m .15222 .33022 L .15816 .33532 L p .442 .147 .367 r
F P
0 g
s
.15222 .33022 m .13608 .34349 L .12304 .33103 L p .724 .579 .692 r
F P
0 g
s
.12304 .33103 m .1405 .31654 L .15222 .33022 L p .724 .579 .692 r
F P
0 g
s
.15816 .33532 m .14033 .35014 L .13608 .34349 L p .442 .147 .367 r
F P
0 g
s
.15816 .33532 m .15235 .32667 L p .1419 .34707 L .838 .831 .84 r
F P
0 g
s
.14033 .35014 m .15816 .33532 L p .1419 .34707 L .838 .831 .84 r
F P
0 g
s
.17742 .32279 m .17265 .31363 L p .1595 .33333 L .816 .83 .86 r
F P
0 g
s
.15816 .33532 m .17742 .32279 L p .1595 .33333 L .816 .83 .86 r
F P
0 g
s
.19863 .31135 m .19466 .30191 L p .17915 .32069 L .798 .827 .874 r
F P
0 g
s
.17742 .32279 m .19863 .31135 L p .17915 .32069 L .798 .827 .874 r
F P
0 g
s
.2208 .30169 m .21767 .29202 L p .20006 .3099 L .78 .822 .885 r
F P
0 g
s
.19863 .31135 m .2208 .30169 L p .20006 .3099 L .78 .822 .885 r
F P
0 g
s
.24632 .29257 m .24376 .28281 L p .22109 .30146 L .762 .815 .895 r
F P
0 g
s
.2208 .30169 m .24632 .29257 L p .22109 .30146 L .762 .815 .895 r
F P
0 g
s
.2729 .28339 m .24632 .29257 L p .27229 .28343 L .55 .205 .337 r
F P
0 g
s
.23648 .26854 m .20919 .27849 L .20603 .26877 L p .762 .812 .893 r
F P
0 g
s
.20603 .26877 m .23389 .25872 L .23648 .26854 L p .762 .812 .893 r
F P
0 g
s
.49078 .1614 m .48992 .14283 L .50782 .14124 L p .708 .601 .735 r
F P
0 g
s
.50782 .14124 m .50873 .16071 L .49078 .1614 L p .708 .601 .735 r
F P
0 g
s
.50873 .16071 m .50782 .14124 L .51712 .14234 L p .372 .333 .685 r
F P
0 g
s
.51712 .14234 m .51787 .16171 L .50873 .16071 L p .372 .333 .685 r
F P
0 g
s
.65759 .64649 m .66533 .65652 L .65532 .65824 L p .439 .529 .853 r
F P
0 g
s
.65532 .65824 m .64765 .64843 L .65759 .64649 L p .439 .529 .853 r
F P
0 g
s
.64765 .64843 m .65532 .65824 L .64089 .66894 L p .732 .626 .74 r
F P
0 g
s
.64089 .66894 m .63343 .65943 L .64765 .64843 L p .732 .626 .74 r
F P
0 g
s
.71705 .76475 m .7276 .76895 L .73251 .75168 L p .768 .656 .739 r
F P
0 g
s
.73251 .75168 m .72573 .74901 L .71705 .76475 L p .768 .656 .739 r
F P
0 g
s
.49957 .61042 m .50605 .6162 L .49801 .62126 L p .469 .581 .884 r
F P
0 g
s
.49801 .62126 m .49076 .61415 L .49912 .61061 L p .469 .581 .884 r
F P
0 g
s
.49801 .62126 m .49912 .61061 L .4995 .61094 L .469 .581 .884 r
F
.49076 .61415 m .49801 .62126 L .48861 .63656 L p .737 .623 .732 r
F P
0 g
s
.49663 .62038 m .50468 .62653 L .506 .61659 L p .877 .571 .467 r
F P
0 g
s
.506 .61659 m .50605 .6162 L p .50572 .61635 L .877 .571 .467 r
F P
0 g
s
.50572 .61635 m .49663 .62038 L .506 .61659 L .877 .571 .467 r
F
.49912 .61061 m .49957 .61042 L p .4995 .61094 L .469 .581 .884 r
F P
0 g
s
.48861 .63656 m .47902 .62776 L .49076 .61415 L p .737 .623 .732 r
F P
0 g
s
.47902 .62776 m .48861 .63656 L .48718 .64693 L p .85 .542 .465 r
F P
0 g
s
.49945 .6541 m .48718 .64693 L .48861 .63656 L p .819 .493 .438 r
F P
0 g
s
.55188 .30088 m .56286 .29701 L .56821 .31415 L p .748 .6 .693 r
F P
0 g
s
.56286 .29701 m .55188 .30088 L .55173 .29048 L p .768 .831 .901 r
F P
0 g
s
.55173 .29048 m .56433 .28652 L .56286 .29701 L p .768 .831 .901 r
F P
0 g
s
.47632 .56564 m .46581 .56933 L .47123 .58646 L p .661 .551 .72 r
F P
0 g
s
.47123 .58646 m .47995 .58325 L .47632 .56564 L p .661 .551 .72 r
F P
0 g
s
.50959 .56155 m .52075 .5627 L .5269 .55456 L p .648 .301 .369 r
F P
0 g
s
.53819 .55726 m .5269 .55456 L .52075 .5627 L p .673 .32 .368 r
F P
0 g
s
.70072 .70952 m .69442 .69916 L .68927 .70768 L p .915 .648 .52 r
F P
0 g
s
.87796 .69306 m .89982 .66613 L .89093 .66 L p .467 .266 .524 r
F P
0 g
s
.63572 .39527 m .63228 .38799 L .62577 .39707 L p .381 .386 .74 r
F P
0 g
s
.62577 .39707 m .63035 .40516 L .63572 .39527 L p .381 .386 .74 r
F P
0 g
s
.61353 .32612 m .61181 .32242 L .59981 .3257 L p .485 .664 .941 r
F P
0 g
s
.5987 .32435 m .59981 .3257 L .61181 .32242 L p .531 .744 .973 r
F P
0 g
s
.54868 .62981 m .54055 .62915 L .54421 .63906 L p .728 .369 .371 r
F P
0 g
s
.68817 .36269 m .68441 .35512 L .67405 .35844 L p .454 .531 .847 r
F P
0 g
s
.55128 .37411 m .54314 .37127 L .54515 .38216 L p .531 .648 .909 r
F P
0 g
s
.54515 .38216 m .55481 .38457 L .55128 .37411 L p .531 .648 .909 r
F P
0 g
s
.48918 .2695 m .48789 .25294 L .47889 .25111 L p .368 .34 .696 r
F P
0 g
s
.47855 .234 m .47889 .25111 L .48789 .25294 L p .364 .325 .681 r
F P
0 g
s
.1894 .14261 m .2105 .12032 L .20187 .11373 L p .829 .821 .842 r
F P
0 g
s
.19003 .44955 m .20631 .4732 L .21583 .46956 L p .862 .572 .496 r
F P
0 g
s
.23235 .49484 m .21583 .46956 L .20631 .4732 L p .866 .58 .502 r
F P
0 g
s
.80446 .49843 m .79086 .52364 L .80069 .52678 L p .442 .25 .523 r
F P
0 g
s
.38603 .18549 m .36637 .20797 L .37248 .2162 L p .863 .833 .816 r
F P
0 g
s
.3512 .23919 m .37248 .2162 L .36637 .20797 L p .858 .833 .821 r
F P
0 g
s
.10814 .64868 m .09077 .62059 L .08216 .62702 L p .878 .623 .549 r
F P
0 g
s
.64661 .37467 m .64888 .38095 L .65884 .38303 L p .898 .593 .461 r
F P
0 g
s
.62055 .29637 m .61351 .29159 L .61742 .30248 L p .916 .567 .362 r
F P
0 g
s
.61742 .30248 m .62222 .3077 L .62055 .29637 L p .916 .567 .362 r
F P
0 g
s
.54473 .35171 m .54984 .35453 L .55849 .34881 L p .708 .336 .342 r
F P
0 g
s
.51884 .58957 m .52779 .59168 L .52636 .58226 L p .531 .664 .921 r
F P
0 g
s
.66381 .71803 m .67133 .73019 L .68136 .72884 L p .417 .492 .83 r
F P
0 g
s
.68948 .73986 m .68136 .72884 L .67133 .73019 L p .426 .514 .845 r
F P
0 g
s
.92259 .67698 m .94131 .64242 L .93413 .64123 L p .911 .887 .795 r
F P
0 g
s
.93413 .64123 m .91571 .67466 L .92259 .67698 L p .911 .887 .795 r
F P
0 g
s
.53795 .66501 m .55134 .66564 L .55504 .65709 L p .667 .807 .95 r
F P
0 g
s
.56706 .65528 m .55504 .65709 L .55134 .66564 L p .714 .839 .941 r
F P
0 g
s
.69997 .33357 m .69032 .3239 L .69 .33347 L p .906 .595 .447 r
F P
0 g
s
.69 .33347 m .69743 .34264 L .69997 .33357 L p .906 .595 .447 r
F P
0 g
s
.51481 .25037 m .51449 .23497 L .50545 .23668 L p .931 .779 .669 r
F P
0 g
s
.18447 .09552 m .15968 .12243 L .16502 .12728 L p .357 .111 .398 r
F P
0 g
s
.14581 .15686 m .16502 .12728 L .15968 .12243 L p .328 .125 .446 r
F P
0 g
s
.18595 .48951 m .20036 .51125 L .20645 .50581 L p .363 .427 .794 r
F P
0 g
s
.82238 .54095 m .83602 .51559 L .83019 .51005 L p .92 .863 .768 r
F P
0 g
s
.84384 .48431 m .83019 .51005 L .83602 .51559 L p .921 .862 .766 r
F P
0 g
s
.34587 .19207 m .32762 .21205 L .33408 .21679 L p .408 .15 .407 r
F P
0 g
s
.06016 .63945 m .08128 .67254 L .08724 .66833 L p .343 .438 .814 r
F P
0 g
s
.1126 .69582 m .08724 .66833 L .08128 .67254 L p .384 .507 .859 r
F P
0 g
s
.56956 .56755 m .58015 .57254 L .57927 .58218 L p .461 .578 .886 r
F P
0 g
s
.58823 .58786 m .57927 .58218 L .58015 .57254 L p .441 .547 .868 r
F P
0 g
s
.57927 .58218 m .58823 .58786 L .57796 .60261 L p .655 .512 .676 r
F P
0 g
s
.57796 .60261 m .5703 .59774 L .57927 .58218 L p .655 .512 .676 r
F P
0 g
s
.71153 .40167 m .71161 .38852 L .69387 .39141 L p .707 .617 .753 r
F P
0 g
s
.69387 .39141 m .69358 .40234 L .71153 .40167 L p .707 .617 .753 r
F P
0 g
s
.52193 .32336 m .51654 .31087 L .49929 .31593 L p .719 .613 .738 r
F P
0 g
s
.60405 .37551 m .59508 .37946 L .59701 .36953 L p .449 .164 .388 r
F P
0 g
s
.59701 .36953 m .60499 .36543 L .60405 .37551 L p .449 .164 .388 r
F P
0 g
s
.60499 .36543 m .59701 .36953 L .59123 .35252 L p .638 .545 .733 r
F P
0 g
s
.59123 .35252 m .59768 .34901 L .60499 .36543 L p .638 .545 .733 r
F P
0 g
s
.12689 .36441 m .13549 .38879 L .15176 .38115 L p .699 .554 .686 r
F P
0 g
s
.15176 .38115 m .14375 .3582 L .12689 .36441 L p .699 .554 .686 r
F P
0 g
s
.8732 .40652 m .87792 .38041 L .86005 .37862 L p .711 .563 .686 r
F P
0 g
s
.86005 .37862 m .85557 .40299 L .8732 .40652 L p .711 .563 .686 r
F P
0 g
s
.45592 .09893 m .43363 .11454 L .44524 .12826 L p .723 .581 .695 r
F P
0 g
s
.44524 .12826 m .46641 .11351 L .45592 .09893 L p .723 .581 .695 r
F P
0 g
s
.76774 .77114 m .8017 .76356 L .79437 .74715 L p .69 .567 .711 r
F P
0 g
s
.79437 .74715 m .76364 .75365 L .76774 .77114 L p .69 .567 .711 r
F P
0 g
s
.20905 .74943 m .24525 .75487 L .24415 .73694 L p .723 .593 .71 r
F P
0 g
s
.24415 .73694 m .21211 .73171 L .20905 .74943 L p .723 .593 .71 r
F P
0 g
s
.11549 .26424 m .11593 .30347 L .13372 .30094 L p .707 .589 .721 r
F P
0 g
s
.13372 .30094 m .13347 .26429 L .11549 .26424 L p .707 .589 .721 r
F P
0 g
s
.67073 .42965 m .66157 .42774 L .67016 .4216 L p .591 .213 .294 r
F P
0 g
s
.67016 .4216 m .67821 .4222 L .67073 .42965 L p .591 .213 .294 r
F P
0 g
s
.67821 .4222 m .67016 .4216 L .67617 .40467 L p .604 .478 .682 r
F P
0 g
s
.67617 .40467 m .68161 .40454 L .67821 .4222 L p .604 .478 .682 r
F P
0 g
s
.64421 .32551 m .64856 .32431 L .65182 .34198 L p .792 .633 .684 r
F P
0 g
s
.64856 .32431 m .64421 .32551 L .64884 .31464 L p .764 .85 .915 r
F P
0 g
s
.64884 .31464 m .65507 .31354 L .64856 .32431 L p .764 .85 .915 r
F P
0 g
s
.39217 .06409 m .35939 .06173 L .36088 .05429 L p .636 .249 .294 r
F P
0 g
s
.36088 .05429 m .39462 .05682 L .39221 .06398 L p .636 .249 .294 r
F P
0 g
s
.36088 .05429 m .39221 .06398 L .39172 .06395 L .636 .249 .294 r
F
.39462 .05682 m .36088 .05429 L .36017 .03633 L p .692 .564 .706 r
F P
0 g
s
.36017 .03633 m .39601 .03888 L .39462 .05682 L p .692 .564 .706 r
F P
0 g
s
.39111 .05335 m .35717 .05112 L .35937 .06165 L p .629 .714 .908 r
F P
0 g
s
.35937 .06165 m .35939 .06173 L p .35963 .06167 L .629 .714 .908 r
F P
0 g
s
.35963 .06167 m .39111 .05335 L .35937 .06165 L .629 .714 .908 r
F
.39221 .06398 m .39217 .06409 L p .39172 .06395 L .636 .249 .294 r
F P
0 g
s
.39601 .03888 m .36017 .03633 L .35796 .02567 L p .634 .716 .906 r
F P
0 g
s
.31902 .02784 m .35796 .02567 L .36017 .03633 L p .665 .741 .907 r
F P
0 g
s
.95274 .45381 m .94166 .42032 L .95196 .41692 L p .437 .429 .752 r
F P
0 g
s
.95196 .41692 m .96352 .45227 L .95274 .45381 L p .437 .429 .752 r
F P
0 g
s
.08052 .43469 m .07006 .46798 L .06318 .46493 L p .303 .176 .536 r
F P
0 g
s
.06318 .46493 m .07398 .43089 L .08042 .43463 L p .303 .176 .536 r
F P
0 g
s
.06318 .46493 m .08042 .43463 L .08025 .43516 L .303 .176 .536 r
F
.07398 .43089 m .06318 .46493 L .04553 .46155 L p .703 .585 .72 r
F P
0 g
s
.04553 .46155 m .05685 .42541 L .07398 .43089 L p .703 .585 .72 r
F P
0 g
s
.06984 .433 m .05921 .46764 L .06997 .46798 L p .893 .8 .75 r
F P
0 g
s
.06997 .46798 m .07006 .46798 L p .07006 .4677 L .893 .8 .75 r
F P
0 g
s
.07006 .4677 m .06984 .433 L .06997 .46798 L .893 .8 .75 r
F
.08042 .43463 m .08052 .43469 L p .08025 .43516 L .303 .176 .536 r
F P
0 g
s
.05685 .42541 m .04553 .46155 L .03462 .46118 L p .892 .796 .747 r
F P
0 g
s
.0283 .49726 m .03462 .46118 L .04553 .46155 L p .9 .779 .72 r
F P
0 g
s
.75174 .68956 m .75816 .66607 L .76567 .66861 L p .942 .824 .698 r
F P
0 g
s
.76567 .66861 m .75893 .69287 L .75183 .6896 L p .942 .824 .698 r
F P
0 g
s
.76567 .66861 m .75183 .6896 L .75191 .6893 L .942 .824 .698 r
F
.75893 .69287 m .76567 .66861 L .78332 .67198 L p .712 .566 .688 r
F P
0 g
s
.78332 .67198 m .77625 .69773 L .75893 .69287 L p .712 .566 .688 r
F P
0 g
s
.76195 .69113 m .76839 .66691 L .75825 .66608 L p .42 .272 .573 r
F P
0 g
s
.75825 .66608 m .75816 .66607 L p .75819 .66628 L .42 .272 .573 r
F P
0 g
s
.75819 .66628 m .76195 .69113 L .75825 .66608 L .42 .272 .573 r
F
.75183 .6896 m .75174 .68956 L p .75191 .6893 L .942 .824 .698 r
F P
0 g
s
.77625 .69773 m .78332 .67198 L .79361 .67285 L p .424 .279 .579 r
F P
0 g
s
.79879 .64439 m .79361 .67285 L .78332 .67198 L p .417 .29 .599 r
F P
0 g
s
.23721 .64593 m .24214 .67327 L .23196 .67471 L p .907 .69 .599 r
F P
0 g
s
.23196 .67471 m .22699 .64655 L .23721 .64593 L p .907 .69 .599 r
F P
0 g
s
.20919 .27849 m .18513 .28925 L .18112 .27976 L p .779 .819 .884 r
F P
0 g
s
.18112 .27976 m .20603 .26877 L .20919 .27849 L p .779 .819 .884 r
F P
0 g
s
.62269 .35628 m .62489 .36466 L .64233 .36022 L p .689 .515 .646 r
F P
0 g
s
.4884 .12942 m .48992 .14283 L .48118 .14555 L p .932 .764 .651 r
F P
0 g
s
.48992 .14283 m .4884 .12942 L .50596 .12552 L p .709 .606 .74 r
F P
0 g
s
.50596 .12552 m .50782 .14124 L .48992 .14283 L p .709 .606 .74 r
F P
0 g
s
.50782 .14124 m .50596 .12552 L .5155 .12538 L p .376 .352 .705 r
F P
0 g
s
.5155 .12538 m .51712 .14234 L .50782 .14124 L p .376 .352 .705 r
F P
0 g
s
.64993 .63681 m .65759 .64649 L .64765 .64843 L p .441 .533 .856 r
F P
0 g
s
.64765 .64843 m .64001 .63886 L .64993 .63681 L p .441 .533 .856 r
F P
0 g
s
.64001 .63886 m .64765 .64843 L .63343 .65943 L p .733 .627 .74 r
F P
0 g
s
.63343 .65943 m .62591 .65003 L .64001 .63886 L p .733 .627 .74 r
F P
0 g
s
.53991 .30692 m .55188 .30088 L .55932 .31724 L p .742 .592 .69 r
F P
0 g
s
.55188 .30088 m .53991 .30692 L .53829 .29669 L p .796 .842 .886 r
F P
0 g
s
.53829 .29669 m .55173 .29048 L .55188 .30088 L p .796 .842 .886 r
F P
0 g
s
.70737 .75837 m .71705 .76475 L .72573 .74901 L p .753 .646 .743 r
F P
0 g
s
.72573 .74901 m .71843 .74418 L .70737 .75837 L p .753 .646 .743 r
F P
0 g
s
.49314 .603 m .49957 .61042 L .49076 .61415 L p .439 .536 .859 r
F P
0 g
s
.49076 .61415 m .48398 .60568 L .49275 .60311 L p .439 .536 .859 r
F P
0 g
s
.49076 .61415 m .49275 .60311 L .49304 .60344 L .439 .536 .859 r
F
.48398 .60568 m .49076 .61415 L .47902 .62776 L p .732 .622 .735 r
F P
0 g
s
.48879 .61231 m .49663 .62038 L .49948 .61075 L p .893 .607 .496 r
F P
0 g
s
.49948 .61075 m .49957 .61042 L p .49924 .61048 L .893 .607 .496 r
F P
0 g
s
.49924 .61048 m .48879 .61231 L .49948 .61075 L .893 .607 .496 r
F
.49275 .60311 m .49314 .603 L p .49304 .60344 L .439 .536 .859 r
F P
0 g
s
.47902 .62776 m .4705 .61759 L .48398 .60568 L p .732 .622 .735 r
F P
0 g
s
.4705 .61759 m .47902 .62776 L .47601 .63775 L p .875 .584 .492 r
F P
0 g
s
.48718 .64693 m .47601 .63775 L .47902 .62776 L p .85 .542 .465 r
F P
0 g
s
.48725 .563 m .47632 .56564 L .47995 .58325 L p .659 .546 .715 r
F P
0 g
s
.47995 .58325 m .48879 .58092 L .48725 .563 L p .659 .546 .715 r
F P
0 g
s
.52075 .5627 m .53158 .56498 L .53819 .55726 L p .673 .32 .368 r
F P
0 g
s
.54805 .5603 m .53819 .55726 L .53158 .56498 L p .685 .329 .365 r
F P
0 g
s
.69442 .69916 m .68772 .68796 L .68246 .69637 L p .914 .648 .521 r
F P
0 g
s
.89982 .66613 m .91716 .63511 L .90749 .63023 L p .446 .279 .56 r
F P
0 g
s
.64038 .40258 m .63572 .39527 L .63035 .40516 L p .402 .439 .785 r
F P
0 g
s
.63035 .40516 m .63674 .41319 L .64038 .40258 L p .402 .439 .785 r
F P
0 g
s
.61181 .32242 m .60999 .31892 L .5987 .32435 L p .531 .744 .973 r
F P
0 g
s
.54055 .62915 m .5323 .62737 L .53463 .63766 L p .762 .407 .383 r
F P
0 g
s
.68441 .35512 m .68012 .34856 L .67062 .35398 L p .49 .589 .88 r
F P
0 g
s
.55996 .37572 m .55128 .37411 L .55481 .38457 L p .576 .697 .924 r
F P
0 g
s
.55481 .38457 m .56507 .38542 L .55996 .37572 L p .576 .697 .924 r
F P
0 g
s
.48789 .25294 m .48741 .23619 L .47855 .234 L p .364 .325 .681 r
F P
0 g
s
.47901 .21696 m .47855 .234 L .48741 .23619 L p .361 .312 .667 r
F P
0 g
s
.2105 .12032 m .23509 .10149 L .22748 .09369 L p .798 .816 .866 r
F P
0 g
s
.20631 .4732 m .22251 .49757 L .23235 .49484 L p .866 .58 .502 r
F P
0 g
s
.24631 .52355 m .23235 .49484 L .22251 .49757 L p .883 .618 .532 r
F P
0 g
s
.78875 .55354 m .80069 .52678 L .79086 .52364 L p .433 .257 .541 r
F P
0 g
s
.79086 .52364 m .77875 .55101 L .78875 .55354 L p .433 .257 .541 r
F P
0 g
s
.36637 .20797 m .34592 .23041 L .3512 .23919 L p .858 .833 .821 r
F P
0 g
s
.32581 .2603 m .3512 .23919 L .34592 .23041 L p .834 .833 .846 r
F P
0 g
s
.09077 .62059 m .07797 .58963 L .06844 .59473 L p .894 .665 .585 r
F P
0 g
s
.52779 .59168 m .53792 .59482 L .53629 .58537 L p .504 .636 .912 r
F P
0 g
s
.53629 .58537 m .52636 .58226 L .52779 .59168 L p .504 .636 .912 r
F P
0 g
s
.65689 .7065 m .66381 .71803 L .6739 .71715 L p .415 .487 .825 r
F P
0 g
s
.68136 .72884 m .6739 .71715 L .66381 .71803 L p .417 .492 .83 r
F P
0 g
s
.94131 .64242 m .95453 .60675 L .9473 .60591 L p .934 .869 .75 r
F P
0 g
s
.9473 .60591 m .93413 .64123 L .94131 .64242 L p .934 .869 .75 r
F P
0 g
s
.64888 .38095 m .65141 .38637 L .66162 .38742 L p .877 .553 .434 r
F P
0 g
s
.61351 .29159 m .60587 .28829 L .6082 .29738 L p .839 .464 .343 r
F P
0 g
s
.6082 .29738 m .61742 .30248 L .61351 .29159 L p .839 .464 .343 r
F P
0 g
s
.52491 .66258 m .53795 .66501 L .5429 .65706 L p .623 .772 .952 r
F P
0 g
s
.55504 .65709 m .5429 .65706 L .53795 .66501 L p .667 .807 .95 r
F P
0 g
s
.69032 .3239 m .67858 .31663 L .68394 .32737 L p .88 .53 .383 r
F P
0 g
s
.68394 .32737 m .69 .33347 L .69032 .3239 L p .88 .53 .383 r
F P
0 g
s
.54984 .35453 m .55542 .35655 L .56306 .34957 L p .662 .293 .335 r
F P
0 g
s
.51449 .23497 m .5149 .21943 L .50578 .22033 L p .929 .788 .684 r
F P
0 g
s
.21332 .07284 m .18447 .09552 L .1888 .10128 L p .395 .11 .358 r
F P
0 g
s
.16502 .12728 m .1888 .10128 L .18447 .09552 L p .357 .111 .398 r
F P
0 g
s
.20036 .51125 m .21137 .53212 L .21861 .52863 L p .347 .391 .765 r
F P
0 g
s
.83019 .51005 m .81651 .53547 L .82238 .54095 L p .92 .863 .768 r
F P
0 g
s
.32762 .21205 m .30926 .22836 L .31418 .23464 L p .434 .152 .385 r
F P
0 g
s
.04468 .6033 m .06016 .63945 L .06679 .63649 L p .313 .374 .766 r
F P
0 g
s
.08724 .66833 m .06679 .63649 L .06016 .63945 L p .343 .438 .814 r
F P
0 g
s
.58015 .57254 m .59013 .57841 L .58823 .58786 L p .441 .547 .868 r
F P
0 g
s
.59713 .59459 m .58823 .58786 L .59013 .57841 L p .427 .521 .851 r
F P
0 g
s
.58823 .58786 m .59713 .59459 L .58562 .60842 L p .66 .513 .674 r
F P
0 g
s
.58562 .60842 m .57796 .60261 L .58823 .58786 L p .66 .513 .674 r
F P
0 g
s
.69294 .3809 m .69387 .39141 L .71161 .38852 L p .713 .623 .755 r
F P
0 g
s
.71161 .38852 m .71013 .37557 L .69294 .3809 L p .713 .623 .755 r
F P
0 g
s
.58991 .64661 m .60058 .63989 L .58995 .62539 L p .75 .592 .681 r
F P
0 g
s
.58995 .62539 m .58118 .63089 L .58991 .64661 L p .75 .592 .681 r
F P
0 g
s
.49473 .30117 m .49929 .31593 L .51654 .31087 L p .716 .611 .739 r
F P
0 g
s
.51654 .31087 m .51239 .2977 L .49473 .30117 L p .716 .611 .739 r
F P
0 g
s
.61291 .37114 m .60405 .37551 L .60499 .36543 L p .457 .176 .399 r
F P
0 g
s
.60499 .36543 m .61292 .36127 L .61291 .37114 L p .457 .176 .399 r
F P
0 g
s
.61292 .36127 m .60499 .36543 L .59768 .34901 L p .651 .553 .731 r
F P
0 g
s
.59768 .34901 m .60498 .34513 L .61292 .36127 L p .651 .553 .731 r
F P
0 g
s
.60498 .34513 m .59768 .34901 L .58938 .34254 L p .721 .817 .924 r
F P
0 g
s
.8661 .43241 m .8732 .40652 L .85557 .40299 L p .713 .565 .687 r
F P
0 g
s
.85557 .40299 m .84883 .42737 L .8661 .43241 L p .713 .565 .687 r
F P
0 g
s
.13549 .38879 m .14641 .41286 L .16199 .40386 L p .698 .554 .688 r
F P
0 g
s
.16199 .40386 m .15176 .38115 L .13549 .38879 L p .698 .554 .688 r
F P
0 g
s
.42489 .14499 m .44524 .12826 L .43363 .11454 L p .722 .579 .694 r
F P
0 g
s
.43363 .11454 m .41223 .1322 L .42489 .14499 L p .722 .579 .694 r
F P
0 g
s
.82418 .73461 m .79437 .74715 L .8017 .76356 L p .692 .57 .714 r
F P
0 g
s
.8017 .76356 m .83455 .74931 L .82418 .73461 L p .692 .57 .714 r
F P
0 g
s
.17421 .73715 m .20905 .74943 L .21211 .73171 L p .722 .594 .712 r
F P
0 g
s
.21211 .73171 m .18051 .72029 L .17421 .73715 L p .722 .594 .712 r
F P
0 g
s
.12065 .22596 m .11549 .26424 L .13347 .26429 L p .705 .587 .721 r
F P
0 g
s
.13347 .26429 m .13844 .22863 L .12065 .22596 L p .705 .587 .721 r
F P
0 g
s
.67962 .43055 m .67073 .42965 L .67821 .4222 L p .578 .214 .315 r
F P
0 g
s
.67821 .4222 m .68587 .42233 L .67962 .43055 L p .578 .214 .315 r
F P
0 g
s
.68587 .42233 m .67821 .4222 L .68161 .40454 L p .62 .5 .694 r
F P
0 g
s
.68161 .40454 m .68761 .40442 L .68587 .42233 L p .62 .5 .694 r
F P
0 g
s
.68761 .40442 m .68161 .40454 L .67755 .39421 L p .532 .666 .922 r
F P
0 g
s
.63738 .32785 m .64421 .32551 L .64864 .34293 L p .774 .617 .685 r
F P
0 g
s
.64421 .32551 m .63738 .32785 L .64098 .31663 L p .772 .846 .908 r
F P
0 g
s
.64098 .31663 m .64884 .31464 L .64421 .32551 L p .772 .846 .908 r
F P
0 g
s
.09591 .40423 m .08052 .43469 L .07398 .43089 L p .325 .153 .488 r
F P
0 g
s
.07398 .43089 m .09004 .39929 L .09578 .40412 L p .325 .153 .488 r
F P
0 g
s
.07398 .43089 m .09578 .40412 L .09545 .40479 L .325 .153 .488 r
F
.09004 .39929 m .07398 .43089 L .05685 .42541 L p .701 .582 .719 r
F P
0 g
s
.05685 .42541 m .07399 .39114 L .09004 .39929 L p .701 .582 .719 r
F P
0 g
s
.08565 .401 m .06984 .433 L .08043 .43468 L p .877 .818 .787 r
F P
0 g
s
.08043 .43468 m .08052 .43469 L p .08056 .43443 L .877 .818 .787 r
F P
0 g
s
.08056 .43443 m .08565 .401 L .08043 .43468 L .877 .818 .787 r
F
.09578 .40412 m .09591 .40423 L p .09545 .40479 L .325 .153 .488 r
F P
0 g
s
.07399 .39114 m .05685 .42541 L .04612 .42369 L p .877 .813 .782 r
F P
0 g
s
.03462 .46118 m .04612 .42369 L .05685 .42541 L p .892 .796 .747 r
F P
0 g
s
.42216 .07248 m .39217 .06409 L .39462 .05682 L p .702 .314 .31 r
F P
0 g
s
.39462 .05682 m .42617 .06572 L .42227 .07229 L p .702 .314 .31 r
F P
0 g
s
.39462 .05682 m .42227 .07229 L .42138 .07204 L .702 .314 .31 r
F
.42617 .06572 m .39462 .05682 L .39601 .03888 L p .693 .563 .703 r
F P
0 g
s
.39601 .03888 m .43098 .04838 L .42617 .06572 L p .693 .563 .703 r
F P
0 g
s
.42297 .06181 m .39111 .05335 L .39217 .064 L p .578 .666 .898 r
F P
0 g
s
.39217 .064 m .39217 .06409 L p .39244 .06407 L .578 .666 .898 r
F P
0 g
s
.39244 .06407 m .42297 .06181 L .39217 .064 L .578 .666 .898 r
F
.42227 .07229 m .42216 .07248 L p .42138 .07204 L .702 .314 .31 r
F P
0 g
s
.43098 .04838 m .39601 .03888 L .39496 .02808 L p .588 .672 .898 r
F P
0 g
s
.35796 .02567 m .39496 .02808 L .39601 .03888 L p .634 .716 .906 r
F P
0 g
s
.52241 .3566 m .52885 .36252 L .53969 .34814 L p .656 .506 .668 r
F P
0 g
s
.94166 .42032 m .92442 .39001 L .93391 .38494 L p .456 .481 .796 r
F P
0 g
s
.93391 .38494 m .95196 .41692 L .94166 .42032 L p .456 .481 .796 r
F P
0 g
s
.24214 .67327 m .24917 .70015 L .23907 .70237 L p .901 .67 .58 r
F P
0 g
s
.23907 .70237 m .23196 .67471 L .24214 .67327 L p .901 .67 .58 r
F P
0 g
s
.74327 .71227 m .75174 .68956 L .75893 .69287 L p .936 .842 .726 r
F P
0 g
s
.75893 .69287 m .75009 .71621 L .74337 .71232 L p .936 .842 .726 r
F P
0 g
s
.75893 .69287 m .74337 .71232 L .74349 .712 L .936 .842 .726 r
F
.75009 .71621 m .75893 .69287 L .77625 .69773 L p .714 .568 .688 r
F P
0 g
s
.77625 .69773 m .76691 .72262 L .75009 .71621 L p .714 .568 .688 r
F P
0 g
s
.75336 .71475 m .76195 .69113 L .75184 .68958 L p .43 .263 .552 r
F P
0 g
s
.75184 .68958 m .75174 .68956 L p .75176 .6898 L .43 .263 .552 r
F P
0 g
s
.75176 .6898 m .75336 .71475 L .75184 .68958 L .43 .263 .552 r
F
.74337 .71232 m .74327 .71227 L p .74349 .712 L .936 .842 .726 r
F P
0 g
s
.76691 .72262 m .77625 .69773 L .78651 .69932 L p .433 .27 .558 r
F P
0 g
s
.79361 .67285 m .78651 .69932 L .77625 .69773 L p .424 .279 .579 r
F P
0 g
s
.18513 .28925 m .16205 .302 L .15724 .2928 L p .797 .824 .873 r
F P
0 g
s
.15724 .2928 m .18112 .27976 L .18513 .28925 L p .797 .824 .873 r
F P
0 g
s
.6446 .36824 m .64233 .36022 L .62489 .36466 L p .688 .515 .647 r
F P
0 g
s
.62489 .36466 m .62729 .37318 L .6446 .36824 L p .688 .515 .647 r
F P
0 g
s
.48024 .13322 m .4884 .12942 L p .48175 .14425 L .932 .764 .651 r
F P
0 g
s
.48515 .11648 m .4884 .12942 L .48024 .13322 L p .932 .733 .611 r
F P
0 g
s
.47791 .12159 m .48515 .11648 L p .48068 .13172 L .932 .733 .611 r
F P
0 g
s
.48024 .13322 m .47791 .12159 L p .48068 .13172 L .932 .733 .611 r
F P
0 g
s
.4884 .12942 m .48515 .11648 L .50194 .11 L p .714 .609 .739 r
F P
0 g
s
.48056 .1059 m .48515 .11648 L .47791 .12159 L p .927 .694 .565 r
F P
0 g
s
.47495 .11247 m .48056 .1059 L p .47816 .12006 L .927 .694 .565 r
F P
0 g
s
.47791 .12159 m .47495 .11247 L p .47816 .12006 L .927 .694 .565 r
F P
0 g
s
.48515 .11648 m .48056 .1059 L .49551 .09584 L p .719 .613 .738 r
F P
0 g
s
.47792 .10049 m .48056 .1059 L .47495 .11247 L p .948 .707 .539 r
F P
0 g
s
.47495 .11247 m .47088 .105 L .47792 .10049 L p .948 .707 .539 r
F P
0 g
s
.47495 .11247 m .48436 .10895 L p .47192 .10531 L .452 .513 .831 r
F P
0 g
s
.47088 .105 m .47495 .11247 L p .47192 .10531 L .452 .513 .831 r
F P
0 g
s
.47791 .12159 m .48753 .12021 L p .4755 .11281 L .41 .443 .783 r
F P
0 g
s
.47495 .11247 m .47791 .12159 L p .4755 .11281 L .41 .443 .783 r
F P
0 g
s
.48024 .13322 m .48971 .13311 L p .47875 .12242 L .386 .393 .744 r
F P
0 g
s
.47791 .12159 m .48024 .13322 L p .47875 .12242 L .386 .393 .744 r
F P
0 g
s
.48118 .14555 m .48024 .13322 L p .48175 .14425 L .932 .764 .651 r
F P
0 g
s
.50194 .11 m .50596 .12552 L .4884 .12942 L p .714 .609 .739 r
F P
0 g
s
.50596 .12552 m .50194 .11 L .51162 .10858 L p .391 .392 .741 r
F P
0 g
s
.51162 .10858 m .5155 .12538 L .50596 .12552 L p .391 .392 .741 r
F P
0 g
s
.48802 .59485 m .49314 .603 L .48398 .60568 L p .411 .486 .826 r
F P
0 g
s
.48398 .60568 m .47851 .59617 L .48759 .59491 L p .411 .486 .826 r
F P
0 g
s
.48398 .60568 m .48759 .59491 L .48785 .59531 L .411 .486 .826 r
F
.47851 .59617 m .48398 .60568 L .4705 .61759 L p .727 .62 .739 r
F P
0 g
s
.48238 .60338 m .48879 .61231 L .49299 .60331 L p .915 .657 .533 r
F P
0 g
s
.49299 .60331 m .49314 .603 L p .4928 .60301 L .915 .657 .533 r
F P
0 g
s
.4928 .60301 m .48238 .60338 L .49299 .60331 L .915 .657 .533 r
F
.48759 .59491 m .48802 .59485 L p .48785 .59531 L .411 .486 .826 r
F P
0 g
s
.4705 .61759 m .4634 .60597 L .47851 .59617 L p .727 .62 .739 r
F P
0 g
s
.4634 .60597 m .4705 .61759 L .46608 .62692 L p .896 .629 .525 r
F P
0 g
s
.47601 .63775 m .46608 .62692 L .4705 .61759 L p .875 .584 .492 r
F P
0 g
s
.64181 .62712 m .64993 .63681 L .64001 .63886 L p .446 .543 .862 r
F P
0 g
s
.64001 .63886 m .63199 .62946 L .64181 .62712 L p .446 .543 .862 r
F P
0 g
s
.63199 .62946 m .64001 .63886 L .62591 .65003 L p .734 .628 .74 r
F P
0 g
s
.62591 .65003 m .6182 .64104 L .63199 .62946 L p .734 .628 .74 r
F P
0 g
s
.52908 .31448 m .53991 .30692 L .54969 .32202 L p .739 .586 .684 r
F P
0 g
s
.53991 .30692 m .52908 .31448 L .52609 .30465 L p .829 .851 .863 r
F P
0 g
s
.52609 .30465 m .53829 .29669 L .53991 .30692 L p .829 .851 .863 r
F P
0 g
s
.49832 .56172 m .48725 .563 L .48879 .58092 L p .658 .541 .71 r
F P
0 g
s
.48879 .58092 m .498 .57972 L .49832 .56172 L p .658 .541 .71 r
F P
0 g
s
.69895 .7507 m .70737 .75837 L .71843 .74418 L p .746 .645 .748 r
F P
0 g
s
.71843 .74418 m .71195 .73824 L .69895 .7507 L p .746 .645 .748 r
F P
0 g
s
.53158 .56498 m .54138 .56805 L .54805 .5603 L p .685 .329 .365 r
F P
0 g
s
.55872 .56352 m .54805 .5603 L .54138 .56805 L p .687 .333 .368 r
F P
0 g
s
.67555 .68586 m .68246 .69637 L .68772 .68796 L p .906 .629 .507 r
F P
0 g
s
.68772 .68796 m .68026 .67694 L .67555 .68586 L p .906 .629 .507 r
F P
0 g
s
.91716 .63511 m .93 .60075 L .92005 .59645 L p .433 .295 .593 r
F P
0 g
s
.64528 .40823 m .64038 .40258 L .63674 .41319 L p .428 .497 .829 r
F P
0 g
s
.63674 .41319 m .6443 .41966 L .64528 .40823 L p .428 .497 .829 r
F P
0 g
s
.60999 .31892 m .60387 .31491 L .59724 .32322 L p .602 .805 .978 r
F P
0 g
s
.59045 .32105 m .59724 .32322 L .60387 .31491 L p .631 .744 .929 r
F P
0 g
s
.5323 .62737 m .52204 .62463 L .52346 .63496 L p .765 .417 .395 r
F P
0 g
s
.68012 .34856 m .67794 .34439 L .66663 .35057 L p .544 .66 .912 r
F P
0 g
s
.66597 .34976 m .66663 .35057 L .67794 .34439 L p .627 .872 .988 r
F P
0 g
s
.56929 .37587 m .55996 .37572 L .56507 .38542 L p .618 .737 .931 r
F P
0 g
s
.56507 .38542 m .57535 .38476 L .56929 .37587 L p .618 .737 .931 r
F P
0 g
s
.48741 .23619 m .48776 .21909 L .47901 .21696 L p .361 .312 .667 r
F P
0 g
s
.48026 .19837 m .47901 .21696 L .48776 .21909 L p .36 .299 .653 r
F P
0 g
s
.23509 .10149 m .26443 .08289 L .25763 .07438 L p .782 .811 .876 r
F P
0 g
s
.22251 .49757 m .23615 .52433 L .24631 .52355 L p .883 .618 .532 r
F P
0 g
s
.25331 .55339 m .24631 .52355 L .23615 .52433 L p .905 .678 .584 r
F P
0 g
s
.78175 .58239 m .78875 .55354 L .77875 .55101 L p .415 .278 .585 r
F P
0 g
s
.77875 .55101 m .7715 .58152 L .78175 .58239 L p .415 .278 .585 r
F P
0 g
s
.34592 .23041 m .32249 .25068 L .32581 .2603 L p .834 .833 .846 r
F P
0 g
s
.29946 .27359 m .32581 .2603 L .32249 .25068 L p .789 .825 .88 r
F P
0 g
s
.07797 .58963 m .06821 .559 L .05829 .56335 L p .9 .687 .606 r
F P
0 g
s
.67858 .31663 m .67034 .31402 L .67791 .32345 L p .846 .434 .255 r
F P
0 g
s
.67791 .32345 m .68394 .32737 L .67858 .31663 L p .846 .434 .255 r
F P
0 g
s
.65141 .38637 m .65432 .39112 L .66453 .39033 L p .844 .503 .409 r
F P
0 g
s
.55542 .35655 m .56113 .3577 L .56742 .34952 L p .615 .257 .339 r
F P
0 g
s
.53792 .59482 m .54652 .5974 L .54552 .58786 L p .513 .643 .914 r
F P
0 g
s
.60587 .28829 m .59197 .28507 L .59614 .29358 L p .761 .381 .335 r
F P
0 g
s
.59614 .29358 m .6082 .29738 L .60587 .28829 L p .761 .381 .335 r
F P
0 g
s
.5125 .65935 m .52491 .66258 L .53092 .65533 L p .597 .744 .946 r
F P
0 g
s
.5429 .65706 m .53092 .65533 L .52491 .66258 L p .623 .772 .952 r
F P
0 g
s
.6739 .71715 m .66698 .70568 L .65689 .7065 L p .415 .487 .825 r
F P
0 g
s
.5149 .21943 m .51619 .20073 L .50707 .20159 L p .927 .794 .694 r
F P
0 g
s
.50707 .20159 m .50578 .22033 L .5149 .21943 L p .927 .794 .694 r
F P
0 g
s
.30926 .22836 m .28676 .2399 L .29068 .24686 L p .502 .174 .343 r
F P
0 g
s
.81651 .53547 m .80523 .56094 L .81157 .56574 L p .93 .852 .744 r
F P
0 g
s
.21137 .53212 m .21758 .55786 L .22523 .55549 L p .321 .31 .691 r
F P
0 g
s
.24538 .05233 m .21332 .07284 L .21656 .07931 L p .423 .115 .337 r
F P
0 g
s
.1888 .10128 m .21656 .07931 L .21332 .07284 L p .395 .11 .358 r
F P
0 g
s
.03382 .56965 m .04468 .6033 L .05173 .60158 L p .3 .341 .738 r
F P
0 g
s
.06679 .63649 m .05173 .60158 L .04468 .6033 L p .313 .374 .766 r
F P
0 g
s
.95453 .60675 m .96608 .56863 L .9588 .56898 L p .941 .86 .732 r
F P
0 g
s
.9588 .56898 m .9473 .60591 L .95453 .60675 L p .941 .86 .732 r
F P
0 g
s
.59013 .57841 m .59991 .58533 L .59713 .59459 L p .427 .521 .851 r
F P
0 g
s
.60537 .60188 m .59713 .59459 L .59991 .58533 L p .414 .494 .833 r
F P
0 g
s
.59713 .59459 m .60537 .60188 L .59295 .61491 L p .664 .514 .671 r
F P
0 g
s
.59295 .61491 m .58562 .60842 L .59713 .59459 L p .664 .514 .671 r
F P
0 g
s
.57823 .6519 m .58991 .64661 L .58118 .63089 L p .754 .6 .687 r
F P
0 g
s
.58118 .63089 m .57186 .63506 L .57823 .6519 L p .754 .6 .687 r
F P
0 g
s
.69062 .37098 m .69294 .3809 L .71013 .37557 L p .72 .626 .753 r
F P
0 g
s
.71013 .37557 m .7071 .36375 L .69062 .37098 L p .72 .626 .753 r
F P
0 g
s
.62161 .36644 m .61291 .37114 L .61292 .36127 L p .449 .177 .407 r
F P
0 g
s
.61292 .36127 m .62119 .35657 L .62161 .36644 L p .449 .177 .407 r
F P
0 g
s
.62119 .35657 m .61292 .36127 L .60498 .34513 L p .652 .555 .733 r
F P
0 g
s
.60498 .34513 m .61264 .34072 L .62119 .35657 L p .652 .555 .733 r
F P
0 g
s
.61264 .34072 m .60498 .34513 L .59697 .33873 L p .732 .823 .922 r
F P
0 g
s
.59697 .33873 m .60498 .34513 L p .58965 .34258 L .721 .817 .924 r
F P
0 g
s
.60444 .33463 m .61264 .34072 L p .59702 .33874 L .732 .823 .922 r
F P
0 g
s
.59697 .33873 m .60444 .33463 L p .59702 .33874 L .732 .823 .922 r
F P
0 g
s
.62047 .33617 m .61264 .34072 L .60444 .33463 L p .738 .826 .919 r
F P
0 g
s
.60444 .33463 m .61222 .33019 L .62047 .33617 L p .738 .826 .919 r
F P
0 g
s
.60444 .33463 m .6048 .34445 L p .61213 .33037 L .449 .176 .406 r
F P
0 g
s
.61222 .33019 m .60444 .33463 L p .61213 .33037 L .449 .176 .406 r
F P
0 g
s
.59697 .33873 m .5969 .34856 L p .60431 .33487 L .455 .177 .403 r
F P
0 g
s
.60444 .33463 m .59697 .33873 L p .60431 .33487 L .455 .177 .403 r
F P
0 g
s
.58938 .34254 m .59697 .33873 L p .58965 .34258 L .721 .817 .924 r
F P
0 g
s
.49163 .28603 m .49473 .30117 L .51239 .2977 L p .713 .61 .74 r
F P
0 g
s
.51239 .2977 m .50946 .28356 L .49163 .28603 L p .713 .61 .74 r
F P
0 g
s
.14641 .41286 m .15942 .43601 L .17434 .42593 L p .696 .554 .689 r
F P
0 g
s
.17434 .42593 m .16199 .40386 L .14641 .41286 L p .696 .554 .689 r
F P
0 g
s
.85662 .45762 m .8661 .43241 L .84883 .42737 L p .715 .567 .687 r
F P
0 g
s
.84883 .42737 m .83988 .45101 L .85662 .45762 L p .715 .567 .687 r
F P
0 g
s
.40571 .16349 m .42489 .14499 L .41223 .1322 L p .721 .577 .693 r
F P
0 g
s
.41223 .1322 m .3922 .15158 L .40571 .16349 L p .721 .577 .693 r
F P
0 g
s
.85176 .71582 m .82418 .73461 L .83455 .74931 L p .694 .574 .716 r
F P
0 g
s
.83455 .74931 m .86383 .72918 L .85176 .71582 L p .694 .574 .716 r
F P
0 g
s
.14203 .71834 m .17421 .73715 L .18051 .72029 L p .72 .595 .715 r
F P
0 g
s
.18051 .72029 m .15141 .70297 L .14203 .71834 L p .72 .595 .715 r
F P
0 g
s
.13183 .18879 m .12065 .22596 L .13844 .22863 L p .702 .585 .721 r
F P
0 g
s
.13844 .22863 m .14899 .19426 L .13183 .18879 L p .702 .585 .721 r
F P
0 g
s
.68903 .43046 m .67962 .43055 L .68587 .42233 L p .544 .195 .327 r
F P
0 g
s
.68587 .42233 m .69421 .42147 L .68903 .43046 L p .544 .195 .327 r
F P
0 g
s
.69421 .42147 m .68587 .42233 L .68761 .40442 L p .618 .506 .704 r
F P
0 g
s
.68761 .40442 m .69383 .40346 L .69421 .42147 L p .618 .506 .704 r
F P
0 g
s
.69383 .40346 m .68761 .40442 L .68312 .39461 L p .56 .7 .935 r
F P
0 g
s
.68312 .39461 m .68761 .40442 L p .678 .39467 L .532 .666 .922 r
F P
0 g
s
.68827 .39432 m .69383 .40346 L p .68335 .3948 L .56 .7 .935 r
F P
0 g
s
.68312 .39461 m .68827 .39432 L p .68335 .3948 L .56 .7 .935 r
F P
0 g
s
.70011 .40195 m .69383 .40346 L .68827 .39432 L p .596 .734 .941 r
F P
0 g
s
.69379 .39348 m .70011 .40195 L p .68839 .39439 L .596 .734 .941 r
F P
0 g
s
.68827 .39432 m .69379 .39348 L p .68839 .39439 L .596 .734 .941 r
F P
0 g
s
.70673 .40016 m .70011 .40195 L .69379 .39348 L p .623 .757 .942 r
F P
0 g
s
.69379 .39348 m .69813 .39257 L p .70673 .40016 L .623 .757 .942 r
F P
0 g
s
.69813 .39257 m .69989 .3922 L .70006 .3924 L p .623 .757 .942 r
F P
0 g
s
.70006 .3924 m .70673 .40016 L p .69813 .39257 L .623 .757 .942 r
F P
0 g
s
.72248 .39654 m .71194 .39914 L .71102 .38999 L p .717 .807 .921 r
F P
0 g
s
.71194 .39914 m .70673 .40016 L .69989 .3922 L p .704 .798 .923 r
F P
0 g
s
.69989 .3922 m .71102 .38999 L .71194 .39914 L p .704 .798 .923 r
F P
0 g
s
.69655 .40199 m .71362 .39859 L .71144 .3914 L p .58 .247 .369 r
F P
0 g
s
.71144 .3914 m .71102 .38999 L p .70906 .39161 L .58 .247 .369 r
F P
0 g
s
.69655 .40199 m .71144 .3914 L .70906 .39161 L .58 .247 .369 r
F
.69379 .39348 m .6897 .40296 L p .69959 .39251 L .53 .206 .363 r
F P
0 g
s
.69989 .3922 m .69379 .39348 L p .69959 .39251 L .53 .206 .363 r
F P
0 g
s
.68827 .39432 m .68305 .40324 L p .69343 .39382 L .555 .22 .357 r
F P
0 g
s
.69379 .39348 m .68827 .39432 L p .69343 .39382 L .555 .22 .357 r
F P
0 g
s
.68312 .39461 m .67683 .40276 L p .68796 .39455 L .585 .238 .347 r
F P
0 g
s
.68827 .39432 m .68312 .39461 L p .68796 .39455 L .585 .238 .347 r
F P
0 g
s
.67755 .39421 m .68312 .39461 L p .678 .39467 L .532 .666 .922 r
F P
0 g
s
.64346 .34478 m .6384 .34706 L .63098 .33065 L p .773 .611 .678 r
F P
0 g
s
.63098 .33065 m .63738 .32785 L .64346 .34478 L p .773 .611 .678 r
F P
0 g
s
.62924 .31918 m .62607 .31319 L .61353 .32612 L p .773 .712 .795 r
F P
0 g
s
.11606 .37564 m .09591 .40423 L .09004 .39929 L p .352 .142 .448 r
F P
0 g
s
.09004 .39929 m .11094 .36978 L .11597 .37552 L p .352 .142 .448 r
F P
0 g
s
.09004 .39929 m .11597 .37552 L .11558 .37608 L .352 .142 .448 r
F
.11094 .36978 m .09004 .39929 L .07399 .39114 L p .699 .58 .718 r
F P
0 g
s
.07399 .39114 m .09624 .35937 L .11094 .36978 L p .699 .58 .718 r
F P
0 g
s
.10641 .37104 m .08565 .401 L .09583 .4042 L p .857 .827 .817 r
F P
0 g
s
.09583 .4042 m .09591 .40423 L p .09599 .40397 L .857 .827 .817 r
F P
0 g
s
.09599 .40397 m .10641 .37104 L .09583 .4042 L .857 .827 .817 r
F
.11597 .37552 m .11606 .37564 L p .11558 .37608 L .352 .142 .448 r
F P
0 g
s
.09624 .35937 m .07399 .39114 L .06368 .38787 L p .858 .823 .813 r
F P
0 g
s
.04612 .42369 m .06368 .38787 L .07399 .39114 L p .877 .813 .782 r
F P
0 g
s
.44918 .08601 m .42216 .07248 L .42617 .06572 L p .761 .382 .336 r
F P
0 g
s
.42617 .06572 m .45463 .08006 L .44934 .08584 L p .761 .382 .336 r
F P
0 g
s
.42617 .06572 m .44934 .08584 L .44854 .08544 L .761 .382 .336 r
F
.45463 .08006 m .42617 .06572 L .43098 .04838 L p .693 .561 .7 r
F P
0 g
s
.43098 .04838 m .46265 .06393 L .45463 .08006 L p .693 .561 .7 r
F P
0 g
s
.45177 .07574 m .42297 .06181 L .42216 .07238 L p .531 .613 .88 r
F P
0 g
s
.42216 .07238 m .42216 .07248 L p .42242 .07251 L .531 .613 .88 r
F P
0 g
s
.42242 .07251 m .45177 .07574 L .42216 .07238 L .531 .613 .88 r
F
.44934 .08584 m .44918 .08601 L p .44854 .08544 L .761 .382 .336 r
F P
0 g
s
.46265 .06393 m .43098 .04838 L .43183 .03765 L p .541 .622 .881 r
F P
0 g
s
.39496 .02808 m .43183 .03765 L .43098 .04838 L p .588 .672 .898 r
F P
0 g
s
.54473 .35171 m .53969 .34814 L .52885 .36252 L p .649 .503 .671 r
F P
0 g
s
.52885 .36252 m .53551 .36719 L .54473 .35171 L p .649 .503 .671 r
F P
0 g
s
.92442 .39001 m .902 .36451 L .9099 .35746 L p .483 .537 .836 r
F P
0 g
s
.9099 .35746 m .93391 .38494 L .92442 .39001 L p .483 .537 .836 r
F P
0 g
s
.24917 .70015 m .25819 .72609 L .2483 .72932 L p .893 .649 .562 r
F P
0 g
s
.2483 .72932 m .23907 .70237 L .24917 .70015 L p .893 .649 .562 r
F P
0 g
s
.73302 .73396 m .74327 .71227 L .75009 .71621 L p .927 .856 .751 r
F P
0 g
s
.75009 .71621 m .73943 .73849 L .7331 .73402 L p .927 .856 .751 r
F P
0 g
s
.75009 .71621 m .7331 .73402 L .73324 .73373 L .927 .856 .751 r
F
.73943 .73849 m .75009 .71621 L .76691 .72262 L p .716 .569 .689 r
F P
0 g
s
.76691 .72262 m .75566 .74631 L .73943 .73849 L p .716 .569 .689 r
F P
0 g
s
.74292 .73728 m .75336 .71475 L .74336 .71229 L p .441 .257 .534 r
F P
0 g
s
.74336 .71229 m .74327 .71227 L p .74327 .7125 L .441 .257 .534 r
F P
0 g
s
.74327 .7125 m .74292 .73728 L .74336 .71229 L .441 .257 .534 r
F
.7331 .73402 m .73302 .73396 L p .73324 .73373 L .927 .856 .751 r
F P
0 g
s
.75566 .74631 m .76691 .72262 L .77705 .72513 L p .444 .263 .54 r
F P
0 g
s
.78651 .69932 m .77705 .72513 L .76691 .72262 L p .433 .27 .558 r
F P
0 g
s
.16205 .302 m .1405 .31654 L .13465 .30784 L p .815 .828 .859 r
F P
0 g
s
.13465 .30784 m .15724 .2928 L .16205 .302 L p .815 .828 .859 r
F P
0 g
s
.64661 .37467 m .6446 .36824 L .62729 .37318 L p .683 .506 .64 r
F P
0 g
s
.62729 .37318 m .62944 .38013 L .64661 .37467 L p .683 .506 .64 r
F P
0 g
s
.49551 .09584 m .50194 .11 L .48515 .11648 L p .719 .613 .738 r
F P
0 g
s
.50194 .11 m .49551 .09584 L .50496 .09227 L p .414 .443 .781 r
F P
0 g
s
.50496 .09227 m .51162 .10858 L .50194 .11 L p .414 .443 .781 r
F P
0 g
s
.51914 .3233 m .52908 .31448 L .54075 .32819 L p .736 .58 .68 r
F P
0 g
s
.52908 .31448 m .51914 .3233 L .51529 .31383 L p .856 .853 .839 r
F P
0 g
s
.51529 .31383 m .52609 .30465 L .52908 .31448 L p .856 .853 .839 r
F P
0 g
s
.48366 .58552 m .48802 .59485 L .47851 .59617 L p .391 .444 .796 r
F P
0 g
s
.47851 .59617 m .47404 .58571 L .48329 .58553 L p .391 .444 .796 r
F P
0 g
s
.47851 .59617 m .48329 .58553 L .48347 .58591 L .391 .444 .796 r
F
.47404 .58571 m .47851 .59617 L .4634 .60597 L p .723 .618 .741 r
F P
0 g
s
.47698 .59317 m .48238 .60338 L .48785 .5951 L p .925 .691 .565 r
F P
0 g
s
.48785 .5951 m .48802 .59485 L p .48771 .5948 L .925 .691 .565 r
F P
0 g
s
.48771 .5948 m .47698 .59317 L .48785 .5951 L .925 .691 .565 r
F
.48329 .58553 m .48366 .58552 L p .48347 .58591 L .391 .444 .796 r
F P
0 g
s
.4634 .60597 m .45779 .5935 L .47404 .58571 L p .723 .618 .741 r
F P
0 g
s
.45779 .5935 m .4634 .60597 L .45769 .61451 L p .912 .668 .557 r
F P
0 g
s
.46608 .62692 m .45769 .61451 L .4634 .60597 L p .896 .629 .525 r
F P
0 g
s
.63323 .61761 m .64181 .62712 L .63199 .62946 L p .454 .556 .87 r
F P
0 g
s
.63199 .62946 m .62355 .62033 L .63323 .61761 L p .454 .556 .87 r
F P
0 g
s
.62355 .62033 m .63199 .62946 L .6182 .64104 L p .736 .628 .739 r
F P
0 g
s
.6182 .64104 m .61019 .63242 L .62355 .62033 L p .736 .628 .739 r
F P
0 g
s
.68817 .36269 m .69062 .37098 L .7071 .36375 L p .729 .641 .761 r
F P
0 g
s
.7071 .36375 m .70313 .35266 L .68817 .36269 L p .729 .641 .761 r
F P
0 g
s
.50959 .56155 m .49832 .56172 L .498 .57972 L p .658 .537 .705 r
F P
0 g
s
.498 .57972 m .50726 .57942 L .50959 .56155 L p .658 .537 .705 r
F P
0 g
s
.68948 .73986 m .69895 .7507 L .71195 .73824 L p .734 .626 .739 r
F P
0 g
s
.71195 .73824 m .70334 .72834 L .68948 .73986 L p .734 .626 .739 r
F P
0 g
s
.54138 .56805 m .55164 .57086 L .55872 .56352 L p .687 .333 .368 r
F P
0 g
s
.56956 .56755 m .55872 .56352 L .55164 .57086 L p .706 .351 .372 r
F P
0 g
s
.66825 .6756 m .67555 .68586 L .68026 .67694 L p .902 .621 .501 r
F P
0 g
s
.68026 .67694 m .67276 .66656 L .66825 .6756 L p .902 .621 .501 r
F P
0 g
s
.93 .60075 m .94091 .56639 L .93045 .56347 L p .429 .303 .605 r
F P
0 g
s
.65177 .41323 m .64528 .40823 L .6443 .41966 L p .465 .56 .868 r
F P
0 g
s
.6443 .41966 m .65288 .42452 L .65177 .41323 L p .465 .56 .868 r
F P
0 g
s
.60387 .31491 m .59538 .31163 L .59045 .32105 L p .631 .744 .929 r
F P
0 g
s
.52204 .62463 m .51359 .62095 L .51367 .63138 L p .807 .466 .41 r
F P
0 g
s
.67794 .34439 m .67572 .34138 L .66597 .34976 L p .627 .872 .988 r
F P
0 g
s
.66408 .34919 m .66597 .34976 L .67572 .34138 L p .708 .884 .962 r
F P
0 g
s
.57838 .37471 m .56929 .37587 L .57535 .38476 L p .658 .772 .933 r
F P
0 g
s
.57535 .38476 m .58554 .38263 L .57838 .37471 L p .658 .772 .933 r
F P
0 g
s
.48776 .21909 m .48903 .20041 L .48026 .19837 L p .36 .299 .653 r
F P
0 g
s
.48142 .18046 m .48026 .19837 L .48903 .20041 L p .36 .301 .655 r
F P
0 g
s
.26443 .08289 m .29504 .07011 L .28957 .06068 L p .744 .794 .893 r
F P
0 g
s
.23615 .52433 m .24317 .55325 L .25331 .55339 L p .905 .678 .584 r
F P
0 g
s
.25677 .58269 m .25331 .55339 L .24317 .55325 L p .912 .706 .612 r
F P
0 g
s
.77748 .61119 m .78175 .58239 L .7715 .58152 L p .41 .291 .606 r
F P
0 g
s
.7715 .58152 m .76724 .61093 L .77748 .61119 L p .41 .291 .606 r
F P
0 g
s
.32249 .25068 m .29706 .26377 L .29946 .27359 L p .789 .825 .88 r
F P
0 g
s
.2729 .28339 m .29946 .27359 L .29706 .26377 L p .764 .816 .894 r
F P
0 g
s
.06821 .559 m .06377 .52862 L .05329 .53152 L p .906 .724 .645 r
F P
0 g
s
.54652 .5974 m .55456 .60031 L .55441 .5907 L p .501 .626 .906 r
F P
0 g
s
.66698 .70568 m .66063 .69605 L .65053 .69725 L p .424 .505 .838 r
F P
0 g
s
.96608 .56863 m .97191 .52912 L .96476 .5309 L p .954 .832 .684 r
F P
0 g
s
.96476 .5309 m .9588 .56898 L .96608 .56863 L p .954 .832 .684 r
F P
0 g
s
.65432 .39112 m .65667 .3942 L .66699 .3917 L p .795 .437 .38 r
F P
0 g
s
.59197 .28507 m .57825 .28461 L .58379 .29235 L p .7 .315 .316 r
F P
0 g
s
.58379 .29235 m .59614 .29358 L .59197 .28507 L p .7 .315 .316 r
F P
0 g
s
.49945 .6541 m .5125 .65935 L .51867 .65239 L p .559 .709 .941 r
F P
0 g
s
.53092 .65533 m .51867 .65239 L .5125 .65935 L p .597 .744 .946 r
F P
0 g
s
.67034 .31402 m .66272 .31318 L .67146 .32139 L p .768 .337 .227 r
F P
0 g
s
.67146 .32139 m .67791 .32345 L .67034 .31402 L p .768 .337 .227 r
F P
0 g
s
.56113 .3577 m .56793 .35785 L .57263 .34886 L p .572 .227 .345 r
F P
0 g
s
.51619 .20073 m .51745 .18129 L .50841 .1825 L p .927 .794 .693 r
F P
0 g
s
.50841 .1825 m .50707 .20159 L .51619 .20073 L p .927 .794 .693 r
F P
0 g
s
.28125 .03682 m .24538 .05233 L .24807 .05904 L p .47 .131 .309 r
F P
0 g
s
.21656 .07931 m .24807 .05904 L .24538 .05233 L p .423 .115 .337 r
F P
0 g
s
.21758 .55786 m .22092 .58635 L .22866 .58432 L p .317 .276 .653 r
F P
0 g
s
.80523 .56094 m .79935 .5865 L .80656 .58971 L p .946 .817 .684 r
F P
0 g
s
.28676 .2399 m .26091 .24941 L .26454 .25652 L p .54 .195 .331 r
F P
0 g
s
.02809 .53372 m .03382 .56965 L .04102 .5687 L p .284 .287 .687 r
F P
0 g
s
.05173 .60158 m .04102 .5687 L .03382 .56965 L p .3 .341 .738 r
F P
0 g
s
.59991 .58533 m .60887 .59286 L .60537 .60188 L p .414 .494 .833 r
F P
0 g
s
.61315 .60962 m .60537 .60188 L .60887 .59286 L p .406 .475 .819 r
F P
0 g
s
.60537 .60188 m .61315 .60962 L .60012 .62206 L p .667 .515 .669 r
F P
0 g
s
.60012 .62206 m .59295 .61491 L .60537 .60188 L p .667 .515 .669 r
F P
0 g
s
.56706 .65528 m .57823 .6519 L .57186 .63506 L p .759 .609 .692 r
F P
0 g
s
.57186 .63506 m .56292 .63775 L .56706 .65528 L p .759 .609 .692 r
F P
0 g
s
.62995 .36172 m .62161 .36644 L .62119 .35657 L p .449 .179 .411 r
F P
0 g
s
.62119 .35657 m .6293 .35188 L .62995 .36172 L p .449 .179 .411 r
F P
0 g
s
.6293 .35188 m .62119 .35657 L .61264 .34072 L p .654 .557 .733 r
F P
0 g
s
.61264 .34072 m .62047 .33617 L .6293 .35188 L p .654 .557 .733 r
F P
0 g
s
.50946 .28356 m .50715 .26824 L .48918 .2695 L p .711 .606 .738 r
F P
0 g
s
.48918 .2695 m .49163 .28603 L .50946 .28356 L p .711 .606 .738 r
F P
0 g
s
.84384 .48431 m .85662 .45762 L .83988 .45101 L p .715 .57 .69 r
F P
0 g
s
.83988 .45101 m .8277 .47629 L .84384 .48431 L p .715 .57 .69 r
F P
0 g
s
.19003 .44955 m .17434 .42593 L .15942 .43601 L p .696 .556 .691 r
F P
0 g
s
.15942 .43601 m .17524 .45984 L .19003 .44955 L p .696 .556 .691 r
F P
0 g
s
.38603 .18549 m .40571 .16349 L .3922 .15158 L p .719 .576 .693 r
F P
0 g
s
.3922 .15158 m .3724 .17371 L .38603 .18549 L p .719 .576 .693 r
F P
0 g
s
.1126 .69582 m .14203 .71834 L .15141 .70297 L p .719 .595 .716 r
F P
0 g
s
.15141 .70297 m .12376 .68167 L .1126 .69582 L p .719 .595 .716 r
F P
0 g
s
.87796 .69306 m .85176 .71582 L .86383 .72918 L p .696 .576 .717 r
F P
0 g
s
.86383 .72918 m .89217 .70414 L .87796 .69306 L p .696 .576 .717 r
F P
0 g
s
.14581 .15686 m .13183 .18879 L .14899 .19426 L p .7 .584 .722 r
F P
0 g
s
.14899 .19426 m .1622 .16434 L .14581 .15686 L p .7 .584 .722 r
F P
0 g
s
.69832 .42937 m .68903 .43046 L .69421 .42147 L p .519 .187 .344 r
F P
0 g
s
.69421 .42147 m .70236 .41983 L .69832 .42937 L p .519 .187 .344 r
F P
0 g
s
.70236 .41983 m .69421 .42147 L .69383 .40346 L p .622 .516 .713 r
F P
0 g
s
.69383 .40346 m .70011 .40195 L .70236 .41983 L p .622 .516 .713 r
F P
0 g
s
.61181 .32242 m .61353 .32612 L .62607 .31319 L p .789 .719 .786 r
F P
0 g
s
.62607 .31319 m .62222 .3077 L .61181 .32242 L p .789 .719 .786 r
F P
0 g
s
.54984 .35453 m .54473 .35171 L .53551 .36719 L p .647 .51 .682 r
F P
0 g
s
.53551 .36719 m .54314 .37127 L .54984 .35453 L p .647 .51 .682 r
F P
0 g
s
.14033 .35014 m .11606 .37564 L .11094 .36978 L p .385 .139 .414 r
F P
0 g
s
.11094 .36978 m .13608 .34349 L .14025 .35001 L p .385 .139 .414 r
F P
0 g
s
.11094 .36978 m .14025 .35001 L .13978 .3505 L .385 .139 .414 r
F
.13608 .34349 m .11094 .36978 L .09624 .35937 L p .698 .578 .717 r
F P
0 g
s
.09624 .35937 m .12304 .33103 L .13608 .34349 L p .698 .578 .717 r
F P
0 g
s
.13147 .34429 m .10641 .37104 L .11599 .3756 L p .833 .831 .845 r
F P
0 g
s
.11599 .3756 m .11606 .37564 L p .11618 .3754 L .833 .831 .845 r
F P
0 g
s
.11618 .3754 m .13147 .34429 L .11599 .3756 L .833 .831 .845 r
F
.14025 .35001 m .14033 .35014 L p .13978 .3505 L .385 .139 .414 r
F P
0 g
s
.12304 .33103 m .09624 .35937 L .08655 .35473 L p .835 .828 .84 r
F P
0 g
s
.06368 .38787 m .08655 .35473 L .09624 .35937 L p .858 .823 .813 r
F P
0 g
s
.47088 .105 m .44918 .08601 L .45463 .08006 L p .829 .476 .388 r
F P
0 g
s
.45463 .08006 m .47792 .10049 L .47117 .10481 L p .829 .476 .388 r
F P
0 g
s
.45463 .08006 m .47117 .10481 L .47024 .10401 L .829 .476 .388 r
F
.47792 .10049 m .45463 .08006 L .46265 .06393 L p .696 .56 .697 r
F P
0 g
s
.47559 .09573 m .45177 .07574 L .4492 .08592 L p .472 .536 .842 r
F P
0 g
s
.4492 .08592 m .44918 .08601 L p .4494 .08608 L .472 .536 .842 r
F P
0 g
s
.4494 .08608 m .47559 .09573 L .4492 .08592 L .472 .536 .842 r
F
.47117 .10481 m .47088 .105 L p .47024 .10401 L .829 .476 .388 r
F P
0 g
s
.46265 .06393 m .48963 .08678 L .47792 .10049 L p .696 .56 .697 r
F P
0 g
s
.48963 .08678 m .46265 .06393 L .46528 .05362 L p .487 .552 .848 r
F P
0 g
s
.43183 .03765 m .46528 .05362 L .46265 .06393 L p .541 .622 .881 r
F P
0 g
s
.902 .36451 m .87516 .34659 L .87912 .3374 L p .531 .614 .881 r
F P
0 g
s
.87912 .3374 m .9099 .35746 L .902 .36451 L p .531 .614 .881 r
F P
0 g
s
.64888 .38095 m .64661 .37467 L .62944 .38013 L p .68 .507 .646 r
F P
0 g
s
.62944 .38013 m .63228 .38799 L .64888 .38095 L p .68 .507 .646 r
F P
0 g
s
.25819 .72609 m .26877 .74931 L .25998 .75489 L p .882 .622 .54 r
F P
0 g
s
.25998 .75489 m .2483 .72932 L .25819 .72609 L p .882 .622 .54 r
F P
0 g
s
.72083 .75447 m .73302 .73396 L .73943 .73849 L p .915 .869 .779 r
F P
0 g
s
.73943 .73849 m .72673 .75959 L .72092 .75455 L p .915 .869 .779 r
F P
0 g
s
.73943 .73849 m .72092 .75455 L .72111 .75423 L .915 .869 .779 r
F
.72673 .75959 m .73943 .73849 L .75566 .74631 L p .717 .572 .69 r
F P
0 g
s
.75566 .74631 m .74216 .76891 L .72673 .75959 L p .717 .572 .69 r
F P
0 g
s
.73044 .75871 m .74292 .73728 L .73312 .734 L p .455 .252 .514 r
F P
0 g
s
.73312 .734 m .73302 .73396 L p .73299 .73422 L .455 .252 .514 r
F P
0 g
s
.73299 .73422 m .73044 .75871 L .73312 .734 L .455 .252 .514 r
F
.72092 .75455 m .72083 .75447 L p .72111 .75423 L .915 .869 .779 r
F P
0 g
s
.74216 .76891 m .75566 .74631 L .76561 .74966 L p .457 .258 .521 r
F P
0 g
s
.77705 .72513 m .76561 .74966 L .75566 .74631 L p .444 .263 .54 r
F P
0 g
s
.1405 .31654 m .12304 .33103 L .11415 .32513 L p .836 .829 .84 r
F P
0 g
s
.11415 .32513 m .13465 .30784 L .1405 .31654 L p .836 .829 .84 r
F P
0 g
s
.48056 .1059 m .47792 .10049 L .48963 .08678 L p .73 .626 .742 r
F P
0 g
s
.48963 .08678 m .49551 .09584 L .48056 .1059 L p .73 .626 .742 r
F P
0 g
s
.49551 .09584 m .48963 .08678 L .4944 .07748 L p .457 .516 .831 r
F P
0 g
s
.4944 .07748 m .50496 .09227 L .49551 .09584 L p .457 .516 .831 r
F P
0 g
s
.53197 .33594 m .52549 .34245 L .5128 .32965 L p .741 .575 .669 r
F P
0 g
s
.5128 .32965 m .51914 .3233 L .53197 .33594 L p .741 .575 .669 r
F P
0 g
s
.51914 .3233 m .5128 .32965 L .50647 .32268 L p .874 .852 .818 r
F P
0 g
s
.50647 .32268 m .51529 .31383 L .51914 .3233 L p .874 .852 .818 r
F P
0 g
s
.47988 .57516 m .48366 .58552 L .47404 .58571 L p .378 .417 .775 r
F P
0 g
s
.47404 .58571 m .47026 .57451 L .47963 .57514 L p .378 .417 .775 r
F P
0 g
s
.47404 .58571 m .47963 .57514 L .47973 .57543 L .378 .417 .775 r
F
.47026 .57451 m .47404 .58571 L .45779 .5935 L p .72 .618 .743 r
F P
0 g
s
.47253 .5821 m .47698 .59317 L .48351 .58569 L p .929 .713 .588 r
F P
0 g
s
.48351 .58569 m .48366 .58552 L p .48342 .58545 L .929 .713 .588 r
F P
0 g
s
.48342 .58545 m .47253 .5821 L .48351 .58569 L .929 .713 .588 r
F
.47963 .57514 m .47988 .57516 L p .47973 .57543 L .378 .417 .775 r
F P
0 g
s
.45779 .5935 m .45335 .58074 L .47026 .57451 L p .72 .618 .743 r
F P
0 g
s
.45335 .58074 m .45779 .5935 L .45104 .60115 L p .921 .698 .583 r
F P
0 g
s
.45769 .61451 m .45104 .60115 L .45779 .5935 L p .912 .668 .557 r
F P
0 g
s
.62446 .60846 m .63323 .61761 L .62355 .62033 L p .459 .565 .875 r
F P
0 g
s
.62355 .62033 m .61491 .61148 L .62446 .60846 L p .459 .565 .875 r
F P
0 g
s
.61491 .61148 m .62355 .62033 L .61019 .63242 L p .737 .628 .738 r
F P
0 g
s
.61019 .63242 m .60188 .62395 L .61491 .61148 L p .737 .628 .738 r
F P
0 g
s
.68441 .35512 m .68817 .36269 L .70313 .35266 L p .739 .646 .756 r
F P
0 g
s
.70313 .35266 m .69743 .34264 L .68441 .35512 L p .739 .646 .756 r
F P
0 g
s
.52075 .5627 m .50959 .56155 L .50726 .57942 L p .658 .533 .699 r
F P
0 g
s
.50726 .57942 m .51671 .58027 L .52075 .5627 L p .658 .533 .699 r
F P
0 g
s
.55164 .57086 m .56194 .57426 L .56956 .56755 L p .706 .351 .372 r
F P
0 g
s
.58015 .57254 m .56956 .56755 L .56194 .57426 L p .73 .375 .378 r
F P
0 g
s
.66088 .66558 m .66825 .6756 L .67276 .66656 L p .901 .619 .499 r
F P
0 g
s
.67276 .66656 m .66533 .65652 L .66088 .66558 L p .901 .619 .499 r
F P
0 g
s
.94091 .56639 m .94668 .5314 L .93589 .53011 L p .423 .326 .64 r
F P
0 g
s
.65896 .41686 m .65177 .41323 L .65288 .42452 L p .499 .609 .893 r
F P
0 g
s
.65288 .42452 m .66157 .42774 L .65896 .41686 L p .499 .609 .893 r
F P
0 g
s
.59538 .31163 m .58608 .31029 L .5828 .32035 L p .686 .789 .928 r
F P
0 g
s
.51359 .62095 m .50605 .6162 L .50468 .62653 L p .843 .516 .434 r
F P
0 g
s
.67572 .34138 m .67214 .33945 L .66408 .34919 L p .708 .884 .962 r
F P
0 g
s
.58731 .37233 m .57838 .37471 L .58554 .38263 L p .689 .796 .931 r
F P
0 g
s
.58554 .38263 m .59508 .37946 L .58731 .37233 L p .689 .796 .931 r
F P
0 g
s
.48903 .20041 m .49033 .18209 L .48142 .18046 L p .36 .301 .655 r
F P
0 g
s
.29504 .07011 m .32679 .06305 L .32287 .0529 L p .701 .77 .905 r
F P
0 g
s
.24317 .55325 m .24665 .58248 L .25677 .58269 L p .912 .706 .612 r
F P
0 g
s
.25956 .6119 m .25677 .58269 L .24665 .58248 L p .913 .712 .617 r
F P
0 g
s
.76724 .61093 m .76315 .63889 L .77338 .6393 L p .41 .29 .605 r
F P
0 g
s
.29706 .26377 m .27056 .27358 L .2729 .28339 L p .764 .816 .894 r
F P
0 g
s
.24632 .29257 m .2729 .28339 L .27056 .27358 L p .759 .814 .896 r
F P
0 g
s
.06377 .52862 m .06436 .49807 L .05356 .49938 L p .907 .758 .685 r
F P
0 g
s
.65667 .3942 m .66028 .39727 L .66984 .39272 L p .745 .379 .36 r
F P
0 g
s
.66272 .31318 m .65507 .31354 L .66489 .3205 L p .709 .276 .219 r
F P
0 g
s
.66489 .3205 m .67146 .32139 L .66272 .31318 L p .709 .276 .219 r
F P
0 g
s
.56793 .35785 m .57445 .35706 L .57771 .34746 L p .532 .205 .359 r
F P
0 g
s
.55456 .60031 m .56215 .60378 L .56297 .59419 L p .481 .599 .894 r
F P
0 g
s
.66063 .69605 m .65361 .68622 L .64359 .68773 L p .429 .515 .845 r
F P
0 g
s
.97191 .52912 m .97092 .48988 L .96417 .49303 L p .96 .79 .627 r
F P
0 g
s
.96417 .49303 m .96476 .5309 L .97191 .52912 L p .96 .79 .627 r
F P
0 g
s
.57825 .28461 m .56433 .28652 L .5712 .29324 L p .646 .267 .312 r
F P
0 g
s
.5712 .29324 m .58379 .29235 L .57825 .28461 L p .646 .267 .312 r
F P
0 g
s
.48718 .64693 m .49945 .6541 L .50657 .64802 L p .516 .663 .928 r
F P
0 g
s
.51867 .65239 m .50657 .64802 L .49945 .6541 L p .559 .709 .941 r
F P
0 g
s
.51745 .18129 m .51787 .16171 L .50899 .1634 L p .93 .787 .682 r
F P
0 g
s
.50899 .1634 m .50841 .1825 L .51745 .18129 L p .93 .787 .682 r
F P
0 g
s
.31902 .02784 m .28125 .03682 L .28265 .04396 L p .527 .162 .29 r
F P
0 g
s
.24807 .05904 m .28265 .04396 L .28125 .03682 L p .47 .131 .309 r
F P
0 g
s
.22092 .58635 m .22372 .61594 L .23145 .61392 L p .317 .27 .646 r
F P
0 g
s
.23145 .61392 m .22866 .58432 L .22092 .58635 L p .317 .27 .646 r
F P
0 g
s
.79879 .64439 m .80287 .61629 L .79537 .61388 L p .949 .799 .66 r
F P
0 g
s
.79935 .5865 m .79537 .61388 L .80287 .61629 L p .949 .799 .66 r
F P
0 g
s
.26091 .24941 m .23389 .25872 L .23752 .26582 L p .547 .199 .33 r
F P
0 g
s
.23752 .26582 m .26454 .25652 L .26091 .24941 L p .547 .199 .33 r
F P
0 g
s
.0283 .49726 m .02809 .53372 L .03538 .53408 L p .278 .237 .632 r
F P
0 g
s
.04102 .5687 m .03538 .53408 L .02809 .53372 L p .284 .287 .687 r
F P
0 g
s
.60887 .59286 m .61714 .60078 L .61315 .60962 L p .406 .475 .819 r
F P
0 g
s
.61491 .61148 m .61315 .60962 L .61714 .60078 L p .254 .288 .705 r
F P
0 g
s
.61315 .60962 m .61491 .61148 L .60188 .62395 L p .552 .339 .546 r
F P
0 g
s
.60188 .62395 m .60012 .62206 L .61315 .60962 L p .552 .339 .546 r
F P
0 g
s
.55504 .65709 m .56706 .65528 L .56292 .63775 L p .762 .619 .701 r
F P
0 g
s
.56292 .63775 m .55371 .63911 L .55504 .65709 L p .762 .619 .701 r
F P
0 g
s
.63796 .35725 m .62995 .36172 L .6293 .35188 L p .453 .181 .41 r
F P
0 g
s
.63735 .34742 m .6293 .35188 L .62047 .33617 L p .655 .557 .732 r
F P
0 g
s
.68136 .72884 m .68948 .73986 L .70334 .72834 L p .731 .626 .741 r
F P
0 g
s
.70334 .72834 m .69611 .71847 L .68136 .72884 L p .731 .626 .741 r
F P
0 g
s
.48789 .25294 m .48918 .2695 L .50715 .26824 L p .709 .605 .738 r
F P
0 g
s
.50715 .26824 m .50591 .25257 L .48789 .25294 L p .709 .605 .738 r
F P
0 g
s
.17524 .45984 m .19131 .48321 L .20631 .4732 L p .696 .556 .692 r
F P
0 g
s
.20631 .4732 m .19003 .44955 L .17524 .45984 L p .696 .556 .692 r
F P
0 g
s
.83019 .51005 m .84384 .48431 L .8277 .47629 L p .716 .571 .69 r
F P
0 g
s
.8277 .47629 m .81435 .50144 L .83019 .51005 L p .716 .571 .69 r
F P
0 g
s
.36637 .20797 m .38603 .18549 L .3724 .17371 L p .719 .576 .693 r
F P
0 g
s
.3724 .17371 m .35301 .19586 L .36637 .20797 L p .719 .576 .693 r
F P
0 g
s
.16502 .12728 m .14581 .15686 L .1622 .16434 L p .698 .581 .721 r
F P
0 g
s
.1622 .16434 m .17994 .13741 L .16502 .12728 L p .698 .581 .721 r
F P
0 g
s
.08724 .66833 m .1126 .69582 L .12376 .68167 L p .717 .595 .719 r
F P
0 g
s
.12376 .68167 m .10072 .65635 L .08724 .66833 L p .717 .595 .719 r
F P
0 g
s
.89982 .66613 m .87796 .69306 L .89217 .70414 L p .697 .579 .719 r
F P
0 g
s
.89217 .70414 m .91571 .67466 L .89982 .66613 L p .697 .579 .719 r
F P
0 g
s
.70696 .4277 m .69832 .42937 L .70236 .41983 L p .506 .186 .358 r
F P
0 g
s
.70236 .41983 m .71025 .41785 L .70696 .4277 L p .506 .186 .358 r
F P
0 g
s
.71025 .41785 m .70236 .41983 L .70011 .40195 L p .627 .525 .718 r
F P
0 g
s
.70011 .40195 m .70673 .40016 L .71025 .41785 L p .627 .525 .718 r
F P
0 g
s
.60999 .31892 m .61181 .32242 L .62222 .3077 L p .812 .732 .777 r
F P
0 g
s
.62222 .3077 m .61742 .30248 L .60999 .31892 L p .812 .732 .777 r
F P
0 g
s
.48794 .42153 m .47914 .41999 L p .49127 .40733 L .372 .243 .572 r
F P
0 g
s
.47914 .41999 m .48339 .40439 L .49206 .4065 L p .372 .243 .572 r
F P
0 g
s
.47588 .4367 m .47914 .41999 L .48787 .42152 L p .368 .256 .593 r
F P
0 g
s
.48787 .42152 m .48794 .42153 L p .48784 .42165 L .368 .256 .593 r
F P
0 g
s
.47588 .4367 m .48787 .42152 L .48784 .42165 L .368 .256 .593 r
F
.47914 .41999 m .47588 .4367 L .45814 .43348 L p .707 .577 .707 r
F P
0 g
s
.48469 .43819 m .47588 .4367 L p .48784 .42165 L .368 .256 .593 r
F P
0 g
s
.48794 .42153 m .48469 .43819 L p .48784 .42165 L .368 .256 .593 r
F P
0 g
s
.48469 .43819 m .48122 .45685 L .47262 .45444 L p .367 .258 .596 r
F P
0 g
s
.47262 .45444 m .47588 .4367 L .48469 .43819 L p .367 .258 .596 r
F P
0 g
s
.47588 .4367 m .47262 .45444 L .45527 .44953 L p .707 .577 .707 r
F P
0 g
s
.45527 .44953 m .45814 .43348 L .47588 .4367 L p .707 .577 .707 r
F P
0 g
s
.48469 .43819 m .47569 .43645 L p .48117 .45667 L .925 .797 .7 r
F P
0 g
s
.48117 .45667 m .48469 .43819 L .48117 .45667 L .925 .797 .7 r
F
.48122 .45685 m .48467 .43828 L p .48117 .45667 L F P
0 g
s
.48467 .43828 m .48469 .43819 L p .48117 .45667 L .925 .797 .7 r
F P
0 g
s
.48339 .40439 m .47914 .41999 L .46144 .41655 L p .707 .577 .707 r
F P
0 g
s
.45814 .43348 m .46144 .41655 L .47914 .41999 L p .707 .577 .707 r
F P
0 g
s
.48794 .42153 m .47897 .4196 L p .48431 .43697 L .924 .798 .703 r
F P
0 g
s
.48469 .43819 m .48794 .42153 L p .48431 .43697 L .924 .798 .703 r
F P
0 g
s
.49206 .4065 m .48794 .42153 L p .49127 .40733 L .372 .243 .572 r
F P
0 g
s
.3023 .77201 m .28444 .74041 L .29146 .73702 L p .354 .417 .788 r
F P
0 g
s
.32968 .79578 m .35356 .82012 L .34876 .82597 L p .398 .511 .856 r
F P
0 g
s
.34876 .82597 m .32396 .80084 L .32968 .79578 L p .398 .511 .856 r
F P
0 g
s
.37733 .84724 m .34876 .82597 L .35356 .82012 L p .433 .567 .889 r
F P
0 g
s
.28444 .74041 m .3023 .77201 L .28791 .78287 L p .707 .577 .707 r
F P
0 g
s
.28791 .78287 m .26877 .74931 L .28444 .74041 L p .707 .577 .707 r
F P
0 g
s
.32396 .80084 m .34876 .82597 L .33802 .84045 L p .707 .577 .707 r
F P
0 g
s
.34876 .82597 m .37733 .84724 L .36836 .86288 L p .707 .577 .707 r
F P
0 g
s
.36836 .86288 m .33802 .84045 L .34876 .82597 L p .707 .577 .707 r
F P
0 g
s
.79829 .39461 m .78722 .40008 L .7823 .39218 L p .529 .23 .404 r
F P
0 g
s
.7823 .39218 m .79311 .38683 L .79829 .39461 L p .529 .23 .404 r
F P
0 g
s
.78722 .40008 m .77614 .40521 L .77142 .39722 L p .535 .232 .4 r
F P
0 g
s
.77142 .39722 m .7823 .39218 L .78722 .40008 L p .535 .232 .4 r
F P
0 g
s
.77614 .40521 m .76475 .41022 L .76035 .40209 L p .539 .233 .397 r
F P
0 g
s
.76035 .40209 m .77142 .39722 L .77614 .40521 L p .539 .233 .397 r
F P
0 g
s
.76475 .41022 m .75323 .41482 L .74915 .40657 L p .547 .236 .392 r
F P
0 g
s
.74915 .40657 m .76035 .40209 L .76475 .41022 L p .547 .236 .392 r
F P
0 g
s
.75323 .41482 m .7417 .419 L .73809 .41058 L p .555 .239 .388 r
F P
0 g
s
.73809 .41058 m .74915 .40657 L .75323 .41482 L p .555 .239 .388 r
F P
0 g
s
.7417 .419 m .72984 .42262 L .72678 .41405 L p .567 .244 .382 r
F P
0 g
s
.72678 .41405 m .73809 .41058 L .7417 .419 L p .567 .244 .382 r
F P
0 g
s
.72984 .42262 m .71805 .4255 L .71544 .41683 L p .582 .252 .375 r
F P
0 g
s
.71544 .41683 m .72678 .41405 L .72984 .42262 L p .582 .252 .375 r
F P
0 g
s
.71025 .41785 m .71544 .41683 L .71805 .4255 L p .626 .277 .36 r
F P
0 g
s
.52145 .35874 m .51456 .35327 L p .531 .34865 L .442 .193 .44 r
F P
0 g
s
.51456 .35327 m .52549 .34245 L .53197 .34838 L p .442 .193 .44 r
F P
0 g
s
.51205 .36938 m .50465 .36461 L p .52011 .35921 L .428 .195 .456 r
F P
0 g
s
.52011 .35921 m .52145 .35874 L .51205 .36938 L .428 .195 .456 r
F
.50465 .36461 m .51456 .35327 L .52145 .35874 L p F P
0 g
s
.50404 .38057 m .4961 .37668 L p .51062 .37006 L .411 .2 .48 r
F P
0 g
s
.51062 .37006 m .51208 .3694 L .50404 .38057 L .411 .2 .48 r
F
.4961 .37668 m .50465 .36461 L .51208 .3694 L p F P
0 g
s
.49748 .39255 m .4891 .38963 L p .50267 .38143 L .395 .211 .51 r
F P
0 g
s
.50267 .38143 m .50407 .38059 L .49748 .39255 L .395 .211 .51 r
F
.4891 .38963 m .4961 .37668 L .50407 .38059 L p F P
0 g
s
.49751 .39256 m .49206 .4065 L .49205 .4065 L p .381 .227 .544 r
F P
0 g
s
.49205 .4065 m .48339 .40439 L p .49635 .39353 L .381 .227 .544 r
F P
0 g
s
.49635 .39353 m .49751 .39256 L .49205 .4065 L .381 .227 .544 r
F
.4891 .38963 m .48339 .40439 L .46599 .39967 L p .707 .577 .707 r
F P
0 g
s
.46144 .41655 m .46599 .39967 L .48339 .40439 L p .707 .577 .707 r
F P
0 g
s
.48326 .40388 m .47897 .4196 L .48713 .42135 L p .919 .811 .723 r
F P
0 g
s
.48713 .42135 m .48794 .42153 L p .48755 .42007 L .919 .811 .723 r
F P
0 g
s
.48339 .40439 m .4891 .38963 L .49678 .3923 L p .381 .227 .544 r
F P
0 g
s
.49678 .3923 m .49751 .39256 L p .49638 .3935 L .381 .227 .544 r
F P
0 g
s
.48339 .40439 m .49678 .3923 L .49638 .3935 L .381 .227 .544 r
F
.49206 .4065 m .48326 .40388 L p .48758 .42016 L .919 .811 .723 r
F P
0 g
s
.48794 .42153 m .49193 .40697 L p .48758 .42016 L .919 .811 .723 r
F P
0 g
s
.49193 .40697 m .49206 .4065 L p .48758 .42016 L .919 .811 .723 r
F P
0 g
s
.48755 .42007 m .48326 .40388 L .48713 .42135 L .919 .811 .723 r
F
.4961 .37668 m .4891 .38963 L .47227 .38318 L p .707 .577 .707 r
F P
0 g
s
.49751 .39256 m .48901 .389 L p .49177 .40481 L .91 .826 .751 r
F P
0 g
s
.49206 .4065 m .49751 .39256 L p .49177 .40481 L .91 .826 .751 r
F P
0 g
s
.49751 .39256 m .49748 .39255 L p .49766 .39222 L .395 .211 .51 r
F P
0 g
s
.50407 .38059 m .49751 .39256 L p .49766 .39222 L .395 .211 .51 r
F P
0 g
s
.46599 .39967 m .47227 .38318 L .4891 .38963 L p .707 .577 .707 r
F P
0 g
s
.48901 .389 m .48326 .40388 L .49111 .40622 L p .91 .826 .751 r
F P
0 g
s
.49111 .40622 m .49206 .4065 L p .49177 .40481 L .91 .826 .751 r
F P
0 g
s
.49177 .40481 m .48901 .389 L .49111 .40622 L .91 .826 .751 r
F
.50465 .36461 m .4961 .37668 L .48021 .36818 L p .707 .577 .707 r
F P
0 g
s
.50407 .38059 m .49607 .37595 L p .49739 .39118 L .894 .839 .784 r
F P
0 g
s
.49751 .39256 m .50407 .38059 L p .49739 .39118 L .894 .839 .784 r
F P
0 g
s
.50407 .38059 m .50404 .38057 L p .50439 .38008 L .411 .2 .48 r
F P
0 g
s
.51208 .3694 m .50407 .38059 L p .50439 .38008 L .411 .2 .48 r
F P
0 g
s
.47227 .38318 m .48021 .36818 L .4961 .37668 L p .707 .577 .707 r
F P
0 g
s
.49607 .37595 m .48901 .389 L .49673 .39223 L p .894 .839 .784 r
F P
0 g
s
.49673 .39223 m .49751 .39256 L p .49739 .39118 L .894 .839 .784 r
F P
0 g
s
.49739 .39118 m .49607 .37595 L .49673 .39223 L .894 .839 .784 r
F
.51456 .35327 m .50465 .36461 L .4899 .35426 L p .707 .577 .707 r
F P
0 g
s
.51208 .3694 m .50469 .36378 L p .50411 .3794 L .876 .847 .812 r
F P
0 g
s
.50407 .38059 m .51208 .3694 L p .50411 .3794 L .876 .847 .812 r
F P
0 g
s
.51208 .3694 m .51205 .36938 L p .5125 .36887 L .428 .195 .456 r
F P
0 g
s
.52145 .35874 m .51208 .3694 L p .5125 .36887 L .428 .195 .456 r
F P
0 g
s
.48021 .36818 m .4899 .35426 L .50465 .36461 L p .707 .577 .707 r
F P
0 g
s
.50469 .36378 m .49607 .37595 L .50346 .38023 L p .876 .847 .812 r
F P
0 g
s
.50346 .38023 m .50407 .38059 L p .50411 .3794 L .876 .847 .812 r
F P
0 g
s
.50411 .3794 m .50469 .36378 L .50346 .38023 L .876 .847 .812 r
F
.52549 .34245 m .51456 .35327 L .50094 .34146 L p .707 .577 .707 r
F P
0 g
s
.4899 .35426 m .50094 .34146 L .51456 .35327 L p .707 .577 .707 r
F P
0 g
s
.52145 .35874 m .51467 .35235 L p .51222 .36849 L .859 .85 .833 r
F P
0 g
s
.51208 .3694 m .52145 .35874 L p .51222 .36849 L .859 .85 .833 r
F P
0 g
s
.53197 .34838 m .52145 .35874 L p .531 .34865 L .442 .193 .44 r
F P
0 g
s
.48122 .45685 m .47654 .47336 L .46793 .471 L p .373 .242 .57 r
F P
0 g
s
.46793 .471 m .47262 .45444 L .48122 .45685 L p .373 .242 .57 r
F P
0 g
s
.47654 .47336 m .47233 .48883 L .46359 .48706 L p .372 .243 .573 r
F P
0 g
s
.46359 .48706 m .46793 .471 L .47654 .47336 L p .372 .243 .573 r
F P
0 g
s
.47233 .48883 m .46938 .50373 L .46052 .50282 L p .368 .256 .593 r
F P
0 g
s
.46052 .50282 m .46359 .48706 L .47233 .48883 L p .368 .256 .593 r
F P
0 g
s
.46938 .50373 m .46797 .51836 L .45909 .51851 L p .363 .275 .621 r
F P
0 g
s
.45909 .51851 m .46052 .50282 L .46938 .50373 L p .363 .275 .621 r
F P
0 g
s
.46797 .51836 m .46836 .53207 L .45959 .53328 L p .361 .303 .656 r
F P
0 g
s
.45959 .53328 m .45909 .51851 L .46797 .51836 L p .361 .303 .656 r
F P
0 g
s
.46836 .53207 m .47053 .54597 L .46196 .54805 L p .363 .334 .692 r
F P
0 g
s
.46196 .54805 m .45959 .53328 L .46836 .53207 L p .363 .334 .692 r
F P
0 g
s
.47053 .54597 m .47433 .56003 L .46597 .56277 L p .369 .363 .722 r
F P
0 g
s
.46597 .56277 m .46196 .54805 L .47053 .54597 L p .369 .363 .722 r
F P
0 g
s
.47026 .57451 m .46597 .56277 L .47433 .56003 L p .373 .381 .74 r
F P
0 g
s
.29146 .73702 m .30874 .76776 L .3023 .77201 L p .354 .417 .788 r
F P
0 g
s
.30874 .76776 m .32968 .79578 L .32396 .80084 L p .373 .462 .823 r
F P
0 g
s
.32396 .80084 m .3023 .77201 L .30874 .76776 L p .373 .462 .823 r
F P
0 g
s
.35356 .82012 m .38134 .84089 L .37733 .84724 L p .433 .567 .889 r
F P
0 g
s
.38134 .84089 m .40829 .85658 L .40545 .86348 L p .463 .61 .91 r
F P
0 g
s
.40545 .86348 m .37733 .84724 L .38134 .84089 L p .463 .61 .91 r
F P
0 g
s
.40829 .85658 m .4374 .86787 L .43575 .87511 L p .508 .666 .933 r
F P
0 g
s
.43575 .87511 m .40545 .86348 L .40829 .85658 L p .508 .666 .933 r
F P
0 g
s
.46825 .87471 m .46772 .8821 L p .4435 .87073 L .554 .716 .948 r
F P
0 g
s
.46772 .8821 m .43575 .87511 L .4374 .86787 L p .554 .716 .948 r
F P
0 g
s
.46825 .87471 m .50125 .87716 L .50121 .88456 L p .6 .76 .955 r
F P
0 g
s
.50121 .88456 m .46772 .8821 L .46825 .87471 L p .6 .76 .955 r
F P
0 g
s
.43575 .87511 m .46772 .8821 L .46641 .90008 L p .707 .577 .707 r
F P
0 g
s
.46772 .8821 m .50121 .88456 L .50115 .90259 L p .707 .577 .707 r
F P
0 g
s
.50115 .90259 m .46641 .90008 L .46772 .8821 L p .707 .577 .707 r
F P
0 g
s
.46825 .87471 m .46746 .88539 L p .49418 .87888 L .681 .357 .419 r
F P
0 g
s
.50125 .87716 m .46825 .87471 L p .49418 .87888 L .681 .357 .419 r
F P
0 g
s
.4374 .86787 m .46825 .87471 L p .4435 .87073 L .554 .716 .948 r
F P
0 g
s
.53297 .87744 m .53406 .88476 L p .50768 .87865 L .623 .779 .956 r
F P
0 g
s
.53406 .88476 m .50121 .88456 L .50125 .87716 L p .623 .779 .956 r
F P
0 g
s
.56403 .87338 m .56632 .88043 L p .53982 .87805 L .669 .814 .953 r
F P
0 g
s
.53297 .87744 m .56403 .87338 L p .53982 .87805 L .669 .814 .953 r
F P
0 g
s
.56632 .88043 m .53406 .88476 L .53297 .87744 L p .669 .814 .953 r
F P
0 g
s
.59382 .86482 m .59733 .87139 L p .57124 .87295 L .717 .845 .943 r
F P
0 g
s
.56403 .87338 m .59382 .86482 L p .57124 .87295 L .717 .845 .943 r
F P
0 g
s
.59733 .87139 m .56632 .88043 L .56403 .87338 L p .717 .845 .943 r
F P
0 g
s
.62248 .85129 m .62685 .85738 L p .59961 .86352 L .767 .87 .923 r
F P
0 g
s
.59382 .86482 m .62248 .85129 L p .59961 .86352 L .767 .87 .923 r
F P
0 g
s
.62685 .85738 m .59733 .87139 L .59382 .86482 L p .767 .87 .923 r
F P
0 g
s
.65112 .83325 m .65645 .8386 L p .62997 .84849 L .802 .882 .904 r
F P
0 g
s
.62248 .85129 m .65112 .83325 L p .62997 .84849 L .802 .882 .904 r
F P
0 g
s
.65645 .8386 m .62685 .85738 L .62248 .85129 L p .802 .882 .904 r
F P
0 g
s
.67696 .81089 m .68304 .81548 L p .65758 .82966 L .841 .888 .874 r
F P
0 g
s
.65112 .83325 m .67696 .81089 L p .65758 .82966 L .841 .888 .874 r
F P
0 g
s
.68304 .81548 m .65645 .8386 L .65112 .83325 L p .841 .888 .874 r
F P
0 g
s
.7002 .78456 m .70685 .7884 L p .68269 .80658 L .872 .887 .843 r
F P
0 g
s
.67696 .81089 m .7002 .78456 L p .68269 .80658 L .872 .887 .843 r
F P
0 g
s
.70685 .7884 m .68304 .81548 L .67696 .81089 L p .872 .887 .843 r
F P
0 g
s
.72673 .75959 m .70685 .7884 L .70022 .78457 L p .895 .88 .813 r
F P
0 g
s
.70022 .78457 m .7002 .78456 L p .70028 .78448 L .895 .88 .813 r
F P
0 g
s
.72673 .75959 m .70022 .78457 L .70028 .78448 L .895 .88 .813 r
F
.68304 .81548 m .70685 .7884 L .72172 .79859 L p .707 .577 .707 r
F P
0 g
s
.70685 .7884 m .72673 .75959 L .74216 .76891 L p .707 .577 .708 r
F P
0 g
s
.74216 .76891 m .72172 .79859 L .70685 .7884 L p .707 .577 .708 r
F P
0 g
s
.7002 .78456 m .72083 .75447 L .72673 .75959 L p .895 .88 .813 r
F P
0 g
s
.70849 .79095 m .73044 .75871 L .72092 .75451 L p .455 .256 .52 r
F P
0 g
s
.72092 .75451 m .72083 .75447 L p .72073 .75479 L .455 .256 .52 r
F P
0 g
s
.72073 .75479 m .70849 .79095 L .72092 .75451 L .455 .256 .52 r
F
.7002 .78456 m .70849 .79095 L p .7184 .76168 L F P
0 g
s
.72083 .75447 m .7002 .78456 L p .7184 .76168 L .455 .256 .52 r
F P
0 g
s
.65645 .8386 m .68304 .81548 L .6966 .82736 L p .707 .577 .707 r
F P
0 g
s
.72172 .79859 m .6966 .82736 L .68304 .81548 L p .707 .577 .707 r
F P
0 g
s
.67696 .81089 m .68449 .81824 L p .69695 .79153 L .475 .253 .497 r
F P
0 g
s
.7002 .78456 m .67696 .81089 L p .69695 .79153 L .475 .253 .497 r
F P
0 g
s
.62685 .85738 m .65645 .8386 L .66832 .85218 L p .707 .577 .707 r
F P
0 g
s
.6966 .82736 m .66832 .85218 L .65645 .8386 L p .707 .577 .707 r
F P
0 g
s
.65112 .83325 m .6577 .84154 L p .67266 .81772 L .5 .255 .475 r
F P
0 g
s
.67696 .81089 m .65112 .83325 L p .67266 .81772 L .5 .255 .475 r
F P
0 g
s
.59733 .87139 m .62685 .85738 L .63655 .87258 L p .707 .577 .707 r
F P
0 g
s
.66832 .85218 m .63655 .87258 L .62685 .85738 L p .707 .577 .707 r
F P
0 g
s
.62248 .85129 m .62786 .86047 L p .64682 .83829 L .531 .263 .454 r
F P
0 g
s
.65112 .83325 m .62248 .85129 L p .64682 .83829 L .531 .263 .454 r
F P
0 g
s
.56632 .88043 m .59733 .87139 L .6051 .88766 L p .707 .577 .707 r
F P
0 g
s
.63655 .87258 m .6051 .88766 L .59733 .87139 L p .707 .577 .707 r
F P
0 g
s
.59382 .86482 m .59811 .8746 L p .61709 .85645 L .558 .274 .441 r
F P
0 g
s
.62248 .85129 m .59382 .86482 L p .61709 .85645 L .558 .274 .441 r
F P
0 g
s
.53406 .88476 m .56632 .88043 L .57143 .89772 L p .707 .577 .707 r
F P
0 g
s
.6051 .88766 m .57143 .89772 L .56632 .88043 L p .707 .577 .707 r
F P
0 g
s
.56403 .87338 m .56685 .8837 L p .5883 .86868 L .595 .294 .427 r
F P
0 g
s
.59382 .86482 m .56403 .87338 L p .5883 .86868 L .595 .294 .427 r
F P
0 g
s
.50121 .88456 m .53406 .88476 L .53652 .90262 L p .707 .577 .707 r
F P
0 g
s
.57143 .89772 m .53652 .90262 L .53406 .88476 L p .707 .577 .707 r
F P
0 g
s
.53297 .87744 m .53434 .88807 L p .55825 .87624 L .631 .317 .42 r
F P
0 g
s
.56403 .87338 m .53297 .87744 L p .55825 .87624 L .631 .317 .42 r
F P
0 g
s
.50125 .87716 m .53297 .87744 L p .50768 .87865 L .623 .779 .956 r
F P
0 g
s
.83931 .36517 m .82783 .36923 L .82047 .35278 L p .707 .577 .707 r
F P
0 g
s
.82047 .35278 m .83326 .34819 L .83931 .36517 L p .707 .577 .707 r
F P
0 g
s
.82783 .36923 m .81655 .37426 L .80817 .3583 L p .707 .577 .707 r
F P
0 g
s
.80817 .3583 m .82047 .35278 L .82783 .36923 L p .707 .577 .707 r
F P
0 g
s
.81655 .37426 m .80502 .38031 L .79635 .3645 L p .707 .577 .707 r
F P
0 g
s
.79635 .3645 m .80817 .3583 L .81655 .37426 L p .707 .577 .707 r
F P
0 g
s
.80502 .38031 m .79311 .38683 L .7851 .37067 L p .707 .577 .707 r
F P
0 g
s
.7851 .37067 m .79635 .3645 L .80502 .38031 L p .707 .577 .707 r
F P
0 g
s
.79311 .38683 m .7823 .39218 L .77473 .37582 L p .707 .577 .707 r
F P
0 g
s
.77473 .37582 m .7851 .37067 L .79311 .38683 L p .707 .577 .707 r
F P
0 g
s
.7823 .39218 m .77142 .39722 L .76415 .38072 L p .707 .577 .707 r
F P
0 g
s
.76415 .38072 m .77473 .37582 L .7823 .39218 L p .707 .577 .707 r
F P
0 g
s
.77142 .39722 m .76035 .40209 L .75365 .38535 L p .707 .577 .707 r
F P
0 g
s
.75365 .38535 m .76415 .38072 L .77142 .39722 L p .707 .577 .707 r
F P
0 g
s
.76035 .40209 m .74915 .40657 L .74298 .38962 L p .707 .577 .707 r
F P
0 g
s
.74298 .38962 m .75365 .38535 L .76035 .40209 L p .707 .577 .707 r
F P
0 g
s
.74915 .40657 m .73809 .41058 L .73278 .39335 L p .707 .577 .707 r
F P
0 g
s
.73278 .39335 m .74298 .38962 L .74915 .40657 L p .707 .577 .707 r
F P
0 g
s
.73809 .41058 m .72678 .41405 L .72248 .39654 L p .707 .577 .707 r
F P
0 g
s
.72248 .39654 m .73278 .39335 L .73809 .41058 L p .707 .577 .707 r
F P
0 g
s
.72678 .41405 m .71544 .41683 L .71194 .39914 L p .707 .577 .707 r
F P
0 g
s
.71194 .39914 m .72248 .39654 L .72678 .41405 L p .707 .577 .707 r
F P
0 g
s
.71544 .41683 m .71025 .41785 L .70673 .40016 L p .744 .601 .698 r
F P
0 g
s
.70673 .40016 m .71194 .39914 L .71544 .41683 L p .744 .601 .698 r
F P
0 g
s
.50094 .34146 m .5128 .32965 L .52549 .34245 L p .707 .577 .707 r
F P
0 g
s
.47262 .45444 m .46793 .471 L .45052 .46632 L p .707 .577 .707 r
F P
0 g
s
.45052 .46632 m .45527 .44953 L .47262 .45444 L p .707 .577 .707 r
F P
0 g
s
.46793 .471 m .46359 .48706 L .44588 .48367 L p .707 .577 .707 r
F P
0 g
s
.44588 .48367 m .45052 .46632 L .46793 .471 L p .707 .577 .707 r
F P
0 g
s
.46359 .48706 m .46052 .50282 L .44256 .50126 L p .707 .577 .707 r
F P
0 g
s
.44256 .50126 m .44588 .48367 L .46359 .48706 L p .707 .577 .707 r
F P
0 g
s
.46052 .50282 m .45909 .51851 L .44108 .5192 L p .707 .577 .707 r
F P
0 g
s
.44108 .5192 m .44256 .50126 L .46052 .50282 L p .707 .577 .707 r
F P
0 g
s
.45909 .51851 m .45959 .53328 L .4418 .53619 L p .707 .577 .707 r
F P
0 g
s
.4418 .53619 m .44108 .5192 L .45909 .51851 L p .707 .577 .707 r
F P
0 g
s
.45959 .53328 m .46196 .54805 L .44457 .55283 L p .707 .577 .707 r
F P
0 g
s
.44457 .55283 m .4418 .53619 L .45959 .53328 L p .707 .577 .707 r
F P
0 g
s
.46196 .54805 m .46597 .56277 L .44905 .56898 L p .707 .577 .707 r
F P
0 g
s
.44905 .56898 m .44457 .55283 L .46196 .54805 L p .707 .577 .707 r
F P
0 g
s
.46597 .56277 m .47026 .57451 L .45335 .58074 L p .705 .571 .702 r
F P
0 g
s
.45335 .58074 m .44905 .56898 L .46597 .56277 L p .705 .571 .702 r
F P
0 g
s
.3023 .77201 m .32396 .80084 L .31117 .81355 L p .707 .577 .707 r
F P
0 g
s
.31117 .81355 m .28791 .78287 L .3023 .77201 L p .707 .577 .707 r
F P
0 g
s
.33802 .84045 m .31117 .81355 L .32396 .80084 L p .707 .577 .707 r
F P
0 g
s
.37733 .84724 m .40545 .86348 L .39904 .88033 L p .707 .577 .707 r
F P
0 g
s
.39904 .88033 m .36836 .86288 L .37733 .84724 L p .707 .577 .707 r
F P
0 g
s
.40545 .86348 m .43575 .87511 L .43194 .89273 L p .707 .577 .707 r
F P
0 g
s
.43194 .89273 m .39904 .88033 L .40545 .86348 L p .707 .577 .707 r
F P
0 g
s
.46641 .90008 m .43194 .89273 L .43575 .87511 L p .707 .577 .707 r
F P
0 g
s
.53652 .90262 m .50115 .90259 L .50121 .88456 L p .707 .577 .707 r
F P
0 g
s
.46599 .39967 m .46144 .41655 L .45241 .41461 L p .918 .808 .723 r
F P
0 g
s
.46144 .41655 m .45814 .43348 L .44907 .43173 L p .922 .796 .704 r
F P
0 g
s
.44907 .43173 m .45241 .41461 L .46144 .41655 L p .922 .796 .704 r
F P
0 g
s
.26877 .74931 m .28791 .78287 L .27985 .78957 L p .878 .616 .537 r
F P
0 g
s
.27985 .78957 m .25998 .75489 L .26877 .74931 L p .878 .616 .537 r
F P
0 g
s
.31117 .81355 m .33802 .84045 L .33199 .84919 L p .837 .541 .488 r
F P
0 g
s
.33802 .84045 m .36836 .86288 L .36334 .8723 L p .809 .499 .466 r
F P
0 g
s
.36334 .8723 m .33199 .84919 L .33802 .84045 L p .809 .499 .466 r
F P
0 g
s
.87516 .34659 m .86456 .34386 L .86625 .33432 L p .596 .694 .911 r
F P
0 g
s
.86625 .33432 m .87912 .3374 L .87516 .34659 L p .596 .694 .911 r
F P
0 g
s
.86456 .34386 m .85414 .3437 L .85432 .33423 L p .652 .752 .923 r
F P
0 g
s
.85432 .33423 m .86625 .33432 L .86456 .34386 L p .652 .752 .923 r
F P
0 g
s
.85414 .3437 m .84324 .34528 L .84208 .3361 L p .693 .787 .923 r
F P
0 g
s
.84208 .3361 m .85432 .33423 L .85414 .3437 L p .693 .787 .923 r
F P
0 g
s
.84324 .34528 m .83326 .34819 L .83154 .33918 L p .728 .813 .918 r
F P
0 g
s
.83154 .33918 m .84208 .3361 L .84324 .34528 L p .728 .813 .918 r
F P
0 g
s
.83326 .34819 m .82047 .35278 L .81804 .34406 L p .744 .824 .913 r
F P
0 g
s
.81804 .34406 m .83154 .33918 L .83326 .34819 L p .744 .824 .913 r
F P
0 g
s
.82047 .35278 m .80817 .3583 L .80519 .34985 L p .764 .836 .907 r
F P
0 g
s
.80817 .3583 m .79635 .3645 L .79318 .35615 L p .78 .843 .9 r
F P
0 g
s
.79318 .35615 m .80519 .34985 L .80817 .3583 L p .78 .843 .9 r
F P
0 g
s
.79635 .3645 m .7851 .37067 L .78222 .36217 L p .784 .846 .898 r
F P
0 g
s
.78222 .36217 m .79318 .35615 L .79635 .3645 L p .784 .846 .898 r
F P
0 g
s
.7851 .37067 m .77473 .37582 L .77201 .36724 L p .774 .841 .903 r
F P
0 g
s
.77201 .36724 m .78222 .36217 L .7851 .37067 L p .774 .841 .903 r
F P
0 g
s
.77473 .37582 m .76415 .38072 L .76155 .37209 L p .767 .837 .906 r
F P
0 g
s
.76155 .37209 m .77201 .36724 L .77473 .37582 L p .767 .837 .906 r
F P
0 g
s
.76415 .38072 m .75365 .38535 L .75129 .37662 L p .762 .835 .907 r
F P
0 g
s
.75129 .37662 m .76155 .37209 L .76415 .38072 L p .762 .835 .907 r
F P
0 g
s
.75365 .38535 m .74298 .38962 L .74085 .38081 L p .753 .83 .911 r
F P
0 g
s
.74085 .38081 m .75129 .37662 L .75365 .38535 L p .753 .83 .911 r
F P
0 g
s
.74298 .38962 m .73278 .39335 L .73103 .3844 L p .745 .825 .913 r
F P
0 g
s
.73103 .3844 m .74085 .38081 L .74298 .38962 L p .745 .825 .913 r
F P
0 g
s
.73278 .39335 m .72248 .39654 L .7212 .38747 L p .732 .817 .917 r
F P
0 g
s
.7212 .38747 m .73103 .3844 L .73278 .39335 L p .732 .817 .917 r
F P
0 g
s
.5128 .32965 m .50094 .34146 L .4941 .33502 L p .845 .847 .845 r
F P
0 g
s
.50094 .34146 m .4899 .35426 L .48245 .34861 L p .86 .847 .83 r
F P
0 g
s
.48245 .34861 m .4941 .33502 L .50094 .34146 L p .86 .847 .83 r
F P
0 g
s
.4899 .35426 m .48021 .36818 L .47215 .36351 L p .877 .844 .808 r
F P
0 g
s
.47215 .36351 m .48245 .34861 L .4899 .35426 L p .877 .844 .808 r
F P
0 g
s
.48021 .36818 m .47227 .38318 L .46371 .3796 L p .895 .835 .779 r
F P
0 g
s
.46371 .3796 m .47215 .36351 L .48021 .36818 L p .895 .835 .779 r
F P
0 g
s
.47227 .38318 m .46599 .39967 L .45712 .39703 L p .909 .822 .749 r
F P
0 g
s
.45712 .39703 m .46371 .3796 L .47227 .38318 L p .909 .822 .749 r
F P
0 g
s
.45241 .41461 m .45712 .39703 L .46599 .39967 L p .918 .808 .723 r
F P
0 g
s
.45814 .43348 m .45527 .44953 L .44639 .44698 L p .923 .793 .699 r
F P
0 g
s
.44639 .44698 m .44907 .43173 L .45814 .43348 L p .923 .793 .699 r
F P
0 g
s
.45527 .44953 m .45052 .46632 L .44158 .46396 L p .917 .81 .726 r
F P
0 g
s
.44158 .46396 m .44639 .44698 L .45527 .44953 L p .917 .81 .726 r
F P
0 g
s
.45052 .46632 m .44588 .48367 L .43677 .48203 L p .918 .808 .722 r
F P
0 g
s
.43677 .48203 m .44158 .46396 L .45052 .46632 L p .918 .808 .722 r
F P
0 g
s
.44588 .48367 m .44256 .50126 L .43332 .5006 L p .923 .795 .701 r
F P
0 g
s
.43332 .5006 m .43677 .48203 L .44588 .48367 L p .923 .795 .701 r
F P
0 g
s
.44256 .50126 m .44108 .5192 L .4318 .51975 L p .926 .774 .673 r
F P
0 g
s
.4318 .51975 m .43332 .5006 L .44256 .50126 L p .926 .774 .673 r
F P
0 g
s
.44108 .5192 m .4418 .53619 L .43264 .53792 L p .926 .746 .639 r
F P
0 g
s
.43264 .53792 m .4318 .51975 L .44108 .5192 L p .926 .746 .639 r
F P
0 g
s
.4418 .53619 m .44457 .55283 L .43563 .55557 L p .922 .716 .606 r
F P
0 g
s
.43563 .55557 m .43264 .53792 L .4418 .53619 L p .922 .716 .606 r
F P
0 g
s
.44457 .55283 m .44905 .56898 L .44035 .57249 L p .916 .688 .578 r
F P
0 g
s
.44035 .57249 m .43563 .55557 L .44457 .55283 L p .916 .688 .578 r
F P
0 g
s
.44905 .56898 m .45335 .58074 L .44592 .58767 L p .909 .665 .558 r
F P
0 g
s
.44592 .58767 m .44035 .57249 L .44905 .56898 L p .909 .665 .558 r
F P
0 g
s
.28791 .78287 m .31117 .81355 L .304 .82129 L p .86 .579 .512 r
F P
0 g
s
.304 .82129 m .27985 .78957 L .28791 .78287 L p .86 .579 .512 r
F P
0 g
s
.33199 .84919 m .304 .82129 L .31117 .81355 L p .837 .541 .488 r
F P
0 g
s
.36836 .86288 m .39904 .88033 L .39542 .89042 L p .784 .466 .451 r
F P
0 g
s
.39542 .89042 m .36334 .8723 L .36836 .86288 L p .784 .466 .451 r
F P
0 g
s
.39904 .88033 m .43194 .89273 L .42976 .90325 L p .749 .426 .436 r
F P
0 g
s
.42976 .90325 m .39542 .89042 L .39904 .88033 L p .749 .426 .436 r
F P
0 g
s
.43194 .89273 m .46641 .90008 L .46562 .91081 L p .714 .389 .427 r
F P
0 g
s
.46562 .91081 m .42976 .90325 L .43194 .89273 L p .714 .389 .427 r
F P
0 g
s
.46641 .90008 m .50115 .90259 L .50112 .91336 L p .682 .359 .423 r
F P
0 g
s
.50112 .91336 m .46562 .91081 L .46641 .90008 L p .682 .359 .423 r
F P
0 g
s
.50115 .90259 m .53652 .90262 L .5379 .9133 L p .664 .344 .422 r
F P
0 g
s
.5379 .9133 m .50112 .91336 L .50115 .90259 L p .664 .344 .422 r
F P
0 g
s
.53652 .90262 m .57143 .89772 L .57427 .9081 L p .63 .319 .425 r
F P
0 g
s
.57427 .9081 m .5379 .9133 L .53652 .90262 L p .63 .319 .425 r
F P
0 g
s
.57143 .89772 m .6051 .88766 L .60941 .89749 L p .594 .296 .432 r
F P
0 g
s
.60941 .89749 m .57427 .9081 L .57143 .89772 L p .594 .296 .432 r
F P
0 g
s
.6051 .88766 m .63655 .87258 L .64196 .8818 L p .558 .277 .445 r
F P
0 g
s
.64196 .8818 m .60941 .89749 L .6051 .88766 L p .558 .277 .445 r
F P
0 g
s
.63655 .87258 m .66832 .85218 L .67494 .86051 L p .531 .267 .459 r
F P
0 g
s
.67494 .86051 m .64196 .8818 L .63655 .87258 L p .531 .267 .459 r
F P
0 g
s
.66832 .85218 m .6966 .82736 L .70418 .83475 L p .501 .259 .479 r
F P
0 g
s
.70418 .83475 m .67494 .86051 L .66832 .85218 L p .501 .259 .479 r
F P
0 g
s
.6966 .82736 m .72172 .79859 L .73007 .80501 L p .477 .258 .501 r
F P
0 g
s
.73007 .80501 m .70418 .83475 L .6966 .82736 L p .477 .258 .501 r
F P
0 g
s
.72172 .79859 m .74216 .76891 L .75174 .77316 L p .458 .26 .523 r
F P
0 g
s
.75157 .7734 m .72172 .79859 L .75174 .77316 L .458 .26 .523 r
F
.75182 .77319 m .73007 .80501 L .72172 .79859 L p F P
0 g
s
.76561 .74966 m .75182 .77319 L .74216 .76891 L p .457 .258 .521 r
F P
0 g
s
.74599 .76811 m .72349 .80121 L .73005 .805 L p .898 .883 .81 r
F P
0 g
s
.73005 .805 m .73007 .80501 L p .73012 .80489 L .898 .883 .81 r
F P
0 g
s
.74599 .76811 m .73005 .805 L .73012 .80489 L .898 .883 .81 r
F
.75174 .77316 m .75182 .77319 L p .75157 .7734 L .458 .26 .523 r
F P
0 g
s
.80519 .34985 m .81804 .34406 L .82047 .35278 L p .764 .836 .907 r
F P
0 g
s
.71102 .38999 m .7212 .38747 L .72248 .39654 L p .717 .807 .921 r
F P
0 g
s
.4941 .33502 m .50647 .32268 L .5128 .32965 L p .845 .847 .845 r
F P
0 g
s
.55542 .35655 m .54984 .35453 L .54314 .37127 L p .644 .514 .69 r
F P
0 g
s
.54314 .37127 m .55128 .37411 L .55542 .35655 L p .644 .514 .69 r
F P
0 g
s
.08655 .35473 m .1136 .32573 L p .12304 .33103 L .835 .828 .84 r
F P
0 g
s
.11423 .32519 m .12304 .33103 L p .1136 .32573 L .835 .828 .84 r
F P
0 g
s
.11833 .33174 m .14055 .31287 L .1347 .30789 L p .431 .141 .37 r
F P
0 g
s
.1347 .30789 m .13465 .30784 L p .1345 .30805 L .431 .141 .37 r
F P
0 g
s
.11833 .33174 m .1347 .30789 L .1345 .30805 L .431 .141 .37 r
F
.1136 .32573 m .11415 .32513 L .11423 .32519 L p .835 .828 .84 r
F P
0 g
s
.46528 .05362 m .4944 .07748 L .48963 .08678 L p .487 .552 .848 r
F P
0 g
s
.65141 .38637 m .64888 .38095 L .63228 .38799 L p .673 .504 .648 r
F P
0 g
s
.63228 .38799 m .63572 .39527 L .65141 .38637 L p .673 .504 .648 r
F P
0 g
s
.47433 .56003 m .47988 .57516 L .47026 .57451 L p .373 .381 .74 r
F P
0 g
s
.45104 .60115 m .44654 .58931 L p .45335 .58074 L .921 .698 .583 r
F P
0 g
s
.446 .58759 m .45335 .58074 L p .44654 .58931 L .921 .698 .583 r
F P
0 g
s
.45548 .58838 m .44864 .56977 L .44118 .57222 L p .371 .388 .748 r
F P
0 g
s
.44118 .57222 m .44035 .57249 L p .44171 .57392 L .371 .388 .748 r
F P
0 g
s
.45548 .58838 m .44118 .57222 L .44171 .57392 L .371 .388 .748 r
F
.44654 .58931 m .44592 .58767 L .446 .58759 L p .921 .698 .583 r
F P
0 g
s
.61714 .60078 m .62446 .60846 L .61491 .61148 L p .254 .288 .705 r
F P
0 g
s
.68012 .34856 m .68441 .35512 L .69743 .34264 L p .751 .654 .753 r
F P
0 g
s
.69743 .34264 m .69 .33347 L .68012 .34856 L p .751 .654 .753 r
F P
0 g
s
.53158 .56498 m .52075 .5627 L .51671 .58027 L p .659 .529 .695 r
F P
0 g
s
.51671 .58027 m .52636 .58226 L .53158 .56498 L p .659 .529 .695 r
F P
0 g
s
.56194 .57426 m .572 .57851 L .58015 .57254 L p .73 .375 .378 r
F P
0 g
s
.59013 .57841 m .58015 .57254 L .572 .57851 L p .754 .4 .384 r
F P
0 g
s
.65328 .65562 m .66088 .66558 L .66533 .65652 L p .898 .612 .494 r
F P
0 g
s
.66533 .65652 m .65759 .64649 L .65328 .65562 L p .898 .612 .494 r
F P
0 g
s
.94668 .5314 m .94643 .49663 L .93558 .49705 L p .422 .358 .681 r
F P
0 g
s
.66662 .41938 m .65896 .41686 L .66157 .42774 L p .536 .656 .913 r
F P
0 g
s
.66157 .42774 m .67073 .42965 L .66662 .41938 L p .536 .656 .913 r
F P
0 g
s
.58608 .31029 m .57659 .31052 L .57507 .32095 L p .732 .819 .919 r
F P
0 g
s
.50605 .6162 m .49957 .61042 L .49663 .62038 L p .877 .571 .467 r
F P
0 g
s
.67214 .33945 m .66817 .33829 L .6616 .34901 L p .758 .896 .939 r
F P
0 g
s
.59575 .36912 m .58731 .37233 L .59508 .37946 L p .715 .813 .926 r
F P
0 g
s
.59508 .37946 m .60405 .37551 L .59575 .36912 L p .715 .813 .926 r
F P
0 g
s
.49033 .18209 m .4909 .1641 L .48183 .16309 L p .362 .313 .668 r
F P
0 g
s
.32679 .06305 m .35939 .06173 L .35717 .05112 L p .658 .738 .909 r
F P
0 g
s
.24665 .58248 m .24944 .6119 L .25956 .6119 L p .913 .712 .617 r
F P
0 g
s
.76315 .63889 m .75816 .66607 L .76839 .66691 L p .412 .285 .596 r
F P
0 g
s
.27056 .27358 m .24376 .28281 L .24632 .29257 L p .759 .814 .896 r
F P
0 g
s
.06436 .49807 m .07006 .46798 L .05921 .46764 L p .901 .786 .725 r
F P
0 g
s
.56215 .60378 m .56951 .60803 L .57135 .59862 L p .458 .566 .877 r
F P
0 g
s
.65361 .68622 m .64635 .67637 L .63637 .67802 L p .43 .52 .848 r
F P
0 g
s
.97092 .48988 m .96352 .45227 L .95718 .45634 L p .956 .739 .569 r
F P
0 g
s
.95718 .45634 m .96417 .49303 L .97092 .48988 L p .956 .739 .569 r
F P
0 g
s
.66028 .39727 m .66501 .3998 L .67362 .39375 L p .694 .324 .341 r
F P
0 g
s
.56433 .28652 m .55173 .29048 L .55909 .29648 L p .59 .226 .32 r
F P
0 g
s
.55909 .29648 m .5712 .29324 L .56433 .28652 L p .59 .226 .32 r
F P
0 g
s
.47601 .63775 m .48718 .64693 L .49521 .64195 L p .472 .609 .906 r
F P
0 g
s
.50657 .64802 m .49521 .64195 L .48718 .64693 L p .516 .663 .928 r
F P
0 g
s
.65507 .31354 m .64884 .31464 L .65797 .32124 L p .651 .239 .25 r
F P
0 g
s
.65797 .32124 m .66489 .3205 L .65507 .31354 L p .651 .239 .25 r
F P
0 g
s
.57445 .35706 m .58149 .35519 L .58348 .34531 L p .499 .19 .373 r
F P
0 g
s
.51787 .16171 m .51712 .14234 L .50845 .14507 L p .932 .775 .664 r
F P
0 g
s
.50845 .14507 m .50899 .1634 L .51787 .16171 L p .932 .775 .664 r
F P
0 g
s
.35796 .02567 m .31902 .02784 L .31898 .03522 L p .588 .205 .283 r
F P
0 g
s
.28265 .04396 m .31898 .03522 L .31902 .02784 L p .527 .162 .29 r
F P
0 g
s
.22372 .61594 m .22699 .64655 L .23451 .64392 L p .317 .272 .649 r
F P
0 g
s
.23451 .64392 m .23145 .61392 L .22372 .61594 L p .317 .272 .649 r
F P
0 g
s
.79361 .67285 m .79879 .64439 L .79127 .64206 L p .948 .807 .671 r
F P
0 g
s
.79537 .61388 m .79127 .64206 L .79879 .64439 L p .949 .799 .66 r
F P
0 g
s
.23389 .25872 m .20603 .26877 L .21025 .27549 L p .543 .196 .33 r
F P
0 g
s
.21025 .27549 m .23752 .26582 L .23389 .25872 L p .543 .196 .33 r
F P
0 g
s
.03462 .46118 m .0283 .49726 L .03546 .49897 L p .282 .194 .575 r
F P
0 g
s
.03538 .53408 m .03546 .49897 L .0283 .49726 L p .278 .237 .632 r
F P
0 g
s
.5429 .65706 m .55504 .65709 L .55371 .63911 L p .761 .625 .709 r
F P
0 g
s
.55371 .63911 m .54421 .63906 L .5429 .65706 L p .761 .625 .709 r
F P
0 g
s
.6739 .71715 m .68136 .72884 L .69611 .71847 L p .728 .623 .742 r
F P
0 g
s
.69611 .71847 m .68927 .70768 L .6739 .71715 L p .728 .623 .742 r
F P
0 g
s
.50591 .25257 m .50545 .23668 L .48741 .23619 L p .707 .603 .738 r
F P
0 g
s
.48741 .23619 m .48789 .25294 L .50591 .25257 L p .707 .603 .738 r
F P
0 g
s
.22251 .49757 m .20631 .4732 L .19131 .48321 L p .697 .557 .692 r
F P
0 g
s
.19131 .48321 m .20645 .50581 L .22251 .49757 L p .697 .557 .692 r
F P
0 g
s
.81651 .53547 m .83019 .51005 L .81435 .50144 L p .716 .571 .691 r
F P
0 g
s
.81435 .50144 m .80069 .52678 L .81651 .53547 L p .716 .571 .691 r
F P
0 g
s
.34592 .23041 m .36637 .20797 L .35301 .19586 L p .719 .576 .694 r
F P
0 g
s
.35301 .19586 m .33408 .21679 L .34592 .23041 L p .719 .576 .694 r
F P
0 g
s
.1888 .10128 m .16502 .12728 L .17994 .13741 L p .696 .578 .719 r
F P
0 g
s
.17994 .13741 m .20187 .11373 L .1888 .10128 L p .696 .578 .719 r
F P
0 g
s
.06679 .63649 m .08724 .66833 L .10072 .65635 L p .715 .594 .72 r
F P
0 g
s
.10072 .65635 m .08216 .62702 L .06679 .63649 L p .715 .594 .72 r
F P
0 g
s
.91571 .67466 m .93413 .64123 L .91716 .63511 L p .7 .582 .72 r
F P
0 g
s
.91716 .63511 m .89982 .66613 L .91571 .67466 L p .7 .582 .72 r
F P
0 g
s
.71805 .4255 m .70696 .4277 L .71025 .41785 L p .626 .277 .36 r
F P
0 g
s
.60387 .31491 m .60999 .31892 L .61742 .30248 L p .8 .691 .744 r
F P
0 g
s
.61742 .30248 m .6082 .29738 L .60387 .31491 L p .8 .691 .744 r
F P
0 g
s
.65432 .39112 m .65141 .38637 L .63572 .39527 L p .666 .505 .657 r
F P
0 g
s
.63572 .39527 m .64038 .40258 L .65432 .39112 L p .666 .505 .657 r
F P
0 g
s
.56113 .3577 m .55542 .35655 L .55128 .37411 L p .644 .523 .701 r
F P
0 g
s
.55128 .37411 m .55996 .37572 L .56113 .3577 L p .644 .523 .701 r
F P
0 g
s
.67794 .34439 m .68012 .34856 L .69 .33347 L p .755 .643 .737 r
F P
0 g
s
.69 .33347 m .68394 .32737 L .67794 .34439 L p .755 .643 .737 r
F P
0 g
s
.54138 .56805 m .53158 .56498 L .52636 .58226 L p .656 .524 .691 r
F P
0 g
s
.52636 .58226 m .53629 .58537 L .54138 .56805 L p .656 .524 .691 r
F P
0 g
s
.572 .57851 m .5817 .58375 L .59013 .57841 L p .754 .4 .384 r
F P
0 g
s
.59991 .58533 m .59013 .57841 L .5817 .58375 L p .777 .427 .394 r
F P
0 g
s
.94643 .49663 m .93996 .46197 L .92922 .46348 L p .426 .397 .723 r
F P
0 g
s
.57659 .31052 m .56659 .31297 L .56668 .32332 L p .777 .842 .901 r
F P
0 g
s
.66817 .33829 m .66243 .33879 L .65774 .34961 L p .786 .886 .918 r
F P
0 g
s
.4909 .1641 m .49041 .14667 L .48118 .14555 L p .367 .331 .686 r
F P
0 g
s
.48024 .13322 m .48118 .14555 L .49041 .14667 L p .37 .352 .708 r
F P
0 g
s
.24944 .6119 m .25233 .64066 L .26249 .64006 L p .913 .709 .614 r
F P
0 g
s
.24376 .28281 m .21767 .29202 L .2208 .30169 L p .762 .815 .895 r
F P
0 g
s
.56951 .60803 m .57682 .6131 L .57954 .60388 L p .442 .539 .861 r
F P
0 g
s
.96352 .45227 m .95196 .41692 L .94654 .4224 L p .947 .701 .532 r
F P
0 g
s
.94654 .4224 m .95718 .45634 L .96352 .45227 L p .947 .701 .532 r
F P
0 g
s
.55173 .29048 m .53829 .29669 L .54649 .30161 L p .55 .204 .334 r
F P
0 g
s
.54649 .30161 m .55909 .29648 L .55173 .29048 L p .55 .204 .334 r
F P
0 g
s
.64884 .31464 m .64098 .31663 L .65072 .3224 L p .626 .228 .27 r
F P
0 g
s
.65072 .3224 m .65797 .32124 L .64884 .31464 L p .626 .228 .27 r
F P
0 g
s
.51712 .14234 m .5155 .12538 L .50741 .12918 L p .935 .773 .657 r
F P
0 g
s
.50741 .12918 m .50845 .14507 L .51712 .14234 L p .935 .773 .657 r
F P
0 g
s
.22699 .64655 m .23196 .67471 L .23922 .67153 L p .316 .288 .668 r
F P
0 g
s
.23922 .67153 m .23451 .64392 L .22699 .64655 L p .316 .288 .668 r
F P
0 g
s
.20603 .26877 m .18112 .27976 L .18587 .28605 L p .522 .183 .333 r
F P
0 g
s
.18587 .28605 m .21025 .27549 L .20603 .26877 L p .522 .183 .333 r
F P
0 g
s
.64573 .64601 m .65328 .65562 L .65759 .64649 L p .897 .609 .491 r
F P
0 g
s
.65759 .64649 m .64993 .63681 L .64573 .64601 L p .897 .609 .491 r
F P
0 g
s
.67508 .4208 m .66662 .41938 L .67073 .42965 L p .562 .686 .923 r
F P
0 g
s
.67073 .42965 m .67962 .43055 L .67508 .4208 L p .562 .686 .923 r
F P
0 g
s
.49957 .61042 m .49314 .603 L .48879 .61231 L p .893 .607 .496 r
F P
0 g
s
.6049 .36482 m .59575 .36912 L .60405 .37551 L p .727 .82 .923 r
F P
0 g
s
.60405 .37551 m .61291 .37114 L .6049 .36482 L p .727 .82 .923 r
F P
0 g
s
.35939 .06173 m .39217 .06409 L .39111 .05335 L p .629 .714 .908 r
F P
0 g
s
.75816 .66607 m .75174 .68956 L .76195 .69113 L p .42 .272 .573 r
F P
0 g
s
.07006 .46798 m .08052 .43469 L .06984 .433 L p .893 .8 .75 r
F P
0 g
s
.64635 .67637 m .63895 .6667 L .62904 .66857 L p .434 .526 .852 r
F P
0 g
s
.68312 .39461 m .67755 .39421 L .67004 .4016 L p .614 .254 .336 r
F P
0 g
s
.66501 .3998 m .67004 .4016 L .67755 .39421 L p .65 .286 .34 r
F P
0 g
s
.46608 .62692 m .47601 .63775 L .4848 .6341 L p .438 .556 .877 r
F P
0 g
s
.49521 .64195 m .4848 .6341 L .47601 .63775 L p .472 .609 .906 r
F P
0 g
s
.59697 .33873 m .58938 .34254 L .58839 .35257 L p .463 .179 .395 r
F P
0 g
s
.58149 .35519 m .58839 .35257 L .58938 .34254 L p .474 .181 .388 r
F P
0 g
s
.39496 .02808 m .35796 .02567 L .35645 .03302 L p .63 .239 .285 r
F P
0 g
s
.31898 .03522 m .35645 .03302 L .35796 .02567 L p .588 .205 .283 r
F P
0 g
s
.78651 .69932 m .79361 .67285 L .78618 .67031 L p .945 .825 .694 r
F P
0 g
s
.79127 .64206 m .78618 .67031 L .79361 .67285 L p .948 .807 .671 r
F P
0 g
s
.04612 .42369 m .03462 .46118 L .04142 .46423 L p .294 .169 .534 r
F P
0 g
s
.03546 .49897 m .04142 .46423 L .03462 .46118 L p .282 .194 .575 r
F P
0 g
s
.53092 .65533 m .5429 .65706 L .54421 .63906 L p .759 .629 .716 r
F P
0 g
s
.54421 .63906 m .53463 .63766 L .53092 .65533 L p .759 .629 .716 r
F P
0 g
s
.66698 .70568 m .6739 .71715 L .68927 .70768 L p .727 .622 .741 r
F P
0 g
s
.68927 .70768 m .68246 .69637 L .66698 .70568 L p .727 .622 .741 r
F P
0 g
s
.48776 .21909 m .48741 .23619 L .50545 .23668 L p .706 .602 .738 r
F P
0 g
s
.50545 .23668 m .50578 .22033 L .48776 .21909 L p .706 .602 .738 r
F P
0 g
s
.20645 .50581 m .21861 .52863 L .23615 .52433 L p .699 .558 .691 r
F P
0 g
s
.23615 .52433 m .22251 .49757 L .20645 .50581 L p .699 .558 .691 r
F P
0 g
s
.33408 .21679 m .31418 .23464 L .32249 .25068 L p .72 .579 .696 r
F P
0 g
s
.32249 .25068 m .34592 .23041 L .33408 .21679 L p .72 .579 .696 r
F P
0 g
s
.80523 .56094 m .81651 .53547 L .80069 .52678 L p .714 .57 .69 r
F P
0 g
s
.80069 .52678 m .78875 .55354 L .80523 .56094 L p .714 .57 .69 r
F P
0 g
s
.21656 .07931 m .1888 .10128 L .20187 .11373 L p .694 .575 .717 r
F P
0 g
s
.20187 .11373 m .22748 .09369 L .21656 .07931 L p .694 .575 .717 r
F P
0 g
s
.05173 .60158 m .06679 .63649 L .08216 .62702 L p .713 .593 .721 r
F P
0 g
s
.08216 .62702 m .06844 .59473 L .05173 .60158 L p .713 .593 .721 r
F P
0 g
s
.93 .60075 m .91716 .63511 L .93413 .64123 L p .702 .584 .721 r
F P
0 g
s
.93413 .64123 m .9473 .60591 L .93 .60075 L p .702 .584 .721 r
F P
0 g
s
.67572 .34138 m .67794 .34439 L .68394 .32737 L p .847 .737 .743 r
F P
0 g
s
.68394 .32737 m .67791 .32345 L .67572 .34138 L p .847 .737 .743 r
F P
0 g
s
.65667 .3942 m .65432 .39112 L .64038 .40258 L p .654 .5 .663 r
F P
0 g
s
.64038 .40258 m .64528 .40823 L .65667 .3942 L p .654 .5 .663 r
F P
0 g
s
.56793 .35785 m .56113 .3577 L .55996 .37572 L p .645 .531 .709 r
F P
0 g
s
.55996 .37572 m .56929 .37587 L .56793 .35785 L p .645 .531 .709 r
F P
0 g
s
.55164 .57086 m .54138 .56805 L .53629 .58537 L p .657 .525 .691 r
F P
0 g
s
.53629 .58537 m .54552 .58786 L .55164 .57086 L p .657 .525 .691 r
F P
0 g
s
.5817 .58375 m .59113 .58994 L .59991 .58533 L p .777 .427 .394 r
F P
0 g
s
.60887 .59286 m .59991 .58533 L .59113 .58994 L p .797 .452 .403 r
F P
0 g
s
.63781 .63642 m .64573 .64601 L .64993 .63681 L p .891 .599 .485 r
F P
0 g
s
.64993 .63681 m .64181 .62712 L .63781 .63642 L p .891 .599 .485 r
F P
0 g
s
.93996 .46197 m .93075 .4313 L .9205 .43466 L p .433 .425 .75 r
F P
0 g
s
.68343 .42138 m .67508 .4208 L .67962 .43055 L p .595 .721 .932 r
F P
0 g
s
.67962 .43055 m .68903 .43046 L .68343 .42138 L p .595 .721 .932 r
F P
0 g
s
.56659 .31297 m .55634 .31683 L .5579 .32702 L p .803 .85 .885 r
F P
0 g
s
.49314 .603 m .48802 .59485 L .48238 .60338 L p .915 .657 .533 r
F P
0 g
s
.66243 .33879 m .65684 .33946 L .65317 .35063 L p .794 .876 .907 r
F P
0 g
s
.61341 .36041 m .6049 .36482 L .61291 .37114 L p .738 .827 .92 r
F P
0 g
s
.61291 .37114 m .62161 .36644 L .61341 .36041 L p .738 .827 .92 r
F P
0 g
s
.49041 .14667 m .48971 .13311 L .48024 .13322 L p .37 .352 .708 r
F P
0 g
s
.39217 .06409 m .42216 .07248 L .42297 .06181 L p .578 .666 .898 r
F P
0 g
s
.25233 .64066 m .25675 .6669 L .26688 .66549 L p .908 .69 .596 r
F P
0 g
s
.75174 .68956 m .74327 .71227 L .75336 .71475 L p .43 .263 .552 r
F P
0 g
s
.21767 .29202 m .19466 .30191 L .19863 .31135 L p .78 .822 .885 r
F P
0 g
s
.08052 .43469 m .09591 .40423 L .08565 .401 L p .877 .818 .787 r
F P
0 g
s
.57682 .6131 m .58394 .61903 L .58737 .61004 L p .423 .508 .841 r
F P
0 g
s
.63895 .6667 m .63152 .65727 L .62163 .65924 L p .436 .531 .856 r
F P
0 g
s
.95196 .41692 m .93391 .38494 L .92969 .39164 L p .923 .632 .474 r
F P
0 g
s
.92969 .39164 m .94654 .4224 L .95196 .41692 L p .923 .632 .474 r
F P
0 g
s
.67004 .4016 m .67683 .40276 L .68312 .39461 L p .614 .254 .336 r
F P
0 g
s
.53829 .29669 m .52609 .30465 L .53484 .30857 L p .509 .185 .353 r
F P
0 g
s
.53484 .30857 m .54649 .30161 L .53829 .29669 L p .509 .185 .353 r
F P
0 g
s
.45769 .61451 m .46608 .62692 L .4752 .62431 L p .406 .503 .845 r
F P
0 g
s
.4848 .6341 m .4752 .62431 L .46608 .62692 L p .438 .556 .877 r
F P
0 g
s
.64098 .31663 m .63358 .31927 L .64367 .32434 L p .593 .206 .278 r
F P
0 g
s
.64367 .32434 m .65072 .3224 L .64098 .31663 L p .593 .206 .278 r
F P
0 g
s
.58839 .35257 m .5969 .34856 L .59697 .33873 L p .463 .179 .395 r
F P
0 g
s
.5155 .12538 m .51162 .10858 L .50445 .11368 L p .937 .744 .617 r
F P
0 g
s
.50445 .11368 m .50741 .12918 L .5155 .12538 L p .937 .744 .617 r
F P
0 g
s
.43183 .03765 m .39496 .02808 L .39251 .03528 L p .694 .301 .298 r
F P
0 g
s
.35645 .03302 m .39251 .03528 L .39496 .02808 L p .63 .239 .285 r
F P
0 g
s
.23196 .67471 m .23907 .70237 L .24603 .69863 L p .318 .309 .692 r
F P
0 g
s
.24603 .69863 m .23922 .67153 L .23196 .67471 L p .318 .309 .692 r
F P
0 g
s
.77705 .72513 m .78651 .69932 L .77941 .69603 L p .939 .843 .721 r
F P
0 g
s
.78618 .67031 m .77941 .69603 L .78651 .69932 L p .945 .825 .694 r
F P
0 g
s
.18112 .27976 m .15724 .2928 L .16252 .29858 L p .495 .168 .34 r
F P
0 g
s
.16252 .29858 m .18587 .28605 L .18112 .27976 L p .495 .168 .34 r
F P
0 g
s
.06368 .38787 m .04612 .42369 L .05257 .42748 L p .315 .146 .486 r
F P
0 g
s
.04142 .46423 m .05257 .42748 L .04612 .42369 L p .294 .169 .534 r
F P
0 g
s
.6082 .29738 m .59614 .29358 L .59538 .31163 L p .762 .634 .719 r
F P
0 g
s
.59538 .31163 m .60387 .31491 L .6082 .29738 L p .762 .634 .719 r
F P
0 g
s
.51867 .65239 m .53092 .65533 L .53463 .63766 L p .751 .624 .718 r
F P
0 g
s
.53463 .63766 m .52346 .63496 L .51867 .65239 L p .751 .624 .718 r
F P
0 g
s
.66063 .69605 m .66698 .70568 L .68246 .69637 L p .729 .624 .74 r
F P
0 g
s
.68246 .69637 m .67555 .68586 L .66063 .69605 L p .729 .624 .74 r
F P
0 g
s
.48903 .20041 m .48776 .21909 L .50578 .22033 L p .705 .599 .735 r
F P
0 g
s
.50578 .22033 m .50707 .20159 L .48903 .20041 L p .705 .599 .735 r
F P
0 g
s
.29706 .26377 m .32249 .25068 L .31418 .23464 L p .723 .584 .698 r
F P
0 g
s
.31418 .23464 m .29068 .24686 L .29706 .26377 L p .723 .584 .698 r
F P
0 g
s
.79935 .5865 m .80523 .56094 L .78875 .55354 L p .711 .566 .689 r
F P
0 g
s
.78875 .55354 m .78175 .58239 L .79935 .5865 L p .711 .566 .689 r
F P
0 g
s
.24317 .55325 m .23615 .52433 L .21861 .52863 L p .703 .559 .689 r
F P
0 g
s
.21861 .52863 m .22523 .55549 L .24317 .55325 L p .703 .559 .689 r
F P
0 g
s
.24807 .05904 m .21656 .07931 L .22748 .09369 L p .694 .573 .715 r
F P
0 g
s
.22748 .09369 m .25763 .07438 L .24807 .05904 L p .694 .573 .715 r
F P
0 g
s
.04102 .5687 m .05173 .60158 L .06844 .59473 L p .712 .594 .722 r
F P
0 g
s
.06844 .59473 m .05829 .56335 L .04102 .5687 L p .712 .594 .722 r
F P
0 g
s
.94091 .56639 m .93 .60075 L .9473 .60591 L p .703 .585 .721 r
F P
0 g
s
.9473 .60591 m .9588 .56898 L .94091 .56639 L p .703 .585 .721 r
F P
0 g
s
.67214 .33945 m .67572 .34138 L .67791 .32345 L p .837 .698 .71 r
F P
0 g
s
.67791 .32345 m .67146 .32139 L .67214 .33945 L p .837 .698 .71 r
F P
0 g
s
.66028 .39727 m .65667 .3942 L .64528 .40823 L p .645 .502 .673 r
F P
0 g
s
.64528 .40823 m .65177 .41323 L .66028 .39727 L p .645 .502 .673 r
F P
0 g
s
.57445 .35706 m .56793 .35785 L .56929 .37587 L p .647 .539 .717 r
F P
0 g
s
.56929 .37587 m .57838 .37471 L .57445 .35706 L p .647 .539 .717 r
F P
0 g
s
.56194 .57426 m .55164 .57086 L .54552 .58786 L p .659 .525 .689 r
F P
0 g
s
.54552 .58786 m .55441 .5907 L .56194 .57426 L p .659 .525 .689 r
F P
0 g
s
.59113 .58994 m .59988 .5969 L .60887 .59286 L p .797 .452 .403 r
F P
0 g
s
.61714 .60078 m .60887 .59286 L .59988 .5969 L p .812 .471 .41 r
F P
0 g
s
.62952 .62705 m .63781 .63642 L .64181 .62712 L p .885 .586 .477 r
F P
0 g
s
.64181 .62712 m .63323 .61761 L .62952 .62705 L p .885 .586 .477 r
F P
0 g
s
.93075 .4313 m .91592 .40344 L .90646 .40846 L p .452 .477 .794 r
F P
0 g
s
.69197 .42097 m .68343 .42138 L .68903 .43046 L p .625 .75 .937 r
F P
0 g
s
.68903 .43046 m .69832 .42937 L .69197 .42097 L p .625 .75 .937 r
F P
0 g
s
.55634 .31683 m .5466 .32239 L .54952 .33218 L p .837 .858 .861 r
F P
0 g
s
.48802 .59485 m .48366 .58552 L .47698 .59317 L p .925 .691 .565 r
F P
0 g
s
.65684 .33946 m .65115 .34086 L .64848 .3522 L p .818 .883 .892 r
F P
0 g
s
.6217 .35582 m .61341 .36041 L .62161 .36644 L p .741 .829 .919 r
F P
0 g
s
.62161 .36644 m .62995 .36172 L .6217 .35582 L p .741 .829 .919 r
F P
0 g
s
.48971 .13311 m .48753 .12021 L .47791 .12159 L p .386 .393 .744 r
F P
0 g
s
.42216 .07248 m .44918 .08601 L .45177 .07574 L p .531 .613 .88 r
F P
0 g
s
.25675 .6669 m .26316 .69266 L .27321 .69047 L p .902 .67 .577 r
F P
0 g
s
.74327 .71227 m .73302 .73396 L .74292 .73728 L p .441 .257 .534 r
F P
0 g
s
.19466 .30191 m .17265 .31363 L .17742 .32279 L p .798 .827 .874 r
F P
0 g
s
.09591 .40423 m .11606 .37564 L .10641 .37104 L p .857 .827 .817 r
F P
0 g
s
.58394 .61903 m .59098 .62576 L .59489 .61695 L p .41 .483 .825 r
F P
0 g
s
.63152 .65727 m .62392 .64809 L .61413 .65036 L p .441 .539 .861 r
F P
0 g
s
.93391 .38494 m .9099 .35746 L .90768 .36538 L p .887 .56 .423 r
F P
0 g
s
.90768 .36538 m .92969 .39164 L .93391 .38494 L p .887 .56 .423 r
F P
0 g
s
.67683 .40276 m .68305 .40324 L .68827 .39432 L p .585 .238 .347 r
F P
0 g
s
.52609 .30465 m .51529 .31383 L .52435 .31703 L p .474 .175 .377 r
F P
0 g
s
.52435 .31703 m .53484 .30857 L .52609 .30465 L p .474 .175 .377 r
F P
0 g
s
.45104 .60115 m .45769 .61451 L .46716 .61325 L p .383 .456 .812 r
F P
0 g
s
.4752 .62431 m .46716 .61325 L .45769 .61451 L p .406 .503 .845 r
F P
0 g
s
.63358 .31927 m .62662 .32239 L .637 .3269 L p .567 .192 .291 r
F P
0 g
s
.637 .3269 m .64367 .32434 L .63358 .31927 L p .567 .192 .291 r
F P
0 g
s
.5969 .34856 m .6048 .34445 L .60444 .33463 L p .455 .177 .403 r
F P
0 g
s
.51162 .10858 m .50496 .09227 L .49942 .09881 L p .934 .708 .572 r
F P
0 g
s
.49942 .09881 m .50445 .11368 L .51162 .10858 L p .934 .708 .572 r
F P
0 g
s
.46528 .05362 m .43183 .03765 L .42782 .04433 L p .754 .369 .324 r
F P
0 g
s
.39251 .03528 m .42782 .04433 L .43183 .03765 L p .694 .301 .298 r
F P
0 g
s
.23907 .70237 m .2483 .72932 L .25479 .72491 L p .32 .331 .715 r
F P
0 g
s
.25479 .72491 m .24603 .69863 L .23907 .70237 L p .32 .331 .715 r
F P
0 g
s
.76561 .74966 m .77705 .72513 L .77031 .72121 L p .931 .858 .747 r
F P
0 g
s
.77941 .69603 m .77031 .72121 L .77705 .72513 L p .939 .843 .721 r
F P
0 g
s
.15724 .2928 m .13465 .30784 L .14055 .31287 L p .469 .154 .349 r
F P
0 g
s
.14055 .31287 m .16252 .29858 L .15724 .2928 L p .469 .154 .349 r
F P
0 g
s
.08655 .35473 m .06368 .38787 L .06947 .39279 L p .342 .134 .445 r
F P
0 g
s
.05257 .42748 m .06947 .39279 L .06368 .38787 L p .315 .146 .486 r
F P
0 g
s
.59614 .29358 m .58379 .29235 L .58608 .31029 L p .762 .624 .707 r
F P
0 g
s
.58608 .31029 m .59538 .31163 L .59614 .29358 L p .762 .624 .707 r
F P
0 g
s
.50657 .64802 m .51867 .65239 L .52346 .63496 L p .752 .631 .725 r
F P
0 g
s
.52346 .63496 m .51367 .63138 L .50657 .64802 L p .752 .631 .725 r
F P
0 g
s
.65361 .68622 m .66063 .69605 L .67555 .68586 L p .731 .625 .74 r
F P
0 g
s
.67555 .68586 m .66825 .6756 L .65361 .68622 L p .731 .625 .74 r
F P
0 g
s
.50707 .20159 m .50841 .1825 L .49033 .18209 L p .705 .599 .736 r
F P
0 g
s
.49033 .18209 m .48903 .20041 L .50707 .20159 L p .705 .599 .736 r
F P
0 g
s
.27056 .27358 m .29706 .26377 L .29068 .24686 L p .725 .586 .7 r
F P
0 g
s
.29068 .24686 m .26454 .25652 L .27056 .27358 L p .725 .586 .7 r
F P
0 g
s
.79537 .61388 m .79935 .5865 L .78175 .58239 L p .71 .565 .689 r
F P
0 g
s
.78175 .58239 m .77748 .61119 L .79537 .61388 L p .71 .565 .689 r
F P
0 g
s
.22523 .55549 m .22866 .58432 L .24665 .58248 L p .705 .561 .689 r
F P
0 g
s
.24665 .58248 m .24317 .55325 L .22523 .55549 L p .705 .561 .689 r
F P
0 g
s
.03538 .53408 m .04102 .5687 L .05829 .56335 L p .709 .593 .723 r
F P
0 g
s
.05829 .56335 m .05329 .53152 L .03538 .53408 L p .709 .593 .723 r
F P
0 g
s
.28265 .04396 m .24807 .05904 L .25763 .07438 L p .693 .57 .713 r
F P
0 g
s
.25763 .07438 m .28957 .06068 L .28265 .04396 L p .693 .57 .713 r
F P
0 g
s
.9588 .56898 m .96476 .5309 L .94668 .5314 L p .705 .588 .722 r
F P
0 g
s
.94668 .5314 m .94091 .56639 L .9588 .56898 L p .705 .588 .722 r
F P
0 g
s
.66817 .33829 m .67214 .33945 L .67146 .32139 L p .83 .673 .689 r
F P
0 g
s
.67146 .32139 m .66489 .3205 L .66817 .33829 L p .83 .673 .689 r
F P
0 g
s
.66501 .3998 m .66028 .39727 L .65177 .41323 L p .64 .504 .681 r
F P
0 g
s
.65177 .41323 m .65896 .41686 L .66501 .3998 L p .64 .504 .681 r
F P
0 g
s
.58149 .35519 m .57445 .35706 L .57838 .37471 L p .649 .545 .724 r
F P
0 g
s
.57838 .37471 m .58731 .37233 L .58149 .35519 L p .649 .545 .724 r
F P
0 g
s
.55441 .5907 m .56297 .59419 L .572 .57851 L p .661 .523 .685 r
F P
0 g
s
.572 .57851 m .56194 .57426 L .55441 .5907 L p .661 .523 .685 r
F P
0 g
s
.62097 .61799 m .62952 .62705 L .63323 .61761 L p .88 .577 .47 r
F P
0 g
s
.63323 .61761 m .62446 .60846 L .62097 .61799 L p .88 .577 .47 r
F P
0 g
s
.7001 .4198 m .69197 .42097 L .69832 .42937 L p .643 .767 .939 r
F P
0 g
s
.69832 .42937 m .70696 .4277 L .7001 .4198 L p .643 .767 .939 r
F P
0 g
s
.48366 .58552 m .47988 .57516 L .47253 .5821 L p .929 .713 .588 r
F P
0 g
s
.62977 .35128 m .6217 .35582 L .62995 .36172 L p .737 .828 .921 r
F P
0 g
s
.62995 .36172 m .63796 .35725 L .62977 .35128 L p .737 .828 .921 r
F P
0 g
s
.44918 .08601 m .47088 .105 L .47559 .09573 L p .472 .536 .842 r
F P
0 g
s
.73302 .73396 m .72083 .75447 L .73044 .75871 L p .455 .252 .514 r
F P
0 g
s
.11606 .37564 m .14033 .35014 L .13147 .34429 L p .833 .831 .845 r
F P
0 g
s
.62392 .64809 m .61606 .63924 L .60641 .64188 L p .449 .551 .868 r
F P
0 g
s
.68305 .40324 m .6897 .40296 L .69379 .39348 L p .555 .22 .357 r
F P
0 g
s
.44592 .58767 m .45104 .60115 L .46061 .60101 L p .37 .422 .785 r
F P
0 g
s
.46716 .61325 m .46061 .60101 L .45104 .60115 L p .383 .456 .812 r
F P
0 g
s
.62041 .32559 m .61222 .33019 L .61281 .33999 L p .447 .173 .404 r
F P
0 g
s
.6048 .34445 m .61281 .33999 L .61222 .33019 L p .449 .176 .406 r
F P
0 g
s
.4944 .07748 m .46528 .05362 L .45985 .05948 L p .822 .461 .373 r
F P
0 g
s
.42782 .04433 m .45985 .05948 L .46528 .05362 L p .754 .369 .324 r
F P
0 g
s
.75182 .77319 m .76561 .74966 L .75928 .74516 L p .919 .872 .775 r
F P
0 g
s
.77031 .72121 m .75928 .74516 L .76561 .74966 L p .931 .858 .747 r
F P
0 g
s
.11415 .32513 m .08655 .35473 L .0916 .36054 L p .376 .131 .41 r
F P
0 g
s
.06947 .39279 m .0916 .36054 L .08655 .35473 L p .342 .134 .445 r
F P
0 g
s
.59988 .5969 m .60802 .60441 L .61714 .60078 L p .812 .471 .41 r
F P
0 g
s
.62446 .60846 m .61714 .60078 L .60802 .60441 L p .821 .481 .413 r
F P
0 g
s
.91592 .40344 m .89749 .38041 L .88961 .3874 L p .477 .529 .832 r
F P
0 g
s
.5466 .32239 m .53729 .32977 L .54106 .33921 L p .862 .858 .836 r
F P
0 g
s
.65115 .34086 m .64544 .34296 L .64345 .35441 L p .834 .883 .878 r
F P
0 g
s
.48753 .12021 m .48436 .10895 L .47495 .11247 L p .41 .443 .783 r
F P
0 g
s
.26316 .69266 m .27125 .71724 L .28109 .71406 L p .895 .649 .559 r
F P
0 g
s
.17265 .31363 m .15235 .32667 L .15816 .33532 L p .816 .83 .86 r
F P
0 g
s
.59098 .62576 m .59832 .6335 L .60785 .63055 L p .419 .487 .824 r
F P
0 g
s
.9099 .35746 m .87912 .3374 L .87814 .34561 L p .82 .458 .37 r
F P
0 g
s
.87814 .34561 m .90768 .36538 L .9099 .35746 L p .82 .458 .37 r
F P
0 g
s
.51529 .31383 m .50647 .32268 L .5129 .32855 L p .451 .176 .404 r
F P
0 g
s
.5129 .32855 m .52435 .31703 L .51529 .31383 L p .451 .176 .404 r
F P
0 g
s
.62662 .32239 m .62041 .32559 L .62096 .33539 L p .538 .219 .374 r
F P
0 g
s
.50496 .09227 m .4944 .07748 L .4874 .08192 L p .9 .609 .484 r
F P
0 g
s
.4874 .08192 m .49942 .09881 L .50496 .09227 L p .9 .609 .484 r
F P
0 g
s
.2483 .72932 m .25998 .75489 L .26693 .75154 L p .329 .365 .747 r
F P
0 g
s
.26693 .75154 m .25479 .72491 L .2483 .72932 L p .329 .365 .747 r
F P
0 g
s
.13465 .30784 m .11415 .32513 L .11833 .33174 L p .431 .141 .37 r
F P
0 g
s
.57659 .31052 m .58608 .31029 L .58379 .29235 L p .761 .616 .698 r
F P
0 g
s
.58379 .29235 m .5712 .29324 L .57659 .31052 L p .761 .616 .698 r
F P
0 g
s
.49521 .64195 m .50657 .64802 L .51367 .63138 L p .75 .634 .733 r
F P
0 g
s
.51367 .63138 m .50468 .62653 L .49521 .64195 L p .75 .634 .733 r
F P
0 g
s
.64635 .67637 m .65361 .68622 L .66825 .6756 L p .731 .625 .74 r
F P
0 g
s
.66825 .6756 m .66088 .66558 L .64635 .67637 L p .731 .625 .74 r
F P
0 g
s
.50841 .1825 m .50899 .1634 L .4909 .1641 L p .706 .601 .736 r
F P
0 g
s
.4909 .1641 m .49033 .18209 L .50841 .1825 L p .706 .601 .736 r
F P
0 g
s
.24376 .28281 m .27056 .27358 L .26454 .25652 L p .725 .587 .701 r
F P
0 g
s
.26454 .25652 m .23752 .26582 L .24376 .28281 L p .725 .587 .701 r
F P
0 g
s
.79127 .64206 m .79537 .61388 L .77748 .61119 L p .71 .564 .688 r
F P
0 g
s
.77748 .61119 m .77338 .6393 L .79127 .64206 L p .71 .564 .688 r
F P
0 g
s
.22866 .58432 m .23145 .61392 L .24944 .6119 L p .705 .561 .689 r
F P
0 g
s
.24944 .6119 m .24665 .58248 L .22866 .58432 L p .705 .561 .689 r
F P
0 g
s
.03546 .49897 m .03538 .53408 L .05329 .53152 L p .707 .591 .724 r
F P
0 g
s
.05329 .53152 m .05356 .49938 L .03546 .49897 L p .707 .591 .724 r
F P
0 g
s
.31898 .03522 m .28265 .04396 L .28957 .06068 L p .692 .567 .71 r
F P
0 g
s
.28957 .06068 m .32287 .0529 L .31898 .03522 L p .692 .567 .71 r
F P
0 g
s
.94643 .49663 m .94668 .5314 L .96476 .5309 L p .707 .59 .722 r
F P
0 g
s
.96476 .5309 m .96417 .49303 L .94643 .49663 L p .707 .59 .722 r
F P
0 g
s
.66243 .33879 m .66817 .33829 L .66489 .3205 L p .808 .643 .678 r
F P
0 g
s
.66489 .3205 m .65797 .32124 L .66243 .33879 L p .808 .643 .678 r
F P
0 g
s
.67004 .4016 m .66501 .3998 L .65896 .41686 L p .638 .51 .691 r
F P
0 g
s
.65896 .41686 m .66662 .41938 L .67004 .4016 L p .638 .51 .691 r
F P
0 g
s
.58839 .35257 m .58149 .35519 L .58731 .37233 L p .65 .551 .729 r
F P
0 g
s
.58731 .37233 m .59575 .36912 L .58839 .35257 L p .65 .551 .729 r
F P
0 g
s
.5817 .58375 m .572 .57851 L .56297 .59419 L p .663 .521 .681 r
F P
0 g
s
.56297 .59419 m .57135 .59862 L .5817 .58375 L p .663 .521 .681 r
F P
0 g
s
.60802 .60441 m .62097 .61799 L .62446 .60846 L p .821 .481 .413 r
F P
0 g
s
.89749 .38041 m .87317 .36309 L .86921 .37221 L p .522 .603 .876 r
F P
0 g
s
.79544 .38617 m .78455 .39157 L .78722 .40008 L p .774 .843 .905 r
F P
0 g
s
.78722 .40008 m .79829 .39461 L .79544 .38617 L p .774 .843 .905 r
F P
0 g
s
.78455 .39157 m .77358 .39665 L .77614 .40521 L p .767 .84 .907 r
F P
0 g
s
.77614 .40521 m .78722 .40008 L .78455 .39157 L p .767 .84 .907 r
F P
0 g
s
.77358 .39665 m .76242 .40156 L .76475 .41022 L p .762 .837 .909 r
F P
0 g
s
.76475 .41022 m .77614 .40521 L .77358 .39665 L p .762 .837 .909 r
F P
0 g
s
.76242 .40156 m .75113 .40607 L .75323 .41482 L p .753 .832 .913 r
F P
0 g
s
.75323 .41482 m .76475 .41022 L .76242 .40156 L p .753 .832 .913 r
F P
0 g
s
.75113 .40607 m .73998 .41012 L .7417 .419 L p .744 .827 .916 r
F P
0 g
s
.7417 .419 m .75323 .41482 L .75113 .40607 L p .744 .827 .916 r
F P
0 g
s
.73998 .41012 m .72859 .41361 L .72984 .42262 L p .73 .819 .92 r
F P
0 g
s
.72984 .42262 m .7417 .419 L .73998 .41012 L p .73 .819 .92 r
F P
0 g
s
.72859 .41361 m .71715 .41641 L .71805 .4255 L p .715 .809 .923 r
F P
0 g
s
.71805 .4255 m .72984 .42262 L .72859 .41361 L p .715 .809 .923 r
F P
0 g
s
.71715 .41641 m .7001 .4198 L .70696 .4277 L p .703 .8 .925 r
F P
0 g
s
.70696 .4277 m .71805 .4255 L .71715 .41641 L p .703 .8 .925 r
F P
0 g
s
.53729 .32977 m .5257 .34145 L .53197 .34838 L p .875 .855 .819 r
F P
0 g
s
.5257 .34145 m .51467 .35235 L .52145 .35874 L p .845 .85 .848 r
F P
0 g
s
.52145 .35874 m .53197 .34838 L .5257 .34145 L p .845 .85 .848 r
F P
0 g
s
.51467 .35235 m .50469 .36378 L .51208 .3694 L p .859 .85 .833 r
F P
0 g
s
.47897 .4196 m .47569 .43645 L .48469 .43819 L p .924 .798 .703 r
F P
0 g
s
.47569 .43645 m .4724 .45432 L .48122 .45685 L p .925 .797 .7 r
F P
0 g
s
.4724 .45432 m .46767 .47101 L .47654 .47336 L p .919 .813 .726 r
F P
0 g
s
.47654 .47336 m .48122 .45685 L .4724 .45432 L p .919 .813 .726 r
F P
0 g
s
.46767 .47101 m .4633 .48721 L .47233 .48883 L p .92 .811 .723 r
F P
0 g
s
.47233 .48883 m .47654 .47336 L .46767 .47101 L p .92 .811 .723 r
F P
0 g
s
.4633 .48721 m .46021 .50309 L .46938 .50373 L p .924 .799 .704 r
F P
0 g
s
.46938 .50373 m .47233 .48883 L .4633 .48721 L p .924 .799 .704 r
F P
0 g
s
.46021 .50309 m .45877 .5189 L .46797 .51836 L p .928 .779 .676 r
F P
0 g
s
.46797 .51836 m .46938 .50373 L .46021 .50309 L p .928 .779 .676 r
F P
0 g
s
.45877 .5189 m .45927 .53379 L .46836 .53207 L p .929 .752 .642 r
F P
0 g
s
.46836 .53207 m .46797 .51836 L .45877 .5189 L p .929 .752 .642 r
F P
0 g
s
.45927 .53379 m .46165 .54868 L .47053 .54597 L p .925 .72 .607 r
F P
0 g
s
.47053 .54597 m .46836 .53207 L .45927 .53379 L p .925 .72 .607 r
F P
0 g
s
.46165 .54868 m .4657 .56352 L .47433 .56003 L p .918 .691 .578 r
F P
0 g
s
.47433 .56003 m .47053 .54597 L .46165 .54868 L p .918 .691 .578 r
F P
0 g
s
.4657 .56352 m .47253 .5821 L .47988 .57516 L p .911 .666 .555 r
F P
0 g
s
.47988 .57516 m .47433 .56003 L .4657 .56352 L p .911 .666 .555 r
F P
0 g
s
.64544 .34296 m .62977 .35128 L .63796 .35725 L p .843 .881 .869 r
F P
0 g
s
.48436 .10895 m .47559 .09573 L .47088 .105 L p .452 .513 .831 r
F P
0 g
s
.27125 .71724 m .28273 .74257 L .29146 .73702 L p .883 .621 .537 r
F P
0 g
s
.28273 .74257 m .30073 .77442 L .30874 .76776 L p .881 .618 .536 r
F P
0 g
s
.30874 .76776 m .29146 .73702 L .28273 .74257 L p .881 .618 .536 r
F P
0 g
s
.30073 .77442 m .32256 .80348 L .32968 .79578 L p .862 .581 .51 r
F P
0 g
s
.32968 .79578 m .30874 .76776 L .30073 .77442 L p .862 .581 .51 r
F P
0 g
s
.32256 .80348 m .34756 .82881 L .35356 .82012 L p .84 .543 .487 r
F P
0 g
s
.35356 .82012 m .32968 .79578 L .32256 .80348 L p .84 .543 .487 r
F P
0 g
s
.34756 .82881 m .37635 .85025 L .38134 .84089 L p .811 .5 .463 r
F P
0 g
s
.38134 .84089 m .35356 .82012 L .34756 .82881 L p .811 .5 .463 r
F P
0 g
s
.37635 .85025 m .4047 .86662 L .40829 .85658 L p .787 .468 .449 r
F P
0 g
s
.40829 .85658 m .38134 .84089 L .37635 .85025 L p .787 .468 .449 r
F P
0 g
s
.4047 .86662 m .43524 .87834 L .4374 .86787 L p .752 .426 .433 r
F P
0 g
s
.4374 .86787 m .40829 .85658 L .4047 .86662 L p .752 .426 .433 r
F P
0 g
s
.43524 .87834 m .46746 .88539 L .46825 .87471 L p .716 .389 .423 r
F P
0 g
s
.46825 .87471 m .4374 .86787 L .43524 .87834 L p .716 .389 .423 r
F P
0 g
s
.46746 .88539 m .50122 .88787 L .50125 .87716 L p .681 .357 .419 r
F P
0 g
s
.50122 .88787 m .53434 .88807 L .53297 .87744 L p .665 .343 .418 r
F P
0 g
s
.53297 .87744 m .50125 .87716 L .50122 .88787 L p .665 .343 .418 r
F P
0 g
s
.53434 .88807 m .56685 .8837 L .56403 .87338 L p .631 .317 .42 r
F P
0 g
s
.56685 .8837 m .59811 .8746 L .59382 .86482 L p .595 .294 .427 r
F P
0 g
s
.59811 .8746 m .62786 .86047 L .62248 .85129 L p .558 .274 .441 r
F P
0 g
s
.62786 .86047 m .6577 .84154 L .65112 .83325 L p .531 .263 .454 r
F P
0 g
s
.6577 .84154 m .68449 .81824 L .67696 .81089 L p .5 .255 .475 r
F P
0 g
s
.68449 .81824 m .70849 .79095 L .7002 .78456 L p .475 .253 .497 r
F P
0 g
s
.15235 .32667 m .13147 .34429 L .14033 .35014 L p .838 .831 .84 r
F P
0 g
s
.61606 .63924 m .60785 .63055 L .59832 .6335 L p .454 .561 .874 r
F P
0 g
s
.87912 .3374 m .86625 .33432 L .86746 .34287 L p .713 .339 .339 r
F P
0 g
s
.86746 .34287 m .87814 .34561 L .87912 .3374 L p .713 .339 .339 r
F P
0 g
s
.86625 .33432 m .85432 .33423 L .85696 .3427 L p .646 .284 .344 r
F P
0 g
s
.85696 .3427 m .86746 .34287 L .86625 .33432 L p .646 .284 .344 r
F P
0 g
s
.85432 .33423 m .84208 .3361 L .84597 .3443 L p .602 .257 .356 r
F P
0 g
s
.84597 .3443 m .85696 .3427 L .85432 .33423 L p .602 .257 .356 r
F P
0 g
s
.84208 .3361 m .83154 .33918 L .83591 .34723 L p .567 .239 .372 r
F P
0 g
s
.83591 .34723 m .84597 .3443 L .84208 .3361 L p .567 .239 .372 r
F P
0 g
s
.83154 .33918 m .81804 .34406 L .82302 .35185 L p .552 .233 .381 r
F P
0 g
s
.82302 .35185 m .83591 .34723 L .83154 .33918 L p .552 .233 .381 r
F P
0 g
s
.81804 .34406 m .80519 .34985 L .81063 .35742 L p .534 .227 .393 r
F P
0 g
s
.81063 .35742 m .82302 .35185 L .81804 .34406 L p .534 .227 .393 r
F P
0 g
s
.80519 .34985 m .79318 .35615 L .79871 .36367 L p .52 .223 .403 r
F P
0 g
s
.79871 .36367 m .81063 .35742 L .80519 .34985 L p .52 .223 .403 r
F P
0 g
s
.79318 .35615 m .78222 .36217 L .78737 .36989 L p .516 .223 .406 r
F P
0 g
s
.78737 .36989 m .79871 .36367 L .79318 .35615 L p .516 .223 .406 r
F P
0 g
s
.78222 .36217 m .77201 .36724 L .77691 .37508 L p .525 .225 .399 r
F P
0 g
s
.77691 .37508 m .78737 .36989 L .78222 .36217 L p .525 .225 .399 r
F P
0 g
s
.77201 .36724 m .76155 .37209 L .76625 .38002 L p .531 .226 .395 r
F P
0 g
s
.76625 .38002 m .77691 .37508 L .77201 .36724 L p .531 .226 .395 r
F P
0 g
s
.76155 .37209 m .75129 .37662 L .75567 .38468 L p .536 .228 .392 r
F P
0 g
s
.75567 .38468 m .76625 .38002 L .76155 .37209 L p .536 .228 .392 r
F P
0 g
s
.75129 .37662 m .74085 .38081 L .74491 .38899 L p .544 .231 .387 r
F P
0 g
s
.74491 .38899 m .75567 .38468 L .75129 .37662 L p .544 .231 .387 r
F P
0 g
s
.74085 .38081 m .73103 .3844 L .73463 .39275 L p .551 .234 .383 r
F P
0 g
s
.73463 .39275 m .74491 .38899 L .74085 .38081 L p .551 .234 .383 r
F P
0 g
s
.73103 .3844 m .7212 .38747 L .72425 .39597 L p .564 .239 .377 r
F P
0 g
s
.72425 .39597 m .73463 .39275 L .73103 .3844 L p .564 .239 .377 r
F P
0 g
s
.7212 .38747 m .71102 .38999 L .71362 .39859 L p .579 .247 .37 r
F P
0 g
s
.71362 .39859 m .72425 .39597 L .7212 .38747 L p .579 .247 .37 r
F P
0 g
s
.71102 .38999 m .69989 .3922 L .69655 .40199 L p .58 .247 .369 r
F P
0 g
s
.6897 .40296 m .69655 .40199 L .69989 .3922 L p .53 .206 .363 r
F P
0 g
s
.50647 .32268 m .4941 .33502 L .50094 .34044 L p .437 .187 .436 r
F P
0 g
s
.50094 .34044 m .5129 .32855 L .50647 .32268 L p .437 .187 .436 r
F P
0 g
s
.4941 .33502 m .48245 .34861 L .48982 .35335 L p .423 .189 .453 r
F P
0 g
s
.48982 .35335 m .50094 .34044 L .4941 .33502 L p .423 .189 .453 r
F P
0 g
s
.48245 .34861 m .47215 .36351 L .48005 .36738 L p .405 .195 .478 r
F P
0 g
s
.48005 .36738 m .48982 .35335 L .48245 .34861 L p .405 .195 .478 r
F P
0 g
s
.47215 .36351 m .46371 .3796 L .47205 .3825 L p .388 .206 .509 r
F P
0 g
s
.47205 .3825 m .48005 .36738 L .47215 .36351 L p .388 .206 .509 r
F P
0 g
s
.46371 .3796 m .45712 .39703 L .46572 .39912 L p .375 .222 .542 r
F P
0 g
s
.46572 .39912 m .47205 .3825 L .46371 .3796 L p .375 .222 .542 r
F P
0 g
s
.45712 .39703 m .45241 .41461 L .46114 .41613 L p .367 .238 .57 r
F P
0 g
s
.46114 .41613 m .46572 .39912 L .45712 .39703 L p .367 .238 .57 r
F P
0 g
s
.45241 .41461 m .44907 .43173 L .45781 .4332 L p .362 .251 .59 r
F P
0 g
s
.45781 .4332 m .46114 .41613 L .45241 .41461 L p .362 .251 .59 r
F P
0 g
s
.44907 .43173 m .44639 .44698 L .45492 .44937 L p .362 .254 .595 r
F P
0 g
s
.45492 .44937 m .45781 .4332 L .44907 .43173 L p .362 .254 .595 r
F P
0 g
s
.44639 .44698 m .44158 .46396 L .45013 .4663 L p .368 .236 .567 r
F P
0 g
s
.45013 .4663 m .45492 .44937 L .44639 .44698 L p .368 .236 .567 r
F P
0 g
s
.44158 .46396 m .43677 .48203 L .44545 .48379 L p .367 .239 .571 r
F P
0 g
s
.44545 .48379 m .45013 .4663 L .44158 .46396 L p .367 .239 .571 r
F P
0 g
s
.43677 .48203 m .43332 .5006 L .44211 .50152 L p .362 .252 .592 r
F P
0 g
s
.44211 .50152 m .44545 .48379 L .43677 .48203 L p .362 .252 .592 r
F P
0 g
s
.43332 .5006 m .4318 .51975 L .44061 .5196 L p .357 .272 .621 r
F P
0 g
s
.44061 .5196 m .44211 .50152 L .43332 .5006 L p .357 .272 .621 r
F P
0 g
s
.4318 .51975 m .43264 .53792 L .44134 .53672 L p .355 .3 .657 r
F P
0 g
s
.44134 .53672 m .44061 .5196 L .4318 .51975 L p .355 .3 .657 r
F P
0 g
s
.43264 .53792 m .43563 .55557 L .44413 .5535 L p .358 .331 .692 r
F P
0 g
s
.44413 .5535 m .44134 .53672 L .43264 .53792 L p .358 .331 .692 r
F P
0 g
s
.43563 .55557 m .44035 .57249 L .44864 .56977 L p .363 .36 .722 r
F P
0 g
s
.44864 .56977 m .44413 .5535 L .43563 .55557 L p .363 .36 .722 r
F P
0 g
s
.44035 .57249 m .44592 .58767 L .45548 .58838 L p .371 .388 .748 r
F P
0 g
s
.46061 .60101 m .45548 .58838 L .44592 .58767 L p .37 .422 .785 r
F P
0 g
s
.61281 .33999 m .62096 .33539 L .62041 .32559 L p .447 .173 .404 r
F P
0 g
s
.45985 .05948 m .4874 .08192 L .4944 .07748 L p .822 .461 .373 r
F P
0 g
s
.25998 .75489 m .27985 .78957 L .28623 .78537 L p .348 .415 .789 r
F P
0 g
s
.28623 .78537 m .26693 .75154 L .25998 .75489 L p .348 .415 .789 r
F P
0 g
s
.27985 .78957 m .304 .82129 L .30966 .81629 L p .368 .461 .824 r
F P
0 g
s
.30966 .81629 m .28623 .78537 L .27985 .78957 L p .368 .461 .824 r
F P
0 g
s
.304 .82129 m .33199 .84919 L .33673 .84341 L p .394 .511 .858 r
F P
0 g
s
.33673 .84341 m .30966 .81629 L .304 .82129 L p .394 .511 .858 r
F P
0 g
s
.33199 .84919 m .36334 .8723 L .36732 .86602 L p .428 .567 .891 r
F P
0 g
s
.36732 .86602 m .33673 .84341 L .33199 .84919 L p .428 .567 .891 r
F P
0 g
s
.36334 .8723 m .39542 .89042 L .39824 .8836 L p .459 .611 .913 r
F P
0 g
s
.39824 .8836 m .36732 .86602 L .36334 .8723 L p .459 .611 .913 r
F P
0 g
s
.39542 .89042 m .42976 .90325 L .4314 .8961 L p .505 .668 .936 r
F P
0 g
s
.4314 .8961 m .39824 .8836 L .39542 .89042 L p .505 .668 .936 r
F P
0 g
s
.42976 .90325 m .46562 .91081 L .46614 .90351 L p .552 .719 .951 r
F P
0 g
s
.46614 .90351 m .4314 .8961 L .42976 .90325 L p .552 .719 .951 r
F P
0 g
s
.46562 .91081 m .50112 .91336 L .50116 .90604 L p .598 .762 .957 r
F P
0 g
s
.50116 .90604 m .46614 .90351 L .46562 .91081 L p .598 .762 .957 r
F P
0 g
s
.50112 .91336 m .5379 .9133 L .53681 .90607 L p .622 .782 .958 r
F P
0 g
s
.53681 .90607 m .50116 .90604 L .50112 .91336 L p .622 .782 .958 r
F P
0 g
s
.5379 .9133 m .57427 .9081 L .57199 .90113 L p .669 .818 .955 r
F P
0 g
s
.57199 .90113 m .53681 .90607 L .5379 .9133 L p .669 .818 .955 r
F P
0 g
s
.57427 .9081 m .60941 .89749 L .60593 .89099 L p .718 .849 .944 r
F P
0 g
s
.60593 .89099 m .57199 .90113 L .57427 .9081 L p .718 .849 .944 r
F P
0 g
s
.60941 .89749 m .64196 .8818 L .63764 .87579 L p .768 .873 .925 r
F P
0 g
s
.63764 .87579 m .60593 .89099 L .60941 .89749 L p .768 .873 .925 r
F P
0 g
s
.64196 .8818 m .67494 .86051 L .66965 .85523 L p .804 .885 .904 r
F P
0 g
s
.66965 .85523 m .63764 .87579 L .64196 .8818 L p .804 .885 .904 r
F P
0 g
s
.67494 .86051 m .70418 .83475 L .69816 .83021 L p .843 .892 .874 r
F P
0 g
s
.69816 .83021 m .66965 .85523 L .67494 .86051 L p .843 .892 .874 r
F P
0 g
s
.70418 .83475 m .73007 .80501 L .72349 .80121 L p .874 .89 .842 r
F P
0 g
s
.72349 .80121 m .69816 .83021 L .70418 .83475 L p .874 .89 .842 r
F P
0 g
s
.73007 .80501 m .75182 .77319 L .74599 .76811 L p .898 .883 .81 r
F P
0 g
s
.75928 .74516 m .74599 .76811 L .75182 .77319 L p .919 .872 .775 r
F P
0 g
s
.0916 .36054 m .11833 .33174 L .11415 .32513 L p .376 .131 .41 r
F P
0 g
s
.56659 .31297 m .57659 .31052 L .5712 .29324 L p .756 .605 .689 r
F P
0 g
s
.5712 .29324 m .55909 .29648 L .56659 .31297 L p .756 .605 .689 r
F P
0 g
s
.4848 .6341 m .49521 .64195 L .50468 .62653 L p .745 .637 .74 r
F P
0 g
s
.50468 .62653 m .49663 .62038 L .4848 .6341 L p .745 .637 .74 r
F P
0 g
s
.63895 .6667 m .64635 .67637 L .66088 .66558 L p .732 .625 .74 r
F P
0 g
s
.66088 .66558 m .65328 .65562 L .63895 .6667 L p .732 .625 .74 r
F P
0 g
s
.49041 .14667 m .4909 .1641 L .50899 .1634 L p .708 .602 .736 r
F P
0 g
s
.50899 .1634 m .50845 .14507 L .49041 .14667 L p .708 .602 .736 r
F P
0 g
s
.21767 .29202 m .24376 .28281 L .23752 .26582 L p .725 .586 .7 r
F P
0 g
s
.23752 .26582 m .21025 .27549 L .21767 .29202 L p .725 .586 .7 r
F P
0 g
s
.78618 .67031 m .79127 .64206 L .77338 .6393 L p .71 .565 .688 r
F P
0 g
s
.77338 .6393 m .76839 .66691 L .78618 .67031 L p .71 .565 .688 r
F P
0 g
s
.23145 .61392 m .23451 .64392 L .25233 .64066 L p .705 .56 .688 r
F P
0 g
s
.25233 .64066 m .24944 .6119 L .23145 .61392 L p .705 .56 .688 r
F P
0 g
s
.04142 .46423 m .03546 .49897 L .05356 .49938 L p .704 .588 .723 r
F P
0 g
s
.05356 .49938 m .05921 .46764 L .04142 .46423 L p .704 .588 .723 r
F P
0 g
s
.35645 .03302 m .31898 .03522 L .32287 .0529 L p .691 .565 .708 r
F P
0 g
s
.32287 .0529 m .35717 .05112 L .35645 .03302 L p .691 .565 .708 r
F P
0 g
s
.96417 .49303 m .95718 .45634 L .93996 .46197 L p .71 .592 .722 r
F P
0 g
s
.93996 .46197 m .94643 .49663 L .96417 .49303 L p .71 .592 .722 r
F P
0 g
s
.65797 .32124 m .65072 .3224 L .65684 .33946 L p .793 .628 .677 r
F P
0 g
s
.65684 .33946 m .66243 .33879 L .65797 .32124 L p .793 .628 .677 r
F P
0 g
s
.67683 .40276 m .67004 .4016 L .66662 .41938 L p .638 .515 .697 r
F P
0 g
s
.66662 .41938 m .67508 .4208 L .67683 .40276 L p .638 .515 .697 r
F P
0 g
s
.5969 .34856 m .58839 .35257 L .59575 .36912 L p .654 .555 .73 r
F P
0 g
s
.59575 .36912 m .6049 .36482 L .5969 .34856 L p .654 .555 .73 r
F P
0 g
s
.59113 .58994 m .5817 .58375 L .57135 .59862 L p .666 .522 .678 r
F P
0 g
s
.57135 .59862 m .57954 .60388 L .59113 .58994 L p .666 .522 .678 r
F P
0 g
s
.4752 .62431 m .4848 .6341 L .49663 .62038 L p .738 .632 .742 r
F P
0 g
s
.49663 .62038 m .48879 .61231 L .4752 .62431 L p .738 .632 .742 r
F P
0 g
s
.55634 .31683 m .56659 .31297 L .55909 .29648 L p .75 .596 .685 r
F P
0 g
s
.55909 .29648 m .54649 .30161 L .55634 .31683 L p .75 .596 .685 r
F P
0 g
s
.63152 .65727 m .63895 .6667 L .65328 .65562 L p .733 .626 .74 r
F P
0 g
s
.65328 .65562 m .64573 .64601 L .63152 .65727 L p .733 .626 .74 r
F P
0 g
s
.48971 .13311 m .49041 .14667 L .50845 .14507 L p .71 .611 .745 r
F P
0 g
s
.50845 .14507 m .50741 .12918 L .48971 .13311 L p .71 .611 .745 r
F P
0 g
s
.19466 .30191 m .21767 .29202 L .21025 .27549 L p .726 .586 .698 r
F P
0 g
s
.21025 .27549 m .18587 .28605 L .19466 .30191 L p .726 .586 .698 r
F P
0 g
s
.23451 .64392 m .23922 .67153 L .25675 .6669 L p .703 .558 .687 r
F P
0 g
s
.25675 .6669 m .25233 .64066 L .23451 .64392 L p .703 .558 .687 r
F P
0 g
s
.77941 .69603 m .78618 .67031 L .76839 .66691 L p .713 .565 .686 r
F P
0 g
s
.76839 .66691 m .76195 .69113 L .77941 .69603 L p .713 .565 .686 r
F P
0 g
s
.05257 .42748 m .04142 .46423 L .05921 .46764 L p .702 .585 .721 r
F P
0 g
s
.05921 .46764 m .06984 .433 L .05257 .42748 L p .702 .585 .721 r
F P
0 g
s
.93075 .4313 m .93996 .46197 L .95718 .45634 L p .712 .594 .723 r
F P
0 g
s
.95718 .45634 m .94654 .4224 L .93075 .4313 L p .712 .594 .723 r
F P
0 g
s
.39251 .03528 m .35645 .03302 L .35717 .05112 L p .691 .563 .706 r
F P
0 g
s
.35717 .05112 m .39111 .05335 L .39251 .03528 L p .691 .563 .706 r
F P
0 g
s
.65115 .34086 m .65684 .33946 L .65072 .3224 L p .789 .618 .669 r
F P
0 g
s
.65072 .3224 m .64367 .32434 L .65115 .34086 L p .789 .618 .669 r
F P
0 g
s
.68305 .40324 m .67683 .40276 L .67508 .4208 L p .64 .524 .706 r
F P
0 g
s
.67508 .4208 m .68343 .42138 L .68305 .40324 L p .64 .524 .706 r
F P
0 g
s
.6048 .34445 m .5969 .34856 L .6049 .36482 L p .656 .557 .731 r
F P
0 g
s
.6049 .36482 m .61341 .36041 L .6048 .34445 L p .656 .557 .731 r
F P
0 g
s
.59988 .5969 m .59113 .58994 L .57954 .60388 L p .668 .521 .675 r
F P
0 g
s
.57954 .60388 m .58737 .61004 L .59988 .5969 L p .668 .521 .675 r
F P
0 g
s
.54649 .30161 m .53484 .30857 L .5466 .32239 L p .746 .588 .679 r
F P
0 g
s
.5466 .32239 m .55634 .31683 L .54649 .30161 L p .746 .588 .679 r
F P
0 g
s
.62392 .64809 m .63152 .65727 L .64573 .64601 L p .734 .626 .739 r
F P
0 g
s
.64573 .64601 m .63781 .63642 L .62392 .64809 L p .734 .626 .739 r
F P
0 g
s
.46716 .61325 m .4752 .62431 L .48879 .61231 L p .732 .631 .747 r
F P
0 g
s
.48879 .61231 m .48238 .60338 L .46716 .61325 L p .732 .631 .747 r
F P
0 g
s
.50741 .12918 m .50445 .11368 L .48753 .12021 L p .715 .616 .745 r
F P
0 g
s
.48753 .12021 m .48971 .13311 L .50741 .12918 L p .715 .616 .745 r
F P
0 g
s
.18587 .28605 m .16252 .29858 L .17265 .31363 L p .726 .584 .696 r
F P
0 g
s
.17265 .31363 m .19466 .30191 L .18587 .28605 L p .726 .584 .696 r
F P
0 g
s
.77031 .72121 m .77941 .69603 L .76195 .69113 L p .714 .567 .687 r
F P
0 g
s
.76195 .69113 m .75336 .71475 L .77031 .72121 L p .714 .567 .687 r
F P
0 g
s
.23922 .67153 m .24603 .69863 L .26316 .69266 L p .702 .557 .687 r
F P
0 g
s
.26316 .69266 m .25675 .6669 L .23922 .67153 L p .702 .557 .687 r
F P
0 g
s
.94654 .4224 m .92969 .39164 L .91592 .40344 L p .715 .596 .722 r
F P
0 g
s
.91592 .40344 m .93075 .4313 L .94654 .4224 L p .715 .596 .722 r
F P
0 g
s
.42782 .04433 m .39251 .03528 L .39111 .05335 L p .691 .561 .703 r
F P
0 g
s
.39111 .05335 m .42297 .06181 L .42782 .04433 L p .691 .561 .703 r
F P
0 g
s
.06947 .39279 m .05257 .42748 L .06984 .433 L p .7 .583 .72 r
F P
0 g
s
.06984 .433 m .08565 .401 L .06947 .39279 L p .7 .583 .72 r
F P
0 g
s
.64367 .32434 m .637 .3269 L .64544 .34296 L p .782 .609 .665 r
F P
0 g
s
.64544 .34296 m .65115 .34086 L .64367 .32434 L p .782 .609 .665 r
F P
0 g
s
.6897 .40296 m .68305 .40324 L .68343 .42138 L p .641 .53 .712 r
F P
0 g
s
.68343 .42138 m .69197 .42097 L .6897 .40296 L p .641 .53 .712 r
F P
0 g
s
.61281 .33999 m .6048 .34445 L .61341 .36041 L p .655 .558 .733 r
F P
0 g
s
.61341 .36041 m .6217 .35582 L .61281 .33999 L p .655 .558 .733 r
F P
0 g
s
.60802 .60441 m .59988 .5969 L .58737 .61004 L p .67 .52 .672 r
F P
0 g
s
.58737 .61004 m .59489 .61695 L .60802 .60441 L p .67 .52 .672 r
F P
0 g
s
.61606 .63924 m .62392 .64809 L .63781 .63642 L p .735 .626 .738 r
F P
0 g
s
.63781 .63642 m .62952 .62705 L .61606 .63924 L p .735 .626 .738 r
F P
0 g
s
.46061 .60101 m .46716 .61325 L .48238 .60338 L p .726 .627 .748 r
F P
0 g
s
.48238 .60338 m .47698 .59317 L .46061 .60101 L p .726 .627 .748 r
F P
0 g
s
.53484 .30857 m .52435 .31703 L .53729 .32977 L p .74 .58 .676 r
F P
0 g
s
.53729 .32977 m .5466 .32239 L .53484 .30857 L p .74 .58 .676 r
F P
0 g
s
.50445 .11368 m .49942 .09881 L .48436 .10895 L p .722 .625 .749 r
F P
0 g
s
.48436 .10895 m .48753 .12021 L .50445 .11368 L p .722 .625 .749 r
F P
0 g
s
.16252 .29858 m .14055 .31287 L .15235 .32667 L p .725 .582 .694 r
F P
0 g
s
.15235 .32667 m .17265 .31363 L .16252 .29858 L p .725 .582 .694 r
F P
0 g
s
.75928 .74516 m .77031 .72121 L .75336 .71475 L p .716 .569 .687 r
F P
0 g
s
.75336 .71475 m .74292 .73728 L .75928 .74516 L p .716 .569 .687 r
F P
0 g
s
.24603 .69863 m .25479 .72491 L .27125 .71724 L p .7 .555 .687 r
F P
0 g
s
.27125 .71724 m .26316 .69266 L .24603 .69863 L p .7 .555 .687 r
F P
0 g
s
.92969 .39164 m .90768 .36538 L .89749 .38041 L p .719 .598 .721 r
F P
0 g
s
.89749 .38041 m .91592 .40344 L .92969 .39164 L p .719 .598 .721 r
F P
0 g
s
.45985 .05948 m .42782 .04433 L .42297 .06181 L p .692 .559 .699 r
F P
0 g
s
.42297 .06181 m .45177 .07574 L .45985 .05948 L p .692 .559 .699 r
F P
0 g
s
.0916 .36054 m .06947 .39279 L .08565 .401 L p .698 .58 .719 r
F P
0 g
s
.08565 .401 m .10641 .37104 L .0916 .36054 L p .698 .58 .719 r
F P
0 g
s
.637 .3269 m .62096 .33539 L .62977 .35128 L p .738 .589 .689 r
F P
0 g
s
.62977 .35128 m .64544 .34296 L .637 .3269 L p .738 .589 .689 r
F P
0 g
s
.69655 .40199 m .6897 .40296 L .69197 .42097 L p .639 .533 .717 r
F P
0 g
s
.69197 .42097 m .7001 .4198 L .69655 .40199 L p .639 .533 .717 r
F P
0 g
s
.62096 .33539 m .61281 .33999 L .6217 .35582 L p .654 .557 .733 r
F P
0 g
s
.6217 .35582 m .62977 .35128 L .62096 .33539 L p .654 .557 .733 r
F P
0 g
s
.59489 .61695 m .60785 .63055 L .62097 .61799 L p .686 .542 .685 r
F P
0 g
s
.62097 .61799 m .60802 .60441 L .59489 .61695 L p .686 .542 .685 r
F P
0 g
s
.60785 .63055 m .61606 .63924 L .62952 .62705 L p .736 .626 .737 r
F P
0 g
s
.62952 .62705 m .62097 .61799 L .60785 .63055 L p .736 .626 .737 r
F P
0 g
s
.45548 .58838 m .46061 .60101 L .47698 .59317 L p .721 .624 .748 r
F P
0 g
s
.47698 .59317 m .47253 .5821 L .45548 .58838 L p .721 .624 .748 r
F P
0 g
s
.5257 .34145 m .53729 .32977 L .52435 .31703 L p .732 .576 .68 r
F P
0 g
s
.52435 .31703 m .5129 .32855 L .5257 .34145 L p .732 .576 .68 r
F P
0 g
s
.49942 .09881 m .4874 .08192 L .47559 .09573 L p .727 .619 .737 r
F P
0 g
s
.47559 .09573 m .48436 .10895 L .49942 .09881 L p .727 .619 .737 r
F P
0 g
s
.14055 .31287 m .11833 .33174 L .13147 .34429 L p .722 .579 .694 r
F P
0 g
s
.13147 .34429 m .15235 .32667 L .14055 .31287 L p .722 .579 .694 r
F P
0 g
s
.74599 .76811 m .75928 .74516 L .74292 .73728 L p .718 .571 .688 r
F P
0 g
s
.74292 .73728 m .73044 .75871 L .74599 .76811 L p .718 .571 .688 r
F P
0 g
s
.25479 .72491 m .26693 .75154 L .28273 .74257 L p .698 .555 .689 r
F P
0 g
s
.28273 .74257 m .27125 .71724 L .25479 .72491 L p .698 .555 .689 r
F P
0 g
s
.90768 .36538 m .87814 .34561 L .87317 .36309 L p .722 .598 .717 r
F P
0 g
s
.87317 .36309 m .89749 .38041 L .90768 .36538 L p .722 .598 .717 r
F P
0 g
s
.4874 .08192 m .45985 .05948 L .45177 .07574 L p .694 .557 .696 r
F P
0 g
s
.45177 .07574 m .47559 .09573 L .4874 .08192 L p .694 .557 .696 r
F P
0 g
s
.11833 .33174 m .0916 .36054 L .10641 .37104 L p .697 .578 .718 r
F P
0 g
s
.10641 .37104 m .13147 .34429 L .11833 .33174 L p .697 .578 .718 r
F P
0 g
s
.71362 .39859 m .69655 .40199 L .7001 .4198 L p .695 .57 .709 r
F P
0 g
s
.7001 .4198 m .71715 .41641 L .71362 .39859 L p .695 .57 .709 r
F P
0 g
s
.44864 .56977 m .45548 .58838 L .47253 .5821 L p .708 .581 .711 r
F P
0 g
s
.47253 .5821 m .4657 .56352 L .44864 .56977 L p .708 .581 .711 r
F P
0 g
s
.72349 .80121 m .74599 .76811 L .73044 .75871 L p .707 .577 .707 r
F P
0 g
s
.73044 .75871 m .70849 .79095 L .72349 .80121 L p .707 .577 .707 r
F P
0 g
s
.83591 .34723 m .82302 .35185 L .83044 .36844 L p .707 .577 .707 r
F P
0 g
s
.83044 .36844 m .84201 .36434 L .83591 .34723 L p .707 .577 .707 r
F P
0 g
s
.81907 .37351 m .83044 .36844 L .82302 .35185 L p .707 .577 .707 r
F P
0 g
s
.73463 .39275 m .72425 .39597 L .72859 .41361 L p .707 .577 .707 r
F P
0 g
s
.72859 .41361 m .73998 .41012 L .73463 .39275 L p .707 .577 .707 r
F P
0 g
s
.71715 .41641 m .72859 .41361 L .72425 .39597 L p .707 .577 .707 r
F P
0 g
s
.51467 .35235 m .5257 .34145 L .5129 .32855 L p .707 .577 .707 r
F P
0 g
s
.87814 .34561 m .86746 .34287 L .86696 .36103 L p .707 .577 .707 r
F P
0 g
s
.86696 .36103 m .87317 .36309 L .87814 .34561 L p .707 .577 .707 r
F P
0 g
s
.86746 .34287 m .85696 .3427 L .85942 .36071 L p .707 .577 .707 r
F P
0 g
s
.85942 .36071 m .86696 .36103 L .86746 .34287 L p .707 .577 .707 r
F P
0 g
s
.85696 .3427 m .84597 .3443 L .85102 .36176 L p .707 .577 .707 r
F P
0 g
s
.85102 .36176 m .85942 .36071 L .85696 .3427 L p .707 .577 .707 r
F P
0 g
s
.84597 .3443 m .83591 .34723 L .84201 .36434 L p .707 .577 .707 r
F P
0 g
s
.84201 .36434 m .85102 .36176 L .84597 .3443 L p .707 .577 .707 r
F P
0 g
s
.82302 .35185 m .81063 .35742 L .81907 .37351 L p .707 .577 .707 r
F P
0 g
s
.81063 .35742 m .79871 .36367 L .80744 .37961 L p .707 .577 .707 r
F P
0 g
s
.80744 .37961 m .81907 .37351 L .81063 .35742 L p .707 .577 .707 r
F P
0 g
s
.79871 .36367 m .78737 .36989 L .79544 .38617 L p .707 .577 .707 r
F P
0 g
s
.79544 .38617 m .80744 .37961 L .79871 .36367 L p .707 .577 .707 r
F P
0 g
s
.78737 .36989 m .77691 .37508 L .78455 .39157 L p .707 .577 .707 r
F P
0 g
s
.78455 .39157 m .79544 .38617 L .78737 .36989 L p .707 .577 .707 r
F P
0 g
s
.77691 .37508 m .76625 .38002 L .77358 .39665 L p .707 .577 .707 r
F P
0 g
s
.77358 .39665 m .78455 .39157 L .77691 .37508 L p .707 .577 .707 r
F P
0 g
s
.76625 .38002 m .75567 .38468 L .76242 .40156 L p .707 .577 .707 r
F P
0 g
s
.76242 .40156 m .77358 .39665 L .76625 .38002 L p .707 .577 .707 r
F P
0 g
s
.75567 .38468 m .74491 .38899 L .75113 .40607 L p .707 .577 .707 r
F P
0 g
s
.75113 .40607 m .76242 .40156 L .75567 .38468 L p .707 .577 .707 r
F P
0 g
s
.74491 .38899 m .73463 .39275 L .73998 .41012 L p .707 .577 .707 r
F P
0 g
s
.73998 .41012 m .75113 .40607 L .74491 .38899 L p .707 .577 .707 r
F P
0 g
s
.72425 .39597 m .71362 .39859 L .71715 .41641 L p .707 .577 .707 r
F P
0 g
s
.5129 .32855 m .50094 .34044 L .51467 .35235 L p .707 .577 .707 r
F P
0 g
s
.50094 .34044 m .48982 .35335 L .50469 .36378 L p .707 .577 .707 r
F P
0 g
s
.50469 .36378 m .51467 .35235 L .50094 .34044 L p .707 .577 .707 r
F P
0 g
s
.48982 .35335 m .48005 .36738 L .49607 .37595 L p .707 .577 .707 r
F P
0 g
s
.49607 .37595 m .50469 .36378 L .48982 .35335 L p .707 .577 .707 r
F P
0 g
s
.48005 .36738 m .47205 .3825 L .48901 .389 L p .707 .577 .707 r
F P
0 g
s
.48901 .389 m .49607 .37595 L .48005 .36738 L p .707 .577 .707 r
F P
0 g
s
.47205 .3825 m .46572 .39912 L .48326 .40388 L p .707 .577 .707 r
F P
0 g
s
.48326 .40388 m .48901 .389 L .47205 .3825 L p .707 .577 .707 r
F P
0 g
s
.46572 .39912 m .46114 .41613 L .47897 .4196 L p .707 .577 .707 r
F P
0 g
s
.47897 .4196 m .48326 .40388 L .46572 .39912 L p .707 .577 .707 r
F P
0 g
s
.46114 .41613 m .45781 .4332 L .47569 .43645 L p .707 .577 .707 r
F P
0 g
s
.47569 .43645 m .47897 .4196 L .46114 .41613 L p .707 .577 .707 r
F P
0 g
s
.45781 .4332 m .45492 .44937 L .4724 .45432 L p .707 .577 .707 r
F P
0 g
s
.4724 .45432 m .47569 .43645 L .45781 .4332 L p .707 .577 .707 r
F P
0 g
s
.45492 .44937 m .45013 .4663 L .46767 .47101 L p .707 .577 .707 r
F P
0 g
s
.46767 .47101 m .4724 .45432 L .45492 .44937 L p .707 .577 .707 r
F P
0 g
s
.45013 .4663 m .44545 .48379 L .4633 .48721 L p .707 .577 .707 r
F P
0 g
s
.4633 .48721 m .46767 .47101 L .45013 .4663 L p .707 .577 .707 r
F P
0 g
s
.44545 .48379 m .44211 .50152 L .46021 .50309 L p .707 .577 .707 r
F P
0 g
s
.46021 .50309 m .4633 .48721 L .44545 .48379 L p .707 .577 .707 r
F P
0 g
s
.44211 .50152 m .44061 .5196 L .45877 .5189 L p .707 .577 .707 r
F P
0 g
s
.45877 .5189 m .46021 .50309 L .44211 .50152 L p .707 .577 .707 r
F P
0 g
s
.44061 .5196 m .44134 .53672 L .45927 .53379 L p .707 .577 .707 r
F P
0 g
s
.45927 .53379 m .45877 .5189 L .44061 .5196 L p .707 .577 .707 r
F P
0 g
s
.44134 .53672 m .44413 .5535 L .46165 .54868 L p .707 .577 .707 r
F P
0 g
s
.46165 .54868 m .45927 .53379 L .44134 .53672 L p .707 .577 .707 r
F P
0 g
s
.44413 .5535 m .44864 .56977 L .4657 .56352 L p .707 .577 .707 r
F P
0 g
s
.4657 .56352 m .46165 .54868 L .44413 .5535 L p .707 .577 .707 r
F P
0 g
s
.26693 .75154 m .28623 .78537 L .30073 .77442 L p .707 .577 .707 r
F P
0 g
s
.30073 .77442 m .28273 .74257 L .26693 .75154 L p .707 .577 .707 r
F P
0 g
s
.28623 .78537 m .30966 .81629 L .32256 .80348 L p .707 .577 .707 r
F P
0 g
s
.32256 .80348 m .30073 .77442 L .28623 .78537 L p .707 .577 .707 r
F P
0 g
s
.30966 .81629 m .33673 .84341 L .34756 .82881 L p .707 .577 .707 r
F P
0 g
s
.34756 .82881 m .32256 .80348 L .30966 .81629 L p .707 .577 .707 r
F P
0 g
s
.33673 .84341 m .36732 .86602 L .37635 .85025 L p .707 .577 .707 r
F P
0 g
s
.37635 .85025 m .34756 .82881 L .33673 .84341 L p .707 .577 .707 r
F P
0 g
s
.36732 .86602 m .39824 .8836 L .4047 .86662 L p .707 .577 .707 r
F P
0 g
s
.4047 .86662 m .37635 .85025 L .36732 .86602 L p .707 .577 .707 r
F P
0 g
s
.39824 .8836 m .4314 .8961 L .43524 .87834 L p .707 .577 .707 r
F P
0 g
s
.43524 .87834 m .4047 .86662 L .39824 .8836 L p .707 .577 .707 r
F P
0 g
s
.4314 .8961 m .46614 .90351 L .46746 .88539 L p .707 .577 .707 r
F P
0 g
s
.46746 .88539 m .43524 .87834 L .4314 .8961 L p .707 .577 .707 r
F P
0 g
s
.46614 .90351 m .50116 .90604 L .50122 .88787 L p .707 .577 .707 r
F P
0 g
s
.50122 .88787 m .46746 .88539 L .46614 .90351 L p .707 .577 .707 r
F P
0 g
s
.50116 .90604 m .53681 .90607 L .53434 .88807 L p .707 .577 .707 r
F P
0 g
s
.53434 .88807 m .50122 .88787 L .50116 .90604 L p .707 .577 .707 r
F P
0 g
s
.53681 .90607 m .57199 .90113 L .56685 .8837 L p .707 .577 .707 r
F P
0 g
s
.56685 .8837 m .53434 .88807 L .53681 .90607 L p .707 .577 .707 r
F P
0 g
s
.57199 .90113 m .60593 .89099 L .59811 .8746 L p .707 .577 .707 r
F P
0 g
s
.59811 .8746 m .56685 .8837 L .57199 .90113 L p .707 .577 .707 r
F P
0 g
s
.60593 .89099 m .63764 .87579 L .62786 .86047 L p .707 .577 .707 r
F P
0 g
s
.62786 .86047 m .59811 .8746 L .60593 .89099 L p .707 .577 .707 r
F P
0 g
s
.63764 .87579 m .66965 .85523 L .6577 .84154 L p .707 .577 .707 r
F P
0 g
s
.6577 .84154 m .62786 .86047 L .63764 .87579 L p .707 .577 .707 r
F P
0 g
s
.66965 .85523 m .69816 .83021 L .68449 .81824 L p .707 .577 .707 r
F P
0 g
s
.68449 .81824 m .6577 .84154 L .66965 .85523 L p .707 .577 .707 r
F P
0 g
s
.69816 .83021 m .72349 .80121 L .70849 .79095 L p .707 .577 .707 r
F P
0 g
s
.70849 .79095 m .68449 .81824 L .69816 .83021 L p .707 .577 .707 r
F P
0 g
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{285.313, 267.563},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004M00012b000`400?l00000o`00003oo`3ooolN
0?ooo`00o`3ooolN0?ooo`00o`3ooolN0?ooo`00o`3ooolN0?ooo`00o`3ooolN0?ooo`00o`3ooolN
0?ooo`00o`3ooolN0?ooo`00H03oool;00000;80oooo001H0?ooo`P000001@2F=4P00`000000XCe8
0:4mB0030:4mB0L00000Z`3oool00580oooo1P00000208HYBP030000002F=4P0USA800<0USA82P00
00050:4mB0030000002aCD`0/De<00<00000Z03oool004l0oooo0`00000608HYBPP000001@2`T;D0
0`000000/92d0;2@]0020;2@]0L00000102aCD`400000:@0oooo001=0?ooo`030000001h8Dl00000
00<0QRU:1@0000020;6A]@030000002`T;D0/92e00P0/92e00<000000;2@]02`T;@01`2`T;@00`00
0000/8nc00000002000000H0/De<0P00002Q0?ooo`00B`3oool2000000<0N25?0`0000070;6A]@03
0000002`T;D0/92e00P0/92e00<000000;2@]02`T;@01`2`T;@00`000000/8nc0;2?/`020;2?/`@0
000000@0/De<00000031GU80`EiB0P00000_0?ooo`P00000J03oool004T0oooo0P00000307PQC`<0
00002P2aTKD00`000000/92e0;2@]@070;2@]@030000002`T;@0/92d00L0/92d00<000000;2?/`2`
Sk<01P2`Sk<3000000<0`EiB0`00000T0?ooo`P000001@2N?4/00`000000Z4A;0:Q4B`05000006<0
oooo00170?ooo`8000000`1h8Dl2000000<0/I6f00<000000;6A]@2aTKD01`2aTKD00`000000/92e
0;2@]@030;2@]@T000001@2`T;@00`000000/8nc0;2?/`070;2?/`040000002aSk800000000000@0
`EiB0P00000L0?ooo`H000000P2B=4d00`000000WSa;09hlB`0809hlB`030000002XA4/0Z4A;00D0
Z4A;1@00001N0?ooo`00A@3oool2000000<0N25?0P0000050;6A]P030000002aTKD0/I6e00D0/I6e
200000040:Rlj0030000002Q]^P0XKKX0080XKKX1`0000080;2?/`040000002aSk80/Hnb0;6?/P80
00001@31GU800`000000oooo0?ooo`0C0?ooo`D000001P2B=4dB000000D0Z4A;00<000000;E@C@2e
D4d01@00001I0?ooo`00@`3oool00`000000K1eF0000000207PQC`800000202aTKH00`000000/I6e
0;6A]@0400000080/lGW00<000000:Rlj02X_>P0202X_>P00`000000XKKX0:6fj0060:6fj0030000
002CZ^D0000000800000102`Sk<00`000000/Hnb0;6?/P040;6?/P8000000P31GU800`000000dWIO
0000000@0?ooo`@0000000<0QbiA0000002B=4d00P2B=4d600000080]9>d00<000000;BC]02dTk@0
202dTk@00`000000]9>d0;BC]0020;BC]0P000001@2eD4d3000005H0oooo00120?ooo`040000001/
7EH0K1eF06`MEP8000002@2aTKH4000000L0/lGW00<000000:Rlj02X_>P00`2X_>P9000000@0XKKX
00<0000009>Zi@2CZ^D00P2CZ^D3000000030;2?/`000000/Hnb00L0/Hnb0P0000030=9fG`030000
003oool0oooo00T0oooo1000000508L^D@@00000202dTk@00`000000]9>d0;BC]0080;BC]0030000
002dTk@0]9>d00L0]9>d00<000000;BC]02dTk@01@0000020;E@C@<00000E03oool00400oooo0P00
000206`MEP80000000<0/I:g0000002aTKH01P2aTKH2000000030;k;i0000000/lGW00H0/lGW2000
00090?ooo`H000001P2CZ^D3000000L0/Hnb00<000000;6>/P0000000`3BMUl00`000000oooo0?oo
o`060?ooo`8000001P27;U43000000030;BC]0000000]9>d00X0]9>d00<000000;BC]02dTk@01`2d
Tk@00`000000]9>d0;BC]0070;BC]0030000002dTk@0]9>d00D0]9>d100000000`31GU0000000000
001B0?ooo`00?`3oool00`000000K1eF06`MEP02000000<0/I:g00<000000;6A]P2aTKH00`2aTKH2
000000@0_/_T00<000000;?5i`2caNL01000000G0?ooo`<00000102CZ^D010000000QicQ00000000
00050;6?/P030000002aS[80/Hjb008000000P3BMUl2000000@0oooo00@0000007hZEP1n:UH00000
0P27;U44000000D0]9>d00<000000;BC]02dTk@0202dTk@00`000000]9>d0;BC]0070;BC]0030000
002dTk@0]9>d00L0]9>d00<000000;BC]02dTk@01`2dTk@01@000000]9>d000000000000`Ei@0080
0000D03oool003d0oooo0P0000000`1/7EH00000000000060;6B]`030000002aTKH0/I6f00800000
1P2nbn@3000001h0oooo0`0000000`2CZ^D0000008NLh@0208NLh@<0000000<0/Hnb0000002aS[80
102aS[801P000000dWIO0=9fG`3BMUl000000?ooo`8000000`1n:UH3000000T0]9>d00<000000;BC
]02dTk@0102dTk@C000000D0]9>d00<000000;BC]02dTk@01`2dTk@010000000]9>d0;BC]02dTk@2
000000030<5ND0000000000004h0oooo000l0?ooo`040000001/7EH00000000000T0/I:g0P000006
0;k;i0800000903oool3000000D0QicQ0P0000060;6>/P050000003BMUl0dWIO0=9fG`0000000`1n
:UH2000000030;BC]0000000]9>d00T0]9>d1`0000040;?5i`030000002Z_NP0Z[gX00L0Z[gX00<0
00000:>gi`2S]nL00P2S]nL8000000H0]9>d00<000000;BC]02dTk@0102dTk@200000080`Ei@00<0
00000?ooo`3oool0BP3oool003/0oooo00<0000006DLF`0000002@2aT[L2000000030<S?h0000000
_/_T00<0_/_T0P00000Y0?ooo`8000001027W>42000000H0/Hjb0P0000020=9fG`<00000102dTk@0
0`000000]9>d0;BC]0040;BC]0<0000000<0_<_V0000002caNL00`2caNL00`000000/lGW0;?5i`02
0;?5i`030000002Z_NP0Z[gX00L0Z[gX00<000000:>gi`2S]nL01`2S]nL00`000000VJkU09V^i@04
00000080]9>d00<000000;BC]02dTk@01P2dTk@2000000030<a[EP000000000004X0oooo000i0?oo
o`80000000@0IAaK0000002aTkL000001`2aT[L010000000b<oP0<S?h038cn02000000030;k;i000
0000000002d0oooo0P0000001@27W>40000007R9e`1hRML0000000L0/Hjb0P0000000`3VVg/00000
0;BC]0040;BC]0030000002dTk@0]9>d00@0000000D0_<_V0000002lbnH0_<_V000000050;?5ia<0
0000102S]nL00`000000VJkU09V^i@0509V^i@<000002@2dTk@3000000030<a[EP000000000004P0
oooo000h0?ooo`040000001U75/0IAaK00000080/I>g00<000000;6B]`2aT[L00`2aT[L2000000D0
b<oP0P00000a0?ooo`8000000`1hRML2000000@0/Hjb00D000000;ZN_0000000iY]k000000060;BC
]08000001`2lbnH7000001<0oooo1`00000709V^i@<000001P2dTk@01@000000]9>d0;BC]02dTk@0
00000080c6]F0P0000160?ooo`00=`3oool010000000IAaK06DLF`0000040;6C]`050000002aT[L0
/I:g0;6B]`0000001@38cn02000003D0oooo00<0000007R9e`1hRML00P1hRML010000000/Hjb0;6>
/P0000020;ZN_0040000003VVg/0iY]k000000<0]9>d0`0000030;c;iP030?ooo`2lbnH000000080
00008@3oool400000080VJkU00@00000092ThP2@Y>80T:CR0P0000040;BC]0030000002dTk@0]9>d
0080]9>d0P0000020<a[EP800000A03oool003D0oooo0P0000000`1U75/00000000000050;6C]`04
0000002aT[L00000000000@0b<oP0P00000g0?ooo`800000101hRML00`000000/Hjb000000030;ZN
_0030000003VVg/0iY]k00<000000`34cn<00`000000_<_V00000002000002P0oooo0`000005092T
hP80000000<0]9>d0000002dTk@01P2dTk@01@000000c6]F0<a[EP3<JeH0000004<0oooo000d0?oo
o`040000001U75/0IAaK000000P0/I>g00<000000<S?h038cn000P38cn02000003P0oooo00@00000
07`XEP1l:5H00000101hRML00`000000^Yjl0;ZN_0020;ZN_0040000003VVg/00000000000D0a<oS
0P00000^0?ooo`8000001@2@Y>82000000P0]9>d0`0000000`3ALUT00000000000110?ooo`00<`3o
ool20000000306DLF`000000/I>g00H0/I>g0P0000000`3<d=d000000<S?h002000003P0oooo0P00
00001@1e9UX000000000002iUK8000000080N8WG0P0000050;ZN_0040000003_]I80kkFB00000080
a<oS0P00000b0?ooo`800000102@Y>83000000P0]9>d00D000000=5bF@3ALUT0dG9I000000100?oo
o`00<P3oool010000000FaaU05/LI@0000070;6C]`030000003<d=d0c=3M0080c=3M0P00000h0?oo
o`030000001e9UX0MBIJ0080000000P0^IBa0000002iUK80000007R9e`000000Lh?D000000<0^Yjl
0P0000020>neTP<00000=P3oool200000003092ThP000000RI[N0080RI[N00<000000;BC]02dTk@0
102dTk@00`000000]9>d000000030=5bF@800000?P3oool00340oooo00H0000005/LI@1K76D00000
0;:C^00000050;6C]`040000003<d=d0c=3M0<c@g@800000>03oool200000080MBIJ00D000000;VD
/@2iU;40^IBa000000020;VE/P050000001cPm@0Lh?D0000002jW[`00P0000020;RO_`040000003_
]I80kkFB000003T0oooo0P00000408VJgP8000000`2dTk@010000000]9>d0;BC]02dTk@2000000<0
dG9I00<000000?ooo`3oool0>`3oool00300oooo00@0000005/LI@1K76D000000`2bTkP200000003
0;6C]`000000000000<0c=3M00<000000?ooo`3oool0=`3oool00`000000MBIJ07DVFP02000000D0
^IBa00@000000;VE/P2iUK8000000P1cPm@00`000000^9no0;RO_`020;RO_`040000003_]I80kkFB
000003/0oooo0P00000408VJgP80000000<0]9>d0000002dTk@0102dTk@010000000dG9I0=5bF@3A
LUT2000003/0oooo000`0?ooo`030000001K76D0000000H0/Y>h00<000000<c@g@3<d=d00P3<d=d0
0`000000oooo0?ooo`0g0?ooo`040000001`9El00000000000P0^IBa0P000000103<dmh000000000
000000040;RO_`@00000?@3oool00`000000RI[N08VJgP0308VJgP030000002dTk@0]9>d00D0]9>d
00<000000=5bF@3ALUT00P3ALUT00`000000oooo0?ooo`0h0?ooo`00;`3oool00`000000FaaU0000
00060;:C^0040000003Dd]L000000<c@g@800000>@3oool01P000000L2EO070UG`000000^9Ba0000
00D0^IBa0`0000020<cCgP050000001XLLP0J7780000002hWkl00P000000102gWKh000000>nnW@00
000n0?ooo`8000000`29V]h2000000L0]9>d0P000000103ALUT000000=YoH@00000i0?ooo`00;P3o
ool00`000000FaaU000000060;:C^0050000003Dd]L0e=;G0=CBe`000000>@3oool200000080L2EO
00@000000;RD/@2hU;400000102iU;4010000000d]CK0=;Df`3Be=/30000000406Qab00000000000
000000<0]ifn00@000000>nnW@3__Yd00000?`3oool300000080QIKL0P0000070;BC]0050000003J
Of40fWmQ0=YoH@000000>03oool002d0oooo00<0000005/LI@0000001P2bTkP01@000000e=;G0=CB
e`3Dd]L0000003T0oooo00D00000070UG`1`9El0L2EO000000040;RD/@040000002iU;4000000000
00@0d]CK100000000`1RI;h000000;NM_P040;NM_P030000003__Yd000000440oooo00<0000008FF
g025U]`00P25U]`00`000000]9>d0;BC]0030;BC]0030000002dTk@0000000<0fWmQ00<000000?oo
o`3oool0=@3oool002`0oooo00<0000005<OLP0000001`2bTkP010000000e=;G0=CBe`00000i0?oo
o`050000001`9El0L2EO070UG`0000001P2hU;400`000000d]CK0=;Df`020=;Df`8000000P3oool0
10000000HVBn069T_P0000050;NM_P030000003__Yd000000480oooo0P00000308FFg0050000002d
Tk@0]9>d0;BC]00000000`2dTk@01@000000fWmQ0=YoH@3JOf40000003H0oooo000[0?ooo`040000
001C7g8000000;:D^0800000102bTkP010000000e=;G0=CBe`00000i0?ooo`050000001[9F<00000
070UG`0000001P2hU;42000000<0d]CK00<000000?ooo`3oool00`3oool010000000HVBn069T_P00
00020;NM_PD00000A03oool010000000QIKL08FFg025U]`2000000030;BC]0000000]9>d00<0]9>d
00D000000=YoH@3JOf40fWmQ0000000e0?ooo`00:`3oool00`000000Damb000000030;:D^0800000
00D0/Y>h0000003Dd]L0e=;G0000000i0?ooo`050000001[9F<0JbES06/UH`0000001P2hU;400`00
0000e]GG0=KEe`03000000H0oooo1P0000020;FL_P030000003_aJP0000004D0oooo0P00000308FF
g0030000002dTk@0]9>d00@0]9>d0P0000020=YoH@030000003oool0oooo0380oooo000Z0?ooo`03
0000001C7g80000000H0/YBh00@000000=CBe`3Dd]L00000>@3oool01`000000JbES06/UH`1[9F<0
00000;RC/@0000000`2hU;42000000<0e]GG00<000000?ooo`3oool01P3oool010000000GUZe05iJ
]@0000040;FL_P040000003_aJP0klFX000004H0oooo0`0000000`1nRmH000000;BC]0060;BC]004
0000003JOf40fWmQ000003<0oooo000Y0?ooo`040000001C7g80Damb000000D0/YBh00<000000=_A
d00000000P00000h0?ooo`050000001[9F<0JbES06/UH`0000000`2hTk400`000000^9Ba00000004
0=KEe`030000003oool0oooo00L0oooo00@0000005iJ]@1NF[D00000102eW;h010000000klFX0000
000000170?ooo`050=5cF`000000OX_F07j;eP0000001`2dTk@2000000030>>?J`000000oooo0340
oooo000X0?ooo`040000001C7g80Damb000000H0/YBh00@000000=_Ad0000000ER9b>03oool00`00
0000JbES06/UH`02000000D0^9>a00<000000=KEe`3FeML00P3FeML00`000000oooo0?ooo`080?oo
o`80000000@0GUZe0000002eW;h0]Ibn100000000`3^aZT000000?ooo`180?ooo`040000001nRmH0
OX_F000000L0]9>d00@000000>>?J`3SSf/00000<@3oool002P0oooo00@0000005<OLP1C7g800000
1@2bU;P010000000fm7@0=_Ad000000h0?ooo`040000001[9F<0JbES000000H0^9>a00<000000=WE
e00000000P3FeML00`000000oooo0?ooo`090?ooo`030000001ME:l0000000<000000P2eV[`01000
0000k/JY0>k6Z@00001:0?ooo`040000003JPF<0OX_F000000D0]9>d00D000000;BC]0000000hhm[
0000000a0?ooo`009`3oool010000000Damb05<OLP0000050;:D^0040000003KdM00fm7@000003P0
oooo00@0000006LVJ000000000001P2hTk401P000000fMGD0=WEe0000000e]GG000000`0oooo00@0
000005eD[`1ME:l00000102eV[`010000000k/JY0>k6Z@00001;0?ooo`040000001nRmH0OX_F0000
00<0]9>d00@000000;BC]02dTk@000000P3SSf/00`000000oooo0?ooo`0^0?ooo`009`3oool0101>
9Wl0000005<OLP0000050;:D^0030000003KdM00000003P0oooo00H0000006LVJ01W9VP000000;RC
/@0000040;RC/@030000003IeM@0fMGD0080fMGD00<000000?ooo`3oool02`3oool010000000GEB_
05eD[`0000040;FJ_0040000003^aZT0k/JY000004/0oooo00L0000007j;eP1nRmH0OX_F0000002d
Tk@0000000@0]9>d00@000000>>?J`3SSf/00000;`3oool002H0oooo00<0000004hVO`1>9Wl00P00
00040;:D^0040000003KdM00fm7@000003L0oooo00@0000006LVJ01W9VP000000`2hTk4200000003
0;RC/@000000fMGD00<0fMGD00<000000?ooo`3oool0303oool010000000GEB_05eD[`0000040;FJ
_0040000003^aZT0k/JY000004`0oooo00D0000007j;eP1nRmH0OX_F000000060;BC]0040000003S
Sf/0hhm[000002h0oooo000V0?ooo`050000001>9Wl0CRIo0000002cUKP00P0000020;:D^0030000
003KdM00000003L0oooo00@0000006LVJ01W9VP000001P2hTk400`000000fMGD0=WEe0020=WEe003
0000003oool0oooo00d0oooo0P000000101ME:l000000;FJ_02eV[`6000004d0oooo00D0000007j;
eP000000N87?000000060;BC]0030000003SSf/0000002h0oooo000U0?ooo`040000001>9Wl0CRIo
000000@0/iFh0P0000020=_Ad0030000003oool0oooo03@0oooo00@0000006LVJ01W9VP000001P2h
Tk400`000000g=GA000000020=WEe0030000003oool0oooo00h0oooo00<0000005a@Z`0000000`00
00020;BI_0040000003^bJh0k/V^000004h0oooo00D0000007R1c`1hPLl0N87?000000050;BC]004
0000003SSf/0hhm[000002d0oooo000U0?ooo`040000001>9Wl0CRIo000000@0/iFh00D000000>7?
a`00000000000=_Ad00e0?ooo`040000001W9VP0IbIX000000H0^9>a00H000000=cEd@3LeM400000
0=WEe000000A0?ooo`040000001LD:/0G52[000000@0]9Vl00@000000>k9[P3^bJh00000C`3oool0
1@000000N87?07R1c`1hPLl0000000D0]9>d00@000000>>?J`3SSf/00000;03oool002D0oooo00<0
000004hVO`0000001@2cUKP010000000hLo70>7?a`00000e0?ooo`040000001W9VT00000000000H0
^9>a00<000000=cEd@3LeM400P3LeM400`000000oooo0?ooo`0@0?ooo`040000001LD:/0G52[0000
00@0]9Vl00@000000>k9[P3^bJh00000D03oool010000000N87?07R1c`0000060;BC]080000000<0
jYig0000003oool0:P3oool002@0oooo00@0000004hVO`1>9Wl00000102cUKP010000000hLo70>7?
a`00000f0?ooo`050000001W9VT000000;RC/@0000001@2hTk401@000000g=GA0=cEd@3LeM400000
01<0oooo00@0000005a@Z`1LD:/00000102dVK`010000000k/V^0>k9[P00001A0?ooo`040000001h
PLl0N87?000000@0]9>d00D000000;BC]0000000jYig0000000[0?ooo`00903oool00`000000CRIo
000000050;>E^0040000003QclL0hLo7000003D0oooo00@0000006LVJ@1W9VT000000P2hTk401@00
0000^9>a0;RC/@2hTk40000000<0g=GA00<000000?ooo`3oool04P3oool20000000305a@Z`000000
]9Vl00<0]9Vl00@000000>k9[P0000000000D@3oool01P000000N87?07R1c`1hPLl000000;BC]080
00000P2dTk@010000000jYig0>ZNM`00000Z0?ooo`008`3oool010000000CRIo04hVO`0000040;>E
^0040000003QclL0hLo7000003D0oooo00@0000006LVJ@1W9VT00000102hTk400`000000^9>a0000
00030=cEd@030000003oool0oooo01<0oooo00<0000005a=Y`0000001`0000000`3]bk4000000?oo
o`1A0?ooo`050000001hPLl0N87?07R1c`0000001@2dTk@00`000000jYig0000000Z0?ooo`008`3o
ool00`000000CRIo000000050;>E^0040000003QclL0hLo7000003@0oooo00@0000006LVJ@1W9VT0
00001P2hTk401@000000g=GA0=cEd@3LeM40000001H0oooo00@0000005a=Y`1LCJL00000102dVK`0
10000000kL^a0>g;/@00001C0?ooo`040000001hPLl00000000000D0]9>d00@000000>ZNM`3ZWWL0
0000:@3oool002<0oooo00<0C2b90000000000000P0000020;>E^0050000003QclL0hLo70>7?a`00
0000<`3oool20000000306LVJ@000000^9>a00D0^9>a00D000000=cEd0000000g=GA0000000G0?oo
o`040000001LCJL0G4fW000000@0]9Vl00<000000>g;/@000000E@3oool010000000LgG607=eaP00
00050;BC]0030000003ZWWL0000002T0oooo000R0?ooo`040000001<;8T0C2b900000080/iFh1000
00000`3QclL000000?ooo`0c0?ooo`040000001W9VT0IbIY000000D0^9>a00D000000=cEd03LeM00
g=G@0000000H0?ooo`040000001LCJL0G4fW000000@0]9Vl00<000000>g;/@000000E@3oool01000
0000LgG607=eaP0000050;BC]0040000003ZWWL0jYig000002P0oooo000R0?ooo`030000001<;8T0
000000D0/iFh00@000000>C<`00000000000<`3oool010000000J2IX0000000000050;RC/@050000
003LeM00g=G@0=cEd00000006@3oool20000000305a=Y`000000]9Vl00<0]9Vl00<000000>g;/@00
0000EP3oool010000000LgG607=eaP0000050;BC]0030000003ZWWL0jYig02P0oooo000R0?ooo`03
0000001<;8T0000000@0/iFh00D000000>C<`03Tc<00i<c00000000b0?ooo`060000001X9VP0J2IX
0000002hTk400000102hTk4010000000g=G@0=cEd000000J0?ooo`030000001LC:L0000000P00000
EP3oool010000000LgG607=eaP0000050;BC]0040000003ZWWL0jYig000002L0oooo000R0?ooo`03
0000001<;8T0000000@0/iFh00@000000>C<`03Tc<000000<P3oool010000000J2IX06PVJ0000003
0;RC/@80000000D0^9>a0000003LeM00g=G@0000000K0?ooo`040000001LC:L0G4bW000000@0]9Vl
00<000000>g;/@000000E`3oool010000000LgG607=eaP0000040;BC]0@000009`3oool00240oooo
00<0000004`/R@0000001@2cUKP010000000i<c00>C<`000000a0?ooo`040000001X9VP0J2IX0000
00H0^9>a00@000000=cEd03LeM000000703oool010000000G4bW05a<Y`0000040;BI_0030000003]
bk40000005L0oooo00@0000007=eaP1cMLH000000P2dTk@2000000050;BC]0000000kjV10>nYP@00
00009P3oool00240oooo00<0000004`/R@000000102cUKP01@000000i<c00>C<`03Tc<00000002l0
oooo00D0KbIR0000001X9VP0J2IX000000060;RC/@80000000<0g=G@0000003oool0703oool00`00
0000G4bW000000040;BI_0040000003]bk40kL^a000005P0oooo00<0000007=eaP1cMLH00P000004
0;BC]0030000003_ZH40000002H0oooo000Q0?ooo`030000001<;8T0000000@0/iFh00@000000>C<
`03Tc<000000<03oool20000000306PVJ0000000^9>a00D0^9>a00@000000=_EdP3KeM8000007P3o
ool00`000000G4bW000000040;BI_0040000003]bk40kL^a000005P0oooo00@0000007=eaP000000
00001@2dTk@010000000kjV10>nYP@00000U0?ooo`008@3oool00`000000C2b9000000040;>E^004
0000003Tc<00i<c0000002l0oooo00@0000006lVHP1_9V8000001P2hTk4010000000fmGB0=_EdP00
000O0?ooo`D000000P2dVK`010000000kL^a00000000001I0?ooo`040000001_KL00Kfg0000000D0
]9>d00<000000>nYP@0000009@3oool00200oooo00<0000004`/R@0000001@2cUKP010000000i<c0
0>C<`000000]0?ooo`8000000P1_9V800`000000^9Bb000000040;RC/@040000003KeM80fmGB0000
0200oooo00<0000005a?ZP0000000P2dV[`4000000030>g9[`000000oooo05P0oooo00@0000006m]
`01_KL0000001@2dTk@00`000000kjV10000000U0?ooo`00803oool500000080/iFh00@000000>C<
`03Tc<000000;@3oool01@000000KbIR06lVHP1_9V80000000<0^9Bb0P0000001@2hTk4000000=_E
dP3KeM8000000240oooo00<0000005a?ZP000000102dV[`010000000kLV_0>g9[`00001J0?ooo`04
0000001_KL00Kfg0000000@0]9>d00@000000>nYP@3_ZH400000903oool00200oooo0P1;=iL00`00
0000]9Jh0;BF^006000002`0oooo00D0000006lVHP1_9V80KbIR000000060;RD/P050000003KeM80
fmGB0=_EdP0000008@3oool00`000000G4nZ000000040;BJ_0040000003]bJl0kLV_000005X0oooo
00@0000006m]`01_KL0000001@2dTk@00`000000kjV10000000T0?ooo`00803oool204/gU`030000
002dU[P0]9Jh0080]9Jh00@000000>O7]P3WakH00000:P3oool200000004080/E`000000KbIR0000
00H0^9Bb0P0000020=_EdP030000003oool0oooo0200oooo00<0000005a?ZP000000102dV[`01000
0000kLV_0>g9[`00001J0?ooo`040000001_KL00Kfg0000000D0]9>d00@000000>nYP@3_ZH400000
8`3oool001l0oooo00<0000004/gU`0000001@2dU[P010000000ilNf0>O7]P00000X0?ooo`800000
0`20;5L2000000H0^9Bb00<000000=GEf03EeMP00P00000S0?ooo`/00000F`3oool010000000Kfg0
06m]`00000050;BC]0030000003_ZH40000002<0oooo000O0?ooo`030000001;=iL0000000@0]9Jh
00@000000>O7]P3WakH000009P3oool3000000<0P2aG0P0000000`2iUK8000000;RD/P030;RD/P80
00000`3EeMP00`000000oooo0?ooo`0R0?ooo`030000001MDjh0000000@0]9Zl00@000000>k7Z`3^
aj/00000F`3oool010000000Kfg006m]`00000040;BC]0@000008`3oool001l0oooo00<0000004/g
U`000000102dU[P010000000ilNf0>O7]P00000T0?ooo`80000000@0RS5D00000020;5L0P2aG0P00
00040;VE/P040000002hU;80^9Bb000000@0eMGH00<000000?ooo`3oool08`3oool00`000000GE>^
000000040;BJ_0040000003^aj/0k/N[000005/0oooo00H0000006m]`01_KL00Kfg00000002dTk@2
000000040;BC]0000000l[N=000002<0oooo000O0?ooo`030000001;=iL0000000@0]9Jh00@00000
0>O7]P3WakH000008P3oool2000000<0RS5D0`0000060;VE/P030000002hU;80000000@0eMGH00<0
00000?ooo`3oool0903oool00`000000GE>^000000040;BJ_0040000003^aj/0k/N[000005`0oooo
00<0000006m]`00000000P0000030;BC]0030000003b]hd0000002<0oooo000O0?ooo`030000001;
=iL0000000@0]9Jh00@000000>O7]P3WakH000007`3oool3000000<0RS5D0P0000000`2iU[<00000
0;VE/P070;VE/P040000003EeMP0eMGH0=GEf08000009`3oool00`000000GE>^000000040;BJ_004
0000003^aj/00000000005`0oooo0P0000000`1/HkL000000;BC]0040;BC]0030000003b]hd00000
0280oooo000O0?ooo`030000001;=iL0000000@0]9Jh00@000000>O7]P3WakH000006`3oool40000
000408`bE0000000RS5D08XaE0800000102iU[<00`000000^IFb0;VE/P030;VE/P<000000P3EeMP0
0`000000oooo0?ooo`0W0?ooo`T0000000<0k/BW0000003oool0F`3oool010000000K6>g06aS]`00
00050;BC]0030000003b]hd000000280oooo000N0?ooo`030000001;=iL0000000@0]9Jh00@00000
0>O7]P3WakH00000603oool4000000D0S39D0`0000060;VF/`040000002iUK80^IFb0;VE/P800000
0`39dn42000002X0oooo00<0000005iG/P000000102eV[`010000000k/BW0>k4Y`00001L0?ooo`05
0000001/HkL0K6>g06aS]`000000102dTk@00`000000l[N=0000000R0?ooo`007P3oool00`000000
BcNG000000040;BF^0040000003WakH0ilNf000001H0oooo0P0000000`2;<U@0000008`bE00408`b
E080000000<0^IJc0000002iU[<01`2iU[<3000000D0bM?Q00<000000?ooo`3oool0:@3oool00`00
0000GUNb000000040;FJ_0040000003^a:L0k/BW000005d0oooo00@0000006aS]`1/HkL00000102d
Tk@00`000000l[N=0000000R0?ooo`007P3oool<00000180oooo0`00000408/bE0030000002<<U@0
0000008000000`2iU[<00`000000^IJc0;VF/`050;VF/`8000001@39dn42000002`0oooo00@00000
05iG/P1NEk800000102eV[`00`000000k/BW0000001M0?ooo`040000001/HkL0K6>g000000@0]9>d
00<000000?:gS@0000008P3oool001h0oooo00<0000004e2Y0000000102dU[P010000000j<6]0>S1
[@00000@0?ooo`<000001P2;<U@3000000L0^IJc00<000000;VF/`2iU[<00P2iU[<2000000030<?@
i0000000bM?Q0080bM?Q0P00000^0?ooo`80000000@0GUNb0000002eV[`0]IZl1@00001M0?ooo`04
0000001/HkL0K6>g000000@0]9>d00<000000?:gS@0000008P3oool001h0oooo00<0000004e2Y000
0000102dU[P010000000j<6]0>S1[@00000>0?ooo`80000000<0QBiE0000002;<U@00P2;<U@40000
00030;VF/`000000^IJc00L0^IJc00<000000;VF/`0000000P0000040<?@i0<00000<03oool00`00
0000Ge^f0000000300000080]Y^l00<000000>k0XP000000G@3oool010000000K6>g06aS]`000005
0;BC]0030000003b]hd000000240oooo000N0?ooo`030000001=@Z@0000000@0]9Jh00@000000>S1
[@3X`Jd00000303oool2000000<0QBiE100000060;VF/`030000002iU[<0^IJc00@0^IJc0`000006
0<?@i0800000<P3oool010000000Ge^f05mK]P0000040;JK_0040000003^`:80k/2R000005`0oooo
00D0000006aS]`1/HkL0K6>g000000040;BC]0030000003b]hd000000240oooo000N0?ooo`030000
001=@Z@0000000@0]9Jh00@000000>S1[@3X`Jd000002P3oool2000000<0QBiE0P0000000`2iU[80
00000;VF/`070;VF/`030000002iU[<0^IJc00@0000000<0`]3U00000033d>@00P33d>@4000003D0
oooo00<0000005mK]P000000102fVk`010000000k/2R0>k0XP00001M0?ooo`040000001/HkL0K6>g
00000080]9>d1@00000Q0?ooo`007P3oool00`000000CD:T000000040;BF^0040000003X`Jd0j<6]
000000P0oooo0`00000208D^E@800000102iU[800`000000^IJc0;VF/`050;VF/`<000001@32d>D4
000003T0oooo00<0000005mK]P000000102fVk`010000000k/2R00000000001M0?ooo`030000001/
HkL0000000<000000P2dTk@00`000000ll6I0000000Q0?ooo`007P3oool00`000000CD:T00000005
0;BF^0030000003X`Jd0000000H0oooo0P00000307h[E`8000001P2iU[800`000000^IJc0;VF/`03
0;VF/`80000000<0`m3U00000032d>D00`32d>D20000000308`dEP3oool0oooo03X0oooo2@000000
0`3__Ih000000?ooo`0;0?ooo`X00000A`3oool20000000306]K[P000000]9>d00<0]9>d00<00000
0??1V@0000008@3oool001h0oooo00<0000004e2Y00000001@2dU[P00`000000j<6]000000040?oo
o`8000000`1n:eL2000000030;VE/P000000^IJb00H0^IJb00<000000;VF/`0000000P0000040<?@
i@0400000032d>D00000000003l0oooo00<00000065P^`000000102fW;d010000000kkfN0>nmWP00
000:0?ooo`80000000D0UcUA0000002UA4l0YDA?000000030;=@D00300000032HED0000000800000
A03oool010000000Je^^06]K[P0000040;BC]0030000003c`IT000000240oooo000N0?ooo`030000
001=@Z@0000000D0]9Jh00<000000>S1[@0000000`3oool00`000000OR]G07h[E`0207h[E`050000
002iUK80^IFb0;VE/P0000001`2iU[82000000H0`m3U0`0000110?ooo`030000001QH;/0000000@0
]Ybm00<000000>nmWP3__Ih00P0000060?ooo`<000000`2G>E4:000000040<9QE@00000000000000
0480oooo00@0000006]K[P1[Fjh00000102dTk@00`000000ll6I0000000Q0?ooo`007P3oool00`00
0000CD:T000000050;BF^0040000003X`Jd000000?ooo`80000000<0N2MI0000001n:eL00P000005
0;VE/P030000002iU[80^IJb0080^IJb0`0000050<?@i@800000A03oool010000000HF2k065P^`00
00040;JL_@<000001@3oool200000080S3AE100000001@31V[0000000<:M/P32WK80000000<0`ind
00D000000<>R^000000000000=IfE`0300000400oooo00@0000006]K[P1[Fjh00000102dTk@00`00
0000ll6I0000000Q0?ooo`007P3oool00`000000CD:T000000030;BF^0H00000101h9eT00`000000
^IFb0;VE/P050;VE/P030000002iU[80^IJb008000000`37d^800`000000`m3U00000002000004H0
oooo0P000000101QH;/000000;JL_@2fW;d300000080k[NG00P000000?ooo`3oool0oooo00000022
;eX0000008`dE@80000000D0_iR_00000031V[00`IZ`000000020<:M/P0500000033Wk@0`ind0<>O
]00000000P33X[P6000003l0oooo00@0000006]K[P1[Fjh000001@2dTk@00`000000ll6I0000000P
0?ooo`007P3oool600000080]INi0`00000307PWF@80000000<0^IBa0000002iUK801P2iUK820000
00@0am;R0`0000190?ooo`030000001SIl40000000<000000P2gW;d01@000000k[NG0>jgU`000000
oooo008000000`22;eX01@000000_iR_0;nH[`2oV:l0000000<0`IZ`00@000000<:M/P32WK800000
0P33Wk@010000000`j:h0<>R^00000020<b`_P80000000<0l:5/0000003oool0?@3oool01@000000
Je^^06]K[P1[Fjh0000000@0]9>d00<000000??1V@000000803oool001h0oooo00<00000051=/000
00001@2eUkT010000000N2MI07PWF@1h9eT2000000<0^IBa00<000000;VE/P2iUK800`2iUK830000
0080am;R0`00001=0?ooo`030000001SIl40000000D0]ibm00<000000>jgU`0000000P000002088_
FP80000000<0_YJ]0000002oV:l00P2oV:l010000000`IZ`0<6J/00000020<:M/P0600000033Wk@0
`ind00000033X[P000000`3</;h2000000030?2QK0000000oooo03h0oooo00@0000006]K[P1[Fjh0
0000102dTk@00`000000ll6I0000000P0?ooo`007P3oool00`000000D4f`000000040;FG^@800000
00<0N2MI0000000000001P2iU;400`000000^IFb0;VE/P02000000<0c=?O0P00001@0?ooo`030000
001SIl40000000@0]ibm1000000207T/H08000000`2nUZd01@000000_iR_0;nH[`2oV:l000000080
`IZ`1@0000001033Wk@000000<>R^00000020<b`_P060000003?^lH000000000003e[gX00000?P3o
ool010000000Je^^06]K[P0000040;BC]0030000003c`IT000000200oooo000N0?ooo`040000001@
CK00D4f`00000080]INi00@0000006hTGP1^95h000002@2iU;42000000<0c=?O0P00001C0?ooo`04
0000001SIl4000000;NL_@80000000<0^9bl0000000000000P1i;602000000030;fD[@000000_YJ]
0080_YJ]00<000000;nH[`2oV:l0100000020;_Aj`030000002_bNd0000000<000000P3</;h20000
00030<Vhb@000000mJmj008000000`3oool7000003<0oooo00@0000006]K[P1[Fjh00000102dTk@0
0`000000ll6I0000000P0?ooo`007`3oool00`000000D4f`0000000200000080KRAN00<000000;RD
/@0000001P2iU;43000000<0c=?O00<000000?ooo`3oool0D`3oool400000080^9bl00<0000007<]
I`1c;FL00P0000030;fD[@030000002nUZd0_YJ]0080_YJ]0P000000303=fN8000000<KGiP000000
^m7[0000002_bNd0_UmI0000002Q_^d0000009[>nP<0000000L0bKS900000000000000000?:`PP00
0000oooo0080000000<0X3Y50000000000000`0000000`34ESX000000000000a0?ooo`030000001[
Fjh0000000P00000803oool001l0oooo00<00000051=/00000000`1^95h01@000000^9Ba0;RD/@2h
U;40000000@0^IBa00@000000=3Dg03@e=`0d=CL0`00001F0?ooo`030000001WKlL000000080^9bl
00L0000007<]I`1c;FL0LbeW0000002kTjh0000000<0_IB]00<000000;jF[@0000000P0000020<gI
hP0300000036enH0000000@000000P2Q_^d00`000000V/kj09[>nP0300000080aKK;100000000`2G
=4L00000000000020:0jA@D0000000<0f6m1000000000000;`3oool20000000306YDYP000000]9>d
00<0]9>d00<000000??9X`000000803oool001l0oooo0P00000206hTGP8000001@2hU;4010000000
^IBa0000000000040=3Dg0030000003oool0oooo05H0oooo00<0000006M_a`1WKlL00P00000207<]
I`8000000P2kTjh00`000000_IB]0;fD[@020;fD[@050000003Ffm`0e]_L0000003=fN800`000005
0?ooo`@0000000<0Qkki00000039^<T01@000002094aBPH0000000<0cZB]0000000000000`000000
0`3QQf8000000000000]0?ooo`040000001ZE:H0JUBV000000@0]9>d00<000000??9X`000000803o
ool001l0oooo0P0000000`1^95h000000;RD/@070;RD/@050000003@e=`0d=CL07PYF`3@e=`00P00
001J0?ooo`040000001WKlL0000006l_K`8000001@2kTjh00`000000_IB]0000000200000080e]_L
0P00000:0?ooo`8000000P1lZO03000000<0RCQO100000001@39WZ/000000<^P[@000000cZB]0080
000000D0e[:e00000000000000000>67HP02000002`0oooo00@0000006YDYP1ZE:H00000102dTk@0
0`000000llVS0000000P0?ooo`007P3oool010000000H25X060QJ00000080;RD/@80000000@0d=CL
07PYF`0000000000G03oool200000080Kbm_00<000000;BC]00000001@2kTjh010000000g=_F0=cK
eP3LfmH2000000d0oooo100000000`1b;6L0000008ThG`02000000040;bF/0000000b9^Z0<RKZP80
00000P3;X:d2000000040=B//000000000000=Rl_P<0000000<0iiQb0000003oool0:P3oool01000
0000JUBV06YDYP0000040;BC]0030000003cbJ<000000200oooo000M0?ooo`060000001P8FP0H25X
0000002bTkL000001P2hU;400`000000e]CG0=KDe`02000005h0oooo00@0000006l_K`1_;fl00000
0`2dTk@010000000^i>^0;^C[P2kTjh2000000030=cKeP000000000000l0oooo0P0000000`1b;FL0
0000078/I`02000000@0_9J`00H000000<RKZP000000bIj[0000003;X:d2000000040=B//0000000
000000000080`JBl00@000000>NHLP3WV78000009P3oool:00000080]9>d00<000000??9X`000000
803oool001`0oooo00@00000060QJ01P8FP000000`2bTkL010000000^9Ba0;RD/@2hU;4300000003
0=KDe`000000oooo05h0oooo00D0000006``L`000000Kbm_000000040;BC]0030000002kTjh00000
0080gm[A0P00000>0?ooo`<000000P1b;FL2000000030:N>^`000000_9J`00<0_9J`00<000000<RK
ZP38VjX02@0000000`31Y;`000000<2W`002000000030>jWO`000000oooo0280oooo0P0000001@2A
?El0000009Y1F`2J@E/0000000<0YDQH00<000000;IFEP0000000P0000000`3cbJ<000000?ooo`0O
0?ooo`00703oool00`000000H25X000000050;:C]`030000002hU;4000000080e]CG0P00001O0?oo
o`050000001/<7<0K31c06``L`0000001P2dTk@01@000000gm[A0=oJd@000000dGMT008000002`3o
ool30000000307@]I`000000LReW008000000P2WS[/00`000000_9J`0;bF/0030;bF/0@0000000P0
bn3X00000000000000000;GRmP000000`JBl000000<0`:O000<000000>jWO`0000008@3oool30000
00<0TCeO00<0000009Y1F`0000001@0000000`2fEUH000000000000200000200oooo000K0?ooo`03
0000001P8FP0000000L0/Y>g00H000000=KDe`3Fe=L000000>J/U@00001O0?ooo`060000001/<7<0
K31c0000002dTk@00000102dTk@010000000f=WI0000003Of]42000000030<Q[GP000000000000P0
oooo0`0000000`1f;FD0000007@]I`02000000030:N>^`000000Yhjk0080Yhjk00@000000;bF/02l
U[00_9J`0P0000000`3Eh^0000000<_Pj006000000040<6T_0000000`:O00<2W`08000000P3^Ygl0
0`000000oooo0?ooo`0K0?ooo`<000000`2=>f400`000000TCeO00000002000000060;BC]0000000
]9>d0;BC]0000000]9>d0P0000020=5eGP030000003oool0oooo01h0oooo000J0?ooo`040000001P
8FP0H25X000000H0/Y>g00<000000=GDf00000000P0000020>J/U@030000003oool0oooo05/0oooo
00@0000006``L`1/<7<000000`2dTk@2000000030;BC]0000000f=WI0080f=WI00D000000:N1Z`00
000000000;mOF00:0000000307T^H`000000MReU0080000000D0Yhjk0000002WS[/0Yhjk00000002
0:N>^`030000002lU[0000000080000000@0eN;P000000000000bn3X1@0000001@2;Z>T000000<2W
`030Yl0000000080_JG10`00000J0?ooo`<0000000<0R3YT0000002=>f400P2=>f43000000050;BC
]0000000]9>d0;BC]00000000P2dTk@00`000000]9>d0;BC]003000000030=5eGP000000000001h0
oooo000I0?ooo`040000001P8FP0H25X000000H0/Y>g00H000000=GDf03Ee=P00000068SJ@000002
0>J/U@030000003oool0oooo05X0oooo00@0000006LaNP00000000001P2dTk@02@000000f=WI0=SI
f@3HfMT000000:N1Z`000000YX2[000000020;EFE`80000000<0WD5F0000002B>UP00P0000000`1o
<5l0000007T^H`0300000080Yhjk00@000000:N>^`2WS[/000000P2WS[/200000080en7N00<00000
090fE00000000P0000020?ooo`030000002;Z>T000000080000000<0`:O00000002mYL400P2mYL40
10000000l[J=0?:fS@00000G0?ooo`80000000<0QCUW00000028>V@00P28>V@3000000050;BC]000
0000]9>d0;BC]00000000`2dTk@00`000000]9>d000000020;BC]0040000002hVKL0^9Vg00000080
dGEN00<000000?ooo`3oool06`3oool001P0oooo00@00000060QJ01P8FP000001P2bTkL010000000
eMCH0=GDf00000020;>>[`040000003V[9D00000000005/0oooo00H0000006LaNP1W<GX000000;BC
]00000040;BC]00:0000003KfMD000000=SIf@000000Yh6[0000002VP:/000000:F2[P<000000P2M
@EH00`2B>UP0000008PdF`0500000080Yhjj00@000000:N>^`2WS[/000000P2WS[/200000080_=?[
1@0000050?ooo`050000001mU^40OIKQ07fFh@0000000`2mYL401@000000^ZC20000003b]Xd00000
01H0oooo00H0000008DiI`25>FL0QCUW00000028>V@2000000030;BC]0000000]9>d0080]9>d00@0
00000;BC]02dTk@000000P2dTk@01@000000]9>d0000002dTk@0000000@0^9Vg0P0000000`3AMEh0
00000000000K0?ooo`005`3oool010000000Eb9a0000000000060;:C]`050000003Ee=P0eMCH0=GD
f00000000P2cSZl2000000030>BTS@000000oooo05X0oooo00<0000006LaNP0000000`2dTk@20000
00030;BC]0000000fmWE0080fmWE0P0000001`2WPJ/000000:J0Z`000000YH:^0000002TPk001`00
00001`2VRkT000000:J=^P2VSKX000000:N>^P0000000`2WS[/2000000040;gDj`00000000000;cC
j`D000001P3oool20000000307B7f0000000_JG1008000000P2jY<83000001@0oooo0P0000001024
>FL0000008DiI`25>FL2000000<0]9>d00D000000;BC]02dTk@0]9>d000000020;BC]0080000002d
Tk@000000000002dTk@000000;BC]00000060;RI]`040000003AMEh0dGEN000001X0oooo000G0?oo
o`050000001G8W4000000;:D^0000000102bTkL01P000000eMCH0=GDf03Ee=P000000;>>[`<00000
0`3TY8d00`000000oooo0?ooo`1G0?ooo`040000001W<GX0Ic5j000000D0]9>d00D000000=_Ie@3K
fMD0fmWE0000000206n3e`030000002VP:/000000080YH:^00/000000:B3/0000000Y8Fc0000002U
QkD000000:F9]`000000YX^i000000020:J=^P040000002WS[X0Yhjj0:N>^`80000000@0_=?[0000
002me>/0_MC[0`0000000`2`PjD000000>ZRO@02000000D0oooo00<0000007B7f01dQmP00P000005
0;ZT`P8000004P3oool2000000@0Q3UW0P0000000`2dTk@000000;BC]0030;BC]0060000002dTk@0
]9>d0;BC]0000000]9>d0P0000000`2^and0000000000003000000L0^9Vg1000000I0?ooo`005P3o
ool010000000Eb9a05LRL@0000020;:D^080000000<0/Y>g0000003Ee=P00P3Ee=P3000000<0/Xf_
00@000000>BTS@3TY8d00000F03oool010000000HcB20000000000050;BC]0040000003Pf<l00000
0=_Ie@8000000P1_PmL3000000040:F2[P000000Y8>`00000080Y8Fc00<000000:F7]@0000000P2U
RKL00`000000YX^i000000020:J=^P80Yhjj0P0000030;cCj`<00000102`PjD00`000000jZ9m0000
00060?ooo`80000000@0K7W>0000002jY<80^ZC20P000000102hX<0000000?:mUP00000?0?ooo`80
000000@0QSUV00000024>FL0Q3UW0`0000030;BC]0050000002dTk@0]9>d0;BC]00000000P2dTk@4
00000080[/O]0`000000102=YND000000000000000070;RI]`030000003SSf`0000001P0oooo000E
0?ooo`040000001G8W40Eb9a000000D0/YBh00@000000=GDf03Ee=P0eMCH0`0000040;:=[`050000
003TY8d0i:B=0>BTS@000000E`3oool00`000000HcB206<dPP03000000<0]9>d00@000000>3Hc`3P
f<l000000P3oool30000000607B<g000000000000000002TPk0000000P2TQK<00`000000YHNe0000
00020:F9]`040000002VRkT000000:J=^P<000000P2jdN`5000000<0/8>U1@0000070?ooo`D00000
0`2hX<000`000000l[fF0000000=0?ooo`<000000`26>FH2000000<0]9>d00@000000;BC]02dTk@0
00000`2dTk@3000000030;gCjP000000^M3[00L000000`25V^000`000000^9Vg0;RI]`030;RI]`05
0000002hVKP000000>>?K00000005`3oool001D0oooo00<0000005LRL@0000001@2bU;P01P000000
fm?A000000000000eMCH00000080DEFh00<000000;:=[`2bSJl00P2bSJl010000000i:B=0>BTS@00
001F0?ooo`040000001S=880HcB2000000<0]9>d0`0000020>3Hc`030000003oool0oooo00<0oooo
00@0000007B<g0000000OYWS100000001@2TQK<000000:F7]@000000YHVg00D000000P2gd>d01P00
0000^]7/000000000000oooo00000080GE:]0`0000000`2^PJ<0000000000002000000L0oooo00@0
00000?2hU01XK/D00000102hX<03000000/0oooo0P00000308LiI@<0000000<0]9>d0000002dTk@0
0P2dTk@010000000]9>d0;BC]02dTk@3000000040<?Fj0000000_M?Z00000080^M3[00D0000006U=
WP1YCIh000000;F?[`02000000@0QI[P00D000000;RI]`2hVKL0^9Vg000000030;RI^0030000003S
Sf`0000001H0oooo000D0?ooo`030000001G8W40000000H0/YBh00T000000=_Cd@3Kdm40fm?A0000
003oool00000055E^0000000102bSJl01@000000i:B=0>BTS@3TY8d0000005D0oooo00@0000006<d
PP1S=88000001@2dTk@010000000h=S?0>3Hc`0000060?ooo`80000000D0OYWS00000027YNP00000
09>bk00500000080Z<G^00@000000;3;kP00000000000P2gd>d01P000000oooo0?ooo`3oool00000
05eB[@80000000H0[X6S000000000000[X6U0000003UUgH2000000L0oooo0P000000101XK/D00000
0;RP`02hX<02000000030??6X@000000oooo00L0oooo0`0000001029>V@0000008LiI@27>FD20000
00<0]9>d00<000000;BC]02dTk@00P2dTk@4000000<0`mKX0P0000030?ooo`040000001YCIh0JDfN
000000<0]Hn_00<0000008FJh025V^000P25V^02000000030;RI]`000000^9Vh00<0^9Vh00<00000
0>>?K00000005@3oool001<0oooo00@0000005LRL@1G8W4000001@2bU;P01@000000fm?A0=_Cd@3K
dm4000000080oooo00<00000055E^0000000102bSJl5000005@0oooo0P0000000`1S=88000000;BC
]0040;BC]0040000003Te/P000000>3Hc`T0oooo0P00000208NUj0030000002C/^`000000080W[c^
00@000000:S5kP2XaNh000000P2`bnh3000000D0oooo00@0000005aB[@00000000000`2^PJD40000
00L0oooo1P0000001@2fWl4000000??6X@3caZ40000000@0oooo0`000000102;>f<0000008TjI029
>V@300000080]9>d00D000000;BC]02dTk@0]9>d000000030;BC]00400000037f>H0amSV0<OHiP<0
00001@3oool:000000@0QI[P00<000000;RI^02hVKP00`2hVKP010000000hhm/0>>?K000000D0?oo
o`004`3oool00`000000Eb9a000000050;:D^0050000003Kdm40fm?A0=_Cd@0000000`3oool01@00
0000DEFh055E^0000000/Xf_0080000000D0/Xf`0000003RWXP0hYj80000001D0?ooo`030000001O
>8X0000000800000102dTk@00`000000i=K80000000;0?ooo`D0000000<0Tk;/0000002N_>h01P00
00080?ooo`<000000P2^PJD2000000030:b1Y@000000h8e_008000001P3oool010000000IFBm06ET
_@0000040;JO`@030000003caZ4000000080oooo0P0000000`2=>f80000008/kH`0208/kH`800000
00<0]9>d0000002dTk@00P2dTk@01P000000]9>d0;BC]02dTk@000000;BC]0<000000P37f>H20000
00L0oooo00@0000006Y8U`1ZB9L00000102fT:l30000000508FJh0000000000007Z7e00000001@2h
VKP010000000hhm/0>>?K000000C0?ooo`004P3oool00`000000Eb9a000000060;:D^0050000003K
dm40fm?A0=_Cd@0000000`3oool00`000000DEFh055E^002000000@0/Xf`00@000000>:NR03RWXP0
0000DP3oool010000000GcR:05lhRP0000020;BC]080000000D0]9>d0000003Te/P0i=K80000000@
0?ooo`<000003P3oool00`000000GeZe05mJ]@02000000<0[86U1@0000050?ooo`040000001UI;d0
IFBm00000080]Yo12000000308dkHP@000000`2dTk@01@000000]9>d0;BC]02dTk@000000080]9>d
0P0000030<SIiP8000002@3oool010000000JTRG06Y8U`0000040;J@[`040000003ccj/000000000
00<0NXOD00<000000;RI^02hVKP0102hVKP2000000030>bQN@000000oooo0140oooo000A0?ooo`80
000000<0Eb9a0000002bU;P0102bU;P01@000000fm?A0=_Cd@3Kdm40000000D0oooo0`0000050;:=
/0040000003RWXP0hYj800000580oooo00@0000005lhRP1O>8X00000102dTk@3000000030>CFb03o
ool0oooo0200oooo00@0000005mJ]@00000000000P2/PJD200000080ZX6X100000040?ooo`X00000
00H0U3mN0000002@?F00T3eP0000002=>f82000000<0]9>d00@000000;BC]02dTk@00000102dTk@2
000000030<KGi`000000b=WV008000002`3oool00`000000JTRG000000050;J@[`050000003ccj/0
00000?ooo`0000000`1jQm@00`000000^9Vh0;RI^0040;RI^0030000003/XGT000000180oooo000A
0?ooo`040000001@9G`00000000000@0/YBh00D000000=_Cd@3Kdm40fm?A000000060?ooo`040000
001EGKh0EEfn000000D0/Xf`00<000000>:NR0000000D@3oool010000000GcR:05lhRP0000050;BC
]0040000003Xdl000000000002<0oooo0P0000000`1QH[d000000:Z1Z0030:Z1Z0<0000000<0_V5L
0000000000002000000309@oGP050000002D?eh0U3mN0000002@?F000`0000000`2dTk@000000;BC
]0020;BC]0060000002dTk@0]9>d0;BC]0000000]9>d0`0000020<KGi`800000303oool010000000
JTRG06Y8U`0000040;J@[`040000003ccj/0lln[00000080oooo00D0000007Z7e01jQm@0NXOD0000
00040;RI^0050000002gV;P000000>bQN@0000004@3oool00100oooo00<00000050UO00000000P2c
UKP200000080/YBh00@000000=_Cd@3Kdm400000203oool205EM_P030000002bSK00/Xf`00<0/Xf`
00@000000>:NR03RWXP00000D03oool5000000@0]9>d00<000000>SC`0000000903oool00`000000
HF:m065R_@02000000060:Z1Z0000000YgnY0000002UP:`000000P2aDUL20000000309e1EP000000
UCaH0080000000@0QcAL0000002D?eh0U3mN1P0000000`2dTk@000000;BC]0020;BC]0060000002d
Tk@0]9>d0;BC]0000000]9>d0`0000020<CGj0<000003P3oool010000000JTRG06Y8U`0000040;J@
[`030000003ccj/0000000<0oooo00<0000007Z7e01jQm@00P1jQm@010000000^9Vh0;RI^0000002
0;NH^0030000003/XGT000000140oooo000@0?ooo`030000001@9G`0000000@0/iFh0`0000020=_C
d@030000003oool0oooo00H0oooo00@0000005EM_P1EGKh000001@2bSK000`000000hYj80000001@
0?ooo`050000001M?940GCbA0000002dTk@00P0000001@2dTk@000000>SC`03Xdl00000002D0oooo
0P00000206I`b0060000002WOjT000000:F0[0000000Xh6^1@0000000`2E?5P0000008hhF`050000
00050;6A]@000000]9>d0;BC]00000000`2dTk@010000000]9>d0;BC]00000020;BC]0<0000000@0
`mKX00000034enP0a=OX0P00000@0?ooo`030000001ZB9L00000008000000`2fT:l00`000000lln[
000000040?ooo`070000001jQm@0NXOD07Z7e0000000^9Vh000000040;NH^0030000003/XGT00000
0100oooo000?0?ooo`030000001@9G`0000000D0/iFh00<000000>3Ab@3PdLT00P00000:0?ooo`03
0000001EGKh0000000@0/Xf`0`0000000`3OV8<000000?ooo`1>0?ooo`040000001M?940GCbA0000
00<0]9>d0`0000000`3Xdl0000000?ooo`0U0?ooo`0=0000001VL<P0IW380000002WOjT000000:F0
[0000000Xh6^0000002SP[0000000:>3/P05000000030:>8]`000000/I6e0080/I6e00D000000;BC
]02dTk@0]9>d000000020;BC]0040000002dTk@0]9>d0;BC]080000000<0`=CY00000033e^P00P33
e^P200000180oooo0P0000000`1/AI8000000;J@[`02000000040;J@[`000000lln[000000D0oooo
00<0000007Z7e01jQm@00P0000050;NH^0030000003/XGT000000100oooo000?0?ooo`030000001@
9G`0000000D0/iFh00@000000>3Ab@3PdLT000002`3oool01@000000EEfn05EM_P000000/Xf`0080
000000D0/Xf`0000003OV8<0giR30000001>0?ooo`040000001M?940GCbA000000D0]9>d00<00000
0>_?^@000000:03oool20000000406eoe0000000YH2/00000080Xh6^00/000000:>2/0000000Xh>b
0000002SQ[@000000:B7]P000000XhRg000000040;6A]@040000002dTk@0]9>d000000<0]9>d1000
00030<3Dj@<00000503oool00`000000K4FB000000040;J@[`80000000<0lln[0000003oool01@3o
ool20000000307=jb`000000]iRh00D0]iRh00<000000>bQN@0000003`3oool000h0oooo00<00000
050UO00000001@2cUKP01@000000h=790>3Ab@3PdLT0000000`0oooo00@0000005EM_P0000000000
102bSK0010000000giR30=nHP`00001=0?ooo`040000001M?940GCbA000000@0]9>d00@000000>_?
^@3[ckT00000:@3oool00`000000KGoD00000002000000060:>1[P000000Xh:`0000002SPk800000
0P2SQ[@00`000000Y8Nf000000020:>8]`050000002aTKD0/I6e0;6A]@0000000`2dTk@010000000
]9>d0000000000030;kCjP0400000030e>T00000000001D0oooo00@0000006a5TP1/AI8000001@2f
T:l3000000H0oooo00D0000007=jb`1cN//0Lg[;000000050;NH^0030000003/XGT0k:5i00l0oooo
000>0?ooo`030000001@9G`0000000D0/iFh00@000000>3Ab@3PdLT000003@3oool20000000305QU
a@000000/Xf`00<0/Xf`00D000000=nHP`3OV8<0giR30000001<0?ooo`H000000P2dTk@00`000000
jlni0000000[0?ooo`80000000P0MhoN00000000000000000:>2/0000000Xh>b00000080XhJd00<0
00000:B7]P0000000P2SR;L00`000000/I6e0;6A]@07000000040;[Aj`000000_]?Z0;kCjP<00000
5`3oool010000000K4FB06a5TP0000040;J@[`040000003bdk80l]>b000000L0oooo00@0000007=j
b`1cN//000001P2gV;P00`000000k:5i0000000>0?ooo`003@3oool00`000000D2El000000050;>E
^0050000003PdLT0h=790>3Ab@0000003P3oool00`000000F6G5000000050;:=/0040000003OV8<0
giR3000004`0oooo00@0000005a0U`1L@9L000000P2dTk@3000000030>_?^@000000oooo02/0oooo
00@0000007N?gP000000Oi_T0`000000202SPk8000000:>6]02SQ[@000000:B7]P000000XhRg1000
00000`2cc>`000000;O?k0020;O?k0030000002jdN/0000000<000006P3oool010000000K4FB06a5
TP0000040;J@[`030000003bdk80000000P0oooo00D0000007=jb`1cN//0Lg[;000000050;NH^0<0
00003P3oool000d0oooo00<00000050UO00000001@2cUKP010000000h=790>3Ab@00000?0?ooo`04
0000001HILD0F6G5000000@0/Xf`00<000000=nHP`3OV8<00P00001;0?ooo`040000001L@9L0G42G
000000@0]9>d0`00000]0?ooo`80000000<0Oi_T00000029YnT02@0000000`2Ta?0000000;?<k003
0;?<k0030000002gcn`00000008000007@3oool010000000K4FB06a5TP0000050;J@[`030000003b
dk80000000T0oooo00@0000007=jb`1cN//000001P2gV;P00`000000l[>80000000=0?ooo`003@3o
ool00`1;:hP00000000000040;>E^0050000003PdLT0h=790>3Ab@000000403oool00`000000F6G5
000000050;:=/08000000P3MTgl00`000000oooo0?ooo`170?ooo`040000001L@9L0G42G000000D0
]9>d00<000000>c</`000000;P3oool20000000807nKi0000000RJOY0000002?[n`0000009RhkP00
000209nok`040000002Ta?00Y<C`00000080/lc/0`00000P0?ooo`D00000102fT:l00`000000l]>b
000000090?ooo`050000001cN//0Lg[;07=jb`0000000`2gV;P3000000030?:cR0000000oooo00`0
oooo000<0?ooo`040000001;:hP000000;>E^08000000P2cUKP010000000h=790>3Ab@00000A0?oo
o`040000001HILD0F6G5000000<0/Xf`00<000000;:>/00000000P3MTgl00`000000oooo0?ooo`17
0?ooo`040000001L@9L0G42G000000@0]9>d00@000000>c</`3/c;<00000<03oool@000000030?3:
ZP000000oooo0200oooo00D0000006i2S01^@X`000000;NA[`02000000050;J@[`000000l]>b0?;C
/P0000002P3oool01@000000Lg[;07=jb`000000]iRh008000000`2fV;T2000000d0oooo000<0?oo
o`800000102cUKP300000080h=7900<000000?ooo`3oool0403oool010000000F6G50000002bSK02
00000080/Xj`00D000000=fCO`3MTgl0gI=o000000180?ooo`H000000P2dTk@00`000000k<bc0000
000g0?ooo`040000001UCJ40IDfQ000000@0]9>d00<000000?3:ZP0000008@3oool010000000KT:<
06i2S00000040;NA[`80000000<0l]>b0000003oool02P3oool00`000000Lg[;07=jb`02000000D0
]YRi0P00000=0?ooo`00303oool2000000D0/iFh00@000000>C<_`00000000004`3oool010000000
F6G505QUa@0000050;:>/0040000003MTgl0gI=o000004P0oooo00@0000005a1V01L@IP000000P2d
Tk@3000000030>c</`000000000003H0oooo1P0000020;BC]0030000003`bZX000000240oooo00@0
000006i2S01^@X`000001@2gTJl3000000`0oooo0P0000000`1^K;l000000;JH^@040;JH^@030000
003b/hP0000000`0oooo000;0?ooo`030000001;:hP0000000@0/iFh00D000000>C<_`3Tc;l0i<bo
0000000D0?ooo`80000000<0G6g;0000002bS[00102bS[0010000000gI=o0=fCO`0000160?ooo`05
0000001L@IP0G46H05a1V0000000102dTk@3000003L0oooo00@0000006E9W01UBI`000000P2dTk@5
00000200oooo00@0000006i2S01^@X`000001@2gTJl010000000kmRi0>oH^@00000<0?ooo`050000
001^K;l0KVbo06i/_`000000102fV;T00`000000l[>80000000<0?ooo`002`3oool00`000000Bb^8
000000040;>E^0040000003Tc;l0i<bo000001D0oooo00@0000005a]b`1LKL/000001P2bS[000`00
0000gI=o000000160?ooo`040000001L@IP0G46H000000D0]9>d00<000000>c</`000000=`3oool0
0`000000IDVL000000050;BC]0030000003_c[0000000200oooo00@0000006i2S01^@X`000001@2g
TJl00`000000kmRi0000000>0?ooo`040000001^K;l0KVbo000000D0]YRi0P00000<0?ooo`002P3o
ool00`000000Bb^8000000050;>E^0040000003Tc;l0i<bo000001H0oooo00@0000005a]b`1LKL/0
00001@2bS[0010000000gI=o0=fCO`0000150?ooo`80000000<0G46H0000002dTk@00`2dTk@01000
0000k<bc0>c</`00000g0?ooo`030000001UBI`0000000@0]9>d00@000000>o>/03_c[0000007`3o
ool010000000KT:<06i2S00000050;NA[`040000003_f;T0kmRi000000h0oooo00@0000006i/_`1^
K;l000001@2fV;T00`000000l[>80?ooo`0;0?ooo`002P3oool00`000000Bb^8000000040;>E^005
0000003Tc;l0i<bo0>C<_`0000005P3oool010000000G6g;05a]b`0000060;:>/080000000<0g99n
0000003oool0@`3oool00`000000GSbA0000000300000080]9>d00<000000>c</`000000>03oool5
00000080]9>d00@000000>o>/03_c[0000007`3oool5000000@0]i6_00<000000>oH^@0000003`3o
ool01@000000KVbo06i/_`1^K;l0000000@0]YRi00<000000?:cR00000002`3oool000X0oooo00<0
000004/[R0000000102cUKP010000000i<bo0>C<_`00000H0?ooo`040000001LKL/0G6g;000000<0
/Xj`0P0000001@2bS[4000000=bBOP3LTWh0000004<0oooo00<0000005hlT@0000000`2dTk@30000
00030>c</`000000oooo03L0oooo00<0000006M5U@0000000P2dTk@6000001l0oooo00D000000710
Q`1`@8L000000;NA/002000000050;NA[`000000kmRi0>oH^@000000403oool010000000KVbo06i/
_`0000050;JH^@8000002`3oool000T0oooo00@0000004/[R01;:hP00000102cUKP010000000i<bo
0>C<_`00000I0?ooo`040000001LKL/000000;:>/08000000`2bS[4010000000g99n0=bBOP000012
0?ooo`040000001N?940GSbA000000D0]9>d0`00000g0?ooo`030000001WAID0000000D0]9>d00@0
00000>kC^03^dkP000007P3oool010000000L4270710Q`0000040;NA/08000000P3_f;TA0?ooo`05
0000001^K;l0KVbo06i/_`0000000P2fV;T4000000/0oooo00090?ooo`030000001;:hP0000000D0
/iFh00@000000>C<_`3Tc;l000006P3oool00`000000G6g;000000060;:>/@040000003LTWh0g99n
00000440oooo00<0000005hlT@0000001@2dTk@010000000jm2i0>_@^@00000g0?ooo`030000001W
AID0000000@0]9>d00@000000>kC^03^dkP000007`3oool010000000L4270710Q`0000040;NA/004
0000003]fl40000000000180oooo00<0000006i/_`0000000`0000020;FG^0030000003d_I400000
00X0oooo00090?ooo`D000000P2cUKP010000000i<bo0>C<_`00000K0?ooo`80000000<0GFk<0000
002bS[401@2bS[4010000000g99n0=bBOP0000100?ooo`@00000102dTk@010000000jm2i0>_@^@00
000f0?ooo`030000001Y@Hh0000000<000000P2dTk@010000000k]>h0>kC^000000N0?ooo`040000
001`@8L0L427000000D0]i6`00<000000>gK`@0000004`3oool20000000306eU^@000000]INh00<0
]INh00<000000?BmT@0000002P3oool000T0oooo00<0000004PaT`0000000P2dU[T7000001/0oooo
00@0000005e^c01MK/`000001@2bS[400`000000g99n0=bBOP02000003l0oooo00@0000005dmTP00
0000]9>d0P0000001@2dTk@000000>_@^@3[d;T0000003L0oooo00@0000006U1SP1Y@Hh000000P2d
Tk@3000000030>kC^0000000oooo01h0oooo00@000000710Q`1`@8L00000102gTK0010000000kM_1
0>gK`@00000C0?ooo`040000001]IKT0KFFi000000D0]INh0P00000:0?ooo`002@3oool00`000000
B36C000000040;BF^@040000003VbKT0i/Vi000001d0oooo00<0000005e^c00000001P2bS[420000
0080gIB000<000000?ooo`3oool0?03oool00`000000GCfB000000030;BC]0<0000000<0jm2i0000
003oool0=@3oool010000000JD6>06U1SP0000050;BC]0<000007P3oool010000000L4270710Q`00
00050;NA/0030000003]fl40000001@0oooo00D000000?>lTP1]IKT0KFFi000000040;FG^0800000
2P3oool000T0oooo00<0000004PaT`000000102dU[T010000000i/Vi0>K9^@00000M0?ooo`040000
001MK/`0GFk<000000@0/Xja00<000000;:>/@0000000P3MU8000`000000oooo0?ooo`0k0?ooo`03
0000001M?I80000000D0]9>d00@000000>_?^@0000000000=P3oool5000000<0]9>d00@000000>_G
_`3[ekl000007P3oool4000000@0]i6`00@000000>gK`@3]fl400000503oool01@000000KFFi06eU
^@1]IKT0000000@0]INh00<000000?BmT@0000002@3oool000P0oooo00@0000004PaT`18<I<00000
102dU[T010000000i/Vi0>K9^@00000N0?ooo`050000001MK/`0GFk<0000002bS[400P0000020;:>
/@050000003MU800gIB00=fDP0000000?03oool00`000000GCfB000000040;BC]0050000003[ckT0
jlni0>_?^@000000=P3oool00`000000Jcn:000000020;BC]080000000@0]9>d0000003[ekl00000
7P3oool01P000000LCn5074oQ@000000]i:`000000<0]i6`00<000000>gK`@0000005@3oool01@00
0000KFFi06eU^@1]IKT0000000@0]INh00<000000?BmT@0000002@3oool000P0oooo00<0000004Pa
T`0000001@2dU[T010000000i/Vi0>K9^@00000O0?ooo`040000001MK/`0GFk<000000D0/Xja00@0
00000=fDP03MU8000000?03oool500000080]9>d00@000000>_?^@3[ckT00000=P3oool010000000
Jcn:06/oRP0000040;BC]080000000<0jmNo0000003oool07@3oool010000000LCn5074oQ@000002
0;NB/0<000000P3]fl400`000000oooo0?ooo`0D0?ooo`040000001]IKT0KFFi000000@0]INh00<0
00000?BmT@3d_I402@3oool000P0oooo00<0000004PaT`000000102dU[T010000000i/Vi0>K9^@00
000P0?ooo`050000001MK/`0000005a]b`0000001@2bS[4010000000gIB00=fDP000000k0?ooo`03
0000001L@9L000000080]9>d100000000`3[ckT000000?ooo`0e0?ooo`030000001[?hX0000000D0
]9>d00@000000>WIa@00000000007@3oool010000000LCn5074oQ@0000050;NB/0030000003]fl40
kM_101L0oooo00@0000006eU^@1]IKT000001@2eUkP00`000000m;fA000000080?ooo`00203oool0
0`000000B36C000000040;BF^@040000003VbKT0i/Vi00000240oooo0P0000000`1LKL/000000;:>
/@050;:>/@040000003MU800gIB0000003X0oooo00<0000005a0U`000000102dTk@010000000k<bd
00000000000e0?ooo`030000001/?XL0000000800000102dTk@00`000000jMW50000000N0?ooo`04
0000001a?hD0LCn5000000D0]i:`0`00000G0?ooo`050000001]IKT0KFFi06eU^@000000102eUkP0
0`000000m;fA000000080?ooo`00203oool00`000000B36C000000040;BF^@040000003VbKT0i/Vi
00000280oooo00@0000005a]b`1LKL/000001@2bS[4010000000gIB00=fDP000000i0?ooo`030000
001L@9L0000000D0]9>d00@000000>c<]03/c;@00000=@3oool00`000000K3j7000000020;BC]080
000000D0]9>d0000003YfLD0jMW50000000M0?ooo`040000001a?hD0LCn5000000D0]i:`00<00000
0>_La0000000603oool01@000000KFFi06eU^@1]IKT000000080]INh1@0000080?ooo`00203oool0
0`000000B36C000000040;BF^@040000003VbKT0i/Vi00000280oooo00@0000005a]b`1LKL/00000
1P2bS[44000003P0oooo00<0000005a0U`000000102dTk@010000000k<bd0>c<]000000e0?ooo`04
0000001/?XL0K3j7000000@0]9>d0P0000000`3YfLD000000?ooo`0L0?ooo`8000000P1a?hD00`00
0000]i:`0;NB/0030;NB/0030000003[g<@0000001P0oooo1`0000020;BG^0030000003ebZ000000
00P0oooo00080?ooo`/000008`3oool010000000G6g;05a]b`0000030;:>/@<000000P3RWXP00`00
0000oooo0?ooo`0f0?ooo`030000001L@9L0000000@0]9>d00@000000>c<]03/c;@00000=@3oool0
0`000000K3j7000000050;BC]0040000003Wf/L00000000001d0oooo100000050;NB/0030000003[
g<@0000001T0oooo00D0000006aK[P1/Fjh0K5^^000000040;BG^0030000003ebZ00000000P0oooo
00080?ooo`0300000017?:40000000@0]9Ni00@000000>S2[`3X`Zl00000903oool010000000G6g;
0000002bS[42000000<0/Xj`00@000000>:NR03RWXP00000=`3oool;000003@0oooo00<0000006/n
R@0000000P0000040;BC]0030000003Wf/L0000001d0oooo00D00000074oQ@1a?hD000000;NB/002
000000<0]i:`00<000000>_La00000006@3oool01@000000K5^^06aK[P1/Fjh0000000@0]9Nh00<0
00000?G:X0000000203oool000P0oooo00<0000004LlX@000000102dUkT010000000j<:_0>S2[`00
000T0?ooo`040000001LKL/0G6g;000000D0/Xj`00@000000>:NR03RWXP00000=`3oool00`000000
FdFN000000040;BC]0040000003]ajd0kLN]000003@0oooo00<0000006/nR@0000000P2dTk@20000
00050;BC]0000000im[70>OJa`0000007@3oool010000000LCn5074oQ@0000030;NB/0<0000000<0
jmc40000003oool06@3oool01@000000mLVQ06aK[P1/Fjh0000000@0]9Nh00<000000?G:X0000000
203oool000P0oooo00<0000004LlX@000000102dUkT010000000j<:_0>S2[`00000U0?ooo`800000
00<0F6C30000002bS[00102bS[0010000000hYj80>:NR000000e0?ooo`040000001KAIh0FdFN0000
00@0]9>d00@000000>g7[@3]ajd00000<`3oool010000000Jcj906/nR@0000040;BC]080000000<0
im[70000003oool0703oool010000000LCn5074oQ@0000060;NB/0030000003[g<@0000001X0oooo
00D0000006aK[P1/Fjh0K5^^000000040;BG^0030000003ebZ00000000P0oooo00080?ooo`030000
0017?:40000000@0]9Ni00@000000>S2[`3X`Zl000009P3oool00`000000F6C3000000050;:>/004
0000003RWXP0hYj8000003D0oooo00@0000005]5WP1KAIh00000102dTk@010000000kLN]0>g7[@00
000c0?ooo`030000001[?XT0000000D0]9>d00@000000>SJaP00000000007@3oool010000000LCn5
074oQ@0000050;NB/080000000<0jmc40?ooo`3oool06@3oool01@000000K5^^06aK[P1/Fjh00000
00@0]9Nh00<000000?G:X0000000203oool000P0oooo00<0000004LlX@000000102dUkT010000000
j<:_0>S2[`00000V0?ooo`040000001HI<<0F6C3000000D0/Xj`00@000000>:NR03RWXP00000=03o
ool010000000FdFN05]5WP0000020;BC]0H00000<P3oool00`000000J4:@00000002000000@0]9>d
00<000000>SJaP0000007@3oool010000000LCn5074oQ@0000060;NB/0030000003[g<@0000001`0
oooo00@0000006aK[P1/Fjh00000102dUkP00`000000mLZP000000080?ooo`00203oool00`000000
AcbQ000000040;BG^@040000003X`Zl0j<:_000002L0oooo00@0000005QT``1HI<<00000102bS[00
10000000hYj80>:NR03RWXPd0?ooo`H000000P2dTk@010000000kL2T0>g0Y000000b0?ooo`050000
001X@Y00J4:@0000002dTk@00P0000001@2dTk@000000>SJaP3Xf/H0000001d0oooo00@00000074o
Q@1a?hD000001@2gT[000`000000jmc40000000M0?ooo`040000001/Fjh0K5^^000000@0]9Nh00<0
00000?G:X0000000203oool000P0oooo00<0000004LlX@000000102dUkT010000000j<:_0>S2[`00
000X0?ooo`030000001HI<<0000000<0/Xj`1P00000c0?ooo`040000001JC:P0FTbX000000@0]9>d
00@000000>g0Y03]`:@00000<@3oool010000000J4:@06Q2T00000040;BC]080000000<0j=[60000
003oool0703oool200000003074oQ@000000]i:`00D0]i:`00<000000>_La00000007@3oool01000
0000K5^^06aK[P0000040;BG^0030000003ebZ00000000P0oooo00080?ooo`0300000017?:400000
00@0]9Ni00@000000>S2[`0000000000:03oool00`000000F6C305QT``0300000080/hn`00@00000
0>N]U@3W[ID00000<`3oool010000000FTbX05Y<Z00000040;BC]0040000003]`:@0kL2T00000340
oooo0P0000000`1X@Y0000000;BC]0030;BC]0040000003/e[d00000000001d0oooo00<0000006i1
RP0000000P0000040;NB/0030000003[g<@0000001h0oooo00@0000006aK[P1/Fjh00000102dUkP0
0`000000mLZP000000080?ooo`00203oool00`000000AcbQ000000020;BG^@@0000000<0ikVU0000
003oool0:03oool3000000@0/hn`00@000000>N]U@3W[ID00000=03oool00`000000FTbX00000004
0;BC]0040000003]`:@0000000000340oooo00@0000006M3TP0000000000102dTk@010000000k=Jm
0>cF_@00000L0?ooo`060000001^@HX0KT6:06i1RP000000]Y6`0P0000020;NB/0030000003[g<@0
000001h0oooo2`0000080?ooo`00203oool500000080]INi00@000000>NiY@3W^JD00000:@3oool0
0`000000DTn`000000050;>?/0040000003W[ID0ijfE000003<0oooo00<0000005Y<Z00000000P2d
Tk@4000000030>bhV`000000oooo02l0oooo00D0000006M3TP1W@i8000000;BC]002000000050;BC
]0000000k=Jm0>cF_@0000007@3oool010000000KT6:06i1RP0000040;JA/080000000<0jmc40000
003oool07P3oool010000000K5>S06aCX`0000040;BF^0030000003de:l0000000P0oooo00080?oo
o`0300000018BJl0000000@0]INi00@000000>NiY@3W^JD00000:@3oool010000000DTn`059?/000
00040;>?/0040000003W[ID0ijfE000003<0oooo1@0000020;BC]0040000003/^9/0k;RK00000300
oooo00@0000006M3TP1W@i8000000`2dTk@3000000030>cF_@000000oooo01/0oooo00D0000006i1
RP1^@HX0KT6:000000040;JA/080000000<0jmc40000003oool07P3oool010000000K5>S06aCX`00
00040;BF^08000002@3oool000P0oooo00<0000004Q9[`000000102eUkT010000000ikVU0>NiY@00
000Y0?ooo`040000001BCk00DTn`000000@0/hn`00@000000>N]U@3W[ID00000<`3oool00`000000
FeBa000000040;BC]0040000003/^9/0k;RK00000300oooo00<0000006M3TP0000001@2dTk@01000
0000k=Fl00000000000L0?ooo`040000001^@HX0KT6:000000D0]Y6`00<000000>kJ_P0000007`3o
ool010000000K5>S06aCX`0000040;BF^0030000003de:l0000000T0oooo00080?ooo`0300000018
BJl0000000@0]INi00D000000>NiY@3W^JD0ikVU0000000X0?ooo`040000001BCk00DTn`000000@0
/hn`00@000000>N]U@3W[ID00000<`3oool00`000000FeBa000000050;BC]0030000003/^9/00000
02l0oooo00<000000>_F_`0000000P0000030;BC]0040000003/eK`0k=Fl000001d0oooo00@00000
06i1RP1^@HX00000102fTK0010000000k]Zn0>kJ_P00000O0?ooo`040000001/Dj<0K5>S000000@0
]9Jh00<000000?CD[`0000002@3oool000P0oooo00<0000004Q9[`0000001@2eUkT010000000ikVU
0>NiY@00000Y0?ooo`030000001BCk00000000D0/hn`00@000000>N]U@3W[ID00000<P3oool01000
0000FeBa05]D/@0000020;BC]0D00000;`3oool01@000000J46?06Q1S`000000]9>d0080000000D0
]9>d0000003/eK`0k=Fl0000000L0?ooo`040000001^@HX0KT6:000000D0]Y6`00<000000>kJ_P00
0000803oool010000000K5>S06aCX`0000040;BF^0030000003de:l0000000T0oooo00080?ooo`03
00000018BJl0000000D0]INi00@000000>NiY@3W^JD00000:@3oool010000000DTn`059?/0000002
0;>?/0H00000<P3oool00`000000FeBa0000000300000080]9>d00<000000>^`T`000000103oool:
00000200oooo00@0000006Q1S`1X@Hl00000102dTk@2000000030>cE_0000000oooo01`0oooo1000
00040;JA/0040000003^f[h0k]Zn00000200oooo00@0000006aCX`1/Dj<00000102dU[P00`000000
m=B_000000090?ooo`002@3oool00`000000B4V_000000040;FG^@040000003W^JD0ikVU000002T0
oooo00<00000059?/00000000`0000020;B?/0040000003Y]9`0jKBL00000380oooo0P0000000`1L
G;P000000;BC]0030;BC]0030000003[/9<0jk2C00@0000000D0SceR0000002F@V00UT9P00000002
09i7G`030000002UCEh0YDeN00H000006P3oool20000000306Q1S`000000]9>d00<0]9>d00@00000
0>_G_`00000000007@3oool00`000000JTNE06Y7U@0300000080]Y6`00<000000>kJ_P000000803o
ool01@000000K5>S06aCX`1/Dj<0000000@0]9Jh00<000000?CD[`0000002@3oool000T0oooo00<0
000004Q9[`000000102eUkT010000000ikVU00000000000Y0?ooo`80000000<0DDJW0000002dSk00
0`2dSk0010000000jKBL0>VdW000000b0?ooo`040000001LG;P0G5bh000000D0]9>d00L000000>^`
T`000000QcUU0000002??F8000000080UT9P00D0000009i7G`2NAel0WTMO000000020:E=GP060000
002/DEh0[55N0:aAGP000000[eAM0`00000F0?ooo`030000003Xf<@0Jcn:00800000102dTk@01000
0000jmNo0>_G_`00000L0?ooo`040000001ZAiD0JTNE000000<0]Y2`0P0000020>kJ_P030000003o
ool0oooo01h0oooo00@0000006aCX`1/Dj<000001@2dU[P2000000X0oooo00090?ooo`0300000018
BJl0000000<0]INi0`0000000`3V[i/000000?ooo`0X0?ooo`040000001AAZL0DDJW000000@0]8n`
00@000000>VdW03Y]9`00000<`3oool010000000G5bh05aL^00000030;BC]0D0000000<0SceR0000
000000002`0000020:aAGP030000002_E5d000000080[eEN0`00000C0?ooo`050000001[?hX0Jcn:
0000002dTk@00P0000001@2dTk@000000>_G_`3[ekl0000001d0oooo00@0000006Y7U@1ZAiD00000
102fT;02000000030>kJ_P3oool0oooo01l0oooo0P0000000`1/Dj<000000;BF^0030;BF^0030000
003de:l0000000X0oooo00090?ooo`0400000018BJl000000;FG^@80000000<0]YRh0000003V[i/0
0P3V[i/00`000000oooo0?ooo`0V0?ooo`040000001AAZL0DDJW000000@0]8n`00@000000>VdW03Y
]9`00000<`3oool01@000000G5bh05aL^0000000]9>d0080000000@0]IBf0000003YZXh0jJZ>0P00
00001@2XRkL000000:R:]@2XR[D000000080Z8Vd00H000000:R8/P2XR;80Z8Rb0000002XQk450000
0080[eEN00<000000;AIG`2dFEl00P00000@0?ooo`050000001[?hX0Jcn:06/oRP0000000`2dTk@3
000000030>_G_`000000oooo01`0oooo00@0000006Y7U@1ZAiD00000102fT;000`000000l]6_0000
000Q0?ooo`80KDfJ100000020;BF^0030000003de:l0000000X0oooo00090?ooo`@00000102fV;P0
10000000iZnK0>J_V`00000X0?ooo`040000001AAZL0DDJW000000D0]8n`00@000000>VdW03Y]9`0
0000<`3oool010000000G5bh0000000000040;FD]P030000003YZXh000000080Z8^g00@000000:R:
]@2XR[D000000P2XRK@010000000Z8Rb0:R8/P0000020:R7/@050000002WQ[00YhJ`0000002XQ[00
0`0000020;AIG`040000002jGf000000000000h0oooo0P0000000`1[?hX000000;BC]0040;BC]004
0000003YfL@00000000001d0oooo00@0000006Y7U@1ZAiD00000102fT;000`000000l]6_0000000P
0?ooo`050000001]CIX0KDfJ06e=VP0000000P2cUKP5000000X0oooo00090?ooo`030000001<Ek`0
000000D0]YRh00@000000>J_V`3V[i/00000:03oool01@000000DDJW0556Y`1AAZL0000000@0]8n`
00@000000>VdW03Y]9`00000<@3oool5000000D0]IBf00H000000>VZSP3YZXh000000:R;]`000002
0:R:]@040000002XRK@0Z8Vd00000080Z8Rb00@000000:R7/@2XQk4000000P2WQ[001@000000Z8J`
0:R6/0000000Z8J`00<000000`2jGf02000000/0oooo00<0000006hmQ01^?H@00`0000030;BC]004
0000003YfL@0jMW4000001d0oooo00@0000006Y7U@1ZAiD00000102fT;0010000000l]6_0?;A[`00
000P0?ooo`040000001]CIX0KDfJ000000D0/iFh00<000000?3L^`0000002P3oool000X0oooo00<0
000004aG_0000000102fV;P01@000000iZnK0>J_V`3V[i/0000002P0oooo00@000000556Y`1AAZL0
0000102dSk0010000000jKBL0>VdW000000_0?ooo`8000000P24>VT010000000GV>o05iS_`000005
0;FD]P<0000000D0Z8^g0000002XR[D0Z8Ze000000020:R9]0030000002XR;8000000080Z8Na00@0
00000:N6/02WQ[0000000`2XQ[001@000000Z8J`0:R6/0000000ZHF_00<000000P31IV82000000T0
oooo00@0000006hmQ01^?H@000000P2dTk@2000000050;BC]0000000jMW40>WIa00000007@3oool0
10000000JTNE06Y7U@0000040;J@/0040000003bdJl0l]6_00000200oooo00@0000006e=VP1]CIX0
0000102cUKP00`000000l=bk0000000;0?ooo`002P3oool00`000000C5Nl000000050;JH^0040000
003V[i/0iZnK000002P0oooo00@000000556Y`1AAZL00000102dSk0010000000jKBL0>VdW000000^
0?ooo`8000000`24>VT010000000GV>o05iS_`0000040;FD]P8000000P3]]YH>000000050:N6/000
0000Z8J`0:R6/00000000P2XQ[0010000000ZHF_0:V5[`2YQJl3000000030<5VHP000000aVeT0080
00001`3oool010000000KSf406hmQ00000040;BC]080000000<0jMW40000003oool07@3oool50000
00<0]Y2`00<000000?;A[`000000803oool01@000000KDfJ06e=VP1]CIX0000000@0/iFh00<00000
0?3L^`0000002`3oool000X0oooo00<0000004aG_00000001@2fV;P010000000iZnK0>J_V`00000X
0?ooo`030000001AAZL0000000T00000;03oool200000080OcQ/0`0000001P2dTk@0000005iS_`1N
Hkl000000;FD]P80000000T0^9no0000003]]YH0kKJF0000002ZbO0000000:32l00000000P2I^o00
10000000Sk;^00000027ZN/200000006086Rj@00000000000000002XQ[0000000P2XQ[0010000000
ZHF_0:V5[`0000030:V5[P0300000036KF@0aVeT0080aVeT00<000000?ooo`3oool00`3oool01000
0000LS]n0000000000050;BC]0040000003Ug</00000000001h0oooo00D0000006Q:V`1XBY/00000
0;F@/002000000040;J@/0000000l]6_00000200oooo00@0000006e=VP1]CIX000001@2cUKP00`00
0000l=bk0000000;0?ooo`002`3oool00`000000C5Nl000000040;JH^0050000003V[i/0iZnK0>J_
V`0000009`3oool2000000030555Y@000000]8n`00<0]8n`00@000000>VfW@3Y]Yd00000:`3oool0
0`000000OcQ/07lhK00207lhK0040000002dTk@0]9>d0;BC]0D000000`2hWkl010000000kKJF0000
000000020:[9l0H0000000P0Sk;^00000027ZN/0QjW[00000021X^T0000008>Tj@80000000<0Z8J`
0000002YQJl00P2YQJl01@000000ZHF^0:V5[P000000ZXF]0080000000<0aVeT0000003<LfL00P00
00020?ooo`060000001b>gh0LS]n0000002dTk@000000`2dTk@010000000iMc;0>GLb`00000O0?oo
o`040000001XBY/0J4ZK000000<0]I2`0P0000000`3bdJl000000?ooo`0O0?ooo`040000001]CIX0
KDfJ000000@0/iFh00<000000?3L^`000000303oool000/0oooo00<0000004aG_00000001@2fV;P0
10000000iZnK00000000000W0?ooo`040000001AAJD0DDFU000000@0]8n`00@000000>VfW@3Y]Yd0
0000:P3oool010000000NcM_0000001o>6`2000000050;BC]0000000]9>d0;BC]00000000P1NK<P0
0`000000^9no0;RO_`030;RO_`80000000<0k;2@0000000000001P3oool500000004086Rj@000000
PjCY08>Tj@@0000000D0ZHF_0000002YQJh0ZHF^000000040:Z5[@030000003<LfL0c7=W0080c7=W
0P000000101g>gT00000078kOP0000020;BC]080000000@0]9>d0000003Ug</00000803oool01000
0000J4ZK06Q:V`0000040;F@/0<000007`3oool01@000000KDfJ06e=VP1]CIX0000000@0/iFh00<0
00000?3L^`000000303oool000/0oooo00<0000004aG_0000000102fV;P3000000030>BZU@000000
oooo02H0oooo00@000000555Y@1AAJD00000102dSk0010000000jKJM0>VfW@00000Y0?ooo`050000
001k=fl0NcM_07/gK`0000000`2dTk@01`000000]9>d0;BC]02dTk@0000005i/b0000000102hWkl2
00000080k;2@00<000000?ooo`3oool02P3oool30000000308>Tj@000000P:3W00@000000P2YQJh0
20000000ZXF]0:Z5[@2ZQJd000000:^5[0000000c7=W0P0000001@3?N6P0000007LkN@1g>gT00000
00D0]9>d00@000000>GLb`3Ug</00000803oool010000000J4ZK06Q:V`0000040;F@/0030000003b
c:P0000001l0oooo00D0000006e=VP1]CIX0KDfJ000000040;>E^0030000003`g;/0000000`0oooo
000<0?ooo`040000001<Ek`000000;JH^080000000<0]YNh0000003TZYD00P3TZYD00`000000oooo
0?ooo`0T0?ooo`040000001AAJD0DDFU000000@0]8n`00@000000>VfW@3Y]Yd00000:03oool01`00
0000NcM_07/gK`1k=fl000000;BC]00000000`2dTk@010000000]9>d00000000000205i/b0040000
002hWkl0000000000080^J2o0P0000000`3ZZ8P000000?ooo`0=0?ooo`80000000@0P:3W0000001k
VN@0NiWT0`0000030:Z5[@050000002[QJ`0ZhF/0:^5[00000000`3?N6P01@000000Mc]i0000002d
Tk@0000000<0]9>d00@000000>7MdP0000000000803oool010000000J4ZK06Q:V`0000050;F@/003
0000003bc:P0000001l0oooo00@0KT^G00000000000000001@2cUKP00`000000l=bk0000000<0?oo
o`00303oool4000000@0]YNh00@000000>BZU@3TZYD000009P3oool010000000DDFU0555Y@000004
0;B?/0040000003Y]Yd0jKJM000002L0oooo0P0000000`1k=fl00000000000020;BC]0030000002d
Tk@0]9>d0080]9>d00<000000<WIi@39fND0100000050;VP_`040000003ZZ8P0jZR8000000l0oooo
0P000000101kVN@0000007F@h01eT>02000000030:Z5[@000000ZhF/0080ZhF/00<000000:^5[000
00000P3?N6P2000000<0]9>d0P000000102dTk@000000>7MdP00000Q0?ooo`040000001XBY/0J4ZK
000000@0]I2`00@000000?;<Z03bc:P000007P3oool010000000KT^G06i;U`1^BiL300000080/iFh
00<000000?3L^`3`g;/03@3oool000`0oooo00<00000051Oa00000001@2fUkP010000000i:ZE0>BZ
U@00000W0?ooo`030000001AAJD0000000@0]8n`00@000000>VfW@3Y]Yd000009@3oool200000080
N3Ia00<000000;BC]02dTk@00`2dTk@00`000000]9>d0000000200000080bMWU00@00000069dc`1R
M<l000000`2iX;l3000000040>ZXR0000000i9]n00000100oooo0P0000001@1eT>0000000769g01a
RM`000000080ZhF/0P0000030:^5[08000000P3BNfT00`000000]9>d0;BC]0020;BC]0040000003Q
gM80hMgB00000240oooo00@0000006Q:V`1XBY/00000102eT;000`000000l/bX0000000O0?ooo`05
0000001^BiL0KT^G06i;U`0000000P2cUKP5000000d0oooo000=0?ooo`030000001@Gl@0000000D0
]YNh00@000000>BZU@3TZYD000009P3oool00`000000DDFU000000040;B?/0040000003Y]Yd0jKJM
000002@0oooo00L0000007PfL@1h=W40N3Ia0000002dTk@0000000D0]9>d00@000000<kJhP3>f^80
c][R0P0000001@3oool00000069dc`000000^J2o008000000`2kXKl200000080i9]n00<000000?oo
o`3oool03`3oool2000000030769g0000000000000800000102[QJ`00`000000[hZ_000000030=9k
J@050000002dTk@0]9>d0000003Lg]P00P00000R0?ooo`040000001XBY/0J4ZK000000@0]I2`00<0
00000?;<Z00000007P3oool01@000000KT^G06i;U`1^BiL0000000D0/iFh00<000000>oN_`000000
3@3oool000d0oooo00<00000051Oa00000001@2fUkP010000000i:ZE0>BZU@00000V0?ooo`030000
001AAJD0000000P000008`3oool01@000000M3Ic0000001h=W4000000080]9>d00<000000;BC]02d
Tk@00P2dTk@2000000030<kJhP000000000000<0oooo00@00000069dc`1RM<l000001@2kXKl01@00
0000i9]n0>BKOP3TVgh0000001<0oooo0P00000206b2e`<0000000<0ZhF/0000002_RZl00P2_RZl0
0`000000dW]Y0=9kJ@0300000080g=kH00<000000?ooo`3oool08@3oool9000000030?;<Z0000000
oooo01d0oooo00D0000006i;U`1^BiL0KT^G000000040;>E^0030000003_g[l0000000h0oooo000>
0?ooo`030000001@Gl@0000000D0]YNh00@000000>BZU@3TZYD000009@3oool3000000@0]8n`00@0
00000>VeW@3Y]Id000008P3oool01@000000M3Ic07@fL`1d=W<0000000@0]9>d00@000000;BC]000
000000000P3Cfmh00`000000oooo0?ooo`040?ooo`80000000<0Ih3H0000002kXKl00P2kXKl00`00
0000_:6m00000002000000030>2BM`000000000001<0oooo0`0000000`1XNm<00000000000050:n:
[`8000000P3QTgP00`000000g=kH0000000T0?ooo`040000001XBYX0J4ZJ000000@0]I2`0`00000N
0?ooo`040000001^BiL0KT^G000000D0/iFh00<000000>oN_`0000003P3oool000h0oooo00<00000
051Oa00000001@2fUkP010000000i:ZE0>BZU@00000U0?ooo`030000001AAJH0000000@0]8n`00@0
00000>VeW@3Y]Id000008@3oool01`000000M3Ic07@fL`1d=W<000000;BC]0000000102dTk@01@00
0000dm_N0=?KgP3Cfmh0000000P0oooo00H0000006N0f01WP=P000000;^Q_`0000040;bQ_@040000
003PTWL000000=N4K`8000004@3oool300000080J7_C0P0000050:n:[`040000003QTgP0hI=h0>6C
N08000008`3oool010000000J4ZJ06Q:VP0000040;F@/0040000003bc:P0l/bX000001d0oooo00D0
000006i;U`1^BiL0KT^G000000040;>E^0040000003_g[l0kmjo000000h0oooo000?0?ooo`030000
001@Gl@0000000D0]YNh0P0000000`3PWh`000000?ooo`0S0?ooo`030000001AAJH0000000@0]8n`
00@000000>VeW@3Y]Id00000803oool20000000307@fL`00000000000080]9>d00T000000;BC]02d
Tk@0]9>d0000003Efm`000000=?KgP0000002@3oool00`000000Ih3H06N0f002000000@0_:6m00@0
00000;jS_@00000000000P3GQ6l3000000d0oooo0P000002090nHP<0000000<0JgcB0000002_RZl0
0`2_RZl01`000000_:2l0000003QTgP000000>:FNP0000008`3oool010000000J4ZJ06Q:VP000004
0;F@/0040000003bc:P0l/bX000001d0oooo00@0000006i;U`1^BiL000001@2cUKP00`000000kmjo
0000000?0?ooo`003`3oool00`000000D5o4000000050;JG^0040000003PWh`0h9n<000002@0oooo
00<000000555YP000000102dSk0010000000jKFM0>VeW@00000O0?ooo`040000001b=GH0LSEf0000
00D0]9>d00<000000;BC]00000000`3Efm`00`000000oooo0?ooo`090?ooo`8000000P1`S^001000
0000_:6m0;bQ_@0000030;jS_@80000000<0ehA_0000003>MfP0100000080?ooo`80000000<0VTAN
0000000000000P2@?V8200000080JgcB00@000000:n:[`00000000000`2lX;`01@000000hYIj0>:F
NP3RUWX000000280oooo00@0000006Q:VP1XBYX00000102eT;0010000000l/bX0?;<Z000000L0?oo
o`050000001^BiL0KT^G06i;U`0000001@2cUKP00`000000kmjo0000000?0?ooo`00403oool00`00
0000D5o4000000030;JG^0030000002gV;P000000080h9n<00<000000?ooo`3oool08@3oool01000
0000DDFV0555YP0000040;B?/0040000003Y]Id0jKFM000001h0oooo00D00000078eMP000000]9>d
000000050;BC]0030000003Efm`0eM_L008000003@3oool01P000000L8kP072>h0000000_:6m0000
00<0_Z>m00<000000;nR^`2oX[/00P000000103>MfP000000<=ZI@33JVD9000000040:A:G@000000
VTAN09Y4GP<0000000<0_iN^0000000000000P1[O=800`000000_:2l0;bP_0020;bP_0030000002l
X;`000000080hYIj0P00000Q0?ooo`040000001XBYX0J4ZJ000000@0]I2`00<000000?;<Z0000000
7@3oool20000000306i;U`000000/iFh00@0/iFh00<000000>oN_`000000403oool00100oooo00@0
0000051Oa0000000]YNh0P0000020;NH^0040000003PWh`0h9n<000002@0oooo00<000000555YP00
0000102dSk0010000000jKFM0>VeW@00000M0?ooo`030000001b=GH0000000<0]9>d00H000000;BC
]02dTk@0]9>d0000003HfmT200000100oooo00@00000072>h01`S^0000000`2nXkd00`000000_j:k
0;nR^`020;nR^`@000000P33JVD200000080^UiN00@000000;1DG02`E5`000000P2TBUd200000006
0<6I[`000000_iN^0;nG[P000000_YF]0P0000001@1dSml000000;bP_02lX;`0000000<0_:2l0P00
00000`3TVG`000000?ooo`0O0?ooo`040000001XBYX0J4ZJ000000@0]I2`00@000000?;<Z03bc:P0
00007@3oool20797S`<00000102cUKP00`000000kmjo0000000@0?ooo`004@3oool00`000000D5o4
000000050;NH^0040000003PWh`0h9n<000002<0oooo00<000000555YP000000102dSk0010000000
jKFM0>VeW@00000L0?ooo`80000000<0LSEf0000002dTk@00`2dTk@00`000000]9>d000000020=SK
f@030000003oool0oooo0100oooo0P0000001@1hVnL000000000002nXkd0000000<0_j:k00D00000
0<2Q^@30XKT000000<2O]`03000000040<=XHP000000^UiN00000080/5AL100000030<6I[`030000
002oUjh0_iN^00<000000P1dSml00`000000_:2l000000040;bP_0040000003TVG`0i9Ul000001l0
oooo00@0000006Q:VP1XBYX00000102eT;0010000000l/bX0?;<Z000000L0?ooo`040000001bAhl0
LTN?00000080/iBh0P0000001@2cUKP000000>oN_`3_g[l000000100oooo000A0?ooo`80000000<0
Eg3@0000002gV;P00`2gV;P01@000000h9n<0>2OS03PWh`000000280oooo00<000000555YP000000
0P2dSk06000001X0oooo0P00000206leN0030000002dTk@0]9>d00@0]9>d00@000000=SKf@3HfmT0
0000503oool01@000000N9_W07RKi`1hVnL0000000@0_j:k00@000000<2Q^@30XKT000000`30WkL7
000000050<>N/`000000`Y^a0<:K/@0000000P31VJl010000000_iN^0;nG[P2oUjh6000000@0_:2l
00@000000;^P_@000000i9Ul0P00000N0?ooo`X0000000<0l/bX0000003oool06`3oool010000000
LTN?0797S`0000040;>D^08000000P3_g[lA0?ooo`004P3oool205M`d0030000002gV;P0]iRh00<0
]iRh00@000000>2OS03PWh`000008P3oool00`000000DDFV0000000200000080/hj_00@000000>R`
V03X/9P000006@3oool01`000000KcEh06leN01_=GP000000;BC]0000000102dTk@010000000fm_G
00000000000F0?ooo`040000001hVnL0000008BYk@80000000D0_j:k00000030XKT0`:6i00000003
0<2O]`0400000032XKL0`Z6g00000080`Yne00@000000<>N/`33W[<000000P32Vk4010000000`IV_
0<6I[`31VJl4000000030=_QfP00000000000080LXgN00@000000;bP_000000000000P2kX;d20000
00030>FKO@000000oooo01d0oooo00@0000006U8V01YB9P00000102eT;0010000000l/j[00000000
000K0?ooo`040000001bAhl0LTN?000000D0/iBh00@000000>WSb`00000000004@3oool00180oooo
00@0000005M`d01GL=000000102gV;P01@000000h9n<0>2OS03PWh`000000240oooo0`0000040;>>
[`040000003X/9P0j;2H000001P0oooo00D0000006`eN`000000KcEh000000030;BC]080000000D0
]9>d0000003KfmL0fm_G0000000H0?ooo`0300000024ZNd0Q:W]0080Q:W]0`0000000`30XKT00000
0<2O]`020<2O]`0400000032XKL0`Z6g00000080`Yne00D000000<>N/`33W[<0`ijc000000020<:K
/@0400000031VJl00000000000<0e>7Q00<000000?ooo`0000000P1bSMh2000000D0^j2m00@00000
0>FKO@3UVgd000007@3oool010000000JDRH06U8V00000040;F@/0040000003bcZ/0l/j[000001/0
oooo00@000000797S`1bAhl000001@2cU;P00`000000jN?;0000000B0?ooo`004`3oool00`000000
Eg3@000000050;NH^0050000003PWh`000000=^CP`000000803oool00`000000D4V[000000050;>>
[`030000003X/9P0000001P0oooo00@0000006`eN`1/=G/000001P2dTk@010000000fm_G0=_Ke`00
000J0?ooo`8000000P24ZNd00`000000SkG`08nel003000000030<2O]`000000`Z6g0080`Z6g00@0
00000<:O]@32WkD000000`33W[<00`000000`Y^a00000002000000030<_Oi`000000e>7Q00800000
0`3oool200000080L8WL00H000000;^P_@2kX;d0^j2m0000002kX;d2000000030>FLOP000000oooo
01/0oooo00@0000006U8V01YB9P00000102eT;000`000000l/j[0000000K0?ooo`040000001bAhl0
LTN?000000D0/iBh00@000000>WSb`3Yhl/000004P3oool001@0oooo00<0000005M`d0000000102g
V;P00`000000h9n<000000020=^CP`030000003oool0oooo01d0oooo00@000000519Z`1@BJ/00000
102cSZl010000000j;2H0>R`V000000F0?ooo`060000001/=G/0K3Ek0000002dTk@00000102dTk@0
1@000000gM[D0000003KfmL0000001`0oooo0`00000208nel0030000002H__80V;kb00<000000P32
XKL010000000`Yne0<:O]@0000020<>N/`<0000000@0`]c/0000003;gnL0bmoW0P0000060?ooo`05
0000001`RM`0L8WL0000002kX;d00P0000030;^P_@040000003UW7h0iIan000001X0oooo00@00000
06U8V01YB9P00000102eT;0010000000l/j[0?;>Z`00000K0?ooo`040000001bAhl0LTN?000000D0
/iBh00<000000>WSb`0000004`3oool001@0oooo00<0000005M`d00000001@2gV;P00`000000fi>3
0=^CP`020=^CP`030000003oool0oooo01`0oooo00@000000519Z`1@BJ/00000102cSZl010000000
j;2H0>R`V000000F0?ooo`030000001/=G/0000000<0]9>d0P0000000`2dTk@000000=gJe0020=gJ
e0030000003oool0oooo01h0oooo0`00000209RnlP030000002OaO<0WlGc00P0000000@0]]K`0000
0032g>`0`]c/0`0000090?ooo`@00000102kX;d00`000000^inm000000020>FLOP030000003oool0
oooo01L0oooo00@0000006U8V01YB9P00000102eT;0010000000l/j[0?;>Z`00000J0?ooo`040000
001bAhl0LTN?000000D0/iBh00@000000>WSb`3Yhl/000004`3oool001D0oooo00<0000005M`d000
00000`2gV;P00`000000]iRh000000030=^CP`030000003oool0oooo01`0oooo00@000000519Z`1@
BJ/00000102cSZl010000000j;2H0>R`V000000E0?ooo`040000001/=G/0K3Ek000000D0]9>d00D0
00000=gJe03Mf]@0gM[D0000000T0?ooo`@000000P2OaO<010000000Z/kc0:[>l`0000030;KFl003
00000032g>`0`]c/00800000303oool01@000000KhOK06n7f`000000^j2m008000000P2kWkd01@00
0000iIan0000003VWWl0000001P0oooo00@0000006U8V01YB9P00000102eT;0010000000l/j[0?;>
Z`00000J0?ooo`040000001bAhl0LTN?000000D0/iBh00<000000>WSb`000000503oool001H0oooo
0P0000000`2gV;P00000000000030;NH^0050000003KTh<0fi>30=^CP`0000007P3oool00`000000
D4V[000000050;>>[`030000003X/9P0000001@0oooo00@0000006`eN`00000000001@2dTk@01@00
0000gm[@0000003Mf]@0000002T0oooo3000000>0?ooo`030000001_Qm/0KhOK008000001@2kWkd0
1@000000iYio0>JNO`3VWWl0000001L0oooo0P0000000`1YB9P000000;F@/0030;F@/0030000003b
cZ/0000001X0oooo00@0000007M4QP00000000001@2cU;P010000000jN?;0>WSb`00000D0?ooo`00
5P3oool00`000000Eg3@000000060;NH^0050000003KTh<0fi>30=^CP`0000007@3oool010000000
D4V[0519Z`0000020;>>[`D000004`3oool01P000000K3Ek06`eN`000000]9>d000000<0]9>d00D0
00000=oJd03Of]00gm[@000000150?ooo`8000000P1_Q]X02`000000^inm0;^O_@2kWkd000000;^O
_@000000iYio0000003VWX00000001H0oooo00<0000006]5TP0000001P0000000`3bcZ/000000?oo
o`0H0?ooo`050000003Pi=L0MdB60000002bU;P00P0000030;>D^0030000003Yhl/0000001D0oooo
000G0?ooo`030000001RPM/0000000H0]iRh00@000000=^CP`3KTh<0fi>30P00000K0?ooo`030000
001@BJ/0000000<000000P2cSZl010000000iZ^C0>J[T`00000B0?ooo`040000001/=G/0K3Ek0000
0080]9>d0P0000001@2dTk@000000=oJd03Of]00000004L0oooo00D0000006n6fP1_Q]X000000;^O
_@0200000080^inm00D000000>JNO`000000iYj00000000E0?ooo`050000001[AI80JdFB06]5TP00
0000102fT:l3000001P0oooo00@0000007M4QP1gA8H00000102bU;P300000080jN?;00<000000?oo
o`3oool04`3oool001P0oooo00<0000006:1f`0000001P2gV;P00`000000fi>30=^CP`02000001/0
oooo0P0000000`1ACk4000000;>>[`030;>>[`040000003VZi<0iZ^C00000140oooo00@0000006`e
N`1/=G/000001@2dTk@010000000gm[@0=oJd00000180?ooo`030000001_Q]X0KhKJ008000001@2k
Wkd01@000000iYj00>JNP03VWX00000001@0oooo00@0000006]5TP1[AI800000102fT:l010000000
lM>a0?7C/@00000H0?ooo`040000001gA8H0MdB6000000H0/YBh0`00000F0?ooo`006@3oool00`00
0000HX7K000000060;NH^08000000P3CQWX2000001T0oooo00@00000055?/@1ACk400000102cSZl0
10000000iZ^C0>J[T`00000@0?ooo`030000001^=GT0000000800000102dTk@01@000000h=W@0000
003Of]00000004T0oooo0P00000206j5f@070000002kWkd0^inm0;^O_@000000^inm000000020>JN
P0030000003oool0oooo0180oooo00@0000006]5TP1[AI800000102fT:l00`000000lM>a0000000H
0?ooo`040000001gA8H0MdB6000000H0/YBh00<000000>3Ue`0000005`3oool001X0oooo00<00000
06:1f`0000001P2gV;P00`000000dhIj0=>6NP020=>6NP030000003oool0oooo01H0oooo00@00000
055?/@1ACk4000001@2cSZl00`000000iZ^C0000000?0?ooo`050000001^=GT0KSEi06heN@000000
1@2dTk@010000000h=W@0>3Id000001;0?ooo`050000001^QMT0KXGI0000002kWkd00P0000030;^O
_@80000000<0ij610000003oool04P3oool010000000JdFB06]5TP0000040;J@[`030000003adk40
000001L0oooo00@0000007M4QP1gA8H000001P2bU;P00`000000h>GG0000000H0?ooo`006P3oool0
10000000HX7K06:1f`0000040;NH^0030000002hV;L0000000@0dhIj00<000000?ooo`3oool05P3o
ool00`000000DDna000000050;>>[`040000003VZi<0iZ^C000000d0oooo0P00000206heN@030000
002dTk@0000000<0]9>d00@000000>3Id03PfM000000C@3oool4000000H0^inm00@000000>NQP@00
000000004@3oool010000000JdFB06]5TP0000050;J@[`030000003adk40000001H0oooo00@00000
07M4QP1gA8H000001P2bU;P010000000h>GG0>3Ue`00000H0?ooo`006`3oool010000000HX7K06:1
f`0000020;NH^0040000002hV;L0^9Rg0;RH]`8000000`3CQWX2000001H0oooo00@00000055?/@1A
Ck400000102cSZl010000000iZ^C00000000000=0?ooo`040000001^=GT0KSEi000000<0]9>d0P00
0000102dTk@000000>3Id000001?0?ooo`040000001]PmP0KH?H000000<0^inm0P000000102jWkd0
00000>NQP@00000A0?ooo`D000000`2fT:l010000000lM>a0?7C/@00000E0?ooo`050000001n@Wd0
000007M4QP0000001@2bU;P010000000h>GG0>3Ue`00000I0?ooo`00703oool01P000000HX7K06:1
f`000000]iRh000000D0^9Rg00<000000=>6NP3CQWX00P3CQWX00`000000oooo0?ooo`0C0?ooo`04
0000001ACk40DDna000000<0/hj_0`0000000`3UYXl000000?ooo`0;0?ooo`030000001a=GH00000
008000001@2dTk@010000000h=W@0>3Id000001?0?ooo`050000001]PmP0KH?H0000002kWkd00P00
00030;ZO_@80000000<0jJF50000003oool03`3oool01@000000KT>=06i3S@000000]Y6_00800000
00@0]Y2_0000003adk4000005@3oool01@000000OT9m07i2O@1n@Wd0000000H0/YBh00<000000>3U
e`0000006P3oool001d0oooo00@0000006:1f`1RPM/000001`2hV;L010000000dhIj0=>6NP3CQWX3
000001<0oooo00D00000055?/@1ACk4000000;>>[`02000000030;>>[`000000iJJ?0080iJJ?00<0
00000?ooo`3oool0203oool01@000000LCEf074eMP1a=GH0000000D0]9>d00@000000=kJdP000000
0000D@3oool4000000H0^Ynm00@000000>VUQ@00000000003P3oool010000000KT>=06i3S@000004
0;JA[`80000000<0lM>a0000003oool04P3oool2000000060=GSh@1n@Wd0OT9m0000002bTkL00000
102bU;P00`000000h>GG0000000K0?ooo`007P3oool20000000306jCi@000000^9Rg00H0^9Rg0`00
00030<emMP030000003oool0oooo0140oooo00@00000055?/@0000000000102cSZl010000000iJJ?
0>FVS`0000090?ooo`070000001a=GH0LCEf074eMP000000]9>d000000030;BC]0040000003Nf]80
g][B000005<0oooo00@0000006b1eP1/PMH000000`2jWkd300000080jJF500<000000?ooo`3oool0
303oool010000000KT>=06i3S@0000050;JA[`<000004P3oool00`000000OT9m07i2O@0207i2O@04
0000002bTkL0/Y>g0;:C]`80000000D0/YBh0000003PiML0h>GG0000000K0?ooo`007`3oool00`00
0000KY?U06jCi@02000000L0^9Rg00<000000<emMP3=OGH00P3=OGH200000140oooo0`0000050;>>
[`040000003UYXl0iJJ?000000P0oooo00D0000007@fM0000000LCEf000000030;BC]080000000@0
]9>d0000003Nf]800000E03oool01@000000K87F06b1eP000000^Ynm008000000`2jWkd200000003
0>ZUQ@000000oooo00`0oooo00@0000006i3S@1^@hd00000102fTJl010000000l=Nh0?3G^000000A
0?ooo`040000001n@Wd0OT9m07i2O@8000001P2bTkL010000000h>GG0>3Ue`00000L0?ooo`00803o
ool200000080KY?U00<000000;RH]`2hV;L00`2hV;L010000000^9Rg0000000000040<emMP800000
3`3oool010000000DEBg055D]`0000050;>>[`030000003UYXl0000000L0oooo00D0000007@fM01d
=W@0M3Id000000060;BC]0040000003Nf]80g][B000005D0oooo100000050;ZO_@030000003ZYHD0
jZF5008000002`3oool01@000000KT>=06i3S@1^@hd0000000@0]Y6_00<000000?3G^00000004@3o
ool01@000000OT9m07i2O@1n@Wd0000000L0/Y>g00@000000=GTh@00000000007@3oool00280oooo
00@0000006jCi@1^TnD000000`2hV;L00`000000^9Rg0;RH]`020;RH]`030000003=OGH0cGef00<0
cGef0P00000>0?ooo`030000001AE;L0000000D0/hj_00@000000>FVS`3UYXl000001@3oool01`00
0000M3Id07@fM01d=W@000000;BC]0000000102dTk@010000000g=_F00000000001G0?ooo`040000
001ZO=<0JWcC000000<0^Ynm00<000000;ZO_@0000000P3ZYHD00`000000oooo0?ooo`090?ooo`80
000000<0KT>=0000002fTJl0102fTJl00`000000l=Nh0000000?0?ooo`80000000@0Pd9h0000001n
@Wd000001`2bTkL010000000eNCQ0=GTh@00000N0?ooo`008`3oool00`000000KY?U06jCi@020000
00030;RH]`000000^9Rg00@0^9Rg0P0000030<emMP0400000033L6l00000000000`0oooo00@00000
055D]`1AE;L000001@2cSZl00`000000iJJ?000000030?ooo`80000000@0O3Q_0000000000000000
0P2dTk@01@000000]9>d0;BC]02dTk@000000080g=_F00<000000?ooo`3oool0EP3oool01@000000
JWcC06Yld`000000^Ynm008000000P2jWkd01@000000jZF50000003XXH40000000X0oooo00<00000
0711R00000000P0000040;JA[`8000003`3oool00`000000cN7W08=2N00208=2N0030000002bTkL0
/Y>g00D0/Y>g00@000000=GTh@3Ei>4000007`3oool002@0oooo0P00000206jCi@030000002hV;L0
^9Rg00H0^9Rg0`0000040<=`K`<000002P3oool00`000000DEBg000000040;>>[`@000000P3oool2
000000<0O3Q_00<000000;BC]02dTk@00P2dTk@00`000000]9>d000000020=cKeP030000003oool0
oooo05P0oooo100000050;ZO_@050000003XXH40j:610>RQP@000000203oool01P000000L4680711
R01`@HP000000;NA[`80000000@0]Y6_0000003`ekP000003@3oool2000000@0Pd9h00<000000;6B
]`000000102bTkL200000080eNCQ00<000000?ooo`3oool07P3oool002H0oooo0P0000000`1hW^X0
0000000000080;RH]`8000001P33L6l4000000H0oooo00D00000055D]`1AE;L000000;>>[`020000
00040;:>/0000000hYj90>:NR@80000000<0QSa[0000001l>6l00P0000000`2dTk@000000;BC]003
0;BC]0040000003LfmH0g=_F000005/0oooo00D0000006Yme01ZOM@0JWgD000000030;ZO_@070000
002kX;d000000>RQP@000000iIYl000000070?ooo`040000001`@HP0L468000000@0]i6_0P000000
0`3`ekP0oooo0?ooo`0:0?ooo`8000001023@WP200000080/I:g00D000000;:C]`2bTkL0/Y>g0000
00030=GTh@030000003oool0oooo01l0oooo000W0?ooo`040000001hW^X0N9kZ07RNjP8000001@2h
V;L00`000000^9Rf0;RH]P03000000@0`g1_00<000000;QSJP2hHfX0100000030?ooo`040000001A
E;L00000000000@0/Xj`00<000000>:NR@0000000`26?6/01@000000]9>d0;BC]02dTk@0000000<0
]9>d00@000000=WKf@0000000000G@3oool01@000000JWgD06Yme0000000^Ynm008000000P2kX;d0
1@000000j:610000003UVW`0000000H0oooo00D000000711R01`@HP0L468000000040;NA[`030000
003^fkl0000000/0oooo00L0000008=2N023@WP0Pd9h00000023@WP0000000D0/I:g00<000000;:C
]`0000000`3Ei>400`000000oooo0?ooo`0P0?ooo`00:03oool2000000<0N9kZ0P0000030;RH]`03
0000002hV;H0^9Rf00<0^9Rf0`0000000`33L6l000000;QSJP050;QSJPH000001@2bS[000`000000
hYj90>:NR@03000000030;BC]0000000]9>d0080]9>d00<000000;BC]00000000P3IfmT00`000000
oooo0?ooo`1L0?ooo`030000001ZOM@0JWgD008000001@2kX;d01@000000iIYl0>FJO03UVW`00000
00D0oooo00@000000711R01`@HP000001@2gTJl00`000000k]^o000000090?ooo`040000002=AG40
SDEa000000<0Pd9h00<000000;6B]`2aT[L01@2aT[L01@000000eNCQ0=GTh@3Ei>40000002<0oooo
000Z0?ooo`8000000`1hW^X3000000T0^9Rf1P0000040;QSJP8000000P1DGKl00`000000/Xj`0;:>
/0030;:>/0030000003RWXT0000000<0]9>d00<000000;BC]02dTk@00P2dTk@010000000fM_I0=WK
f@00001P0?ooo`8000000P1]PmP01`000000^j2m0;^P_@2kX;d000000;^P_@0000000P3UVW`20000
00<0oooo00D000000711R01`@HP0L468000000040;NA[`030000003^fkl0000000P0oooo0P000003
08e5L@0400000023@WP00000000000L0/I:g00D000000<gRi`000000eNCQ0000000T0?ooo`00;03o
ool2000000<0N9kZ0P0000090;RH]P030000002iUkD0^INe0080^INe1`0000000`1DGKl000000;:>
/0040;:>/0040000003RWXT0hYj9000000<0]9>d00D000000;BC]000000000000=;Kg`0200000680
oooo00L0000006f3f01]PmP0KH?H0000002kX;d0000000<0^j2m0P0000000`3WVgT0000000000002
0?ooo`80000000<0L4680000002gTJl0102gTJl00`000000k]^o000000060?ooo`8000001@2=AG42
000000L0/I:g0P0000030<gRi`030000003oool0oooo02<0oooo000^0?ooo`<000000P28/?020000
00L0^9Rf00<000000;VG]@2iUkD01P2iUkD01@000000^INd0000001DGKl0000000H0/Xj`0P000000
0`3QWXT000000;BC]0020;BC]0050000003Bfml0d]_O0=;Kg`000000I03oool00`000000KH?H06f3
f002000000D0^j2m00@000000>NKN@000000hHma0P00000207A0P`800000102gTJl00`000000k]^o
000000020?ooo`D00000102=AG4300000080/I6f00<000000;6B]`2aT[L00`2aT[L010000000cN;W
0<gRi`3=h^L2000002H0oooo000`0?ooo`0300000028/?00R;3`0080R;3`0`0000030;RH]P030000
002iUkD0^INe00L0^INe00<000000;VG]00000000P1DGKl00`000000/Xj`0;:>/0030;:>/0050000
003QWXT0hIj90000002dTk@00P000000103:f^H000000=;Kg`00001V0?ooo`8000000P1`R]`01P00
0000^j2m0;^P_@2kX;d000000;jU_`80000000<0hHma0000001d@8<00P1d@8<010000000]i:`0000
000000020;NA[`030000003^fkl000000080000000@0UdU/0;3Al@2GBF`000000P2=AG43000000D0
/I6f00<000000;6B]`2aT[L00P2aT[L00`000000cN;W0<gRi`02000002P0oooo000b0?ooo`800000
1028/?02000000030;RH]P000000^INe00P0^INe00H000000;VG]02iUk@0000005AM_`0000030;:>
/080000000D0]9>d0000003QWXT0hIj9000000040<[JiP030000003oool0oooo06H0oooo00D00000
072:g01`R]`000000;^P_@0200000080_ZFo00@000000<2U_P00000000000`1d@8<010000000]i:`
0;NB/02gT[0200000080k]^o1P2GBF`3000000T0/I6f00D000000;6B]`00000000000<gRi`020000
02X0oooo000d0?ooo`<000000`28/?04000000L0^INe00@000000;VG]02iUk@000000P1DGKl30000
00<0]9>d00@000000>6NR@3QWXT000000P3:f^H2000006T0oooo00<00000072:g01`R]`00P000004
0;jU_`0300000030YKh0000000<0M42300<000000;NB/02gT[000P2gT[0010000000jmo600000000
000209M9K0@0000000<0/96f0000002aTKH02@2aTKH2000000030<gRi`000000000002`0oooo000g
0?ooo`80000000<0R;3`0000002H__800P2H__8500000080^INe00L000000;VG]02iUk@0^INd0000
001DGKl0000000H0]9>d00<000000>6NR@3QWXT00P00001/0?ooo`8000000P1cU>@01P000000_ZFo
0;jU_`000000`:Fn000000<0M42300<000000;NB/02gT[000`2gT[000`000000jmo6000000030000
00H0/96f00<000000;6A]P2aTKH01@2aTKH200000080_]_^00<000000?ooo`3oool0;03oool003T0
oooo0P00000809RnlPP0000000<0FF[90000002dTk@0102dTk@010000000hIj90>6NR@00001^0?oo
o`8000000P1cU>@01@000000_ZFo000000000000M4650080000000<0M4230000002gT[000`2gT[00
0`000000jmo60>_OaP02000000P0/96f00<000000;6A]P2aTKH00P2aTKH300000080_]_^0P00000_
0?ooo`00?@3oool600000080V;kb00<000000:_<l@2[c?400P2[c?4205UZb@030000002dTk@0]9>d
00@0]9>d00@000000>6NR@3QWXT00000K`3oool4000000030<2U_P000000M4650080M4650P000004
0;NB/0050000003[glH000000;2@]00000002@2`TKH010000000/I6f0000000000030;kKkP800000
<@3oool004<0oooo2000000205UZb@030000002dTk@0]9>d00<0]9>d00@000000>6NR@3QWXT00000
L03oool010000000O:;[07bRj`00000307A1Q@030000002dTk@0]9>d0080000000D0]i:`0000003[
glH0jmo6000000020;2@]0030000002`TKH0/96f00@0/96f100000030;kKkP800000<`3oool004/0
oooo00@0000005UZb@1IJ/T000001@2dTk@010000000hIj90>6NR@00001`0?ooo`030000001lX^/0
000000<0M46500<000000;BC]02dTk@00P2dTk@2000000030>_OaP000000/92d0080/92d00<00000
0;2A]P2`TKH0100000020:oAlP030000002nfnh0_]_^00800000=@3oool004`0oooo00<0000005UZ
b@0000001@2dTk@01@000000hIj90000003LU88000000700oooo00D0000007A1Q@1d@HD0M4650000
00050;BC]080000000<0jmo60000000000001@0000050:oAlP@00000=`3oool004`0oooo00@00000
05UZb@1IJ/T000001@2dTk@010000000g9B20=bDPP00001`0?ooo`040000001d@HD0M465000000H0
]9>d00<000000>GRc`000000102L`O800`000000[m7b0:oAlP05000003/0oooo001=0?ooo`040000
001IJ/T0FF[9000000<0]9>d00<000000;BC]00000000P3LU8800`000000oooo0?ooo`1/0?ooo`05
0000001d@HD0M46507A1Q@0000001@2dTk@00`000000iN;?0000000800000400oooo001>0?ooo`04
0000001IJ/T000000;BC]08000000P2dTk@01@000000g9B20=bDPP3LU880000006d0oooo00@00000
07A1Q@1d@HD000001@2dTk@010000000iN;?0>GRc`0000180?ooo`00CP3oool010000000FF[905UZ
b@0000050;BC]0050000003LU880g9B20=bDPP000000J`3oool010000000M46507A1Q@0000050;BC
]0040000003Uh/l0iN;?000004T0oooo001?0?ooo`80000000<0GWKB0000002dTk@0102dTk@01000
0000g9B20=bDPP00001Z0?ooo`050000001i@7l0000007A1Q@0000001@2dTk@00`000000iN;?0000
001:0?ooo`00D03oool010000000GWKB05ifdP0000050;BC]0040000003LU880g9B2000006P0oooo
00D0000007U0O`1i@7l0ND1o000000050;BC]0040000003Uh/l0iN;?000004X0oooo001A0?ooo`03
0000001NM]80000000D0]9>d00D000000=bDPP3LU880g9B20000001V0?ooo`070000001i@7l0ND1o
07U0O`000000]9>d000000030;BC]0040000003Uh/l0iN;?000004/0oooo001A0?ooo`040000001N
M]80GWKB000000D0]9>d00D000000=bDPP000000eh]l0000001T0?ooo`050000001i@7l0ND1o07U0
O`0000000`2dTk@2000000040;BC]0000000iN;?000004`0oooo001B0?ooo`040000001NM]80GWKB
000000D0]9>d00D000000=N;O03GRg`0eh]l0000001R0?ooo`050000001i@7l0ND1o07U0O`000000
1P2dTk@010000000iN;?0>GRc`00001<0?ooo`00D`3oool010000000GWKB05ifdP0000030;BC]003
0000002dTk@0000000<0eh]l00<000000?ooo`3oool0GP3oool01@000000ND1o07U0O`1i@7l00000
00H0]9>d00@000000=oSe`0000000000C@3oool005@0oooo00<0000005ifdP0000000P2dTk@01@00
0000]9>d0;BC]02dTk@0000000<0eh]l00<000000?ooo`3oool0G03oool00`000000ND1o07U0O`02
07U0O`030000002dTk@0]9>d00<0]9>d00@000000=oSe`3OhmL00000CP3oool005@0oooo00H00000
05ifdP1NM]8000000;BC]00000040;BC]0050000003GRg`0eh]l0=N;O0000000G03oool00`000000
Od5i0000000207U0O`030000002dTk@0]9>d00<0]9>d00@000000=oSe`3OhmL00000C`3oool005D0
oooo00@0000005ifdP1NM]8000001@2dTk@00`000000eh]l0=N;O0020=N;O0030000003oool0oooo
05P0oooo00H0000007m1N@1o@GT0000007U0O`0000050;BC]0040000003OhmL0gn?G00000500oooo
001F0?ooo`80000000<0I8;K0000002dTk@0102dTk@00`000000eh]l0=N;O0020=N;O0030000003o
ool0oooo05H0oooo00<0000007m1N@1o@GT00P1o@GT00`000000]9>d0;BC]0040;BC]0030000003O
hmL000000540oooo001G0?ooo`040000001TP]/0I8;K000000D0]9>d00H000000=N;O03GRg`00000
0<moMP00001F0?ooo`030000001o@GT0Od5i0080Od5i00<000000;BC]0000000102dTk@010000000
gn?G0=oSe`00001A0?ooo`00F03oool010000000I8;K06B2f`0000050;BC]0030000003GRg`00000
0080cgmf0P00001C0?ooo`040000001o@GT0Od5i07m1N@8000000`2dTk@2000000050;BC]0000000
gn?G0=oSe`000000DP3oool005T0oooo00<0000006B2f`0000001P2dTk@00`000000cgmf0<moMP03
0<moMP030000003oool0oooo04l0oooo00D0000007m1N@1o@GT0Od5i000000070;BC]0040000003O
hmL0gn?G000005<0oooo001J0?ooo`030000001TP]/0000000@0]9>d00@000000;BC]00000000000
103?OgH00`000000oooo0?ooo`1=0?ooo`050000001o@GT0Od5i07m1N@0000001`2dTk@010000000
enCO00000000001D0?ooo`00F`3oool00`000000I8;K000000020;BC]0030000002dTk@0]9>d0080
]9>d00<000000<moMP3?OgH00P3?OgH2000004/0oooo0`0000000`1o@GT00000000000070;BC]004
0000003Gi=l0enCO000005D0oooo001L0?ooo`050000001TP]/000000;BC]00000001@2dTk@20000
00@0cgmf00<000000?ooo`3oool0AP3oool2000000040<gQi`27@g@0Qd=d000000P0]9>d00@00000
0=OTg`3Gi=l00000EP3oool005d0oooo00<0000006B2f`000000202dTk@010000000cgmf0<moMP3?
OgH3000004@0oooo0P0000001`27@g@0cN7W08M3M027@g@000000;BC]00000001@2dTk@200000080
enCO00<000000?ooo`3oool0E@3oool005h0oooo00@0000006fAi000000000001`2dTk@3000000<0
bGMb0P0000100?ooo`8000000P27@g@0103=hNL0Qd=d0000000000030;BC]0050000002dTk@0]9>d
0;BC]00000000P3Gi=l2000005P0oooo001O0?ooo`040000001]TN@0KI7T000000P0]9>d00<00000
0<UgLP39Mg800`39Mg82000003d0oooo00<0000008M3M027@g@00`27@g@00`000000]9>d0;BC]004
0;BC]0030000002dTk@000000080enCO00<000000?ooo`3oool0F03oool00600oooo0P0000000`1]
TN@00000000000050;BC]0040000002dTk@00000000000D0bGMb0P00000i0?ooo`80000000<0STI`
00000027@g@00P27@g@00`000000]9>d0;BC]0060;BC]0040000003Gi=l0enCO000005/0oooo001R
0?ooo`040000001]TN@0KI7T000000<0]9>d00<000000;BC]02dTk@00P2dTk@2000000@0bGMb0`00
000e0?ooo`8000000`2>AW0010000000Qd=d0000000000070;BC]0<0000000<0enCO0000003oool0
F`3oool006<0oooo00<0000006fAi01]TN@00P0000000`2dTk@000000;BC]0050;BC]080000000<0
bGMb00000030KFh00P30KFh200000340oooo0P00000608i6L0030000002dTk@0]9>d00H0]9>d00D0
00000<gRi`3=h^L0cN;W0000001M0?ooo`00I03oool200000080KI7T00<000000;BC]02dTk@01`2d
Tk@2000000D0`6e^0P00000/0?ooo`<000001P2>AW02000000030;BC]0000000]9>d00@0]9>d0P00
00020<gRi`800000GP3oool006H0oooo0P0000000`1eW>T00000000000080;BC]0<000001@30KFh4
000002@0oooo1000000209Q;K@030000002>AW00STI`0080STI`0P0000030;BC]0030000002dTk@0
]9>d0080]9>d00D000000<gRi`3=h^L0cN;W0000001P0?ooo`00I`3oool010000000MIcY07FLj@1e
W>T2000000D0]9>d00@000000;BC]02dTk@0]9>d0P0000040<1]KP030000002gHf`0]f=/00@00000
6@3oool7000000H0V4]]00<0000008i6L02>AW000P0000060;BC]0040000002dTk@0000000000080
cN;W0P00001Q0?ooo`00J03oool2000000<0MIcY0P0000030;BC]0030000002dTk@0]9>d00<0]9>d
0P0000000`30KFh000000;MSK0060;MSK1T00000102QDF/00`000000V4]]09Q;K@0509Q;K@@00000
202dTk@2000000<0cN;W00<000000?ooo`3oool0H@3oool006X0oooo0P00000307FLj@<00000202d
Tk@4000000L0]f=/00<000000:iKJ`2^Ff/01P2^Ff/00`000000ZUM[0:YGJ`060:YGJ`030000002Q
DF/0XE5[00L0XE5[00<0000009Q;K@2HBfd0100000020;BC]0030000002dTk@0]9>d00D0]9>d0P00
00000`34gn`000000<gRi`02000006@0oooo001/0?ooo`8000000`1eW>T2000000P0]9>d00<00000
0;BC]02dTk@0100000020;MSK0030000002^Ff/0[U][00L0[U][00<000000:YGJ`2ZEf/01P2ZEf/0
0`000000XE5[0:5AJ`030:5AJ`L000001`2dTk@00`000000]9>d0;BC]0020;BC]08000000`34gn`2
000006H0oooo001^0?ooo`<000000P21Znl2000000H0]9>d00<000000;BC]02dTk@0102dTk@K0000
00@0]9>d00<000000;BC]02dTk@01`2dTk@00`000000]9>d0;BC]002000000<0a=o/0P00001X0?oo
o`00L03oool00`000000PJ__086[k`02086[k`8000000`2dTk@00`000000]9>d0;BC]0070;BC]003
0000002dTk@0]9>d00L0]9>d00<000000;BC]02dTk@01P2dTk@00`000000]9>d0;BC]0070;BC]003
0000002dTk@0]9>d00L0]9>d0`0000030<COk0800000JP3oool00780oooo0P000003086[k`800000
00<0]9>d0000002dTk@0202dTk@00`000000]9>d0;BC]0070;BC]0030000002dTk@0]9>d00H0]9>d
00<000000;BC]02dTk@0202dTk@00`000000]9>d0;BC]0030;BC]0<0000000@0]mWa00000034gn`0
a=o/0P00001/0?ooo`00M03oool300000080PJ__100000070;BC]0030000002dTk@0]9>d00L0]9>d
00<000000;BC]02dTk@01P2dTk@00`000000]9>d0;BC]0080;BC]0030000002dTk@0000000<00000
102gfO43000006h0oooo001g0?ooo`80000000@0PJ__0000002=^?<0SKSc1@0000020;BC]0030000
002dTk@0]9>d00L0]9>d00<000000;BC]02dTk@01`2dTk@00`000000]9>d0;BC]0050;BC]0@00000
1@2gfO4300000740oooo001i0?ooo`8000001`2=^?<7000000D0]9>d00<000000;BC]02dTk@01`2d
Tk@00`000000]9>d0;BC]00500000080Zm7d00<000000;OIl@2gfO401000001d0?ooo`00O@3oool5
00000080SKSc00<0000009W3m02I`o@00P2I`o@B000000H0Zm7d1000001h0?ooo`00PP3oool70000
00D0VL?d00<0000009o8m@2Ob?D01`2Ob?D00`000000Zm7d0:_Am006000007`0oooo00290?oooa80
0000PP3oool00?l0oooo7P3oool00?l0oooo7P3oool00?l0oooo7P3oool00?l0oooo7P3oool00?l0
oooo7P3oool00?l0oooo7P3oool00001\
\>"],
  ImageRangeCache->{{{0, 284.313}, {266.563, 0}} -> {-5.90252*^-05, \
0.0311585, 0.00351767, 0.00351767}}]
}, Open  ]],

Cell["\<\
You can also get a nice drawing of a knot (or link) with rendering by OpenGL. \
Geve the P-data to the following function.
Note that the function ShowKnotbyOpengl[] has not yet been implemented on \
Macintosh version. Note that you can change the outermost domain by clicking \
the left mouse button and the rotation (drugging the left mouse button) mode \
by keying the z-key in the OpenGL program and must exit from the OpenGL \
program by keying the esc-key.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ShowKnotbyOpengl[pdata]\)], "Input"],

Cell[BoxData[
    \("KnotOgl"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can also give the plural P-data through a file to ",
  StyleBox["ShowKnotFromFile[filename]",
    FontWeight->"Bold"],
  " function. The file has to\nfinish by EOF (555) in the last line of the \
file. Check the sample Pdata file \"trivialknot.prd\"."
}], "Text"],

Cell[BoxData[
    \(ShowKnotFronFile["\<trivialknot.prd\>"]\)], "Input"],

Cell["\<\
You can get the writhe and mirrorimage of a given knot and link.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(WritheKnotFromPdata[pdata]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GetMirrorImageKnot[pdata]\)], "Input"],

Cell[BoxData[
    \({{10}, {7, \(-18\), 1, 3, \(-15\), 20, \(-9\), \(-11\), \(-4\), 
        12}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Braid representation", "Section"],

Cell["\<\
Given P-data of an arbitrary knot (or link) diagram, following function takes \
some steps, that is, Ridemeister's move of type 2 for the part of the \
obtained diagram satisfied with the certain condition, until it get its braid \
representation. This is the implementation of Vogel's algorithm-1990. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bword = GetBraidRep[pdata]\)], "Input"],

Cell[BoxData[
    \("AbbbaaBBAA"\)], "Output"]
}, Open  ]],

Cell["\<\
Most of the time, you can get the shorter B-word by simplifing the knot by \
the function ReductionKnotLink[]  ahead of GetBraidRep. Note that \
ReductionKnotLink[] is available for knots in the current version.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(bword = GetBraidRep[ReductionKnotLink[pdata]]\),
      FontWeight->"Bold"]], "Input",
  FontWeight->"Plain"],

Cell[BoxData[
    \("aaaBBBAAbb"\)], "Output"]
}, Open  ]],

Cell["\<\
To get the braid diagram for the B-word, use the following function with its \
B-word.\
\>", "Text"],

Cell[BoxData[
    \(ShowBraid[bword]\)], "Input"],

Cell["\<\
To get the braid diagram of the B-word in the file \"nonalternate12.prd\", \
use the folllowing with its file name.
The folllowing outputs all results to the display.\
\>", "Text"],

Cell[BoxData[
    \(GetBraidRepFromFile["\<nonalternate12.prd\>"]\)], "Input"],

Cell["\<\
The following outputs all results to the fixed file \"BraidForm.brd\".\
\>", "Text"],

Cell[BoxData[
    \(GetBraidRepFromFile["\<nonalternate12.prd\>", 1]\)], "Input"],

Cell["\<\
We recommend you to use the folllowing for a very big input file.\
\>", "Text"],

Cell[BoxData[
    \(GetBraidRepFromFile["\<nonalternate12.prd\>", 2]\)], "Input"],

Cell["\<\
Note that all non-alternating knots of 12,13,14 and 15 crossings are given in \
the P-data files \
\"nonalternate12.prd\",\"nonalternate13.prd\",\"nonalternate14.prd\", and \
\"nonalternate15.prd\", which were converted from the knot table \
(http://www.math.utk.edu/~morwen/download) made by Prof. Morwen \
Thistlethwaite and that all datum in the files  \
\"nonalternate12.brd\",\"nonalternate13.brd\",\"nonalternate14.brd\", \
\"nonalternate15.brd\" and \"nonalternate16.brd\" give braid forms of
knots of 12,13,14,15 and 16 crossings which are directly obtaind (and so may \
not be minimal braid index) using the function GetBraidRepFromFile[].We thank \
heartily Prof. Thistlethwaite in him having accepted to distribute them with \
our software.\
\>", "Text"],

Cell[CellGroupData[{

Cell["About B-word and B-word to P-data", "Subsection"],

Cell["\<\
Braid is expressed by a string using symbols, called B-word. The symbols of \
B-word are a, b, ...(resp. A, B, ...) for sigma1, sigma2, ...(resp. \
sigma1^-1, sigma2^-1,...). Therefore, for example, using symboles between a \
(or A) and e (or E), you can express a 6-string braid. Check this. It will be \
noticed that you must use A^2 for sigma1^-2.\
\>", "Text"],

Cell[BoxData[
    \(ShowBraid["\<aB^2c^3dba\>"]\)], "Input"],

Cell["\<\
To get a P-data of an arbitrary braid, use the following function.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotFromBraid["\<abcD^2c\>"]\)], "Input"],

Cell[BoxData[
    \({{4, 1, 1}, {\(-11\), 10, 2, 1, 3, \(-5\)}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polynomial invariants", "Section"],

Cell[TextData[{
  "Here are the functions in order to get several kinds of polynomial \
invariants for the given P-data or B-word.\nNote that if the global variable \
$PolynomialNormal is False, all invariants give unnormalized forms and that\n\
",
  StyleBox["$PolynomialNormal is False",
    FontSize->16],
  " as default in the current version and so you will get usually \
unnormalized polynomials."
}], "Text"],

Cell[CellGroupData[{

Cell["Skein Polynomial for the given P-data", "Subsection"],

Cell[TextData[{
  "You",
  StyleBox[" ",
    FontWeight->"Bold"],
  "can obtain 4 kinds of polynomials for the given P-data by",
  StyleBox[" SkeinPolynomial[type, pdata]",
    FontWeight->"Bold"],
  " function. \nYou can also give the plural P-data through a file to ",
  StyleBox["SkeinPolynomialFromFile[type, filename]",
    FontWeight->"Bold"],
  " function. The file has to\nfinish by EOF (555) in the last line of the \
file. Check the sample Pdata file \"pdata.prd\".\n \n(Notice)  This table \
shows the correspondence of 4 kinds of polynomial which can be obtained by \
this func with their type.\n\n",
  Cell[BoxData[GridBox[{
          {"Polynomials", "types"},
          {\(Jones\ Polynomial\), "0"},
          {\(Two\ variable\ Jones\ Polynomial\), "1"},
          {\(Alexander\ Polynomial\ by\ Conway\ relation\), \(-1\)},
          {\(Conway\ Polynomial\), \(-2\)}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]]
}], "Text"],

Cell[CellGroupData[{

Cell["Jones Polynomial", "Subsubsection"],

Cell["In case of Jones Polynomial for the given P-data, set ", "Text"],

Cell[BoxData[
    \(type\  = \ 0\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomial[type, pdata]\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomialFromFile[type, \ "\<pdata.prd\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Two variable Jones Polynomial ", "Subsubsection"],

Cell["\<\
In case of two variable Jones Polynomial for the given P-data, set\
\>", "Text"],

Cell[BoxData[
    \(type\  = \ 1\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomial[type, pdata]\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomialFromFile[type, \ "\<pdata.prd\>"]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Alexander Polynomial by Conway relation", "Subsubsection"],

Cell["\<\
In case of Alexander Polynomial by Conway relation for the given P-data, \
set\
\>", "Text"],

Cell[BoxData[
    \(type\  = \ \(-1\)\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomial[type, pdata]\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomialFromFile[type, \ "\<trivialknot.prd\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conway Polynomial", "Subsubsection"],

Cell["In case of Conway Polynomial for the given P-data, set", "Text"],

Cell[BoxData[
    \(type\  = \ \(-2\)\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomial[type, pdata]\)], "Input"],

Cell[BoxData[
    \(SkeinPolynomialFromFile[type, \ "\<pdata.prd\>"]\)], "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Kauffman Polynomial of skein type for the given P-data", "Subsection"],

Cell["\<\
This func returns the Kauffman polynomial of the given P-data.\
\>", "Text"],

Cell[BoxData[{
    \(KauffmanPolynomial[pdata]\), "\[IndentingNewLine]", 
    \(KauffmanPolynomial[0, pdata]\)}], "Input"],

Cell["This func returns the Q-polynomial of the given P-data.", "Text"],

Cell[BoxData[
    \(KauffmanPolynomial[1, pdata]\)], "Input"],

Cell[BoxData[
    \(KauffmanPolynomialFromFile[0, "\<trivialknot.prd\>"]\)], "Input"],

Cell[TextData[{
  "This func returns Kauffman polynomials of knots in the file \
\"nonalternate12.prd\". Note that if you abort this function from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Kernel menu, you must terminate the external C-program to compute \
Kauffman polynomials in the desktop command menu for next computation ."
}], "Text"],

Cell[BoxData[
    \(KauffmanPolynomialFromFile[0, "\<nonalternate12.prd\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Jones Polynomial for the given B-word", "Subsection"],

Cell["\<\
This func returns Jones Polynomial for the given B-word  of up to 14-braid \
using Hecke representation in the range that limitation of memory allows.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(JonesPolynomialbyBraid["\<abcddd\>"]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Jones Polynomial by Hecke representation for ["\
\[InvisibleSpace]"abcddd"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "Jones Polynomial by Hecke representation for [", "abcddd", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(-\(1\/t\^4\)\) + 1\/t\^3 + 1\/t\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(JonesPolynomialbyBraid[bword]\)], "Input"],

Cell[TextData[{
  "You can also give the plural B-words through the file to ",
  StyleBox["JonesPolynomialbyBraidFromFile[filename]",
    FontWeight->"Bold"],
  ". \nThe file has to include a B-word per a line, and EOF (555) as in the \
last line. Check the sample B-word file \"BraidForm.brd\""
}], "Text"],

Cell[BoxData[
    \(JonesPolynomialbyBraidFromFile["\<BraidForm.brd\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Alexander Polynomial by Burau representation for the given B-word\
\>", "Subsection"],

Cell["\<\
This returns the Alexander polynomial by Burau representation for the B-word. \
B-word can be obtained by GetBraidRep or you can specify by yourself. \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(AlexanderPolynomialbyBurauRep["\<abcdddd\>"]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Alexander Polynomial by Burau representation for"\
\[InvisibleSpace]"["\[InvisibleSpace]"abcdddd"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "Alexander Polynomial by Burau representation for", "[", "abcdddd", 
        "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(-1\) + t - t\^2 + t\^3\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(AlexanderPolynomialbyBurauRep[bword]\)], "Input"],

Cell[BoxData[
    \(AlexanderPolynomialbyBurauRepFromFile["\<nonalternate12.brd\>"]\)], \
"Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
One variable reduced invariant of  two variable Jones (or HOMFLY) polynomial \
of 3-parallel version for a  given B-word\
\>", "Subsection"],

Cell[TextData[{
  "This returns one variable reduced invariant of  two variable Jones (or \
HOMFLY) polynomial of 3-parallel version for the given B-word. Note that the \
reduction method depends on Jun Murakami's one associated with Hecke algebras \
(Young diagram depth 4 reduction). This function needs memory so very much. \
In case of lacking the memory, it returns nothing. Note that you can not \
obtain the correct result in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 or the older version although this function acts correctly in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.2 or the newer version.  "
}], "Text"],

Cell[BoxData[
    \(The\ trivial\ knot\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False],

Cell[CellGroupData[{

Cell[BoxData[
    \(ThreeParallelPolynomialInvariant["\<abcd\>"]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"abcd"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "abcd", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(1\)], "Output"],

Cell[BoxData[
    \(Kinoshita - Terasaka\ knot\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(KT = "\<aCbCbbCA^4bb\>";\)\  (*\ 
      4 - braid\ *) \), "\[IndentingNewLine]", 
    \(\(\(KT1 = "\<aCbCbbCA^4bbdD\>"\)\(;\)\(\ \)\( (*\ 
      5 - braid\ *) \)\(\[IndentingNewLine]\)\(KT2 = \
"\<DaCbCbbCA^4bbd\>"\)\(;\)\( (*\ 5 - braid\ *) \)\)\)}], "Input"],

Cell[BoxData[
    \(Conway\ knot\)], "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[BoxData[
    \(\(CW = "\<aCbCbbCaB^3\>";\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ft = ThreeParallelPolynomialInvariant[KT]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"aCbCbbCA^4bb"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "aCbCbbCA^4bb", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(1\/q\^34\)\((\(-1\) + 3\ q - 5\ q\^2 + 9\ q\^3 - 12\ q\^4 + 
        6\ q\^5 + 9\ q\^6 - 28\ q\^7 + 58\ q\^8 - 105\ q\^9 + 144\ q\^10 - 
        169\ q\^11 + 191\ q\^12 - 191\ q\^13 + 156\ q\^14 - 106\ q\^15 + 
        57\ q\^16 + 30\ q\^17 - 141\ q\^18 + 233\ q\^19 - 325\ q\^20 + 
        435\ q\^21 - 530\ q\^22 + 551\ q\^23 - 530\ q\^24 + 462\ q\^25 - 
        309\ q\^26 + 99\ q\^27 + 109\ q\^28 - 286\ q\^29 + 447\ q\^30 - 
        529\ q\^31 + 517\ q\^32 - 462\ q\^33 + 395\ q\^34 - 305\ q\^35 + 
        206\ q\^36 - 147\ q\^37 + 92\ q\^38 - 18\ q\^39 - 47\ q\^40 + 
        85\ q\^41 - 131\ q\^42 + 177\ q\^43 - 181\ q\^44 + 156\ q\^45 - 
        129\ q\^46 + 97\ q\^47 - 55\ q\^48 + 23\ q\^49 - 4\ q\^50 - 
        8\ q\^51 + 12\ q\^52 - 9\ q\^53 + 5\ q\^54 - 3\ q\^55 + 
        q\^56)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ft1 = ThreeParallelPolynomialInvariant[KT1]\), "\[IndentingNewLine]", 
    \(ft2 = ThreeParallelPolynomialInvariant[KT2]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"aCbCbbCA^4bbdD"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "aCbCbbCA^4bbdD", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(1\/q\^\(75/2\)\)\((\((1 + q)\)\ \((1 + q\^2)\)\ \((1 + q + q\^2 + 
            q\^3 + q\^4)\)\ \((\(-1\) + 3\ q - 5\ q\^2 + 9\ q\^3 - 12\ q\^4 + 
            6\ q\^5 + 9\ q\^6 - 28\ q\^7 + 58\ q\^8 - 105\ q\^9 + 
            144\ q\^10 - 169\ q\^11 + 191\ q\^12 - 191\ q\^13 + 156\ q\^14 - 
            106\ q\^15 + 57\ q\^16 + 30\ q\^17 - 141\ q\^18 + 233\ q\^19 - 
            325\ q\^20 + 435\ q\^21 - 530\ q\^22 + 551\ q\^23 - 530\ q\^24 + 
            462\ q\^25 - 309\ q\^26 + 99\ q\^27 + 109\ q\^28 - 286\ q\^29 + 
            447\ q\^30 - 529\ q\^31 + 517\ q\^32 - 462\ q\^33 + 395\ q\^34 - 
            305\ q\^35 + 206\ q\^36 - 147\ q\^37 + 92\ q\^38 - 18\ q\^39 - 
            47\ q\^40 + 85\ q\^41 - 131\ q\^42 + 177\ q\^43 - 181\ q\^44 + 
            156\ q\^45 - 129\ q\^46 + 97\ q\^47 - 55\ q\^48 + 23\ q\^49 - 
            4\ q\^50 - 8\ q\^51 + 12\ q\^52 - 9\ q\^53 + 5\ q\^54 - 
            3\ q\^55 + q\^56)\))\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"DaCbCbbCA^4bbd"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "DaCbCbbCA^4bbd", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(1\/q\^\(75/2\)\)\((\((1 + q)\)\ \((1 + q\^2)\)\ \((1 + q + q\^2 + 
            q\^3 + q\^4)\)\ \((\(-1\) + 3\ q - 5\ q\^2 + 9\ q\^3 - 12\ q\^4 + 
            6\ q\^5 + 9\ q\^6 - 28\ q\^7 + 58\ q\^8 - 105\ q\^9 + 
            144\ q\^10 - 169\ q\^11 + 191\ q\^12 - 191\ q\^13 + 156\ q\^14 - 
            106\ q\^15 + 57\ q\^16 + 30\ q\^17 - 141\ q\^18 + 233\ q\^19 - 
            325\ q\^20 + 435\ q\^21 - 530\ q\^22 + 551\ q\^23 - 530\ q\^24 + 
            462\ q\^25 - 309\ q\^26 + 99\ q\^27 + 109\ q\^28 - 286\ q\^29 + 
            447\ q\^30 - 529\ q\^31 + 517\ q\^32 - 462\ q\^33 + 395\ q\^34 - 
            305\ q\^35 + 206\ q\^36 - 147\ q\^37 + 92\ q\^38 - 18\ q\^39 - 
            47\ q\^40 + 85\ q\^41 - 131\ q\^42 + 177\ q\^43 - 181\ q\^44 + 
            156\ q\^45 - 129\ q\^46 + 97\ q\^47 - 55\ q\^48 + 23\ q\^49 - 
            4\ q\^50 - 8\ q\^51 + 12\ q\^52 - 9\ q\^53 + 5\ q\^54 - 
            3\ q\^55 + q\^56)\))\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[ft/ft1]\)], "Input"],

Cell[BoxData[
    \(q\^\(7/2\)\/\(\((1 + q)\)\ \((1 + q\^2)\)\ \((1 + q + q\^2 + q\^3 + \
q\^4)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[ft1/ft2]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell["\<\
The following computation confirms Morton's one (\"any finite invariants of \
degree n with n<11 can not recognize two different mutant knots\").\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ft = ThreeParallelPolynomialInvariant[KT]\), "\[IndentingNewLine]", 
    \(fc = ThreeParallelPolynomialInvariant[CW]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"aCbCbbCA^4bb"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "aCbCbbCA^4bb", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(1\/q\^34\)\((\(-1\) + 3\ q - 5\ q\^2 + 9\ q\^3 - 12\ q\^4 + 
        6\ q\^5 + 9\ q\^6 - 28\ q\^7 + 58\ q\^8 - 105\ q\^9 + 144\ q\^10 - 
        169\ q\^11 + 191\ q\^12 - 191\ q\^13 + 156\ q\^14 - 106\ q\^15 + 
        57\ q\^16 + 30\ q\^17 - 141\ q\^18 + 233\ q\^19 - 325\ q\^20 + 
        435\ q\^21 - 530\ q\^22 + 551\ q\^23 - 530\ q\^24 + 462\ q\^25 - 
        309\ q\^26 + 99\ q\^27 + 109\ q\^28 - 286\ q\^29 + 447\ q\^30 - 
        529\ q\^31 + 517\ q\^32 - 462\ q\^33 + 395\ q\^34 - 305\ q\^35 + 
        206\ q\^36 - 147\ q\^37 + 92\ q\^38 - 18\ q\^39 - 47\ q\^40 + 
        85\ q\^41 - 131\ q\^42 + 177\ q\^43 - 181\ q\^44 + 156\ q\^45 - 
        129\ q\^46 + 97\ q\^47 - 55\ q\^48 + 23\ q\^49 - 4\ q\^50 - 
        8\ q\^51 + 12\ q\^52 - 9\ q\^53 + 5\ q\^54 - 3\ q\^55 + 
        q\^56)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("3-parallel one variable invariant for "\
\[InvisibleSpace]"["\[InvisibleSpace]"aCbCbbCaB^3"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel one variable invariant for ", "[", "aCbCbbCaB^3", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(\(1\/q\^34\)\((\(-1\) + 3\ q - 5\ q\^2 + 9\ q\^3 - 13\ q\^4 + 
        12\ q\^5 - 7\ q\^6 + 16\ q\^8 - 47\ q\^9 + 76\ q\^10 - 103\ q\^11 + 
        138\ q\^12 - 161\ q\^13 + 156\ q\^14 - 136\ q\^15 + 110\ q\^16 - 
        36\ q\^17 - 71\ q\^18 + 163\ q\^19 - 251\ q\^20 + 351\ q\^21 - 
        430\ q\^22 + 429\ q\^23 - 393\ q\^24 + 330\ q\^25 - 203\ q\^26 + 
        39\ q\^27 + 109\ q\^28 - 226\ q\^29 + 341\ q\^30 - 397\ q\^31 + 
        380\ q\^32 - 340\ q\^33 + 295\ q\^34 - 221\ q\^35 + 132\ q\^36 - 
        77\ q\^37 + 22\ q\^38 + 48\ q\^39 - 100\ q\^40 + 115\ q\^41 - 
        131\ q\^42 + 147\ q\^43 - 128\ q\^44 + 90\ q\^45 - 61\ q\^46 + 
        39\ q\^47 - 13\ q\^48 - 5\ q\^49 + 12\ q\^50 - 14\ q\^51 + 
        13\ q\^52 - 9\ q\^53 + 5\ q\^54 - 3\ q\^55 + q\^56)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[ft - fc]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-1\) + q)\)\^11\ \((1 + 2\ q + 2\ q\^2 + q\^3)\)\^3\ \((1 - 
                q + 2\ q\^2 - q\^3 + 
                q\^4)\)\ \((1 + q\^2 + q\^4 + q\^6 + q\^8 + q\^10 + \
q\^12)\)\^2\)\/q\^30\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
The following computation gives another one in the case of 12 crossings by  \
Imafuji-Ochiai. Note that you will need
several minutes to calculate.\
\>", "Text"],

Cell[BoxData[
    StyleBox[\(bword1\  = \ "\<AbcDcbbabbCCDb\>"\n
      bword2\  = \ "\<ABcdBabbCCddbc\>"\),
      FontFamily->"Osaka\.81|\.93\.99\.95\.9d"]], "Input"],

Cell[BoxData[{
    \(pol1 = 
      ThreeParallelPolynomialInvariant[bword1]\), "\[IndentingNewLine]", 
    \(pol2 = ThreeParallelPolynomialInvariant[bword2]\)}], "Input"],

Cell[BoxData[
    \(Simplify[pol1 - pol2]\)], "Input"],

Cell[BoxData[
    StyleBox[\(bword1\  = \ "\<AbcDcbbabbccDb\>"\n
      bword2\  = \ "\<ABcdBabbccddbc\>"\n\n
      bword1\  = \ "\<ABcDcBBabbCCDb\>"\n
      bword2\  = \ "\<AbcDcbbaBBCCDB\>"\n
      bword3\  = \ "\<ABcdBaBBCCddBc\>"\),
      FontFamily->"Osaka\.81|\.93\.99\.95\.9d"]], "Input"],

Cell[BoxData[{
    \(bword1\  = \ "\<abCdbCaabbbCDC\>"\), "\n", 
    \(bword2\  = \ "\<AbcdCAbbbCDccb\>"\)}], "Input"],

Cell["\<\
The following example gives another one in the case of n  crossings with \
n<18.\
\>", "Text"],

Cell[BoxData[
    StyleBox[\(bword1 = "\<DcccDABBAABdcDcaBBab\>"\n
      bword2 = "\<DcccDaBBabdcDcABBAAB\>"\),
      FontFamily->"Osaka\.81|\.93\.99\.95\.9d"]], "Input"],

Cell["\<\
The function SLInvarint[] can compute 3-parallel 2-variables invariants of \
braids with up to 3,4,5 index. To use the function SLInvarint[], you must \
extend Macintosh virtual memory system to the maximal limit [900Mbyte].
    \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SLInvarint[KT] // Timing\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("3-parallel sl_n invariant for "\[InvisibleSpace]"["\
\[InvisibleSpace]"aCbCbbCA^4bb"\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "3-parallel sl_n invariant for ", "[", "aCbCbbCA^4bb", "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \({12.528`\ Second, \((\((\(-1\) + \[Lambda])\)\ \((\(-1\) + q\ \
\[Lambda])\)\^4\ \((\(-1\) + q\^2\ \[Lambda])\)\ \((q\^4 - 2\ q\^5 + 
                5\ q\^6 - 9\ q\^7 + 14\ q\^8 - 17\ q\^9 + 22\ q\^10 - 
                25\ q\^11 + 29\ q\^12 - 29\ q\^13 + 30\ q\^14 - 29\ q\^15 + 
                29\ q\^16 - 25\ q\^17 + 22\ q\^18 - 17\ q\^19 + 14\ q\^20 - 
                9\ q\^21 + 5\ q\^22 - 2\ q\^23 + q\^24 - q\^2\ \[Lambda] - 
                2\ q\^4\ \[Lambda] + 3\ q\^6\ \[Lambda] - 
                18\ q\^7\ \[Lambda] + 28\ q\^8\ \[Lambda] - 
                61\ q\^9\ \[Lambda] + 94\ q\^10\ \[Lambda] - 
                144\ q\^11\ \[Lambda] + 178\ q\^12\ \[Lambda] - 
                226\ q\^13\ \[Lambda] + 245\ q\^14\ \[Lambda] - 
                264\ q\^15\ \[Lambda] + 245\ q\^16\ \[Lambda] - 
                226\ q\^17\ \[Lambda] + 178\ q\^18\ \[Lambda] - 
                144\ q\^19\ \[Lambda] + 94\ q\^20\ \[Lambda] - 
                61\ q\^21\ \[Lambda] + 28\ q\^22\ \[Lambda] - 
                18\ q\^23\ \[Lambda] + 3\ q\^24\ \[Lambda] - 
                2\ q\^26\ \[Lambda] - q\^28\ \[Lambda] + 2\ q\ \[Lambda]\^2 - 
                2\ q\^2\ \[Lambda]\^2 + 9\ q\^3\ \[Lambda]\^2 - 
                13\ q\^4\ \[Lambda]\^2 + 29\ q\^5\ \[Lambda]\^2 - 
                30\ q\^6\ \[Lambda]\^2 + 57\ q\^7\ \[Lambda]\^2 - 
                52\ q\^8\ \[Lambda]\^2 + 84\ q\^9\ \[Lambda]\^2 - 
                77\ q\^10\ \[Lambda]\^2 + 121\ q\^11\ \[Lambda]\^2 - 
                107\ q\^12\ \[Lambda]\^2 + 169\ q\^13\ \[Lambda]\^2 - 
                165\ q\^14\ \[Lambda]\^2 + 213\ q\^15\ \[Lambda]\^2 - 
                176\ q\^16\ \[Lambda]\^2 + 213\ q\^17\ \[Lambda]\^2 - 
                165\ q\^18\ \[Lambda]\^2 + 169\ q\^19\ \[Lambda]\^2 - 
                107\ q\^20\ \[Lambda]\^2 + 121\ q\^21\ \[Lambda]\^2 - 
                77\ q\^22\ \[Lambda]\^2 + 84\ q\^23\ \[Lambda]\^2 - 
                52\ q\^24\ \[Lambda]\^2 + 57\ q\^25\ \[Lambda]\^2 - 
                30\ q\^26\ \[Lambda]\^2 + 29\ q\^27\ \[Lambda]\^2 - 
                13\ q\^28\ \[Lambda]\^2 + 9\ q\^29\ \[Lambda]\^2 - 
                2\ q\^30\ \[Lambda]\^2 + 
                2\ q\^31\ \[Lambda]\^2 - \[Lambda]\^3 - 
                4\ q\^2\ \[Lambda]\^3 + 3\ q\^3\ \[Lambda]\^3 - 
                16\ q\^4\ \[Lambda]\^3 + 16\ q\^5\ \[Lambda]\^3 - 
                56\ q\^6\ \[Lambda]\^3 + 60\ q\^7\ \[Lambda]\^3 - 
                130\ q\^8\ \[Lambda]\^3 + 144\ q\^9\ \[Lambda]\^3 - 
                250\ q\^10\ \[Lambda]\^3 + 239\ q\^11\ \[Lambda]\^3 - 
                356\ q\^12\ \[Lambda]\^3 + 327\ q\^13\ \[Lambda]\^3 - 
                431\ q\^14\ \[Lambda]\^3 + 351\ q\^15\ \[Lambda]\^3 - 
                452\ q\^16\ \[Lambda]\^3 + 368\ q\^17\ \[Lambda]\^3 - 
                452\ q\^18\ \[Lambda]\^3 + 351\ q\^19\ \[Lambda]\^3 - 
                431\ q\^20\ \[Lambda]\^3 + 327\ q\^21\ \[Lambda]\^3 - 
                356\ q\^22\ \[Lambda]\^3 + 239\ q\^23\ \[Lambda]\^3 - 
                250\ q\^24\ \[Lambda]\^3 + 144\ q\^25\ \[Lambda]\^3 - 
                130\ q\^26\ \[Lambda]\^3 + 60\ q\^27\ \[Lambda]\^3 - 
                56\ q\^28\ \[Lambda]\^3 + 16\ q\^29\ \[Lambda]\^3 - 
                16\ q\^30\ \[Lambda]\^3 + 3\ q\^31\ \[Lambda]\^3 - 
                4\ q\^32\ \[Lambda]\^3 - q\^34\ \[Lambda]\^3 + \[Lambda]\^4 - 
                q\ \[Lambda]\^4 + 6\ q\^2\ \[Lambda]\^4 - 
                8\ q\^3\ \[Lambda]\^4 + 24\ q\^4\ \[Lambda]\^4 - 
                21\ q\^5\ \[Lambda]\^4 + 55\ q\^6\ \[Lambda]\^4 - 
                49\ q\^7\ \[Lambda]\^4 + 105\ q\^8\ \[Lambda]\^4 - 
                79\ q\^9\ \[Lambda]\^4 + 183\ q\^10\ \[Lambda]\^4 - 
                157\ q\^11\ \[Lambda]\^4 + 307\ q\^12\ \[Lambda]\^4 - 
                275\ q\^13\ \[Lambda]\^4 + 488\ q\^14\ \[Lambda]\^4 - 
                446\ q\^15\ \[Lambda]\^4 + 662\ q\^16\ \[Lambda]\^4 - 
                567\ q\^17\ \[Lambda]\^4 + 738\ q\^18\ \[Lambda]\^4 - 
                567\ q\^19\ \[Lambda]\^4 + 662\ q\^20\ \[Lambda]\^4 - 
                446\ q\^21\ \[Lambda]\^4 + 488\ q\^22\ \[Lambda]\^4 - 
                275\ q\^23\ \[Lambda]\^4 + 307\ q\^24\ \[Lambda]\^4 - 
                157\ q\^25\ \[Lambda]\^4 + 183\ q\^26\ \[Lambda]\^4 - 
                79\ q\^27\ \[Lambda]\^4 + 105\ q\^28\ \[Lambda]\^4 - 
                49\ q\^29\ \[Lambda]\^4 + 55\ q\^30\ \[Lambda]\^4 - 
                21\ q\^31\ \[Lambda]\^4 + 24\ q\^32\ \[Lambda]\^4 - 
                8\ q\^33\ \[Lambda]\^4 + 6\ q\^34\ \[Lambda]\^4 - 
                q\^35\ \[Lambda]\^4 + q\^36\ \[Lambda]\^4 - q\ \[Lambda]\^5 + 
                q\^2\ \[Lambda]\^5 - 6\ q\^3\ \[Lambda]\^5 + 
                8\ q\^4\ \[Lambda]\^5 - 24\ q\^5\ \[Lambda]\^5 + 
                22\ q\^6\ \[Lambda]\^5 - 54\ q\^7\ \[Lambda]\^5 + 
                46\ q\^8\ \[Lambda]\^5 - 105\ q\^9\ \[Lambda]\^5 + 
                80\ q\^10\ \[Lambda]\^5 - 185\ q\^11\ \[Lambda]\^5 + 
                168\ q\^12\ \[Lambda]\^5 - 347\ q\^13\ \[Lambda]\^5 + 
                332\ q\^14\ \[Lambda]\^5 - 574\ q\^15\ \[Lambda]\^5 + 
                547\ q\^16\ \[Lambda]\^5 - 798\ q\^17\ \[Lambda]\^5 + 
                701\ q\^18\ \[Lambda]\^5 - 888\ q\^19\ \[Lambda]\^5 + 
                701\ q\^20\ \[Lambda]\^5 - 798\ q\^21\ \[Lambda]\^5 + 
                547\ q\^22\ \[Lambda]\^5 - 574\ q\^23\ \[Lambda]\^5 + 
                332\ q\^24\ \[Lambda]\^5 - 347\ q\^25\ \[Lambda]\^5 + 
                168\ q\^26\ \[Lambda]\^5 - 185\ q\^27\ \[Lambda]\^5 + 
                80\ q\^28\ \[Lambda]\^5 - 105\ q\^29\ \[Lambda]\^5 + 
                46\ q\^30\ \[Lambda]\^5 - 54\ q\^31\ \[Lambda]\^5 + 
                22\ q\^32\ \[Lambda]\^5 - 24\ q\^33\ \[Lambda]\^5 + 
                8\ q\^34\ \[Lambda]\^5 - 6\ q\^35\ \[Lambda]\^5 + 
                q\^36\ \[Lambda]\^5 - q\^37\ \[Lambda]\^5 + 
                q\^3\ \[Lambda]\^6 + 4\ q\^5\ \[Lambda]\^6 - 
                3\ q\^6\ \[Lambda]\^6 + 15\ q\^7\ \[Lambda]\^6 - 
                16\ q\^8\ \[Lambda]\^6 + 57\ q\^9\ \[Lambda]\^6 - 
                61\ q\^10\ \[Lambda]\^6 + 131\ q\^11\ \[Lambda]\^6 - 
                142\ q\^12\ \[Lambda]\^6 + 248\ q\^13\ \[Lambda]\^6 - 
                212\ q\^14\ \[Lambda]\^6 + 309\ q\^15\ \[Lambda]\^6 - 
                229\ q\^16\ \[Lambda]\^6 + 311\ q\^17\ \[Lambda]\^6 - 
                170\ q\^18\ \[Lambda]\^6 + 263\ q\^19\ \[Lambda]\^6 - 
                141\ q\^20\ \[Lambda]\^6 + 263\ q\^21\ \[Lambda]\^6 - 
                170\ q\^22\ \[Lambda]\^6 + 311\ q\^23\ \[Lambda]\^6 - 
                229\ q\^24\ \[Lambda]\^6 + 309\ q\^25\ \[Lambda]\^6 - 
                212\ q\^26\ \[Lambda]\^6 + 248\ q\^27\ \[Lambda]\^6 - 
                142\ q\^28\ \[Lambda]\^6 + 131\ q\^29\ \[Lambda]\^6 - 
                61\ q\^30\ \[Lambda]\^6 + 57\ q\^31\ \[Lambda]\^6 - 
                16\ q\^32\ \[Lambda]\^6 + 15\ q\^33\ \[Lambda]\^6 - 
                3\ q\^34\ \[Lambda]\^6 + 4\ q\^35\ \[Lambda]\^6 + 
                q\^37\ \[Lambda]\^6 - 2\ q\^6\ \[Lambda]\^7 + 
                2\ q\^7\ \[Lambda]\^7 - 9\ q\^8\ \[Lambda]\^7 + 
                12\ q\^9\ \[Lambda]\^7 - 27\ q\^10\ \[Lambda]\^7 + 
                30\ q\^11\ \[Lambda]\^7 - 58\ q\^12\ \[Lambda]\^7 + 
                51\ q\^13\ \[Lambda]\^7 - 89\ q\^14\ \[Lambda]\^7 + 
                85\ q\^15\ \[Lambda]\^7 - 133\ q\^16\ \[Lambda]\^7 + 
                102\ q\^17\ \[Lambda]\^7 - 163\ q\^18\ \[Lambda]\^7 + 
                137\ q\^19\ \[Lambda]\^7 - 186\ q\^20\ \[Lambda]\^7 + 
                130\ q\^21\ \[Lambda]\^7 - 186\ q\^22\ \[Lambda]\^7 + 
                137\ q\^23\ \[Lambda]\^7 - 163\ q\^24\ \[Lambda]\^7 + 
                102\ q\^25\ \[Lambda]\^7 - 133\ q\^26\ \[Lambda]\^7 + 
                85\ q\^27\ \[Lambda]\^7 - 89\ q\^28\ \[Lambda]\^7 + 
                51\ q\^29\ \[Lambda]\^7 - 58\ q\^30\ \[Lambda]\^7 + 
                30\ q\^31\ \[Lambda]\^7 - 27\ q\^32\ \[Lambda]\^7 + 
                12\ q\^33\ \[Lambda]\^7 - 9\ q\^34\ \[Lambda]\^7 + 
                2\ q\^35\ \[Lambda]\^7 - 2\ q\^36\ \[Lambda]\^7 + 
                q\^9\ \[Lambda]\^8 + 2\ q\^11\ \[Lambda]\^8 + 
                q\^12\ \[Lambda]\^8 - 4\ q\^13\ \[Lambda]\^8 + 
                19\ q\^14\ \[Lambda]\^8 - 32\ q\^15\ \[Lambda]\^8 + 
                67\ q\^16\ \[Lambda]\^8 - 95\ q\^17\ \[Lambda]\^8 + 
                142\ q\^18\ \[Lambda]\^8 - 172\ q\^19\ \[Lambda]\^8 + 
                218\ q\^20\ \[Lambda]\^8 - 228\ q\^21\ \[Lambda]\^8 + 
                246\ q\^22\ \[Lambda]\^8 - 228\ q\^23\ \[Lambda]\^8 + 
                218\ q\^24\ \[Lambda]\^8 - 172\ q\^25\ \[Lambda]\^8 + 
                142\ q\^26\ \[Lambda]\^8 - 95\ q\^27\ \[Lambda]\^8 + 
                67\ q\^28\ \[Lambda]\^8 - 32\ q\^29\ \[Lambda]\^8 + 
                19\ q\^30\ \[Lambda]\^8 - 4\ q\^31\ \[Lambda]\^8 + 
                q\^32\ \[Lambda]\^8 + 2\ q\^33\ \[Lambda]\^8 + 
                q\^35\ \[Lambda]\^8 - q\^13\ \[Lambda]\^9 + 
                2\ q\^14\ \[Lambda]\^9 - 5\ q\^15\ \[Lambda]\^9 + 
                9\ q\^16\ \[Lambda]\^9 - 15\ q\^17\ \[Lambda]\^9 + 
                20\ q\^18\ \[Lambda]\^9 - 27\ q\^19\ \[Lambda]\^9 + 
                32\ q\^20\ \[Lambda]\^9 - 38\ q\^21\ \[Lambda]\^9 + 
                40\ q\^22\ \[Lambda]\^9 - 42\ q\^23\ \[Lambda]\^9 + 
                40\ q\^24\ \[Lambda]\^9 - 38\ q\^25\ \[Lambda]\^9 + 
                32\ q\^26\ \[Lambda]\^9 - 27\ q\^27\ \[Lambda]\^9 + 
                20\ q\^28\ \[Lambda]\^9 - 15\ q\^29\ \[Lambda]\^9 + 
                9\ q\^30\ \[Lambda]\^9 - 5\ q\^31\ \[Lambda]\^9 + 
                2\ q\^32\ \[Lambda]\^9 - 
                q\^33\ \[Lambda]\^9)\))\)/\((\((\(-1\) + q)\)\^6\ q\^19\ \((1 \
+ q + q\^2)\)\ \[Lambda]\^2)\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["a mutation of a Knot", "Section"],

Cell[TextData[{
  "You  can do a flip, mutation, vertical mutation, and horizontal mutation \
of a knot (but not a link) by a new function MutationOfTangle. In the case, \
you will get the in-between output and then can convert them into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " expression using the Function ToExpression through cutting-pasting \
operation of the output data. Moreover, you can change the outermost ",
  "region ",
  "of a projection in the execution by clicking the right-hand mouse and \
selecting an item from a pop-up menu."
}], "Text"],

Cell[BoxData[
    \(\(pdata = {{17}, {\(-31\), 29, 20, 17, \(-1\), \(-33\), 2, 27, \(-25\), 
            8, \(-30\), 5, 28, \(-9\), 11, \(-3\), \(-13\)}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MutationOfTangle[pdata]\)], "Input"],

Cell[BoxData[
    \("Mutate tangle:"\)], "Print"],

Cell[BoxData[
    \("pdata1 = {{17}, {15, -13, 28, -18, 25, 16, -29, 31, -1, -33, 2, -19, \
17, 8, 5, -3, -21}}"\)], "Print"],

Cell[BoxData[
    \({{17}, {15, \(-13\), 28, \(-18\), 25, 16, \(-29\), 31, \(-1\), \(-33\), 
        2, \(-19\), 17, 8, 5, \(-3\), \(-21\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ToExpression["\<pdata1 = {{17}, {15, -13, 28, -18, 25, 16, -29, 31, -1, \
-33, 2, -19, 17, 8, 5, -3, -21}}\>"]\)], "Input"],

Cell[BoxData[
    \({{17}, {15, \(-13\), 28, \(-18\), 25, 16, \(-29\), 31, \(-1\), \(-33\), 
        2, \(-19\), 17, 8, 5, \(-3\), \(-21\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MutationOfTangle[pdata1]\)], "Input"],

Cell[BoxData[
    \("H-Reverse a tangle:"\)], "Print"],

Cell[BoxData[
    \("pdata1 = {{17}, {-21, 15, -13, 28, -18, 25, 16, -29, 31, -1, -19, 17, \
8, 5, -3, 20, -23}}"\)], "Print"],

Cell[BoxData[
    \({{17}, {15, \(-13\), 28, \(-18\), 25, 16, \(-29\), 31, \(-1\), \(-33\), 
        2, \(-19\), 17, 8, 5, \(-3\), \(-21\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data conversion", "Section"],

Cell["\<\
Let \"knot1\"and \"link1\" be data files made by Jeff Week's Snappea. You \
will get a p-data by the following function PLDataFromSnapPeaData[].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PLDataFromSnapPeaData["\<knot1\>"]\)], "Input"],

Cell[BoxData[
    \("The corresponding p-data:"\)], "Print"],

Cell[BoxData[
    \({{3}, {\(-5\), \(-1\), \(-3\)}}\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pdata = {{3}, {\(-5\), \(-1\), \(-3\)}};\)\), "\[IndentingNewLine]", 
    \(ShowKnotbyOpengl[pdata]\)}], "Input"],

Cell[BoxData[
    \("./KnotOgl"\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PLDataFromSnapPeaData["\<link1\>"]\)], "Input"],

Cell[BoxData[
    \("The corresponding p-data:"\)], "Print"],

Cell[BoxData[
    \({{2, 3}, {10, \(-8\), 2, \(-4\), 6}}\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(pdata = {{2, 3}, {10, \(-8\), 2, \(-4\), 
            6}};\)\), "\[IndentingNewLine]", 
    \(ShowKnotbyOpengl[pdata]\)}], "Input"],

Cell[BoxData[
    \("./KnotOgl"\)], "Output"]
}, Open  ]],

Cell["\<\
At converse, let \"LastPLdata.sp\" be a data file made by the function \
GetPdatabyTracking[]. You will get a file SnappeaFromPL.pl which is a data \
file of Snappea.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SnapPeaDataFromPLData["\<LastPLdata.sp\>"]\)], "Input"],

Cell[BoxData[
    \("Outputted to SnappeaFromPL.pl which must been only used in J. Weeks's \
SnapPea."\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let \"GauseanFormExample\" be a data file including Gausean forms such as \
",
  StyleBox["{{1,4},{3,8},{5,10},{7,14},{9,2},{11,20},{13,16},{15,6},{17,22},{\
19,12},{21,18}}. ",
    FontFamily->"\.82l\.82r \.83S\.83V\.83b\.83N",
    FontSize->10],
  " You can get a pdata file \"GauseanFormExample.prd\"."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotbyGauseanFormFromFile["\<GauseanFormExample\>"]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Outputted to a p-data file: \
"\[InvisibleSpace]"GauseanFormExample.prd"\),
      SequenceForm[ "Outputted to a p-data file: ", "GauseanFormExample.prd"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(!! "\<GauseanFormExample.prd\>"\)\)], "Input"],

Cell["\<\
 22   1
 22
  4  -8  10 -14  -2  16  20  -6  22  12  18 
 22   1
 22
  4  -8  10 -13  -2  19  -7  21  11  17  15 
 22   1
 22
  4  -8  10 -14  -2  20  16  -6 -22  12 -18 
555
17\
\>", "Print",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotbyGauseanForm[{{1, 4}, {3, 8}, {5, 10}, {7, 14}, {9, 2}, {11, 
          16}, {13, 20}, {15, 6}, {17, 22}, {19, 12}, {21, 18}}]\)], "Input"],

Cell[BoxData[
    \({{11}, {4, \(-8\), 10, \(-14\), \(-2\), 16, 20, \(-6\), 22, 12, 
        18}}\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["Also, you can get a pdata from Doker-Thistlethwaite's form.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotbyDT[{4, 8, \(-12\), 
        2, \(-14\), \(-6\), \(-16\), \(-10\)}]\)], "Input"],

Cell[BoxData[
    \({{8}, {4, 8, \(-11\), 2, \(-15\), \(-5\), \(-9\), \(-13\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotbyDowkerThistlethwaiteNotation[{4, 8, \(-12\), 
        2, \(-14\), \(-6\), \(-16\), \(-10\)}]\)], "Input"],

Cell[BoxData[
    \({{8}, {4, 8, \(-11\), 2, \(-15\), \(-5\), \(-9\), \(-13\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "You can get a pdata file from a data file of Dowker-Thistlethwaite's forms \
which is including datum such as:\n",
  StyleBox["16        1      4   8  10 -14   2 -16 -20  -6 -22 -26 -12 -28 \
-30 -18 -32 -24\n",
    FontFamily->"\.82l\.82r \.83S\.83V\.83b\.83N",
    FontSize->10],
  "crossing number  Dowker-Thistlethwaite's form (see  an unpacked data at \
knotscape 1.01 SunOS in http://www.math.utk.edu/~morwen/download/)"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotbyDTFromFile["\<na16.dt\>"]\)], "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \({{16}, {4, \(-8\), 10, 15, \(-2\), 21, 7, \(-11\), 27, 13, \(-17\), 31, 
        19, \(-23\), 25, \(-29\)}}\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \({{16}, {4, \(-8\), 10, 15, \(-2\), 21, 7, \(-11\), 27, 13, \(-17\), 
        28, \(-30\), 19, 32, \(-24\)}}\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \({{16}, {4, \(-8\), 10, 15, \(-2\), 21, 7, \(-11\), \(-26\), 
        13, \(-17\), 31, \(-18\), \(-23\), 25, \(-29\)}}\)], "Print"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(KnotbyDTFromFileToFile["\<nonalternate16.dt\>", \
"\<nonalternate16.prd\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plat Closures", "Section"],

Cell["\<\
You will get a pdata determined by a plat closure given by a even braid. 
Note that $RecursionLimit=512 for a plat with a big crossing number.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotFromPlat["\<bbabcDcabed\>"]\)], "Input"],

Cell[BoxData[
    \({{11}, {20, \(-11\), 8, \(-16\), 17, \(-14\), 21, \(-4\), \(-13\), 12, 
        9}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\( (*\ 
      figure\ eight\ knot\ \
*) \)\(\[IndentingNewLine]\)\(\(pdata2\)\(=\)\(KnotFromPlat["\<BcBB\>"]\)\(\ \
\ \)\)\)\)], "Input"],

Cell[BoxData[
    \({{4}, {\(-6\), 8, \(-2\), 4}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SkeinPolynomial[0, pdata2]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Jones Polynomial for "\[InvisibleSpace]"["\
\[InvisibleSpace]{{4}, {\(-6\), 8, \(-2\), 4}}\[InvisibleSpace]"]"\),
      SequenceForm[ "Jones Polynomial for ", "[", {{4}, {-6, 8, -2, 4}}, "]"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    \(1 - t + t\^2 - t\^3 + t\^4\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(KnotFromPlat["\<abbdcccc\>"]\)], "Input"],

Cell[BoxData[
    \("Wrong data !!! (All braids must have even strings for plat \
closure.)"\)], "Print"],

Cell[BoxData[
    \("abbdcccc"\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resolution trees of 2-string tangles", "Section"],

Cell["\<\
You can input a tangle T by a function TangleResolution[] using a mouse \
tracking operation and as a result get two base HOMFLYpolynomials \[Alpha] \
and \[Beta] of T such that \[Alpha] T0 + \[Beta] T1 about the trivial base \
tangles T0 and T1. The following example gives a computation result of a \
tangle decomposition of Kinoshita-Terasaka knot.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TangleResolution[0]\)], "Input"],

Cell[BoxData[
    \({{0, 
        2 + 1\/\(x\ y\^3\) - 2\/y\^2 - 1\/\(x\ y\) + 
          x\/y}, {4, \(-\(1\/y\^3\)\) + x\/y\^2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TangleResolution[0]\)], "Input"],

Cell[BoxData[
    \({{4, 1\/\(x\^2\ y\^2\) - 1\/\(x\ y\) - x\/y}, {0, 
        1\/x - 1\/\(x\ y\^2\) + 2\/y - 1\/\(x\^2\ y\)}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(KT = "\<aCbCbbCA^4bb\>";\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pdata = KnotFromBraid[KT]\)], "Input"],

Cell[BoxData[
    \({{13}, {\(-8\), 20, \(-12\), 14, \(-4\), 2, 10, \(-24\), \(-26\), 6, 
        1, \(-16\), \(-18\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SkeinPolynomial[1, pdata]\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Two variable Jones Polynomial for \
"\[InvisibleSpace]"["\[InvisibleSpace]{{13}, {\(-8\), 20, \(-12\), 
            14, \(-4\), 2, 10, \(-24\), \(-26\), 6, 
            1, \(-16\), \(-18\)}}\[InvisibleSpace]"]"\),
      SequenceForm[ 
      "Two variable Jones Polynomial for ", "[", {{13}, {-8, 20, -12, 14, -4, 
        2, 10, -24, -26, 6, 1, -16, -18}}, "]"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\(-x\) + x\^3 - y + 6\ x\^2\ y - 3\ x\^4\ y + 6\ x\ y\^2 - 
      11\ x\^3\ y\^2 + 2\ x\^5\ y\^2 + y\^3 - 11\ x\^2\ y\^3 + 
      6\ x\^4\ y\^3 - 3\ x\ y\^4 + 7\ x\^3\ y\^4 + 2\ x\^2\ y\^5\)], "Output"]
}, Open  ]],

Cell[BoxData[{
    \(\(\[Alpha]1 = 
        2 + 1\/\(x\ y\^3\) - 2\/y\^2 - 1\/\(x\ y\) + 
          x\/y;\)\), "\[IndentingNewLine]", 
    \(\(\[Beta]1 = \(-\(1\/y\^3\)\) + x\/y\^2;\)\), "\[IndentingNewLine]", 
    \(\(\[Alpha]2 = 
        1\/x - 1\/\(x\ y\^2\) + 2\/y - 
          1\/\(x\^2\ y\);\)\), "\[IndentingNewLine]", 
    \(\(\[Beta]2 = 1\/\(x\^2\ y\^2\) - 1\/\(x\ y\) - x\/y;\)\)}], "Input"],

Cell[BoxData[
    \(\(VK = \[Alpha]1\ \[Alpha]2\ \((x + 
                y)\)\  + \[Alpha]1\ \[Beta]2\  + \[Beta]1\ \[Alpha]2\  + \ \
\[Beta]1\ \[Beta]2\ \((1/x - y \((x + y)\)/x)\);\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[VK]\)], "Input"],

Cell[BoxData[
    \(7 - 3\/x\^2 + 1\/y\^4 - 1\/\(x\^2\ y\^4\) - 1\/\(x\^3\ y\^3\) + 
      6\/\(x\ y\^3\) - \(3\ x\)\/y\^3 - 11\/y\^2 + 
      6\/\(x\^2\ y\^2\) + \(2\ x\^2\)\/y\^2 + 1\/\(x\^3\ y\) - 
      11\/\(x\ y\) + \(6\ x\)\/y + \(2\ y\)\/x\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[x^3\ y^4\ %]\)], "Input"],

Cell[BoxData[
    \(\(-x\) + x\^3 - y + 6\ x\^2\ y - 3\ x\^4\ y + 6\ x\ y\^2 - 
      11\ x\^3\ y\^2 + 2\ x\^5\ y\^2 + y\^3 - 11\ x\^2\ y\^3 + 
      6\ x\^4\ y\^3 - 3\ x\ y\^4 + 7\ x\^3\ y\^4 + 2\ x\^2\ y\^5\)], "Output"]
}, Open  ]],

Cell["You can execute the tangle program as a standalone one.", "Text"],

Cell[BoxData[
    \(TangleResolution[1]\)], "Input"],

Cell[BoxData[{
    \(\(tt1 = {{0, 
            2 + 1\/\(x\ y\^3\) - 2\/y\^2 - 1\/\(x\ y\) + 
              x\/y}, {4, \(-\(1\/y\^3\)\) + 
              x\/y\^2}};\)\), "\[IndentingNewLine]", 
    \(\(tt2 = {{4, 1\/\(x\^2\ y\^2\) - 1\/\(x\ y\) - x\/y}, {0, 
            1\/x - 1\/\(x\ y\^2\) + 2\/y - 1\/\(x\^2\ y\)}};\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(HOMFLYbyTangleDecomposition[tt1, tt2]\)], "Input"],

Cell[BoxData[
    \(\(2\ x\^5\ y\^2 + y\ \((\(-1\) + y\^2)\) + x\^4\ \((\(-3\)\ y + 6\ \
y\^3)\) + x\ \((\(-1\) + 6\ y\^2 - 3\ y\^4)\) + x\^2\ y\ \((6 - 11\ y\^2 + 2\ \
y\^4)\) + x\^3\ \((1 - 11\ y\^2 + 7\ y\^4)\)\)\/\(x\^3\ y\^4\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(HOMFLYbyTangleDecomposition[tt2, tt1]\)], "Input"],

Cell[BoxData[
    \(\(2\ x\^5\ y\^2 + y\ \((\(-1\) + y\^2)\) + x\^4\ \((\(-3\)\ y + 6\ \
y\^3)\) + x\ \((\(-1\) + 6\ y\^2 - 3\ y\^4)\) + x\^2\ y\ \((6 - 11\ y\^2 + 2\ \
y\^4)\) + x\^3\ \((1 - 11\ y\^2 + 7\ y\^4)\)\)\/\(x\^3\ y\^4\)\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bug reports", "Title"],

Cell["\<\
(1) ReductionKnotLink[] fail to simplify links in this version.
(2) GetBraidRep[] fail to convert alternating twist knots of about 15 or more \
crossings.
\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{724, 644},
WindowMargins->{{33, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 114, 6, 285, "Title"],
Cell[1856, 59, 110, 3, 93, "Subtitle"],
Cell[1969, 64, 165, 3, 107, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2159, 71, 31, 0, 53, "Section"],
Cell[2193, 73, 74, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[2292, 77, 61, 1, 30, "Input"],
Cell[2356, 80, 101, 2, 29, "Output"]
}, Open  ]],
Cell[2472, 85, 151, 5, 33, "Text"],
Cell[2626, 92, 48, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[2699, 97, 55, 0, 47, "Subsection"],
Cell[2757, 99, 8008, 242, 502, "Text"],
Cell[10768, 343, 181, 6, 33, "Text"],
Cell[10952, 351, 56, 1, 30, "Input"],
Cell[11011, 354, 55, 1, 30, "Input"],
Cell[11069, 357, 54, 1, 30, "Input"],
Cell[11126, 360, 54, 1, 30, "Input"],
Cell[11183, 363, 51, 1, 30, "Input"],
Cell[11237, 366, 49, 1, 30, "Input"],
Cell[11289, 369, 47, 1, 30, "Input"],
Cell[11339, 372, 55, 1, 30, "Input"],
Cell[11397, 375, 53, 1, 30, "Input"],
Cell[11453, 378, 56, 1, 30, "Input"],
Cell[11512, 381, 67, 1, 30, "Input"],
Cell[11582, 384, 61, 1, 30, "Input"],
Cell[11646, 387, 60, 1, 30, "Input"],
Cell[11709, 390, 61, 1, 30, "Input"],
Cell[11773, 393, 68, 1, 30, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[11890, 400, 42, 0, 53, "Section"],
Cell[11935, 402, 286, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[12246, 411, 65, 1, 30, "Input"],
Cell[12314, 414, 79, 1, 29, "Output"]
}, Open  ]],
Cell[12408, 418, 1176, 27, 147, "Text"],

Cell[CellGroupData[{
Cell[13609, 449, 84, 1, 30, "Input"],
Cell[13696, 452, 85, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13818, 458, 122, 5, 48, "Subsection"],
Cell[13943, 465, 980, 18, 166, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14972, 489, 44, 0, 53, "Section"],
Cell[15019, 491, 139, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[15183, 498, 131, 2, 30, "Input"],
Cell[15317, 502, 112, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15466, 509, 57, 1, 30, "Input"],
Cell[15526, 512, 382, 6, 42, "Message"],
Cell[15911, 520, 442550, 19382, 276, 355671, 18305, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[458476, 19905, 485, 8, 90, "Text"],

Cell[CellGroupData[{
Cell[458986, 19917, 56, 1, 30, "Input"],
Cell[459045, 19920, 43, 1, 29, "Output"]
}, Open  ]],
Cell[459103, 19924, 286, 6, 52, "Text"],
Cell[459392, 19932, 72, 1, 30, "Input"],
Cell[459467, 19935, 88, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[459580, 19941, 59, 1, 30, "Input"],
Cell[459642, 19944, 35, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459714, 19950, 58, 1, 30, "Input"],
Cell[459775, 19953, 111, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[459935, 19961, 39, 0, 53, "Section"],
Cell[459977, 19963, 326, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[460328, 19972, 59, 1, 30, "Input"],
Cell[460390, 19975, 46, 1, 29, "Output"]
}, Open  ]],
Cell[460451, 19979, 235, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[460711, 19987, 137, 3, 30, "Input"],
Cell[460851, 19992, 46, 1, 29, "Output"]
}, Open  ]],
Cell[460912, 19996, 110, 3, 33, "Text"],
Cell[461025, 20001, 49, 1, 30, "Input"],
Cell[461077, 20004, 190, 4, 52, "Text"],
Cell[461270, 20010, 78, 1, 30, "Input"],
Cell[461351, 20013, 94, 2, 33, "Text"],
Cell[461448, 20017, 81, 1, 30, "Input"],
Cell[461532, 20020, 89, 2, 33, "Text"],
Cell[461624, 20024, 81, 1, 30, "Input"],
Cell[461708, 20027, 775, 13, 128, "Text"],

Cell[CellGroupData[{
Cell[462508, 20044, 55, 0, 47, "Subsection"],
Cell[462566, 20046, 374, 6, 71, "Text"],
Cell[462943, 20054, 60, 1, 30, "Input"],
Cell[463006, 20057, 90, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[463121, 20063, 61, 1, 30, "Input"],
Cell[463185, 20066, 77, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[463323, 20074, 40, 0, 53, "Section"],
Cell[463366, 20076, 415, 9, 75, "Text"],

Cell[CellGroupData[{
Cell[463806, 20089, 59, 0, 47, "Subsection"],
Cell[463868, 20091, 983, 24, 215, "Text"],

Cell[CellGroupData[{
Cell[464876, 20119, 41, 0, 43, "Subsubsection"],
Cell[464920, 20121, 70, 0, 33, "Text"],
Cell[464993, 20123, 45, 1, 30, "Input"],
Cell[465041, 20126, 61, 1, 30, "Input"],
Cell[465105, 20129, 81, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[465223, 20135, 55, 0, 43, "Subsubsection"],
Cell[465281, 20137, 90, 2, 33, "Text"],
Cell[465374, 20141, 45, 1, 30, "Input"],
Cell[465422, 20144, 61, 1, 30, "Input"],
Cell[465486, 20147, 81, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[465604, 20153, 64, 0, 29, "Subsubsection"],
Cell[465671, 20155, 102, 3, 33, "Text"],
Cell[465776, 20160, 50, 1, 30, "Input"],
Cell[465829, 20163, 61, 1, 30, "Input"],
Cell[465893, 20166, 87, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[466017, 20172, 42, 0, 43, "Subsubsection"],
Cell[466062, 20174, 70, 0, 33, "Text"],
Cell[466135, 20176, 50, 1, 30, "Input"],
Cell[466188, 20179, 61, 1, 30, "Input"],
Cell[466252, 20182, 81, 1, 30, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[466382, 20189, 76, 0, 47, "Subsection"],
Cell[466461, 20191, 86, 2, 33, "Text"],
Cell[466550, 20195, 122, 2, 50, "Input"],
Cell[466675, 20199, 71, 0, 33, "Text"],
Cell[466749, 20201, 61, 1, 30, "Input"],
Cell[466813, 20204, 85, 1, 30, "Input"],
Cell[466901, 20207, 358, 7, 71, "Text"],
Cell[467262, 20216, 88, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[467387, 20222, 59, 0, 47, "Subsection"],
Cell[467449, 20224, 174, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[467648, 20231, 69, 1, 30, "Input"],
Cell[467720, 20234, 263, 5, 25, "Print"],
Cell[467986, 20241, 67, 1, 42, "Output"]
}, Open  ]],
Cell[468068, 20245, 62, 1, 30, "Input"],
Cell[468133, 20248, 307, 6, 52, "Text"],
Cell[468443, 20256, 84, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[468564, 20262, 95, 2, 47, "Subsection"],
Cell[468662, 20266, 174, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[468861, 20273, 77, 1, 30, "Input"],
Cell[468941, 20276, 303, 6, 25, "Print"],
Cell[469247, 20284, 58, 1, 29, "Output"]
}, Open  ]],
Cell[469320, 20288, 69, 1, 30, "Input"],
Cell[469392, 20291, 98, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469527, 20298, 150, 3, 66, "Subsection"],
Cell[469680, 20303, 657, 13, 90, "Text"],
Cell[470340, 20318, 103, 3, 25, "Print"],

Cell[CellGroupData[{
Cell[470468, 20325, 77, 1, 30, "Input"],
Cell[470548, 20328, 268, 5, 25, "Print"],
Cell[470819, 20335, 35, 1, 29, "Output"],
Cell[470857, 20338, 111, 3, 25, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471005, 20346, 283, 5, 90, "Input"],
Cell[471291, 20353, 97, 3, 25, "Print"]
}, Open  ]],
Cell[471403, 20359, 60, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[471488, 20364, 74, 1, 30, "Input"],
Cell[471565, 20367, 284, 5, 25, "Print"],
Cell[471852, 20374, 838, 12, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[472727, 20391, 155, 2, 50, "Input"],
Cell[472885, 20395, 288, 5, 25, "Print"],
Cell[473176, 20402, 970, 13, 159, "Output"],
Cell[474149, 20417, 288, 5, 25, "Print"],
Cell[474440, 20424, 970, 13, 159, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475447, 20442, 49, 1, 30, "Input"],
Cell[475499, 20445, 113, 2, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[475649, 20452, 50, 1, 30, "Input"],
Cell[475702, 20455, 35, 1, 29, "Output"]
}, Open  ]],
Cell[475752, 20459, 169, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[475946, 20466, 151, 2, 50, "Input"],
Cell[476100, 20470, 284, 5, 25, "Print"],
Cell[476387, 20477, 838, 12, 140, "Output"],
Cell[477228, 20491, 282, 5, 25, "Print"],
Cell[477513, 20498, 817, 11, 140, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[478367, 20514, 50, 1, 30, "Input"],
Cell[478420, 20517, 239, 4, 48, "Output"]
}, Open  ]],
Cell[478674, 20524, 171, 4, 52, "Text"],
Cell[478848, 20530, 166, 3, 41, "Input"],
Cell[479017, 20535, 170, 3, 50, "Input"],
Cell[479190, 20540, 54, 1, 30, "Input"],
Cell[479247, 20543, 294, 6, 101, "Input"],
Cell[479544, 20551, 118, 2, 50, "Input"],
Cell[479665, 20555, 104, 3, 33, "Text"],
Cell[479772, 20560, 170, 3, 41, "Input"],
Cell[479945, 20565, 253, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[480223, 20574, 57, 1, 30, "Input"],
Cell[480283, 20577, 268, 5, 25, "Print"],
Cell[480554, 20584, 9714, 142, 676, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[490329, 20733, 39, 0, 53, "Section"],
Cell[490371, 20735, 576, 11, 90, "Text"],
Cell[490950, 20748, 169, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[491144, 20754, 56, 1, 30, "Input"],
Cell[491203, 20757, 49, 1, 25, "Print"],
Cell[491255, 20760, 125, 2, 25, "Print"],
Cell[491383, 20764, 154, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491574, 20771, 143, 2, 70, "Input"],
Cell[491720, 20775, 154, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[491911, 20782, 57, 1, 30, "Input"],
Cell[491971, 20785, 54, 1, 25, "Print"],
Cell[492028, 20788, 126, 2, 44, "Print"],
Cell[492157, 20792, 154, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[492360, 20800, 34, 0, 53, "Section"],
Cell[492397, 20802, 168, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[492590, 20809, 67, 1, 30, "Input"],
Cell[492660, 20812, 60, 1, 25, "Print"],
Cell[492723, 20815, 64, 1, 25, "Print"],
Cell[492790, 20818, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492865, 20824, 136, 2, 50, "Input"],
Cell[493004, 20828, 45, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493086, 20834, 67, 1, 30, "Input"],
Cell[493156, 20837, 60, 1, 25, "Print"],
Cell[493219, 20840, 69, 1, 25, "Print"],
Cell[493291, 20843, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493366, 20849, 154, 3, 50, "Input"],
Cell[493523, 20854, 45, 1, 29, "Output"]
}, Open  ]],
Cell[493583, 20858, 190, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[493798, 20866, 75, 1, 30, "Input"],
Cell[493876, 20869, 115, 2, 25, "Print"],
Cell[493994, 20873, 38, 1, 29, "Output"]
}, Open  ]],
Cell[494047, 20877, 336, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[494408, 20889, 84, 1, 30, "Input"],
Cell[494495, 20892, 234, 5, 25, "Print"],
Cell[494732, 20899, 38, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494807, 20905, 68, 1, 30, "Input"],
Cell[494878, 20908, 254, 14, 195, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495169, 20927, 164, 2, 50, "Input"],
Cell[495336, 20931, 110, 2, 25, "Print"],
Cell[495449, 20935, 38, 1, 29, "Output"]
}, Open  ]],
Cell[495502, 20939, 75, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[495602, 20943, 105, 2, 30, "Input"],
Cell[495710, 20947, 93, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[495840, 20953, 131, 2, 30, "Input"],
Cell[495974, 20957, 93, 1, 29, "Output"]
}, Open  ]],
Cell[496082, 20961, 457, 9, 85, "Text"],

Cell[CellGroupData[{
Cell[496564, 20974, 64, 1, 30, "Input"],
Cell[496631, 20977, 34, 1, 25, "Print"],
Cell[496668, 20980, 140, 2, 25, "Print"],
Cell[496811, 20984, 34, 1, 25, "Print"],
Cell[496848, 20987, 140, 2, 25, "Print"],
Cell[496991, 20991, 34, 1, 25, "Print"],
Cell[497028, 20994, 150, 2, 25, "Print"],
Cell[497181, 20998, 38, 1, 29, "Output"]
}, Open  ]],
Cell[497234, 21002, 108, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497379, 21009, 32, 0, 53, "Section"],
Cell[497414, 21011, 166, 3, 52, "Text"],

Cell[CellGroupData[{
Cell[497605, 21018, 64, 1, 30, "Input"],
Cell[497672, 21021, 117, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[497826, 21028, 159, 4, 50, "Input"],
Cell[497988, 21034, 63, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[498088, 21040, 59, 1, 30, "Input"],
Cell[498150, 21043, 272, 5, 25, "Print"],
Cell[498425, 21050, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[498522, 21056, 61, 1, 30, "Input"],
Cell[498586, 21059, 105, 2, 25, "Print"],
Cell[498694, 21063, 44, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[498787, 21070, 55, 0, 53, "Section"],
Cell[498845, 21072, 375, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[499245, 21082, 52, 1, 30, "Input"],
Cell[499300, 21085, 143, 3, 44, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499480, 21093, 52, 1, 30, "Input"],
Cell[499535, 21096, 140, 2, 44, "Output"]
}, Open  ]],
Cell[499690, 21101, 61, 1, 30, "Input"],

Cell[CellGroupData[{
Cell[499776, 21106, 58, 1, 30, "Input"],
Cell[499837, 21109, 133, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[500007, 21116, 58, 1, 30, "Input"],
Cell[500068, 21119, 435, 8, 44, "Print"],
Cell[500506, 21129, 222, 3, 29, "Output"]
}, Open  ]],
Cell[500743, 21135, 401, 8, 152, "Input"],
Cell[501147, 21145, 197, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[501369, 21152, 43, 1, 30, "Input"],
Cell[501415, 21155, 261, 4, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501713, 21164, 52, 1, 30, "Input"],
Cell[501768, 21167, 222, 3, 29, "Output"]
}, Open  ]],
Cell[502005, 21173, 71, 0, 33, "Text"],
Cell[502079, 21175, 52, 1, 30, "Input"],
Cell[502134, 21178, 333, 6, 80, "Input"],

Cell[CellGroupData[{
Cell[502492, 21188, 70, 1, 30, "Input"],
Cell[502565, 21191, 245, 3, 47, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[502847, 21199, 70, 1, 30, "Input"],
Cell[502920, 21202, 245, 3, 47, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[503226, 21212, 28, 0, 105, "Title"],
Cell[503257, 21214, 179, 5, 71, "Text"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

